/* Emacs: this is -*- C -*- code, */
/* generated 2011-11-08T22:50:02-08 by Liar version 4.118. */

#include "liarc.h"

#define LABEL_1_4 3
#define LABEL_1_5 5
#define TAG_1_6 1
#define LABEL_1_8 7
#define LABEL_1_9 9
#define LABEL_1_11 11
#define LABEL_1_13 13
#define LABEL_1_12 15
#define LABEL_1_17 17
#define LABEL_1_18 19
#define LABEL_1_19 21
#define LABEL_1_20 23
#define LABEL_1_21 25
#define LABEL_1_14 27
#define LABEL_1_15 29
#define LABEL_1_25 31
#define LABEL_1_22 33
#define LABEL_1_23 35
#define LABEL_1_30 37
#define LABEL_1_31 39
#define LABEL_1_32 41
#define LABEL_1_33 43
#define LABEL_1_34 45
#define LABEL_1_36 47
#define LABEL_1_24 49
#define LABEL_1_27 51
#define LABEL_1_28 53
#define LABEL_1_35 55
#define LABEL_1_42 57
#define LABEL_1_39 59
#define LABEL_1_40 61
#define LABEL_1_47 63
#define LABEL_1_48 65
#define LABEL_1_50 67
#define LABEL_1_51 69
#define LABEL_1_52 71
#define LABEL_1_54 73
#define LABEL_1_41 75
#define LABEL_1_58 77
#define LABEL_1_43 79
#define LABEL_1_44 81
#define LABEL_1_45 83
#define LABEL_1_62 85
#define LABEL_1_46 87
#define LABEL_1_65 89
#define LABEL_1_56 91
#define LABEL_1_53 93
#define LABEL_1_60 95
#define TAG_1_61 46
#define LABEL_1_68 97
#define LABEL_1_64 99
#define LABEL_1_73 101
#define LABEL_1_74 103
#define LABEL_1_70 105
#define LABEL_1_69 107
#define LABEL_1_71 109
#define LABEL_1_75 111
#define TAG_1_76 54
#define LABEL_1_77 113
#define LABEL_1_78 115
#define LABEL_1_85 117
#define LABEL_1_86 119
#define LABEL_1_79 121
#define LABEL_1_80 123
#define LABEL_1_83 125
#define LABEL_1_89 127
#define LABEL_1_91 129
#define LABEL_1_87 131
#define LABEL_1_90 133
#define LABEL_1_95 135
#define TAG_1_96 66
#define ENVIRONMENT_LABEL_1_3 206
#define DEBUGGING_LABEL_1_2 205
#define OBJECT_1_13 204
#define OBJECT_1_12 203
#define OBJECT_1_11 202
#define OBJECT_1_10 201
#define OBJECT_1_9 200
#define OBJECT_1_8 199
#define OBJECT_1_7 198
#define OBJECT_1_6 197
#define OBJECT_1_5 196
#define OBJECT_1_4 195
#define OBJECT_1_3 194
#define OBJECT_1_2 193
#define OBJECT_1_1 192
#define OBJECT_1_0 191
#define EXECUTE_CACHE_1_98 137
#define EXECUTE_CACHE_1_97 139
#define EXECUTE_CACHE_1_94 141
#define EXECUTE_CACHE_1_92 143
#define EXECUTE_CACHE_1_88 145
#define EXECUTE_CACHE_1_84 147
#define EXECUTE_CACHE_1_82 149
#define EXECUTE_CACHE_1_81 151
#define EXECUTE_CACHE_1_72 153
#define EXECUTE_CACHE_1_67 155
#define EXECUTE_CACHE_1_66 157
#define EXECUTE_CACHE_1_63 159
#define EXECUTE_CACHE_1_59 161
#define EXECUTE_CACHE_1_57 163
#define EXECUTE_CACHE_1_55 165
#define EXECUTE_CACHE_1_49 167
#define EXECUTE_CACHE_1_93 169
#define EXECUTE_CACHE_1_38 171
#define EXECUTE_CACHE_1_37 173
#define EXECUTE_CACHE_1_29 175
#define EXECUTE_CACHE_1_26 177
#define EXECUTE_CACHE_1_16 179
#define EXECUTE_CACHE_1_10 181
#define EXECUTE_CACHE_1_7 183
#define FREE_REFERENCE_1_4 186
#define FREE_REFERENCE_1_3 187
#define FREE_REFERENCE_1_2 188
#define FREE_REFERENCE_1_1 189
#define FREE_REFERENCE_1_0 190
#define FREE_REFERENCES_LABEL_1_0 136
#define NUMBER_OF_LINKER_SECTIONS_1_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
butils_so_code_1 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd26;
  machine_word Wrd57;
  machine_word Wrd51;
  machine_word Wrd56;
  machine_word Wrd55;
  machine_word Wrd52;
  machine_word Wrd50;
  machine_word Wrd45;
  machine_word Wrd40;
  machine_word Wrd41;
  machine_word Wrd32;
  machine_word Wrd33;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd20;
  machine_word Wrd14;
  machine_word Wrd34;
  machine_word Wrd28;
  machine_word Wrd29;
  machine_word Wrd30;
  machine_word Wrd27;
  machine_word Wrd19;
  machine_word Wrd21;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd46;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd43;
  machine_word Wrd35;
  machine_word Wrd37;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd18;
  machine_word Wrd12;
  machine_word Wrd8;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd13;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_1_4);
      goto compile_system_111;

    case 1:
      current_block = (Rpc - LABEL_1_5);
      goto lambda_140;

    case 2:
      current_block = (Rpc - LABEL_1_8);
      goto label_113;

    case 3:
      current_block = (Rpc - LABEL_1_9);
      goto continuation_0;

    case 4:
      current_block = (Rpc - LABEL_1_11);
      goto continuation_1;

    case 5:
      current_block = (Rpc - LABEL_1_13);
      goto find_option_110;

    case 6:
      current_block = (Rpc - LABEL_1_12);
      goto continuation_2;

    case 7:
      current_block = (Rpc - LABEL_1_17);
      goto loop_108;

    case 8:
      current_block = (Rpc - LABEL_1_18);
      goto label_114;

    case 9:
      current_block = (Rpc - LABEL_1_19);
      goto label_117;

    case 10:
      current_block = (Rpc - LABEL_1_20);
      goto label_115;

    case 11:
      current_block = (Rpc - LABEL_1_21);
      goto label_116;

    case 12:
      current_block = (Rpc - LABEL_1_14);
      goto continuation_5;

    case 13:
      current_block = (Rpc - LABEL_1_15);
      goto lambda_4;

    case 14:
      current_block = (Rpc - LABEL_1_25);
      goto label_118;

    case 15:
      current_block = (Rpc - LABEL_1_22);
      goto continuation_15;

    case 16:
      current_block = (Rpc - LABEL_1_23);
      goto lambda_14;

    case 17:
      current_block = (Rpc - LABEL_1_30);
      goto label_119;

    case 18:
      current_block = (Rpc - LABEL_1_31);
      goto label_120;

    case 19:
      current_block = (Rpc - LABEL_1_32);
      goto label_121;

    case 20:
      current_block = (Rpc - LABEL_1_33);
      goto label_122;

    case 21:
      current_block = (Rpc - LABEL_1_34);
      goto label_123;

    case 22:
      current_block = (Rpc - LABEL_1_36);
      goto label_124;

    case 23:
      current_block = (Rpc - LABEL_1_24);
      goto continuation_3;

    case 24:
      current_block = (Rpc - LABEL_1_27);
      goto continuation_27;

    case 25:
      current_block = (Rpc - LABEL_1_28);
      goto continuation_16;

    case 26:
      current_block = (Rpc - LABEL_1_35);
      goto continuation_11;

    case 27:
      current_block = (Rpc - LABEL_1_42);
      goto label_125;

    case 28:
      current_block = (Rpc - LABEL_1_39);
      goto continuation_40;

    case 29:
      current_block = (Rpc - LABEL_1_40);
      goto lambda_39;

    case 30:
      current_block = (Rpc - LABEL_1_47);
      goto label_126;

    case 31:
      current_block = (Rpc - LABEL_1_48);
      goto label_127;

    case 32:
      current_block = (Rpc - LABEL_1_50);
      goto continuation_22;

    case 33:
      current_block = (Rpc - LABEL_1_51);
      goto label_132;

    case 34:
      current_block = (Rpc - LABEL_1_52);
      goto loop_25;

    case 35:
      current_block = (Rpc - LABEL_1_54);
      goto label_128;

    case 36:
      current_block = (Rpc - LABEL_1_41);
      goto continuation_12;

    case 37:
      current_block = (Rpc - LABEL_1_58);
      goto label_129;

    case 38:
      current_block = (Rpc - LABEL_1_43);
      goto continuation_66;

    case 39:
      current_block = (Rpc - LABEL_1_44);
      goto continuation_65;

    case 40:
      current_block = (Rpc - LABEL_1_45);
      goto continuation_64;

    case 41:
      current_block = (Rpc - LABEL_1_62);
      goto label_130;

    case 42:
      current_block = (Rpc - LABEL_1_46);
      goto continuation_34;

    case 43:
      current_block = (Rpc - LABEL_1_65);
      goto label_131;

    case 44:
      current_block = (Rpc - LABEL_1_56);
      goto continuation_28;

    case 45:
      current_block = (Rpc - LABEL_1_53);
      goto continuation_21;

    case 46:
      current_block = (Rpc - LABEL_1_60);
      goto lambda_147;

    case 47:
      current_block = (Rpc - LABEL_1_68);
      goto label_133;

    case 48:
      current_block = (Rpc - LABEL_1_64);
      goto continuation_31;

    case 49:
      current_block = (Rpc - LABEL_1_73);
      goto label_134;

    case 50:
      current_block = (Rpc - LABEL_1_74);
      goto label_135;

    case 51:
      current_block = (Rpc - LABEL_1_70);
      goto continuation_56;

    case 52:
      current_block = (Rpc - LABEL_1_69);
      goto continuation_57;

    case 53:
      current_block = (Rpc - LABEL_1_71);
      goto continuation_55;

    case 54:
      current_block = (Rpc - LABEL_1_75);
      goto lambda_148;

    case 55:
      current_block = (Rpc - LABEL_1_77);
      goto continuation_54;

    case 56:
      current_block = (Rpc - LABEL_1_78);
      goto continuation_53;

    case 57:
      current_block = (Rpc - LABEL_1_85);
      goto continuation_48;

    case 58:
      current_block = (Rpc - LABEL_1_86);
      goto label_137;

    case 59:
      current_block = (Rpc - LABEL_1_79);
      goto continuation_41;

    case 60:
      current_block = (Rpc - LABEL_1_80);
      goto continuation_42;

    case 61:
      current_block = (Rpc - LABEL_1_83);
      goto continuation_60;

    case 62:
      current_block = (Rpc - LABEL_1_89);
      goto loop_50;

    case 63:
      current_block = (Rpc - LABEL_1_91);
      goto label_136;

    case 64:
      current_block = (Rpc - LABEL_1_87);
      goto continuation_61;

    case 65:
      current_block = (Rpc - LABEL_1_90);
      goto continuation_47;

    case 66:
      current_block = (Rpc - LABEL_1_95);
      goto lambda_150;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (compile_system_139)
DEFLABEL (compile_system_111)
  INTERRUPT_CHECK (26, LABEL_1_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_1_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_1_5])));
  Rhp += 2;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd10 = Wrd7;
  (Wrd11.Obj) = (Rsp [2]);
  ((Wrd10.pObj) [2]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd10.pObj) [3]) = (Wrd9.Obj);
  (Rsp [2]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_7]));

DEFLABEL (lambda_140)
  CLOSURE_HEADER (LABEL_1_5);

DEFLABEL (lambda_100)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_152;
  Wrd5 = Wrd9;

DEFLABEL (label_151)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_9]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd15.Obj) = (Rsp [3]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [3]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_10]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_1_9);
  (Rsp [0]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_11]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_1_0]);
  (* (--Rsp)) = (Wrd12.Obj);
  goto find_option_110;

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_1_11);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_12]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_1_1]);
  (* (--Rsp)) = (Wrd11.Obj);
  goto find_option_110;

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_1_12);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_14]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_15]))));
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_16]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_1_14);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_22]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_23]))));
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_16]));

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_1_22);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_27]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_28]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_29]));

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_1_28);
  (* (--Rsp)) = Rvl;
  goto loop_25;

DEFLABEL (label_152)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_8])), (Wrd6.pObj));

DEFLABEL (label_113)
  (Wrd5.Obj) = Rvl;
  goto label_151;

DEFLABEL (continuation_27)
  INTERRUPT_CHECK (27, LABEL_1_27);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_39]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_40]))));
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_16]));

DEFLABEL (continuation_40)
  INTERRUPT_CHECK (27, LABEL_1_39);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_43]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_44]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_45]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_29]));

DEFLABEL (continuation_64)
  INTERRUPT_CHECK (27, LABEL_1_45);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_3]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_154;
  Wrd5 = Wrd9;

DEFLABEL (label_153)
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_63]));

DEFLABEL (continuation_65)
  INTERRUPT_CHECK (27, LABEL_1_44);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd6.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_1_61);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_1_60])));
  Rhp += 2;
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd6.pObj)));
  Wrd9 = Wrd6;
  (Wrd10.Obj) = (Rsp [4]);
  ((Wrd9.pObj) [2]) = (Wrd10.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  ((Wrd9.pObj) [3]) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_16]));

DEFLABEL (continuation_66)
  INTERRUPT_CHECK (27, LABEL_1_43);
  (Wrd6.Obj) = (Rsp [3]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [3]);
  (Rsp [2]) = (Wrd5.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_1_11]);
  (Rsp [3]) = (Wrd8.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_59]));

DEFLABEL (label_154)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_62])), (Wrd6.pObj));

DEFLABEL (label_130)
  (Wrd5.Obj) = Rvl;
  goto label_153;

DEFLABEL (find_option_141)
DEFLABEL (find_option_110)
  INTERRUPT_CHECK (26, LABEL_1_13);
  (Wrd5.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd5.Obj);
  goto loop_108;

DEFLABEL (loop_142)
DEFLABEL (loop_108)
  INTERRUPT_CHECK (26, LABEL_1_17);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_155;
  Rvl = (current_block [OBJECT_1_4]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_155)
  if (! ((Wrd6.uLng) == 1))
    goto label_165;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd9.Obj) = ((Wrd11.pObj) [0]);

DEFLABEL (label_164)
  (Wrd18.Obj) = (Rsp [1]);
  if ((Wrd9.Obj) == (Wrd18.Obj))
    goto label_160;
  (Wrd22.Obj) = (Rsp [0]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if (! ((Wrd23.uLng) == 1))
    goto label_159;
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
  (Wrd19.Obj) = ((Wrd21.pObj) [1]);

DEFLABEL (label_158)
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd30.uLng) == 1))
    goto label_157;
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd28.Obj) = ((Wrd29.pObj) [1]);

DEFLABEL (label_156)
  (Rsp [0]) = (Wrd28.Obj);
  goto loop_108;

DEFLABEL (label_157)
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_21]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_3]), 1);

DEFLABEL (label_116)
  (Wrd28.Obj) = Rvl;
  goto label_156;

DEFLABEL (label_159)
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_20]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_3]), 1);

DEFLABEL (label_115)
  (Wrd19.Obj) = Rvl;
  goto label_158;

DEFLABEL (label_160)
  (Wrd38.Obj) = (Rsp [0]);
  (Wrd39.uLng) = (OBJECT_TYPE (Wrd38.Obj));
  if (! ((Wrd39.uLng) == 1))
    goto label_163;
  (Wrd37.pObj) = (OBJECT_ADDRESS (Wrd38.Obj));
  (Wrd35.Obj) = ((Wrd37.pObj) [1]);

DEFLABEL (label_162)
  (Rsp [2]) = (Wrd35.Obj);
  Rsp = (& (Rsp [2]));
  (Wrd48.Obj) = (Rsp [0]);
  (Wrd49.uLng) = (OBJECT_TYPE (Wrd48.Obj));
  if (! ((Wrd49.uLng) == 1))
    goto label_161;
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd48.Obj));
  Rvl = ((Wrd46.pObj) [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_161)
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_2]), 1);

DEFLABEL (label_163)
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_19]))));
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_3]), 1);

DEFLABEL (label_117)
  (Wrd35.Obj) = Rvl;
  goto label_162;

DEFLABEL (label_165)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_18]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_2]), 1);

DEFLABEL (label_114)
  (Wrd9.Obj) = Rvl;
  goto label_164;

DEFLABEL (lambda_143)
DEFLABEL (lambda_4)
  INTERRUPT_CHECK (26, LABEL_1_15);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_24]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_1]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_168;
  Wrd8 = Wrd12;

DEFLABEL (label_167)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_26]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_1_24);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_166;
  Rvl = (current_block [OBJECT_1_8]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_166)
  (Wrd9.Obj) = (current_block [OBJECT_1_7]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_38]));

DEFLABEL (label_168)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_25])), (Wrd9.pObj));

DEFLABEL (label_118)
  (Wrd8.Obj) = Rvl;
  goto label_167;

DEFLABEL (lambda_144)
DEFLABEL (lambda_14)
  INTERRUPT_CHECK (26, LABEL_1_23);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_184;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [1]);

DEFLABEL (label_183)
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd16.uLng) == 1))
    goto label_182;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (* (--Rsp)) = (Wrd15.Obj);

DEFLABEL (label_181)
  (Wrd24.Obj) = (Rsp [1]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if (! ((Wrd25.uLng) == 1))
    goto label_180;
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd23.Obj) = ((Wrd22.pObj) [0]);
  (* (--Rsp)) = (Wrd23.Obj);

DEFLABEL (label_179)
  (Wrd33.Obj) = (Rsp [2]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if (! ((Wrd34.uLng) == 1))
    goto label_178;
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd30.Obj) = ((Wrd32.pObj) [1]);

DEFLABEL (label_177)
  (Wrd41.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd41.uLng) == 1))
    goto label_176;
  (Wrd40.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd39.Obj) = ((Wrd40.pObj) [1]);

DEFLABEL (label_175)
  (Rsp [2]) = (Wrd39.Obj);
  (Wrd48.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_35]))));
  (* (--Rsp)) = (Wrd48.Obj);
  (Wrd49.Obj) = (current_block [OBJECT_1_5]);
  (* (--Rsp)) = (Wrd49.Obj);
  (Wrd50.Obj) = (current_block [OBJECT_1_6]);
  (* (--Rsp)) = (Wrd50.Obj);
  (Wrd52.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_2]));
  (Wrd55.Obj) = ((Wrd52.pObj) [0]);
  (Wrd56.uLng) = (OBJECT_TYPE (Wrd55.Obj));
  if ((Wrd56.uLng) == 50)
    goto label_174;
  Wrd51 = Wrd55;

DEFLABEL (label_173)
  (* (--Rsp)) = (Wrd51.Obj);
  (Wrd57.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd57.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_37]));

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_1_35);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_41]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_1_5]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_1_6]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd11.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_2]));
  (Wrd14.Obj) = ((Wrd11.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_172;
  Wrd10 = Wrd14;

DEFLABEL (label_171)
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd16.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_37]));

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_1_41);
  (Wrd5.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_2]));
  (Wrd11.Obj) = ((Wrd8.pObj) [0]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if ((Wrd12.uLng) == 50)
    goto label_170;
  Wrd7 = Wrd11;

DEFLABEL (label_169)
  (Rsp [1]) = (Wrd7.Obj);
  (Wrd13.Obj) = (current_block [OBJECT_1_10]);
  (Rsp [2]) = (Wrd13.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_1_5]);
  (Rsp [3]) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_37]));

DEFLABEL (label_170)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_58])), (Wrd8.pObj));

DEFLABEL (label_129)
  (Wrd7.Obj) = Rvl;
  goto label_169;

DEFLABEL (label_172)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_42])), (Wrd11.pObj));

DEFLABEL (label_125)
  (Wrd10.Obj) = Rvl;
  goto label_171;

DEFLABEL (label_174)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_36])), (Wrd52.pObj));

DEFLABEL (label_124)
  (Wrd51.Obj) = Rvl;
  goto label_173;

DEFLABEL (label_176)
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_34]))));
  (* (--Rsp)) = (Wrd45.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_3]), 1);

DEFLABEL (label_123)
  (Wrd39.Obj) = Rvl;
  goto label_175;

DEFLABEL (label_178)
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_33]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_3]), 1);

DEFLABEL (label_122)
  (Wrd30.Obj) = Rvl;
  goto label_177;

DEFLABEL (label_180)
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_32]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_2]), 1);

DEFLABEL (label_121)
  (* (--Rsp)) = Rvl;
  goto label_179;

DEFLABEL (label_182)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_31]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_2]), 1);

DEFLABEL (label_120)
  (* (--Rsp)) = Rvl;
  goto label_181;

DEFLABEL (label_184)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_30]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_3]), 1);

DEFLABEL (label_119)
  (Wrd5.Obj) = Rvl;
  goto label_183;

DEFLABEL (lambda_145)
DEFLABEL (lambda_39)
  INTERRUPT_CHECK (26, LABEL_1_40);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_46]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd12.uLng) == 1))
    goto label_194;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd8.Obj) = ((Wrd10.pObj) [1]);

DEFLABEL (label_193)
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd19.uLng) == 1))
    goto label_192;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [0]);
  (* (--Rsp)) = (Wrd18.Obj);

DEFLABEL (label_191)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_49]));

DEFLABEL (continuation_34)
  INTERRUPT_CHECK (27, LABEL_1_46);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_64]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd12.uLng) == 1))
    goto label_190;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [0]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_189)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_49]));

DEFLABEL (continuation_31)
  INTERRUPT_CHECK (27, LABEL_1_64);
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (Rsp [2]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_188;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [1]);

DEFLABEL (label_187)
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd16.uLng) == 1))
    goto label_186;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd14.Obj) = ((Wrd15.pObj) [1]);

DEFLABEL (label_185)
  (Rsp [2]) = (Wrd14.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd23.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_1_76);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_1_75])));
  Rhp += 2;
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd23.pObj)));
  Wrd26 = Wrd23;
  (Wrd27.Obj) = (Rsp [1]);
  ((Wrd26.pObj) [2]) = (Wrd27.Obj);
  (Wrd25.Obj) = (Rsp [0]);
  ((Wrd26.pObj) [3]) = (Wrd25.Obj);
  (Rsp [1]) = (Wrd22.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_16]));

DEFLABEL (label_186)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_74]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_3]), 1);

DEFLABEL (label_135)
  (Wrd14.Obj) = Rvl;
  goto label_185;

DEFLABEL (label_188)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_73]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_3]), 1);

DEFLABEL (label_134)
  (Wrd5.Obj) = Rvl;
  goto label_187;

DEFLABEL (label_190)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_65]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_2]), 1);

DEFLABEL (label_131)
  (* (--Rsp)) = Rvl;
  goto label_189;

DEFLABEL (label_192)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_48]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_2]), 1);

DEFLABEL (label_127)
  (* (--Rsp)) = Rvl;
  goto label_191;

DEFLABEL (label_194)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_47]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_3]), 1);

DEFLABEL (label_126)
  (Wrd8.Obj) = Rvl;
  goto label_193;

DEFLABEL (loop_146)
DEFLABEL (loop_25)
  INTERRUPT_CHECK (26, LABEL_1_52);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_197;
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);

DEFLABEL (label_196)
  (Wrd9.Obj) = (Rsp [0]);
  if ((Wrd9.Obj) == ((SCHEME_OBJECT) 0))
    goto label_195;
  (Wrd11.Obj) = (current_block [OBJECT_1_9]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_38]));

DEFLABEL (label_195)
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_56]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_57]));

DEFLABEL (continuation_28)
  INTERRUPT_CHECK (27, LABEL_1_56);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_66]));

DEFLABEL (label_197)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_50]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_53]))));
  (* (--Rsp)) = (Wrd21.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_202;
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd24.Obj) = ((Wrd23.pObj) [0]);
  (* (--Rsp)) = (Wrd24.Obj);

DEFLABEL (label_201)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_55]));

DEFLABEL (continuation_21)
  INTERRUPT_CHECK (27, LABEL_1_53);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_67]));

DEFLABEL (continuation_22)
  INTERRUPT_CHECK (27, LABEL_1_50);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_198;
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = Rvl;
  goto label_196;

DEFLABEL (label_198)
  (Wrd38.Obj) = (Rsp [1]);
  (Wrd39.uLng) = (OBJECT_TYPE (Wrd38.Obj));
  if (! ((Wrd39.uLng) == 1))
    goto label_200;
  (Wrd37.pObj) = (OBJECT_ADDRESS (Wrd38.Obj));
  (Wrd35.Obj) = ((Wrd37.pObj) [1]);

DEFLABEL (label_199)
  (Rsp [1]) = (Wrd35.Obj);
  Rsp = (& (Rsp [1]));
  goto loop_25;

DEFLABEL (label_200)
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_51]))));
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_3]), 1);

DEFLABEL (label_132)
  (Wrd35.Obj) = Rvl;
  goto label_199;

DEFLABEL (label_202)
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_54]))));
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_2]), 1);

DEFLABEL (label_128)
  (* (--Rsp)) = Rvl;
  goto label_201;

DEFLABEL (lambda_147)
  CLOSURE_HEADER (LABEL_1_60);

DEFLABEL (lambda_63)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_4]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_210;
  Wrd5 = Wrd9;

DEFLABEL (label_209)
  if ((Wrd5.Obj) == ((SCHEME_OBJECT) 0))
    goto label_204;
  (Wrd12.Obj) = (current_block [OBJECT_1_12]);
  (* (--Rsp)) = (Wrd12.Obj);
  goto label_203;

DEFLABEL (label_204)
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);

DEFLABEL (label_203)
DEFLABEL (label_208)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_69]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_70]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd19.Obj) = (Rsp [3]);
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [3]);
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_71]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd25.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd25.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_72]));

DEFLABEL (continuation_55)
  INTERRUPT_CHECK (27, LABEL_1_71);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_81]));

DEFLABEL (continuation_56)
  INTERRUPT_CHECK (27, LABEL_1_70);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_207;
  (Wrd28.uLng) = (OBJECT_TYPE (Rvl));
  if ((Wrd28.uLng) == 1)
    goto label_205;
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_3]), 1);

DEFLABEL (label_205)
  (Wrd26.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd24.Obj) = ((Wrd26.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd24.Obj);

DEFLABEL (label_206)
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_77]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_78]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_79]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_80]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd18.Obj) = (Rsp [7]);
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [2]);
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_29]));

DEFLABEL (continuation_42)
  INTERRUPT_CHECK (27, LABEL_1_80);
  (* (--Rsp)) = Rvl;
  goto loop_50;

DEFLABEL (label_207)
  (Wrd30.Obj) = (current_block [OBJECT_1_4]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd30.Obj);
  goto label_206;

DEFLABEL (label_210)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_68])), (Wrd6.pObj));

DEFLABEL (label_133)
  (Wrd5.Obj) = Rvl;
  goto label_209;

DEFLABEL (continuation_41)
  INTERRUPT_CHECK (27, LABEL_1_79);
  (* (--Rsp)) = Rvl;

DEFLABEL (label_211)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_55]));

DEFLABEL (continuation_53)
  INTERRUPT_CHECK (27, LABEL_1_78);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_49]));

DEFLABEL (continuation_54)
  INTERRUPT_CHECK (27, LABEL_1_77);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_83]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = Rvl;
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_84]));

DEFLABEL (continuation_60)
  INTERRUPT_CHECK (27, LABEL_1_83);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_87]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_88]));

DEFLABEL (continuation_61)
  INTERRUPT_CHECK (27, LABEL_1_87);
  (Rsp [3]) = Rvl;
  (Wrd6.Obj) = (Rsp [0]);
  (Rsp [4]) = (Wrd6.Obj);
  Rsp = (& (Rsp [3]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_94]));

DEFLABEL (continuation_57)
  INTERRUPT_CHECK (27, LABEL_1_69);
  (* (--Rsp)) = Rvl;
  goto label_206;

DEFLABEL (lambda_148)
  CLOSURE_HEADER (LABEL_1_75);

DEFLABEL (lambda_37)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = ((Wrd6.pObj) [2]);
  (Rsp [1]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_82]));

DEFLABEL (loop_149)
DEFLABEL (loop_50)
  INTERRUPT_CHECK (26, LABEL_1_89);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_212;
  (Wrd7.Obj) = (current_block [OBJECT_1_13]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd8.Obj);
  (Wrd10.Obj) = (Rsp [8]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd9.Obj) = ((Wrd11.pObj) [2]);
  (Rsp [2]) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_93]));

DEFLABEL (label_212)
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_85]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_90]))));
  (* (--Rsp)) = (Wrd17.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_218;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [0]);
  (* (--Rsp)) = (Wrd20.Obj);

DEFLABEL (label_217)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_92]));

DEFLABEL (continuation_47)
  INTERRUPT_CHECK (27, LABEL_1_90);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd6.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_1_96);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_1_95])));
  Rhp += 1;
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd6.pObj)));
  Wrd7 = Wrd6;
  (Wrd8.Obj) = (Rsp [3]);
  ((Wrd7.pObj) [2]) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_97]));

DEFLABEL (continuation_48)
  INTERRUPT_CHECK (27, LABEL_1_85);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_214;
  (Wrd7.Obj) = (Rsp [0]);
  (Rsp [1]) = (Wrd7.Obj);
  Rsp = (& (Rsp [1]));
  (Wrd12.Obj) = (Rsp [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 1)
    goto label_213;
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_2]), 1);

DEFLABEL (label_213)
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd9.Obj) = ((Wrd11.pObj) [0]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd9.Obj);
  goto label_211;

DEFLABEL (label_214)
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd19.uLng) == 1))
    goto label_216;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd15.Obj) = ((Wrd17.pObj) [1]);

DEFLABEL (label_215)
  (Rsp [0]) = (Wrd15.Obj);
  goto loop_50;

DEFLABEL (label_216)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_86]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_3]), 1);

DEFLABEL (label_137)
  (Wrd15.Obj) = Rvl;
  goto label_215;

DEFLABEL (label_218)
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_91]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_2]), 1);

DEFLABEL (label_136)
  (* (--Rsp)) = Rvl;
  goto label_217;

DEFLABEL (lambda_150)
  CLOSURE_HEADER (LABEL_1_95);

DEFLABEL (lambda_45)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Wrd8.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd8.Obj);
  (Rsp [1]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_98]));

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_4 3
#define LABEL_5 5
#define LABEL_6 7
#define ENVIRONMENT_LABEL_3 14
#define DEBUGGING_LABEL_2 13
#define PURIFICATION_ROOT 12
#define OBJECT_3 11
#define OBJECT_2 10
#define OBJECT_1 9
#define OBJECT_0 8
#define FREE_REFERENCES_LABEL_0 8
#define NUMBER_OF_LINKER_SECTIONS_1 0

#ifndef WANT_ONLY_DATA

SCHEME_OBJECT *
butils_so_25546d56899604be (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_4);
      goto label_3;

    case 1:
      current_block = (Rpc - LABEL_5);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_6);
      goto expression_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (expression_1)
  (current_block [ENVIRONMENT_LABEL_3]) = (Rrb [REGBLOCK_ENV]);
  INVOKE_INTERFACE_4 (23, (& (current_block [LABEL_5])), current_block, (& (current_block [FREE_REFERENCES_LABEL_0])), NUMBER_OF_LINKER_SECTIONS_1);

DEFLABEL (label_4)
  {
    SCHEME_OBJECT * sub_block = (OBJECT_ADDRESS (current_block [OBJECT_3]));
    (sub_block [206]) = (Rrb [REGBLOCK_ENV]);
    INVOKE_INTERFACE_4 (23, (& (current_block [LABEL_4])), sub_block, (& (sub_block [136])), 2);
  }

DEFLABEL (label_3)
  (Wrd5.Obj) = (Rrb [3]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_0]);
  (* (--Rsp)) = (Wrd6.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_1]);
  (Rsp [2]) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

INVOKE_INTERFACE_TARGET_4
INVOKE_PRIMITIVE_TARGET
}

int
decl_butils_so_25546d56899604be (void)
{
  DECLARE_SUBCODE ("butils_so_code_1", 67, butils_so_code_1);
  return (0);
}

DECLARE_COMPILED_CODE ("butils.so", 3, decl_butils_so_25546d56899604be, butils_so_25546d56899604be)

#endif /* !WANT_ONLY_DATA */

#ifndef WANT_ONLY_CODE

static const unsigned char prog_butils_so_data_25546d56899604be [1320] =
  "\xd2\x01\x04\xea\x01\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x0c\x0c\x0d"
  "\x0c\x0c\x1d\x0c\x0c\x0d\xb8\x08\xc1\xc1\x0d\x0d\x0d\x0d\x0d\x0d"
  "\xb9\x0d\x24\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28"
  "\x0d\xba\x28\xb2\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d"
  "\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\xb1\x28\x0d"
  "\x28\x0d\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\xba\x98"
  "\x88\xb2\xc3\xb2\x2a\xb0\x22\x29\x22\x29\x22\x29\x21\x17\x02\x50"
  "\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74\x77"
  "\x61\x72\x65\x2f\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61"
  "\x73\x65\x2d\x39\x2e\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68"
  "\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63\x2f"
  "\x63\x72\x65\x66\x2f\x62\x75\x74\x69\x6c\x73\x2e\x69\x6e\x66\x15"
  "\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72"
  "\x6f\x6f\x74\x5d\x02\x1a\x4e\x6f\x20\x63\x72\x65\x66\x20\x70\x61"
  "\x63\x6b\x61\x67\x65\x20\x66\x6f\x72\x20\x66\x69\x6c\x65\x3a\x04"
  "\x62\x69\x6e\x04\x61\x6c\x6c\x0f\x69\x6d\x70\x6f\x72\x74\x65\x64"
  "\x20\x6e\x61\x6d\x65\x73\x18\x50\x61\x63\x6b\x61\x67\x65\x20\x61"
  "\x6c\x72\x65\x61\x64\x79\x20\x65\x78\x69\x73\x74\x73\x3a\x02\x12"
  "\x42\x6f\x67\x75\x73\x20\x64\x65\x70\x65\x6e\x64\x65\x6e\x63\x79"
  "\x3a\x0d\x70\x61\x63\x6b\x61\x67\x65\x20\x6e\x61\x6d\x65\x0f\x63"
  "\x6f\x6d\x70\x69\x6c\x65\x2d\x73\x79\x73\x74\x65\x6d\x04\x63\x64"
  "\x72\x04\x63\x61\x72\x08\x69\x6d\x70\x6f\x72\x74\x73\x0d\x64\x65"
  "\x70\x65\x6e\x64\x65\x6e\x63\x69\x65\x73\x1e\x6d\x69\x63\x72\x6f"
  "\x63\x6f\x64\x65\x2d\x69\x64\x2f\x6f\x70\x65\x72\x61\x74\x69\x6e"
  "\x67\x2d\x73\x79\x73\x74\x65\x6d\x08\x73\x74\x72\x69\x6e\x67\x3f"
  "\x08\x73\x79\x6d\x62\x6f\x6c\x3f\x0e\x70\x61\x63\x6b\x61\x67\x65"
  "\x2f\x66\x69\x6c\x65\x73\x16\x63\x6f\x6d\x70\x69\x6c\x65\x2d\x66"
  "\x69\x6c\x65\x3a\x73\x66\x2d\x6f\x6e\x6c\x79\x3f\x06\x04\x20\x77"
  "\x69\x74\x68\x2d\x77\x6f\x72\x6b\x69\x6e\x67\x2d\x64\x69\x72\x65"
  "\x63\x74\x6f\x72\x79\x2d\x70\x61\x74\x68\x6e\x61\x6d\x65\x04\x13"
  "\x72\x65\x61\x64\x2d\x70\x61\x63\x6b\x61\x67\x65\x2d\x6d\x6f\x64"
  "\x65\x6c\x04\x09\x66\x6f\x72\x2d\x65\x61\x63\x68\x04\x09\x66\x6f"
  "\x72\x2d\x61\x6c\x6c\x3f\x03\x10\x70\x6d\x6f\x64\x65\x6c\x2f\x70"
  "\x61\x63\x6b\x61\x67\x65\x73\x06\x17\x67\x75\x61\x72\x61\x6e\x74"
  "\x65\x65\x2d\x6c\x69\x73\x74\x2d\x6f\x66\x2d\x74\x79\x70\x65\x04"
  "\x06\x65\x72\x72\x6f\x72\x05\x03\x0e\x2d\x3e\x65\x6e\x76\x69\x72"
  "\x6f\x6e\x6d\x65\x6e\x74\x03\x0d\x70\x61\x63\x6b\x61\x67\x65\x2f"
  "\x6e\x61\x6d\x65\x03\x20\x63\x6f\x6e\x73\x74\x72\x75\x63\x74\x2d"
  "\x65\x78\x74\x65\x72\x6e\x61\x6c\x2d\x64\x65\x73\x63\x72\x69\x70"
  "\x74\x69\x6f\x6e\x73\x04\x1b\x63\x72\x65\x66\x2f\x67\x65\x6e\x65"
  "\x72\x61\x74\x65\x2d\x63\x6f\x6e\x73\x74\x72\x75\x63\x74\x6f\x72"
  "\x73\x04\x0b\x61\x70\x70\x65\x6e\x64\x2d\x6d\x61\x70\x03\x1d\x63"
  "\x6f\x6e\x73\x74\x72\x75\x63\x74\x2d\x70\x61\x63\x6b\x61\x67\x65"
  "\x73\x2d\x66\x72\x6f\x6d\x2d\x66\x69\x6c\x65\x03\x0e\x6e\x61\x6d"
  "\x65\x2d\x3e\x70\x61\x63\x6b\x61\x67\x65\x03\x0d\x2d\x3e\x6e\x61"
  "\x6d\x65\x73\x74\x72\x69\x6e\x67\x04\x06\x61\x73\x73\x6f\x63\x05"
  "\x16\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x2d\x6c\x69\x6e"
  "\x6b\x2d\x6e\x61\x6d\x65\x05\x0d\x63\x6f\x6d\x70\x69\x6c\x65\x2d"
  "\x66\x69\x6c\x65\x04\x12\x70\x61\x74\x68\x6e\x61\x6d\x65\x2d\x6e"
  "\x65\x77\x2d\x74\x79\x70\x65\x03\x04\x05\x6c\x6f\x61\x64\x04\x05"
  "\x66\x69\x6e\x64\x04\x0b\x70\x61\x74\x68\x6e\x61\x6d\x65\x3d\x3f"
  "\x19\x46\x88\x01\x81\x85\x02\x45\x86\x01\x81\x87\x02\x44\x84\x01"
  "\x81\x8b\x02\x43\x82\x01\x81\x89\x02\x42\x80\x01\x81\x85\x02\x41"
  "\x7e\x81\x8b\x02\x40\x7c\x81\x83\x02\x3f\x7a\x81\x8d\x02\x3e\x78"
  "\x81\x85\x02\x3d\x76\x81\x85\x02\x3c\x74\x81\x8b\x02\x3b\x72\x81"
  "\x89\x02\x3a\x70\x81\x85\x02\x39\x6e\x81\x8d\x02\x38\x6c\x81\x87"
  "\x02\x37\x6a\x81\x89\x02\x36\x68\x81\x87\x02\x35\x66\x81\x87\x02"
  "\x34\x64\x81\x85\x02\x33\x62\x81\x85\x02\x32\x60\x81\x85\x02\x31"
  "\x5e\x81\x8f\x02\x30\x5c\x81\x83\x02\x2f\x5a\x81\x87\x02\x2e\x58"
  "\x81\x83\x02\x2d\x56\x81\x8f\x02\x2c\x54\x81\x8d\x02\x2b\x52\x81"
  "\x8b\x02\x2a\x50\x81\x89\x02\x29\x4e\x81\x89\x02\x28\x4c\x81\x87"
  "\x02\x27\x4a\x81\x91\x02\x26\x48\x81\x8d\x02\x25\x46\x81\x8f\x02"
  "\x24\x44\x81\x8d\x02\x23\x42\x81\x85\x02\x22\x40\x81\x85\x02\x21"
  "\x3e\x83\x04\x20\x3c\x81\x89\x02\x1f\x3a\x81\x8d\x02\x1e\x38\x81"
  "\x87\x02\x1d\x36\x81\x8b\x02\x1c\x34\x81\x89\x02\x1b\x32\x81\x83"
  "\x02\x1a\x30\x81\x8d\x02\x19\x2e\x81\x87\x02\x18\x2c\x81\x87\x02"
  "\x17\x2a\x81\x85\x02\x16\x28\x81\x83\x02\x15\x26\x81\x83\x02\x14"
  "\x24\x83\x04\x13\x22\x81\x89\x02\x12\x20\x81\x85\x02\x11\x1e\x83"
  "\x04\x10\x1c\x81\x89\x02\x0f\x1a\x81\x87\x02\x0e\x18\x81\x87\x02"
  "\x0d\x16\x81\x87\x02\x0c\x14\x81\x87\x02\x0b\x12\x81\x87\x02\x0a"
  "\x10\x81\x87\x02\x09\x0e\x81\x85\x02\x08\x0c\x81\x85\x02\x07\x0a"
  "\x81\x85\x02\x06\x08\x81\x83\x02\x05\x06\x81\x83\x02\x04\x04\xfd"
  "\x07\x87\x01\xcf\x01\x11\x6c\x6f\x63\x61\x6c\x2d\x61\x73\x73\x69"
  "\x67\x6e\x6d\x65\x6e\x74\x04\x03\x08\x80\x80\x04\x02\x06\x81\x81"
  "\x02\x01\x04\x81\x81\x02\x07\x0f";

SCHEME_OBJECT *
butils_so_data_25546d56899604be (entry_count_t dispatch_base)
{
  SCHEME_OBJECT ccb;
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES_FOR_DATA ();

  ccb = (unstackify (((unsigned char *) (& (prog_butils_so_data_25546d56899604be [0]))), (sizeof (prog_butils_so_data_25546d56899604be)), dispatch_base));
  current_block = (OBJECT_ADDRESS (ccb));
  return (& (current_block [LABEL_6]));
}

DECLARE_COMPILED_DATA_NS ("butils.so", butils_so_data_25546d56899604be)

#endif /* !WANT_ONLY_CODE */

DECLARE_DYNAMIC_INITIALIZATION ("butils.so", "a0fbc8f0e9a92ae4")
