/* Emacs: this is -*- C -*- code, */
/* generated 2011-11-08T22:50:42-08 by Liar version 4.118. */

#include "liarc.h"

#define LABEL_1_4 3
#define ENVIRONMENT_LABEL_1_3 6
#define DEBUGGING_LABEL_1_2 5
#define OBJECT_1_0 4
#define FREE_REFERENCES_LABEL_1_0 4
#define NUMBER_OF_LINKER_SECTIONS_1_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_1 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd7;
  machine_word Wrd10;
  machine_word Wrd9;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_1_4);
      goto car_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (car_3)
DEFLABEL (car_0)
  INTERRUPT_CHECK (26, LABEL_1_4);
  (Wrd9.Obj) = (Rsp [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if (! ((Wrd10.uLng) == 1))
    goto label_4;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  Rvl = ((Wrd7.pObj) [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_0]), 1);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_2_4 3
#define ENVIRONMENT_LABEL_2_3 6
#define DEBUGGING_LABEL_2_2 5
#define OBJECT_2_0 4
#define FREE_REFERENCES_LABEL_2_0 4
#define NUMBER_OF_LINKER_SECTIONS_2_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_2 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd7;
  machine_word Wrd10;
  machine_word Wrd9;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_2_4);
      goto cdr_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (cdr_3)
DEFLABEL (cdr_0)
  INTERRUPT_CHECK (26, LABEL_2_4);
  (Wrd9.Obj) = (Rsp [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if (! ((Wrd10.uLng) == 1))
    goto label_4;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  Rvl = ((Wrd7.pObj) [1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_0]), 1);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_3_4 3
#define ENVIRONMENT_LABEL_3_3 5
#define DEBUGGING_LABEL_3_2 4
#define FREE_REFERENCES_LABEL_3_0 4
#define NUMBER_OF_LINKER_SECTIONS_3_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_3 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd7;
  machine_word Wrd10;
  machine_word Wrd9;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_3_4);
      goto cons_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (cons_3)
DEFLABEL (cons_0)
  INTERRUPT_CHECK (26, LABEL_3_4);
  (Wrd9.Obj) = (Rsp [0]);
  (Wrd10.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_4_4 3
#define ENVIRONMENT_LABEL_4_3 6
#define DEBUGGING_LABEL_4_2 5
#define OBJECT_4_0 4
#define FREE_REFERENCES_LABEL_4_0 4
#define NUMBER_OF_LINKER_SECTIONS_4_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_4 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_4_4);
      goto general_car_cdr_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (general_car_cdr_3)
DEFLABEL (general_car_cdr_0)
  INTERRUPT_CHECK (26, LABEL_4_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_0]), 2);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_5_4 3
#define ENVIRONMENT_LABEL_5_3 7
#define DEBUGGING_LABEL_5_2 6
#define OBJECT_5_1 5
#define OBJECT_5_0 4
#define FREE_REFERENCES_LABEL_5_0 4
#define NUMBER_OF_LINKER_SECTIONS_5_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_5 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_5_4);
      goto nullP_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (nullP_3)
DEFLABEL (nullP_0)
  INTERRUPT_CHECK (26, LABEL_5_4);
  (Wrd6.Obj) = (Rsp [0]);
  if ((Wrd6.Obj) == (current_block [OBJECT_5_0]))
    goto label_5;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_4;

DEFLABEL (label_5)
  Rvl = (current_block [OBJECT_5_1]);

DEFLABEL (label_4)
DEFLABEL (label_6)
  Rsp = (& (Rsp [1]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_6_4 3
#define ENVIRONMENT_LABEL_6_3 6
#define DEBUGGING_LABEL_6_2 5
#define OBJECT_6_0 4
#define FREE_REFERENCES_LABEL_6_0 4
#define NUMBER_OF_LINKER_SECTIONS_6_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_6 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd7;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_6_4);
      goto pairP_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (pairP_3)
DEFLABEL (pairP_0)
  INTERRUPT_CHECK (26, LABEL_6_4);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.uLng) = (OBJECT_TYPE (Wrd6.Obj));
  if ((Wrd7.uLng) == 1)
    goto label_5;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_4;

DEFLABEL (label_5)
  Rvl = (current_block [OBJECT_6_0]);

DEFLABEL (label_4)
DEFLABEL (label_6)
  Rsp = (& (Rsp [1]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_7_4 3
#define ENVIRONMENT_LABEL_7_3 7
#define DEBUGGING_LABEL_7_2 6
#define OBJECT_7_1 5
#define OBJECT_7_0 4
#define FREE_REFERENCES_LABEL_7_0 4
#define NUMBER_OF_LINKER_SECTIONS_7_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_7 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd11;
  machine_word Wrd10;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_7_4);
      goto set_carB_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (set_carB_3)
DEFLABEL (set_carB_0)
  INTERRUPT_CHECK (26, LABEL_7_4);
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_4;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd8.Obj) = (Rsp [1]);
  ((Wrd7.pObj) [0]) = (Wrd8.Obj);
  Rvl = (current_block [OBJECT_7_0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_7_1]), 2);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_8_4 3
#define ENVIRONMENT_LABEL_8_3 7
#define DEBUGGING_LABEL_8_2 6
#define OBJECT_8_1 5
#define OBJECT_8_0 4
#define FREE_REFERENCES_LABEL_8_0 4
#define NUMBER_OF_LINKER_SECTIONS_8_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_8 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd11;
  machine_word Wrd10;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_8_4);
      goto set_cdrB_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (set_cdrB_3)
DEFLABEL (set_cdrB_0)
  INTERRUPT_CHECK (26, LABEL_8_4);
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_4;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd8.Obj) = (Rsp [1]);
  ((Wrd7.pObj) [1]) = (Wrd8.Obj);
  Rvl = (current_block [OBJECT_8_0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_8_1]), 2);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_9_4 3
#define ENVIRONMENT_LABEL_9_3 5
#define DEBUGGING_LABEL_9_2 4
#define FREE_REFERENCES_LABEL_9_0 4
#define NUMBER_OF_LINKER_SECTIONS_9_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_9 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_9_4);
      goto list_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (list_3)
DEFLABEL (list_0)
  INTERRUPT_CHECK (26, LABEL_9_4);
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_10_4 3
#define LABEL_10_5 5
#define LABEL_10_7 7
#define LABEL_10_8 9
#define LABEL_10_6 11
#define ENVIRONMENT_LABEL_10_3 15
#define DEBUGGING_LABEL_10_2 14
#define OBJECT_10_1 13
#define OBJECT_10_0 12
#define FREE_REFERENCES_LABEL_10_0 12
#define NUMBER_OF_LINKER_SECTIONS_10_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_10 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd10;
  machine_word Wrd29;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd20;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd11;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_10_4);
      goto cons__7;

    case 1:
      current_block = (Rpc - LABEL_10_5);
      goto loop_5;

    case 2:
      current_block = (Rpc - LABEL_10_7);
      goto label_9;

    case 3:
      current_block = (Rpc - LABEL_10_8);
      goto label_10;

    case 4:
      current_block = (Rpc - LABEL_10_6);
      goto continuation_4;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (cons__12)
DEFLABEL (cons__7)
  INTERRUPT_CHECK (26, LABEL_10_4);
  goto loop_5;

DEFLABEL (loop_13)
DEFLABEL (loop_5)
  INTERRUPT_CHECK (26, LABEL_10_5);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_14;
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_14)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_6]))));
  (* (--Rsp)) = (Wrd11.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_18;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [1]);
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_17)
  (Wrd24.Obj) = (Rsp [3]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if (! ((Wrd25.uLng) == 1))
    goto label_16;
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd23.Obj) = ((Wrd22.pObj) [0]);
  (* (--Rsp)) = (Wrd23.Obj);

DEFLABEL (label_15)
  goto loop_5;

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_10_6);
  (Wrd10.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_16)
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_8]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_10_1]), 1);

DEFLABEL (label_10)
  (* (--Rsp)) = Rvl;
  goto label_15;

DEFLABEL (label_18)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10_7]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_10_0]), 1);

DEFLABEL (label_9)
  (* (--Rsp)) = Rvl;
  goto label_17;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_11_4 3
#define LABEL_11_5 5
#define LABEL_11_7 7
#define ENVIRONMENT_LABEL_11_3 15
#define DEBUGGING_LABEL_11_2 14
#define OBJECT_11_2 13
#define OBJECT_11_1 12
#define OBJECT_11_0 11
#define EXECUTE_CACHE_11_6 9
#define FREE_REFERENCES_LABEL_11_0 8
#define NUMBER_OF_LINKER_SECTIONS_11_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_11 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd11;
  machine_word Wrd13;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd6;
  machine_word Wrd10;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_11_4);
      goto make_list_10;

    case 1:
      current_block = (Rpc - LABEL_11_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_11_7);
      goto loop_7;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (make_list_13)
DEFLABEL (make_list_10)
  INTERRUPT_CHECK (26, LABEL_11_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_11_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_11_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_11_5);
  (Wrd5.Obj) = (Rsp [1]);
  if ((Wrd5.Obj) == (current_block [OBJECT_11_1]))
    goto label_16;
  (* (--Rsp)) = (Wrd5.Obj);
  goto label_15;

DEFLABEL (label_16)
  (Wrd10.Obj) = (current_block [OBJECT_11_2]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_15)
DEFLABEL (label_17)
  (Wrd8.Obj) = (current_block [OBJECT_11_2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  goto loop_7;

DEFLABEL (loop_14)
DEFLABEL (loop_7)
  INTERRUPT_CHECK (26, LABEL_11_7);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.Lng) = (FIXNUM_TO_LONG (Wrd5.Obj));
  if ((Wrd6.Lng) == 0)
    goto label_18;
  (Wrd10.Lng) = ((Wrd6.Lng) - 1L);
  (Wrd7.Obj) = (LONG_TO_FIXNUM (Wrd10.Lng));
  (Rsp [0]) = (Wrd7.Obj);
  (Wrd14.Obj) = (Rsp [2]);
  (Wrd15.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd14.Obj);
  (* (Rhp++)) = (Wrd15.Obj);
  (Wrd13.pObj) = (& (Rhp [-2]));
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd13.pObj)));
  (Rsp [1]) = (Wrd11.Obj);
  goto loop_7;

DEFLABEL (label_18)
  Rvl = (Rsp [1]);
  Rsp = (& (Rsp [5]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_12_5 3
#define LABEL_12_6 5
#define LABEL_12_7 7
#define LABEL_12_8 9
#define LABEL_12_4 11
#define ENVIRONMENT_LABEL_12_3 15
#define DEBUGGING_LABEL_12_2 14
#define OBJECT_12_1 13
#define OBJECT_12_0 12
#define FREE_REFERENCES_LABEL_12_0 12
#define NUMBER_OF_LINKER_SECTIONS_12_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_12 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd11;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd27;
  machine_word Wrd30;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd39;
  machine_word Wrd31;
  machine_word Wrd33;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd13;
  machine_word Wrd15;
  machine_word Wrd17;
  machine_word Wrd16;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_12_5);
      goto loop_6;

    case 1:
      current_block = (Rpc - LABEL_12_6);
      goto label_10;

    case 2:
      current_block = (Rpc - LABEL_12_7);
      goto label_11;

    case 3:
      current_block = (Rpc - LABEL_12_8);
      goto continuation_1;

    case 4:
      current_block = (Rpc - LABEL_12_4);
      goto circular_list_8;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (circular_list_14)
DEFLABEL (circular_list_8)
  INTERRUPT_CHECK (26, LABEL_12_4);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_16;

DEFLABEL (label_15)
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_16)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_8]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  goto loop_6;

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_12_8);
  goto label_15;

DEFLABEL (loop_13)
DEFLABEL (loop_6)
  INTERRUPT_CHECK (26, LABEL_12_5);
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 1))
    goto label_22;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd13.Obj) = ((Wrd15.pObj) [1]);

DEFLABEL (label_21)
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd22.uLng) == 1)
    goto label_18;
  (Wrd23.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd24.Obj) = (Rsp [3]);
  (Rsp [1]) = (Wrd24.Obj);
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd30.uLng) == 1)
    goto label_17;
  INVOKE_PRIMITIVE ((current_block [OBJECT_12_1]), 2);

DEFLABEL (label_17)
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  ((Wrd27.pObj) [1]) = (Wrd24.Obj);
  Rsp = (& (Rsp [3]));
  goto label_15;

DEFLABEL (label_18)
  (Wrd34.Obj) = (Rsp [0]);
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if (! ((Wrd35.uLng) == 1))
    goto label_20;
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd31.Obj) = ((Wrd33.pObj) [1]);

DEFLABEL (label_19)
  (Rsp [0]) = (Wrd31.Obj);
  goto loop_6;

DEFLABEL (label_20)
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_7]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_12_0]), 1);

DEFLABEL (label_11)
  (Wrd31.Obj) = Rvl;
  goto label_19;

DEFLABEL (label_22)
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12_6]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_12_0]), 1);

DEFLABEL (label_10)
  (Wrd13.Obj) = Rvl;
  goto label_21;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_13_4 3
#define LABEL_13_5 5
#define LABEL_13_7 7
#define LABEL_13_8 9
#define LABEL_13_9 11
#define ENVIRONMENT_LABEL_13_3 20
#define DEBUGGING_LABEL_13_2 19
#define OBJECT_13_3 18
#define OBJECT_13_2 17
#define OBJECT_13_1 16
#define OBJECT_13_0 15
#define EXECUTE_CACHE_13_6 13
#define FREE_REFERENCES_LABEL_13_0 12
#define NUMBER_OF_LINKER_SECTIONS_13_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_13 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd32;
  machine_word Wrd29;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd12;
  machine_word Wrd10;
  machine_word Wrd34;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd22;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_13_4);
      goto make_circular_list_15;

    case 1:
      current_block = (Rpc - LABEL_13_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_13_7);
      goto loop_11;

    case 3:
      current_block = (Rpc - LABEL_13_8);
      goto label_17;

    case 4:
      current_block = (Rpc - LABEL_13_9);
      goto label_18;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (make_circular_list_20)
DEFLABEL (make_circular_list_15)
  INTERRUPT_CHECK (26, LABEL_13_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_13_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_13_5);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.Lng) = (FIXNUM_TO_LONG (Wrd5.Obj));
  if ((Wrd6.Lng) > 0)
    goto label_22;
  Rvl = (current_block [OBJECT_13_2]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_22)
  (Wrd9.Obj) = (Rsp [1]);
  if ((Wrd9.Obj) == (current_block [OBJECT_13_1]))
    goto label_24;
  (* (--Rsp)) = (Wrd9.Obj);
  goto label_23;

DEFLABEL (label_24)
  (Wrd22.Obj) = (current_block [OBJECT_13_2]);
  (* (--Rsp)) = (Wrd22.Obj);

DEFLABEL (label_23)
DEFLABEL (label_25)
  (Wrd15.Obj) = (Rsp [0]);
  (Wrd16.Obj) = (current_block [OBJECT_13_2]);
  (* (Rhp++)) = (Wrd15.Obj);
  (* (Rhp++)) = (Wrd16.Obj);
  (Wrd13.pObj) = (& (Rhp [-2]));
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd13.pObj)));
  (* (--Rsp)) = (Wrd14.Obj);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd18.Obj) = (Rsp [3]);
  (Wrd19.Lng) = (FIXNUM_TO_LONG (Wrd18.Obj));
  (Wrd20.Lng) = ((Wrd19.Lng) - 1L);
  (Wrd21.Obj) = (LONG_TO_FIXNUM (Wrd20.Lng));
  (* (--Rsp)) = (Wrd21.Obj);
  goto loop_11;

DEFLABEL (loop_21)
DEFLABEL (loop_11)
  INTERRUPT_CHECK (26, LABEL_13_7);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd6.uLng) == 26))
    goto label_30;
  (Wrd34.Lng) = (FIXNUM_TO_LONG (Wrd5.Obj));
  if ((Wrd34.Lng) == 0)
    goto label_27;

DEFLABEL (label_26)
  (Wrd13.Obj) = (Rsp [0]);
  (Wrd14.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  (Wrd15.Lng) = ((Wrd14.Lng) - 1L);
  (Wrd12.Obj) = (LONG_TO_FIXNUM (Wrd15.Lng));
  (Rsp [0]) = (Wrd12.Obj);
  (Wrd19.Obj) = (Rsp [3]);
  (Wrd20.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd19.Obj);
  (* (Rhp++)) = (Wrd20.Obj);
  (Wrd18.pObj) = (& (Rhp [-2]));
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd18.pObj)));
  (Rsp [1]) = (Wrd16.Obj);
  goto loop_11;

DEFLABEL (label_27)
  (Wrd26.Obj) = (Rsp [2]);
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if (! ((Wrd27.uLng) == 1))
    goto label_29;
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd25.Obj) = (Rsp [1]);
  ((Wrd24.pObj) [1]) = (Wrd25.Obj);

DEFLABEL (label_28)
  Rvl = (Rsp [1]);
  Rsp = (& (Rsp [6]));
  goto pop_return;

DEFLABEL (label_29)
  (Wrd29.Obj) = (Rsp [1]);
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_9]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_13_3]), 2);

DEFLABEL (label_18)
  goto label_28;

DEFLABEL (label_30)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_8]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_INTERFACE_0 (45);

DEFLABEL (label_17)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_26;
  goto label_27;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_14_4 3
#define LABEL_14_5 5
#define LABEL_14_7 7
#define LABEL_14_8 9
#define ENVIRONMENT_LABEL_14_3 16
#define DEBUGGING_LABEL_14_2 15
#define OBJECT_14_1 14
#define OBJECT_14_0 13
#define EXECUTE_CACHE_14_6 11
#define FREE_REFERENCES_LABEL_14_0 10
#define NUMBER_OF_LINKER_SECTIONS_14_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_14 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_14_4);
      goto make_initialized_list_9;

    case 1:
      current_block = (Rpc - LABEL_14_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_14_7);
      goto loop_7;

    case 3:
      current_block = (Rpc - LABEL_14_8);
      goto continuation_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (make_initialized_list_12)
DEFLABEL (make_initialized_list_9)
  INTERRUPT_CHECK (26, LABEL_14_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_14_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_14_5);
  (Wrd5.Obj) = (current_block [OBJECT_14_1]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (Wrd7.Lng) = (FIXNUM_TO_LONG (Wrd6.Obj));
  (Wrd8.Lng) = ((Wrd7.Lng) - 1L);
  (Wrd9.Obj) = (LONG_TO_FIXNUM (Wrd8.Lng));
  (* (--Rsp)) = (Wrd9.Obj);
  goto loop_7;

DEFLABEL (loop_13)
DEFLABEL (loop_7)
  INTERRUPT_CHECK (26, LABEL_14_7);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.Lng) = (FIXNUM_TO_LONG (Wrd5.Obj));
  if (! ((Wrd6.Lng) < 0))
    goto label_14;
  Rvl = (Rsp [1]);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_14)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_8]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd11.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd11.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_14_8);
  (Wrd9.Obj) = (Rsp [1]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd11.Obj) = (Rsp [0]);
  (Wrd12.Lng) = (FIXNUM_TO_LONG (Wrd11.Obj));
  (Wrd13.Lng) = ((Wrd12.Lng) - 1L);
  (Wrd10.Obj) = (LONG_TO_FIXNUM (Wrd13.Lng));
  (Rsp [0]) = (Wrd10.Obj);
  goto loop_7;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_15_4 3
#define ENVIRONMENT_LABEL_15_3 5
#define DEBUGGING_LABEL_15_2 4
#define FREE_REFERENCES_LABEL_15_0 4
#define NUMBER_OF_LINKER_SECTIONS_15_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_15 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd7;
  machine_word Wrd10;
  machine_word Wrd9;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_15_4);
      goto xcons_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (xcons_3)
DEFLABEL (xcons_0)
  INTERRUPT_CHECK (26, LABEL_15_4);
  (Wrd9.Obj) = (Rsp [1]);
  (Wrd10.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_16_4 3
#define LABEL_16_7 5
#define LABEL_16_8 7
#define LABEL_16_5 9
#define LABEL_16_9 11
#define TAG_16_10 4
#define LABEL_16_13 13
#define ENVIRONMENT_LABEL_16_3 26
#define DEBUGGING_LABEL_16_2 25
#define OBJECT_16_3 24
#define OBJECT_16_2 23
#define OBJECT_16_1 22
#define OBJECT_16_0 21
#define EXECUTE_CACHE_16_12 15
#define EXECUTE_CACHE_16_11 17
#define EXECUTE_CACHE_16_6 19
#define FREE_REFERENCES_LABEL_16_0 14
#define NUMBER_OF_LINKER_SECTIONS_16_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_16 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd34;
  machine_word Wrd38;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd11;
  machine_word Wrd6;
  machine_word Wrd19;
  machine_word Wrd25;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd10;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd26;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd23;
  machine_word Wrd24;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd5;
  machine_word Wrd30;
  machine_word Wrd31;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_16_4);
      goto iota_10;

    case 1:
      current_block = (Rpc - LABEL_16_7);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_16_8);
      goto continuation_6;

    case 3:
      current_block = (Rpc - LABEL_16_5);
      goto continuation_0;

    case 4:
      current_block = (Rpc - LABEL_16_9);
      goto lambda_15;

    case 5:
      current_block = (Rpc - LABEL_16_13);
      goto label_12;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (iota_14)
DEFLABEL (iota_10)
  INTERRUPT_CHECK (26, LABEL_16_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_16_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_16_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_16_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_16_5);
  (Wrd5.Obj) = (Rsp [2]);
  if ((Wrd5.Obj) == (current_block [OBJECT_16_1]))
    goto label_19;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_16_8]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_16_0]);
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_16_12]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_16_8);
  (Wrd30.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd30.Obj);

DEFLABEL (label_18)
  (Wrd13.Obj) = (Rsp [2]);
  if ((Wrd13.Obj) == (current_block [OBJECT_16_1]))
    goto label_17;
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_16_7]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd18.Obj) = (current_block [OBJECT_16_0]);
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_16_12]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_16_7);
  (Wrd31.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd31.Obj);

DEFLABEL (label_16)
  (Wrd21.Obj) = (Rsp [2]);
  (Rsp [3]) = (Wrd21.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd24.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_16_10);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_16_9])));
  Rhp += 2;
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd24.pObj)));
  Wrd27 = Wrd24;
  (Wrd28.Obj) = (Rsp [1]);
  ((Wrd27.pObj) [2]) = (Wrd28.Obj);
  (Wrd26.Obj) = (Rsp [0]);
  ((Wrd27.pObj) [3]) = (Wrd26.Obj);
  (Rsp [4]) = (Wrd23.Obj);
  Rsp = (& (Rsp [3]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_16_11]));

DEFLABEL (label_17)
  (Wrd20.Obj) = (current_block [OBJECT_16_3]);
  (* (--Rsp)) = (Wrd20.Obj);
  goto label_16;

DEFLABEL (label_19)
  (Wrd12.Obj) = (current_block [OBJECT_16_2]);
  (* (--Rsp)) = (Wrd12.Obj);
  goto label_18;

DEFLABEL (lambda_15)
  CLOSURE_HEADER (LABEL_16_9);

DEFLABEL (lambda_8)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd13.Obj) = (Rsp [1]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd14.uLng) == 26))
    goto label_23;
  (Wrd15.Obj) = (Rsp [0]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [2]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 26))
    goto label_23;
  (Wrd21.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  (Wrd25.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (multiply_with_overflow ((Wrd21.Lng), (Wrd25.Lng), (& (Wrd19.Lng))))
    goto label_23;
  (Wrd12.Obj) = (LONG_TO_FIXNUM (Wrd19.Lng));

DEFLABEL (label_22)
  (Rsp [1]) = (Wrd12.Obj);
  (Wrd27.Obj) = (Rsp [0]);
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd26.Obj) = ((Wrd28.pObj) [3]);
  (Rsp [0]) = (Wrd26.Obj);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if ((Wrd31.uLng) == 26)
    goto label_21;

DEFLABEL (label_20)
  INVOKE_INTERFACE_0 (43);

DEFLABEL (label_21)
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd33.uLng) == 26))
    goto label_20;
  (Wrd36.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  (Wrd38.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  (Wrd34.Lng) = ((Wrd36.Lng) + (Wrd38.Lng));
  if (! (LONG_TO_FIXNUM_P (Wrd34.Lng)))
    goto label_20;
  Rvl = (LONG_TO_FIXNUM (Wrd34.Lng));
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_23)
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [2]);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_16_13]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (* (--Rsp)) = (Wrd6.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_INTERFACE_0 (41);

DEFLABEL (label_12)
  (Wrd12.Obj) = Rvl;
  goto label_22;

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_17_4 3
#define LABEL_17_5 5
#define LABEL_17_6 7
#define LABEL_17_7 9
#define LABEL_17_8 11
#define ENVIRONMENT_LABEL_17_3 16
#define DEBUGGING_LABEL_17_2 15
#define OBJECT_17_2 14
#define OBJECT_17_1 13
#define OBJECT_17_0 12
#define FREE_REFERENCES_LABEL_17_0 12
#define NUMBER_OF_LINKER_SECTIONS_17_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_17 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd47;
  machine_word Wrd39;
  machine_word Wrd41;
  machine_word Wrd43;
  machine_word Wrd42;
  machine_word Wrd38;
  machine_word Wrd30;
  machine_word Wrd32;
  machine_word Wrd24;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_17_4);
      goto listP_10;

    case 1:
      current_block = (Rpc - LABEL_17_5);
      goto loop_8;

    case 2:
      current_block = (Rpc - LABEL_17_6);
      goto label_12;

    case 3:
      current_block = (Rpc - LABEL_17_7);
      goto label_13;

    case 4:
      current_block = (Rpc - LABEL_17_8);
      goto label_14;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (listP_16)
DEFLABEL (listP_10)
  INTERRUPT_CHECK (26, LABEL_17_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  goto loop_8;

DEFLABEL (loop_17)
DEFLABEL (loop_8)
  INTERRUPT_CHECK (26, LABEL_17_5);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_21;
  if ((Wrd5.Obj) == (current_block [OBJECT_17_1]))
    goto label_19;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_18;

DEFLABEL (label_19)
  Rvl = (current_block [OBJECT_17_2]);

DEFLABEL (label_18)
DEFLABEL (label_20)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_21)
  if (! ((Wrd6.uLng) == 1))
    goto label_32;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [1]);
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_31)
  (Wrd21.Obj) = (Rsp [0]);
  (Wrd22.Obj) = (Rsp [2]);
  if ((Wrd21.Obj) == (Wrd22.Obj))
    goto label_24;
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if ((Wrd24.uLng) == 1)
    goto label_26;
  if ((Wrd21.Obj) == (current_block [OBJECT_17_1]))
    goto label_23;

DEFLABEL (label_24)
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_22;

DEFLABEL (label_23)
  Rvl = (current_block [OBJECT_17_2]);

DEFLABEL (label_22)
DEFLABEL (label_25)
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_26)
  if (! ((Wrd24.uLng) == 1))
    goto label_30;
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd30.Obj) = ((Wrd32.pObj) [1]);

DEFLABEL (label_29)
  (Rsp [1]) = (Wrd30.Obj);
  (Wrd42.Obj) = (Rsp [2]);
  (Wrd43.uLng) = (OBJECT_TYPE (Wrd42.Obj));
  if (! ((Wrd43.uLng) == 1))
    goto label_28;
  (Wrd41.pObj) = (OBJECT_ADDRESS (Wrd42.Obj));
  (Wrd39.Obj) = ((Wrd41.pObj) [1]);

DEFLABEL (label_27)
  (Rsp [2]) = (Wrd39.Obj);
  Rsp = (& (Rsp [1]));
  goto loop_8;

DEFLABEL (label_28)
  (Wrd47.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_8]))));
  (* (--Rsp)) = (Wrd47.Obj);
  (* (--Rsp)) = (Wrd42.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_17_0]), 1);

DEFLABEL (label_14)
  (Wrd39.Obj) = Rvl;
  goto label_27;

DEFLABEL (label_30)
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_7]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_17_0]), 1);

DEFLABEL (label_13)
  (Wrd30.Obj) = Rvl;
  goto label_29;

DEFLABEL (label_32)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_6]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_17_0]), 1);

DEFLABEL (label_12)
  (* (--Rsp)) = Rvl;
  goto label_31;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_18_4 3
#define LABEL_18_5 5
#define LABEL_18_6 7
#define LABEL_18_7 9
#define LABEL_18_8 11
#define ENVIRONMENT_LABEL_18_3 16
#define DEBUGGING_LABEL_18_2 15
#define OBJECT_18_2 14
#define OBJECT_18_1 13
#define OBJECT_18_0 12
#define FREE_REFERENCES_LABEL_18_0 12
#define NUMBER_OF_LINKER_SECTIONS_18_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_18 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd49;
  machine_word Wrd41;
  machine_word Wrd43;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd40;
  machine_word Wrd32;
  machine_word Wrd34;
  machine_word Wrd25;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_18_4);
      goto dotted_listP_12;

    case 1:
      current_block = (Rpc - LABEL_18_5);
      goto loop_10;

    case 2:
      current_block = (Rpc - LABEL_18_6);
      goto label_14;

    case 3:
      current_block = (Rpc - LABEL_18_7);
      goto label_15;

    case 4:
      current_block = (Rpc - LABEL_18_8);
      goto label_16;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (dotted_listP_18)
DEFLABEL (dotted_listP_12)
  INTERRUPT_CHECK (26, LABEL_18_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  goto loop_10;

DEFLABEL (loop_19)
DEFLABEL (loop_10)
  INTERRUPT_CHECK (26, LABEL_18_5);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_23;
  if ((Wrd5.Obj) == (current_block [OBJECT_18_1]))
    goto label_21;
  Rvl = (current_block [OBJECT_18_2]);
  goto label_20;

DEFLABEL (label_21)
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_20)
DEFLABEL (label_22)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_23)
  if (! ((Wrd6.uLng) == 1))
    goto label_33;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [1]);
  (* (--Rsp)) = (Wrd15.Obj);

DEFLABEL (label_32)
  (Wrd22.Obj) = (Rsp [0]);
  (Wrd23.Obj) = (Rsp [2]);
  if ((Wrd22.Obj) == (Wrd23.Obj))
    goto label_25;
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if ((Wrd25.uLng) == 1)
    goto label_27;
  if ((Wrd22.Obj) == (current_block [OBJECT_18_1]))
    goto label_25;
  Rvl = (current_block [OBJECT_18_2]);
  goto label_24;

DEFLABEL (label_25)
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_24)
DEFLABEL (label_26)
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_27)
  if (! ((Wrd25.uLng) == 1))
    goto label_31;
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
  (Wrd32.Obj) = ((Wrd34.pObj) [1]);

DEFLABEL (label_30)
  (Rsp [1]) = (Wrd32.Obj);
  (Wrd44.Obj) = (Rsp [2]);
  (Wrd45.uLng) = (OBJECT_TYPE (Wrd44.Obj));
  if (! ((Wrd45.uLng) == 1))
    goto label_29;
  (Wrd43.pObj) = (OBJECT_ADDRESS (Wrd44.Obj));
  (Wrd41.Obj) = ((Wrd43.pObj) [1]);

DEFLABEL (label_28)
  (Rsp [2]) = (Wrd41.Obj);
  Rsp = (& (Rsp [1]));
  goto loop_10;

DEFLABEL (label_29)
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_8]))));
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd44.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_18_0]), 1);

DEFLABEL (label_16)
  (Wrd41.Obj) = Rvl;
  goto label_28;

DEFLABEL (label_31)
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_7]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_18_0]), 1);

DEFLABEL (label_15)
  (Wrd32.Obj) = Rvl;
  goto label_30;

DEFLABEL (label_33)
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_6]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_18_0]), 1);

DEFLABEL (label_14)
  (* (--Rsp)) = Rvl;
  goto label_32;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_19_4 3
#define LABEL_19_5 5
#define LABEL_19_6 7
#define LABEL_19_7 9
#define LABEL_19_8 11
#define ENVIRONMENT_LABEL_19_3 15
#define DEBUGGING_LABEL_19_2 14
#define OBJECT_19_1 13
#define OBJECT_19_0 12
#define FREE_REFERENCES_LABEL_19_0 12
#define NUMBER_OF_LINKER_SECTIONS_19_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_19 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd41;
  machine_word Wrd33;
  machine_word Wrd35;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd32;
  machine_word Wrd24;
  machine_word Wrd26;
  machine_word Wrd21;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_19_4);
      goto circular_listP_10;

    case 1:
      current_block = (Rpc - LABEL_19_5);
      goto loop_8;

    case 2:
      current_block = (Rpc - LABEL_19_6);
      goto label_12;

    case 3:
      current_block = (Rpc - LABEL_19_7);
      goto label_13;

    case 4:
      current_block = (Rpc - LABEL_19_8);
      goto label_14;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (circular_listP_16)
DEFLABEL (circular_listP_10)
  INTERRUPT_CHECK (26, LABEL_19_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  goto loop_8;

DEFLABEL (loop_17)
DEFLABEL (loop_8)
  INTERRUPT_CHECK (26, LABEL_19_5);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_18;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_18)
  if (! ((Wrd6.uLng) == 1))
    goto label_27;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [1]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_26)
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.Obj) = (Rsp [2]);
  if ((Wrd18.Obj) == (Wrd19.Obj))
    goto label_25;
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd21.uLng) == 1)
    goto label_20;
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_19)
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_20)
  if (! ((Wrd21.uLng) == 1))
    goto label_24;
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd24.Obj) = ((Wrd26.pObj) [1]);

DEFLABEL (label_23)
  (Rsp [1]) = (Wrd24.Obj);
  (Wrd36.Obj) = (Rsp [2]);
  (Wrd37.uLng) = (OBJECT_TYPE (Wrd36.Obj));
  if (! ((Wrd37.uLng) == 1))
    goto label_22;
  (Wrd35.pObj) = (OBJECT_ADDRESS (Wrd36.Obj));
  (Wrd33.Obj) = ((Wrd35.pObj) [1]);

DEFLABEL (label_21)
  (Rsp [2]) = (Wrd33.Obj);
  Rsp = (& (Rsp [1]));
  goto loop_8;

DEFLABEL (label_22)
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_8]))));
  (* (--Rsp)) = (Wrd41.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_19_0]), 1);

DEFLABEL (label_14)
  (Wrd33.Obj) = Rvl;
  goto label_21;

DEFLABEL (label_24)
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_7]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_19_0]), 1);

DEFLABEL (label_13)
  (Wrd24.Obj) = Rvl;
  goto label_23;

DEFLABEL (label_25)
  Rvl = (current_block [OBJECT_19_1]);
  goto label_19;

DEFLABEL (label_27)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_6]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_19_0]), 1);

DEFLABEL (label_12)
  (* (--Rsp)) = Rvl;
  goto label_26;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_20_4 3
#define ENVIRONMENT_LABEL_20_3 9
#define DEBUGGING_LABEL_20_2 8
#define OBJECT_20_0 7
#define EXECUTE_CACHE_20_5 5
#define FREE_REFERENCES_LABEL_20_0 4
#define NUMBER_OF_LINKER_SECTIONS_20_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_20 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_20_4);
      goto guarantee_pair_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (guarantee_pair_4)
DEFLABEL (guarantee_pair_1)
  INTERRUPT_CHECK (26, LABEL_20_4);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_5;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_5]));

DEFLABEL (label_5)
  Rvl = (current_block [OBJECT_20_0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_21_4 3
#define ENVIRONMENT_LABEL_21_3 11
#define DEBUGGING_LABEL_21_2 10
#define OBJECT_21_2 9
#define OBJECT_21_1 8
#define OBJECT_21_0 7
#define EXECUTE_CACHE_21_5 5
#define FREE_REFERENCES_LABEL_21_0 4
#define NUMBER_OF_LINKER_SECTIONS_21_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_21 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_21_4);
      goto error_not_pair_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (error_not_pair_5)
DEFLABEL (error_not_pair_2)
  INTERRUPT_CHECK (26, LABEL_21_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_21_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [2]);
  if ((Wrd7.Obj) == (current_block [OBJECT_21_1]))
    goto label_7;
  Wrd9 = Wrd7;
  goto label_6;

DEFLABEL (label_7)
  (Wrd9.Obj) = (current_block [OBJECT_21_2]);

DEFLABEL (label_6)
DEFLABEL (label_8)
  (Rsp [2]) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_22_4 3
#define LABEL_22_5 5
#define ENVIRONMENT_LABEL_22_3 13
#define DEBUGGING_LABEL_22_2 12
#define OBJECT_22_0 11
#define EXECUTE_CACHE_22_7 7
#define EXECUTE_CACHE_22_6 9
#define FREE_REFERENCES_LABEL_22_0 6
#define NUMBER_OF_LINKER_SECTIONS_22_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_22 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_22_4);
      goto guarantee_list_1;

    case 1:
      current_block = (Rpc - LABEL_22_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (guarantee_list_4)
DEFLABEL (guarantee_list_1)
  INTERRUPT_CHECK (26, LABEL_22_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_22_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_22_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_5;
  Rvl = (current_block [OBJECT_22_0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_5)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_22_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_23_4 3
#define ENVIRONMENT_LABEL_23_3 11
#define DEBUGGING_LABEL_23_2 10
#define OBJECT_23_2 9
#define OBJECT_23_1 8
#define OBJECT_23_0 7
#define EXECUTE_CACHE_23_5 5
#define FREE_REFERENCES_LABEL_23_0 4
#define NUMBER_OF_LINKER_SECTIONS_23_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_23 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_23_4);
      goto error_not_list_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (error_not_list_5)
DEFLABEL (error_not_list_2)
  INTERRUPT_CHECK (26, LABEL_23_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_23_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [2]);
  if ((Wrd7.Obj) == (current_block [OBJECT_23_1]))
    goto label_7;
  Wrd9 = Wrd7;
  goto label_6;

DEFLABEL (label_7)
  (Wrd9.Obj) = (current_block [OBJECT_23_2]);

DEFLABEL (label_6)
DEFLABEL (label_8)
  (Rsp [2]) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_23_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_24_4 3
#define LABEL_24_5 5
#define ENVIRONMENT_LABEL_24_3 13
#define DEBUGGING_LABEL_24_2 12
#define OBJECT_24_0 11
#define EXECUTE_CACHE_24_7 7
#define EXECUTE_CACHE_24_6 9
#define FREE_REFERENCES_LABEL_24_0 6
#define NUMBER_OF_LINKER_SECTIONS_24_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_24 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_24_4);
      goto guarantee_dotted_list_1;

    case 1:
      current_block = (Rpc - LABEL_24_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (guarantee_dotted_list_4)
DEFLABEL (guarantee_dotted_list_1)
  INTERRUPT_CHECK (26, LABEL_24_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_24_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_24_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_5;
  Rvl = (current_block [OBJECT_24_0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_5)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_24_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_25_4 3
#define ENVIRONMENT_LABEL_25_3 11
#define DEBUGGING_LABEL_25_2 10
#define OBJECT_25_2 9
#define OBJECT_25_1 8
#define OBJECT_25_0 7
#define EXECUTE_CACHE_25_5 5
#define FREE_REFERENCES_LABEL_25_0 4
#define NUMBER_OF_LINKER_SECTIONS_25_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_25 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_25_4);
      goto error_not_dotted_list_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (error_not_dotted_list_5)
DEFLABEL (error_not_dotted_list_2)
  INTERRUPT_CHECK (26, LABEL_25_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_25_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [2]);
  if ((Wrd7.Obj) == (current_block [OBJECT_25_1]))
    goto label_7;
  Wrd9 = Wrd7;
  goto label_6;

DEFLABEL (label_7)
  (Wrd9.Obj) = (current_block [OBJECT_25_2]);

DEFLABEL (label_6)
DEFLABEL (label_8)
  (Rsp [2]) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_25_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_26_4 3
#define LABEL_26_5 5
#define ENVIRONMENT_LABEL_26_3 13
#define DEBUGGING_LABEL_26_2 12
#define OBJECT_26_0 11
#define EXECUTE_CACHE_26_7 7
#define EXECUTE_CACHE_26_6 9
#define FREE_REFERENCES_LABEL_26_0 6
#define NUMBER_OF_LINKER_SECTIONS_26_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_26 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_26_4);
      goto guarantee_circular_list_1;

    case 1:
      current_block = (Rpc - LABEL_26_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (guarantee_circular_list_4)
DEFLABEL (guarantee_circular_list_1)
  INTERRUPT_CHECK (26, LABEL_26_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_26_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_26_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_5;
  Rvl = (current_block [OBJECT_26_0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_5)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_26_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_27_4 3
#define ENVIRONMENT_LABEL_27_3 11
#define DEBUGGING_LABEL_27_2 10
#define OBJECT_27_2 9
#define OBJECT_27_1 8
#define OBJECT_27_0 7
#define EXECUTE_CACHE_27_5 5
#define FREE_REFERENCES_LABEL_27_0 4
#define NUMBER_OF_LINKER_SECTIONS_27_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_27 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_27_4);
      goto error_not_circular_list_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (error_not_circular_list_5)
DEFLABEL (error_not_circular_list_2)
  INTERRUPT_CHECK (26, LABEL_27_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_27_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [2]);
  if ((Wrd7.Obj) == (current_block [OBJECT_27_1]))
    goto label_7;
  Wrd9 = Wrd7;
  goto label_6;

DEFLABEL (label_7)
  (Wrd9.Obj) = (current_block [OBJECT_27_2]);

DEFLABEL (label_6)
DEFLABEL (label_8)
  (Rsp [2]) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_27_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_28_4 3
#define LABEL_28_5 5
#define LABEL_28_7 7
#define LABEL_28_6 9
#define LABEL_28_8 11
#define LABEL_28_10 13
#define LABEL_28_9 15
#define LABEL_28_11 17
#define LABEL_28_12 19
#define ENVIRONMENT_LABEL_28_3 25
#define DEBUGGING_LABEL_28_2 24
#define OBJECT_28_3 23
#define OBJECT_28_2 22
#define OBJECT_28_1 21
#define OBJECT_28_0 20
#define FREE_REFERENCES_LABEL_28_0 20
#define NUMBER_OF_LINKER_SECTIONS_28_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_28 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd18;
  machine_word Wrd20;
  machine_word Wrd7;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd27;
  machine_word Wrd19;
  machine_word Wrd15;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd14;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_28_4);
      goto list_of_typeP_14;

    case 1:
      current_block = (Rpc - LABEL_28_5);
      goto loop_12;

    case 2:
      current_block = (Rpc - LABEL_28_7);
      goto label_16;

    case 3:
      current_block = (Rpc - LABEL_28_6);
      goto continuation_3;

    case 4:
      current_block = (Rpc - LABEL_28_8);
      goto label_17;

    case 5:
      current_block = (Rpc - LABEL_28_10);
      goto label_18;

    case 6:
      current_block = (Rpc - LABEL_28_9);
      goto continuation_8;

    case 7:
      current_block = (Rpc - LABEL_28_11);
      goto label_19;

    case 8:
      current_block = (Rpc - LABEL_28_12);
      goto label_20;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (list_of_typeP_22)
DEFLABEL (list_of_typeP_14)
  INTERRUPT_CHECK (26, LABEL_28_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  goto loop_12;

DEFLABEL (loop_23)
DEFLABEL (loop_12)
  INTERRUPT_CHECK (26, LABEL_28_5);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_27;
  if ((Wrd5.Obj) == (current_block [OBJECT_28_1]))
    goto label_25;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_24;

DEFLABEL (label_25)
  Rvl = (current_block [OBJECT_28_2]);

DEFLABEL (label_24)
DEFLABEL (label_26)
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_27)
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_28_6]))));
  (* (--Rsp)) = (Wrd14.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_44;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (* (--Rsp)) = (Wrd17.Obj);

DEFLABEL (label_43)
  (Wrd24.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd24.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_28_6);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_28;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_28)
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_42;
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [1]);
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_41)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (Rsp [2]);
  if ((Wrd16.Obj) == (Wrd17.Obj))
    goto label_31;
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd19.uLng) == 1)
    goto label_33;
  if ((Wrd16.Obj) == (current_block [OBJECT_28_1]))
    goto label_30;

DEFLABEL (label_31)
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_29;

DEFLABEL (label_30)
  Rvl = (current_block [OBJECT_28_2]);

DEFLABEL (label_29)
DEFLABEL (label_32)
  Rsp = (& (Rsp [5]));
  goto pop_return;

DEFLABEL (label_33)
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_28_9]))));
  (* (--Rsp)) = (Wrd27.Obj);
  if (! ((Wrd19.uLng) == 1))
    goto label_40;
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd30.Obj) = ((Wrd29.pObj) [0]);
  (* (--Rsp)) = (Wrd30.Obj);

DEFLABEL (label_39)
  (Wrd37.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd37.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_28_9);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_34;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [5]));
  goto pop_return;

DEFLABEL (label_34)
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_38;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_37)
  (Rsp [1]) = (Wrd7.Obj);
  (Wrd19.Obj) = (Rsp [2]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 1))
    goto label_36;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd16.Obj) = ((Wrd18.pObj) [1]);

DEFLABEL (label_35)
  (Rsp [2]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  goto loop_12;

DEFLABEL (label_36)
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_28_12]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_28_3]), 1);

DEFLABEL (label_20)
  (Wrd16.Obj) = Rvl;
  goto label_35;

DEFLABEL (label_38)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_28_11]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_28_3]), 1);

DEFLABEL (label_19)
  (Wrd7.Obj) = Rvl;
  goto label_37;

DEFLABEL (label_40)
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_28_10]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_28_0]), 1);

DEFLABEL (label_18)
  (* (--Rsp)) = Rvl;
  goto label_39;

DEFLABEL (label_42)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_28_8]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_28_3]), 1);

DEFLABEL (label_17)
  (* (--Rsp)) = Rvl;
  goto label_41;

DEFLABEL (label_44)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_28_7]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_28_0]), 1);

DEFLABEL (label_16)
  (* (--Rsp)) = Rvl;
  goto label_43;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_29_4 3
#define LABEL_29_5 5
#define ENVIRONMENT_LABEL_29_3 14
#define DEBUGGING_LABEL_29_2 13
#define OBJECT_29_1 12
#define OBJECT_29_0 11
#define EXECUTE_CACHE_29_7 7
#define EXECUTE_CACHE_29_6 9
#define FREE_REFERENCES_LABEL_29_0 6
#define NUMBER_OF_LINKER_SECTIONS_29_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_29 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd12;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_29_4);
      goto guarantee_list_of_type_3;

    case 1:
      current_block = (Rpc - LABEL_29_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (guarantee_list_of_type_6)
DEFLABEL (guarantee_list_of_type_3)
  INTERRUPT_CHECK (26, LABEL_29_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_29_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_29_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_29_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_7;
  Rvl = (current_block [OBJECT_29_1]);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_7)
  (Wrd9.Obj) = (Rsp [0]);
  (Rsp [1]) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  if ((Wrd10.Obj) == (current_block [OBJECT_29_0]))
    goto label_9;
  Wrd12 = Wrd10;
  goto label_8;

DEFLABEL (label_9)
  (Wrd12.Obj) = ((SCHEME_OBJECT) 0);

DEFLABEL (label_8)
DEFLABEL (label_10)
  (Rsp [3]) = (Wrd12.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_29_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_30_4 3
#define LABEL_30_5 5
#define LABEL_30_6 7
#define LABEL_30_7 9
#define LABEL_30_8 11
#define ENVIRONMENT_LABEL_30_3 16
#define DEBUGGING_LABEL_30_2 15
#define OBJECT_30_2 14
#define OBJECT_30_1 13
#define OBJECT_30_0 12
#define FREE_REFERENCES_LABEL_30_0 12
#define NUMBER_OF_LINKER_SECTIONS_30_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_30 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd53;
  machine_word Wrd58;
  machine_word Wrd55;
  machine_word Wrd54;
  machine_word Wrd52;
  machine_word Wrd44;
  machine_word Wrd46;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd43;
  machine_word Wrd35;
  machine_word Wrd37;
  machine_word Wrd25;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd6;
  machine_word Wrd7;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_30_4);
      goto listP__length_13;

    case 1:
      current_block = (Rpc - LABEL_30_5);
      goto loop_11;

    case 2:
      current_block = (Rpc - LABEL_30_6);
      goto label_15;

    case 3:
      current_block = (Rpc - LABEL_30_7);
      goto label_16;

    case 4:
      current_block = (Rpc - LABEL_30_8);
      goto label_17;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (listP__length_19)
DEFLABEL (listP__length_13)
  INTERRUPT_CHECK (26, LABEL_30_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd7.Obj) = (current_block [OBJECT_30_0]);
  (Rsp [2]) = (Wrd7.Obj);
  goto loop_11;

DEFLABEL (loop_20)
DEFLABEL (loop_11)
  INTERRUPT_CHECK (26, LABEL_30_5);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_24;
  if ((Wrd5.Obj) == (current_block [OBJECT_30_2]))
    goto label_22;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_21;

DEFLABEL (label_22)
  Rvl = (Rsp [2]);

DEFLABEL (label_21)
DEFLABEL (label_23)
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_24)
  if (! ((Wrd6.uLng) == 1))
    goto label_35;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [1]);
  (* (--Rsp)) = (Wrd15.Obj);

DEFLABEL (label_34)
  (Wrd22.Obj) = (Rsp [0]);
  (Wrd23.Obj) = (Rsp [2]);
  if ((Wrd22.Obj) == (Wrd23.Obj))
    goto label_27;
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if ((Wrd25.uLng) == 1)
    goto label_29;
  if ((Wrd22.Obj) == (current_block [OBJECT_30_2]))
    goto label_26;

DEFLABEL (label_27)
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_25;

DEFLABEL (label_26)
  (Wrd31.Obj) = (Rsp [3]);
  (Wrd32.Lng) = (FIXNUM_TO_LONG (Wrd31.Obj));
  (Wrd33.Lng) = ((Wrd32.Lng) + 1L);
  Rvl = (LONG_TO_FIXNUM (Wrd33.Lng));

DEFLABEL (label_25)
DEFLABEL (label_28)
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_29)
  if (! ((Wrd25.uLng) == 1))
    goto label_33;
  (Wrd37.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
  (Wrd35.Obj) = ((Wrd37.pObj) [1]);

DEFLABEL (label_32)
  (Rsp [1]) = (Wrd35.Obj);
  (Wrd47.Obj) = (Rsp [2]);
  (Wrd48.uLng) = (OBJECT_TYPE (Wrd47.Obj));
  if (! ((Wrd48.uLng) == 1))
    goto label_31;
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  (Wrd44.Obj) = ((Wrd46.pObj) [1]);

DEFLABEL (label_30)
  (Rsp [2]) = (Wrd44.Obj);
  (Wrd54.Obj) = (Rsp [3]);
  (Wrd55.Lng) = (FIXNUM_TO_LONG (Wrd54.Obj));
  (Wrd58.Lng) = ((Wrd55.Lng) + 2L);
  (Wrd53.Obj) = (LONG_TO_FIXNUM (Wrd58.Lng));
  (Rsp [3]) = (Wrd53.Obj);
  Rsp = (& (Rsp [1]));
  goto loop_11;

DEFLABEL (label_31)
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30_8]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (* (--Rsp)) = (Wrd47.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_30_1]), 1);

DEFLABEL (label_17)
  (Wrd44.Obj) = Rvl;
  goto label_30;

DEFLABEL (label_33)
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30_7]))));
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_30_1]), 1);

DEFLABEL (label_16)
  (Wrd35.Obj) = Rvl;
  goto label_32;

DEFLABEL (label_35)
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30_6]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_30_1]), 1);

DEFLABEL (label_15)
  (* (--Rsp)) = Rvl;
  goto label_34;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_31_4 3
#define LABEL_31_5 5
#define LABEL_31_7 7
#define LABEL_31_6 9
#define LABEL_31_8 11
#define LABEL_31_10 13
#define LABEL_31_9 15
#define LABEL_31_11 17
#define LABEL_31_12 19
#define ENVIRONMENT_LABEL_31_3 25
#define DEBUGGING_LABEL_31_2 24
#define OBJECT_31_3 23
#define OBJECT_31_2 22
#define OBJECT_31_1 21
#define OBJECT_31_0 20
#define FREE_REFERENCES_LABEL_31_0 20
#define NUMBER_OF_LINKER_SECTIONS_31_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_31 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd30;
  machine_word Wrd20;
  machine_word Wrd7;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd31;
  machine_word Wrd19;
  machine_word Wrd16;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd15;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_31_4);
      goto list_of_typeP__length_17;

    case 1:
      current_block = (Rpc - LABEL_31_5);
      goto loop_15;

    case 2:
      current_block = (Rpc - LABEL_31_7);
      goto label_19;

    case 3:
      current_block = (Rpc - LABEL_31_6);
      goto continuation_4;

    case 4:
      current_block = (Rpc - LABEL_31_8);
      goto label_20;

    case 5:
      current_block = (Rpc - LABEL_31_10);
      goto label_21;

    case 6:
      current_block = (Rpc - LABEL_31_9);
      goto continuation_10;

    case 7:
      current_block = (Rpc - LABEL_31_11);
      goto label_22;

    case 8:
      current_block = (Rpc - LABEL_31_12);
      goto label_23;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (list_of_typeP__length_25)
DEFLABEL (list_of_typeP__length_17)
  INTERRUPT_CHECK (26, LABEL_31_4);
  (Wrd5.Obj) = (current_block [OBJECT_31_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd6.Obj);
  (* (--Rsp)) = (Wrd6.Obj);
  goto loop_15;

DEFLABEL (loop_26)
DEFLABEL (loop_15)
  INTERRUPT_CHECK (26, LABEL_31_5);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_30;
  if ((Wrd5.Obj) == (current_block [OBJECT_31_2]))
    goto label_28;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_27;

DEFLABEL (label_28)
  Rvl = (Rsp [2]);

DEFLABEL (label_27)
DEFLABEL (label_29)
  Rsp = (& (Rsp [5]));
  goto pop_return;

DEFLABEL (label_30)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31_6]))));
  (* (--Rsp)) = (Wrd15.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_47;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [0]);
  (* (--Rsp)) = (Wrd18.Obj);

DEFLABEL (label_46)
  (Wrd25.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd25.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_31_6);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_31;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [5]));
  goto pop_return;

DEFLABEL (label_31)
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_45;
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [1]);
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_44)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Obj) = (Rsp [2]);
  if ((Wrd16.Obj) == (Wrd17.Obj))
    goto label_34;
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd19.uLng) == 1)
    goto label_36;
  if ((Wrd16.Obj) == (current_block [OBJECT_31_2]))
    goto label_33;

DEFLABEL (label_34)
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_32;

DEFLABEL (label_33)
  (Wrd25.Obj) = (Rsp [3]);
  (Wrd26.Lng) = (FIXNUM_TO_LONG (Wrd25.Obj));
  (Wrd27.Lng) = ((Wrd26.Lng) + 1L);
  Rvl = (LONG_TO_FIXNUM (Wrd27.Lng));

DEFLABEL (label_32)
DEFLABEL (label_35)
  Rsp = (& (Rsp [6]));
  goto pop_return;

DEFLABEL (label_36)
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31_9]))));
  (* (--Rsp)) = (Wrd31.Obj);
  if (! ((Wrd19.uLng) == 1))
    goto label_43;
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd34.Obj) = ((Wrd33.pObj) [0]);
  (* (--Rsp)) = (Wrd34.Obj);

DEFLABEL (label_42)
  (Wrd41.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd41.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_31_9);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_37;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [6]));
  goto pop_return;

DEFLABEL (label_37)
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_41;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_40)
  (Rsp [1]) = (Wrd7.Obj);
  (Wrd19.Obj) = (Rsp [2]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 1))
    goto label_39;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd16.Obj) = ((Wrd18.pObj) [1]);

DEFLABEL (label_38)
  (Rsp [2]) = (Wrd16.Obj);
  (Wrd26.Obj) = (Rsp [3]);
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  (Wrd30.Lng) = ((Wrd27.Lng) + 2L);
  (Wrd25.Obj) = (LONG_TO_FIXNUM (Wrd30.Lng));
  (Rsp [3]) = (Wrd25.Obj);
  Rsp = (& (Rsp [1]));
  goto loop_15;

DEFLABEL (label_39)
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31_12]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31_3]), 1);

DEFLABEL (label_23)
  (Wrd16.Obj) = Rvl;
  goto label_38;

DEFLABEL (label_41)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31_11]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31_3]), 1);

DEFLABEL (label_22)
  (Wrd7.Obj) = Rvl;
  goto label_40;

DEFLABEL (label_43)
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31_10]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31_1]), 1);

DEFLABEL (label_21)
  (* (--Rsp)) = Rvl;
  goto label_42;

DEFLABEL (label_45)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31_8]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31_3]), 1);

DEFLABEL (label_20)
  (* (--Rsp)) = Rvl;
  goto label_44;

DEFLABEL (label_47)
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31_7]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_31_1]), 1);

DEFLABEL (label_19)
  (* (--Rsp)) = Rvl;
  goto label_46;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_32_4 3
#define LABEL_32_7 5
#define LABEL_32_5 7
#define ENVIRONMENT_LABEL_32_3 14
#define DEBUGGING_LABEL_32_2 13
#define EXECUTE_CACHE_32_8 9
#define EXECUTE_CACHE_32_6 11
#define FREE_REFERENCES_LABEL_32_0 8
#define NUMBER_OF_LINKER_SECTIONS_32_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_32 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_32_4);
      goto guarantee_list__length_3;

    case 1:
      current_block = (Rpc - LABEL_32_7);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_32_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (guarantee_list__length_6)
DEFLABEL (guarantee_list__length_3)
  INTERRUPT_CHECK (26, LABEL_32_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_32_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_32_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_32_5);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_8;

DEFLABEL (label_7)
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_8)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_32_7]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_32_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_32_7);
  goto label_7;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_33_4 3
#define LABEL_33_7 5
#define LABEL_33_5 7
#define ENVIRONMENT_LABEL_33_3 15
#define DEBUGGING_LABEL_33_2 14
#define OBJECT_33_0 13
#define EXECUTE_CACHE_33_8 9
#define EXECUTE_CACHE_33_6 11
#define FREE_REFERENCES_LABEL_33_0 8
#define NUMBER_OF_LINKER_SECTIONS_33_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_33 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_33_4);
      goto guarantee_list_of_type__length_5;

    case 1:
      current_block = (Rpc - LABEL_33_7);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_33_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (guarantee_list_of_type__length_8)
DEFLABEL (guarantee_list_of_type__length_5)
  INTERRUPT_CHECK (26, LABEL_33_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_33_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_33_5);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_10;

DEFLABEL (label_9)
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [5]));
  goto pop_return;

DEFLABEL (label_10)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_7]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [5]);
  if ((Wrd12.Obj) == (current_block [OBJECT_33_0]))
    goto label_12;
  (* (--Rsp)) = (Wrd12.Obj);
  goto label_11;

DEFLABEL (label_12)
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);

DEFLABEL (label_11)
DEFLABEL (label_13)
  (Wrd15.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_33_8]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_33_7);
  goto label_9;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_34_4 3
#define ENVIRONMENT_LABEL_34_3 9
#define DEBUGGING_LABEL_34_2 8
#define OBJECT_34_0 7
#define EXECUTE_CACHE_34_5 5
#define FREE_REFERENCES_LABEL_34_0 4
#define NUMBER_OF_LINKER_SECTIONS_34_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_34 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_34_4);
      goto length_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (length_3)
DEFLABEL (length_0)
  INTERRUPT_CHECK (26, LABEL_34_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_34_0]);
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_35_4 3
#define LABEL_35_5 5
#define LABEL_35_6 7
#define LABEL_35_8 9
#define LABEL_35_9 11
#define LABEL_35_11 13
#define LABEL_35_12 15
#define LABEL_35_13 17
#define ENVIRONMENT_LABEL_35_3 29
#define DEBUGGING_LABEL_35_2 28
#define OBJECT_35_4 27
#define OBJECT_35_3 26
#define OBJECT_35_2 25
#define OBJECT_35_1 24
#define OBJECT_35_0 23
#define EXECUTE_CACHE_35_10 19
#define EXECUTE_CACHE_35_7 21
#define FREE_REFERENCES_LABEL_35_0 18
#define NUMBER_OF_LINKER_SECTIONS_35_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_35 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd43;
  machine_word Wrd35;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd34;
  machine_word Wrd28;
  machine_word Wrd21;
  machine_word Wrd10;
  machine_word Wrd12;
  machine_word Wrd32;
  machine_word Wrd24;
  machine_word Wrd26;
  machine_word Wrd20;
  machine_word Wrd23;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd37;
  machine_word Wrd11;
  machine_word Wrd19;
  machine_word Wrd25;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd9;
  machine_word Wrd36;
  machine_word Wrd57;
  machine_word Wrd49;
  machine_word Wrd51;
  machine_word Wrd53;
  machine_word Wrd52;
  machine_word Wrd48;
  machine_word Wrd40;
  machine_word Wrd42;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_35_4);
      goto length_P_26;

    case 1:
      current_block = (Rpc - LABEL_35_5);
      goto label_28;

    case 2:
      current_block = (Rpc - LABEL_35_6);
      goto label_29;

    case 3:
      current_block = (Rpc - LABEL_35_8);
      goto Z__length_P_16;

    case 4:
      current_block = (Rpc - LABEL_35_9);
      goto label_30;

    case 5:
      current_block = (Rpc - LABEL_35_11);
      goto Z__same_length_25;

    case 6:
      current_block = (Rpc - LABEL_35_12);
      goto label_31;

    case 7:
      current_block = (Rpc - LABEL_35_13);
      goto label_32;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (length_P_34)
DEFLABEL (length_P_26)
  INTERRUPT_CHECK (26, LABEL_35_4);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_45;
  if (! (INDEX_FIXNUM_P (Wrd5.Obj)))
    goto label_38;

DEFLABEL (label_37)
  goto Z__length_P_16;

DEFLABEL (label_38)
  (Wrd9.Obj) = (current_block [OBJECT_35_1]);
  if ((Wrd5.Obj) == (Wrd9.Obj))
    goto label_40;
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_35_2]);
  (Rsp [1]) = (Wrd11.Obj);

DEFLABEL (label_39)
  (Wrd37.Obj) = (current_block [OBJECT_35_4]);
  (Rsp [2]) = (Wrd37.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_7]));

DEFLABEL (label_40)
  (Wrd13.Obj) = (Rsp [1]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 1)
    goto label_44;
  if (INDEX_FIXNUM_P (Wrd13.Obj))
    goto label_43;
  if ((Wrd13.Obj) == (Wrd9.Obj))
    goto label_41;
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd19.Obj) = (current_block [OBJECT_35_2]);
  (Rsp [1]) = (Wrd19.Obj);
  goto label_39;

DEFLABEL (label_41)
  Rvl = (current_block [OBJECT_35_3]);

DEFLABEL (label_42)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_43)
  (Wrd25.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  if ((Wrd25.Lng) == 0)
    goto label_41;

DEFLABEL (label_44)
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_42;

DEFLABEL (label_45)
  (Wrd30.Obj) = (Rsp [1]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if ((Wrd31.uLng) == 1)
    goto label_47;
  if (INDEX_FIXNUM_P (Wrd30.Obj))
    goto label_46;
  if ((Wrd30.Obj) == (current_block [OBJECT_35_1]))
    goto label_44;
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd36.Obj) = (current_block [OBJECT_35_2]);
  (Rsp [1]) = (Wrd36.Obj);
  goto label_39;

DEFLABEL (label_46)
  (Rsp [0]) = (Wrd30.Obj);
  (Rsp [1]) = (Wrd5.Obj);
  goto label_37;

DEFLABEL (label_47)
  if (! ((Wrd6.uLng) == 1))
    goto label_51;
  (Wrd42.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd40.Obj) = ((Wrd42.pObj) [1]);

DEFLABEL (label_50)
  (Rsp [0]) = (Wrd40.Obj);
  (Wrd52.Obj) = (Rsp [1]);
  (Wrd53.uLng) = (OBJECT_TYPE (Wrd52.Obj));
  if (! ((Wrd53.uLng) == 1))
    goto label_49;
  (Wrd51.pObj) = (OBJECT_ADDRESS (Wrd52.Obj));
  (Wrd49.Obj) = ((Wrd51.pObj) [1]);

DEFLABEL (label_48)
  (Rsp [1]) = (Wrd49.Obj);
  goto Z__same_length_25;

DEFLABEL (label_49)
  (Wrd57.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_6]))));
  (* (--Rsp)) = (Wrd57.Obj);
  (* (--Rsp)) = (Wrd52.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_35_0]), 1);

DEFLABEL (label_29)
  (Wrd49.Obj) = Rvl;
  goto label_48;

DEFLABEL (label_51)
  (Wrd48.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_5]))));
  (* (--Rsp)) = (Wrd48.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_35_0]), 1);

DEFLABEL (label_28)
  (Wrd40.Obj) = Rvl;
  goto label_50;

DEFLABEL (Z__length_P_35)
DEFLABEL (Z__length_P_16)
  INTERRUPT_CHECK (26, LABEL_35_8);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_57;
  if ((Wrd5.Obj) == (current_block [OBJECT_35_1]))
    goto label_52;
  (Rsp [0]) = (Wrd5.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_35_4]);
  (Rsp [1]) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_10]));

DEFLABEL (label_52)
  (Wrd12.Obj) = (Rsp [0]);
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  if ((Wrd13.Lng) == 0)
    goto label_54;

DEFLABEL (label_55)
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_53;

DEFLABEL (label_54)
  Rvl = (current_block [OBJECT_35_3]);

DEFLABEL (label_53)
DEFLABEL (label_56)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_57)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! ((Wrd17.Lng) > 0))
    goto label_55;
  (Wrd23.Lng) = ((Wrd17.Lng) - 1L);
  (Wrd20.Obj) = (LONG_TO_FIXNUM (Wrd23.Lng));
  (Rsp [0]) = (Wrd20.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_59;
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd24.Obj) = ((Wrd26.pObj) [1]);

DEFLABEL (label_58)
  (Rsp [1]) = (Wrd24.Obj);
  goto Z__length_P_16;

DEFLABEL (label_59)
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_9]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_35_0]), 1);

DEFLABEL (label_30)
  (Wrd24.Obj) = Rvl;
  goto label_58;

DEFLABEL (Z__same_length_36)
DEFLABEL (Z__same_length_25)
  INTERRUPT_CHECK (26, LABEL_35_11);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_65;
  (Wrd8.Obj) = (current_block [OBJECT_35_1]);
  if ((Wrd5.Obj) == (Wrd8.Obj))
    goto label_61;

DEFLABEL (label_60)
  (Wrd9.Obj) = (current_block [OBJECT_35_4]);
  (Rsp [1]) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_10]));

DEFLABEL (label_61)
  (Wrd10.Obj) = (Rsp [1]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd11.uLng) == 1)
    goto label_64;
  if ((Wrd10.Obj) == (Wrd8.Obj))
    goto label_62;
  (Rsp [0]) = (Wrd10.Obj);
  goto label_60;

DEFLABEL (label_62)
  Rvl = (current_block [OBJECT_35_3]);

DEFLABEL (label_63)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_64)
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_63;

DEFLABEL (label_65)
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if ((Wrd21.uLng) == 1)
    goto label_66;
  if ((Wrd20.Obj) == (current_block [OBJECT_35_1]))
    goto label_64;
  (Rsp [0]) = (Wrd20.Obj);
  goto label_60;

DEFLABEL (label_66)
  if (! ((Wrd6.uLng) == 1))
    goto label_70;
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd28.pObj) [1]);

DEFLABEL (label_69)
  (Rsp [0]) = (Wrd26.Obj);
  (Wrd38.Obj) = (Rsp [1]);
  (Wrd39.uLng) = (OBJECT_TYPE (Wrd38.Obj));
  if (! ((Wrd39.uLng) == 1))
    goto label_68;
  (Wrd37.pObj) = (OBJECT_ADDRESS (Wrd38.Obj));
  (Wrd35.Obj) = ((Wrd37.pObj) [1]);

DEFLABEL (label_67)
  (Rsp [1]) = (Wrd35.Obj);
  goto Z__same_length_25;

DEFLABEL (label_68)
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_13]))));
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_35_0]), 1);

DEFLABEL (label_32)
  (Wrd35.Obj) = Rvl;
  goto label_67;

DEFLABEL (label_70)
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_12]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_35_0]), 1);

DEFLABEL (label_31)
  (Wrd26.Obj) = Rvl;
  goto label_69;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_36_4 3
#define ENVIRONMENT_LABEL_36_3 6
#define DEBUGGING_LABEL_36_2 5
#define OBJECT_36_0 4
#define FREE_REFERENCES_LABEL_36_0 4
#define NUMBER_OF_LINKER_SECTIONS_36_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_36 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_36_4);
      goto not_pairP_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (not_pairP_4)
DEFLABEL (not_pairP_1)
  INTERRUPT_CHECK (26, LABEL_36_4);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_6;
  Rvl = (current_block [OBJECT_36_0]);
  goto label_5;

DEFLABEL (label_6)
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_5)
DEFLABEL (label_7)
  Rsp = (& (Rsp [1]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_37_4 3
#define ENVIRONMENT_LABEL_37_3 10
#define DEBUGGING_LABEL_37_2 9
#define OBJECT_37_1 8
#define OBJECT_37_0 7
#define EXECUTE_CACHE_37_5 5
#define FREE_REFERENCES_LABEL_37_0 4
#define NUMBER_OF_LINKER_SECTIONS_37_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_37 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_37_4);
      goto null_listP_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (null_listP_5)
DEFLABEL (null_listP_2)
  INTERRUPT_CHECK (26, LABEL_37_4);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_8;
  if ((Wrd5.Obj) == (current_block [OBJECT_37_0]))
    goto label_6;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37_5]));

DEFLABEL (label_6)
  Rvl = (current_block [OBJECT_37_1]);

DEFLABEL (label_7)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_8)
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_7;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_38_4 3
#define LABEL_38_5 5
#define LABEL_38_6 7
#define LABEL_38_7 9
#define LABEL_38_8 11
#define LABEL_38_9 13
#define LABEL_38_10 15
#define LABEL_38_11 17
#define LABEL_38_13 19
#define LABEL_38_15 21
#define LABEL_38_16 23
#define LABEL_38_12 25
#define LABEL_38_17 27
#define LABEL_38_18 29
#define LABEL_38_19 31
#define LABEL_38_14 33
#define LABEL_38_22 35
#define LABEL_38_23 37
#define LABEL_38_20 39
#define ENVIRONMENT_LABEL_38_3 51
#define DEBUGGING_LABEL_38_2 50
#define OBJECT_38_4 49
#define OBJECT_38_3 48
#define OBJECT_38_2 47
#define OBJECT_38_1 46
#define OBJECT_38_0 45
#define EXECUTE_CACHE_38_24 41
#define EXECUTE_CACHE_38_21 43
#define FREE_REFERENCES_LABEL_38_0 40
#define NUMBER_OF_LINKER_SECTIONS_38_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_38 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd24;
  machine_word Wrd25;
  machine_word Wrd16;
  machine_word Wrd12;
  machine_word Wrd7;
  machine_word Wrd13;
  machine_word Wrd58;
  machine_word Wrd57;
  machine_word Wrd56;
  machine_word Wrd48;
  machine_word Wrd51;
  machine_word Wrd47;
  machine_word Wrd42;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd26;
  machine_word Wrd20;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd59;
  machine_word Wrd53;
  machine_word Wrd52;
  machine_word Wrd55;
  machine_word Wrd54;
  machine_word Wrd50;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd46;
  machine_word Wrd43;
  machine_word Wrd35;
  machine_word Wrd37;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd34;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd30;
  machine_word Wrd27;
  machine_word Wrd19;
  machine_word Wrd21;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_38_4);
      goto list__28;

    case 1:
      current_block = (Rpc - LABEL_38_5);
      goto label_30;

    case 2:
      current_block = (Rpc - LABEL_38_6);
      goto label_31;

    case 3:
      current_block = (Rpc - LABEL_38_7);
      goto label_32;

    case 4:
      current_block = (Rpc - LABEL_38_8);
      goto label_33;

    case 5:
      current_block = (Rpc - LABEL_38_9);
      goto label_34;

    case 6:
      current_block = (Rpc - LABEL_38_10);
      goto label_35;

    case 7:
      current_block = (Rpc - LABEL_38_11);
      goto n_ary_12;

    case 8:
      current_block = (Rpc - LABEL_38_13);
      goto binary_25;

    case 9:
      current_block = (Rpc - LABEL_38_15);
      goto label_36;

    case 10:
      current_block = (Rpc - LABEL_38_16);
      goto label_37;

    case 11:
      current_block = (Rpc - LABEL_38_12);
      goto continuation_9;

    case 12:
      current_block = (Rpc - LABEL_38_17);
      goto label_38;

    case 13:
      current_block = (Rpc - LABEL_38_18);
      goto label_39;

    case 14:
      current_block = (Rpc - LABEL_38_19);
      goto lose_27;

    case 15:
      current_block = (Rpc - LABEL_38_14);
      goto continuation_22;

    case 16:
      current_block = (Rpc - LABEL_38_22);
      goto label_40;

    case 17:
      current_block = (Rpc - LABEL_38_23);
      goto label_41;

    case 18:
      current_block = (Rpc - LABEL_38_20);
      goto lambda_26;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (list__43)
DEFLABEL (list__28)
  INTERRUPT_CHECK (26, LABEL_38_4);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_49;

DEFLABEL (label_48)
  Rvl = (current_block [OBJECT_38_2]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_49)
  if (! ((Wrd6.uLng) == 1))
    goto label_61;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd9.Obj) = ((Wrd11.pObj) [1]);

DEFLABEL (label_60)
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_48;
  (Wrd22.Obj) = (Rsp [1]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if (! ((Wrd23.uLng) == 1))
    goto label_59;
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
  (Wrd19.Obj) = ((Wrd21.pObj) [1]);

DEFLABEL (label_58)
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd30.uLng) == 1))
    goto label_57;
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd29.Obj) = ((Wrd28.pObj) [1]);
  (* (--Rsp)) = (Wrd29.Obj);

DEFLABEL (label_56)
  (Wrd38.Obj) = (Rsp [2]);
  (Wrd39.uLng) = (OBJECT_TYPE (Wrd38.Obj));
  if (! ((Wrd39.uLng) == 1))
    goto label_55;
  (Wrd37.pObj) = (OBJECT_ADDRESS (Wrd38.Obj));
  (Wrd35.Obj) = ((Wrd37.pObj) [1]);

DEFLABEL (label_54)
  (Wrd46.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if (! ((Wrd46.uLng) == 1))
    goto label_53;
  (Wrd44.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd45.Obj) = ((Wrd44.pObj) [0]);
  (* (--Rsp)) = (Wrd45.Obj);

DEFLABEL (label_52)
  (Wrd54.Obj) = (Rsp [3]);
  (Wrd55.uLng) = (OBJECT_TYPE (Wrd54.Obj));
  if (! ((Wrd55.uLng) == 1))
    goto label_51;
  (Wrd52.pObj) = (OBJECT_ADDRESS (Wrd54.Obj));
  (Wrd53.Obj) = ((Wrd52.pObj) [0]);
  (* (--Rsp)) = (Wrd53.Obj);

DEFLABEL (label_50)
  goto n_ary_12;

DEFLABEL (label_51)
  (Wrd59.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_10]))));
  (* (--Rsp)) = (Wrd59.Obj);
  (* (--Rsp)) = (Wrd54.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_38_1]), 1);

DEFLABEL (label_35)
  (* (--Rsp)) = Rvl;
  goto label_50;

DEFLABEL (label_53)
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_9]))));
  (* (--Rsp)) = (Wrd50.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_38_1]), 1);

DEFLABEL (label_34)
  (* (--Rsp)) = Rvl;
  goto label_52;

DEFLABEL (label_55)
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_8]))));
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_38_0]), 1);

DEFLABEL (label_33)
  (Wrd35.Obj) = Rvl;
  goto label_54;

DEFLABEL (label_57)
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_7]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_38_0]), 1);

DEFLABEL (label_32)
  (* (--Rsp)) = Rvl;
  goto label_56;

DEFLABEL (label_59)
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_6]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_38_0]), 1);

DEFLABEL (label_31)
  (Wrd19.Obj) = Rvl;
  goto label_58;

DEFLABEL (label_61)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_5]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_38_0]), 1);

DEFLABEL (label_30)
  (Wrd9.Obj) = Rvl;
  goto label_60;

DEFLABEL (n_ary_44)
DEFLABEL (n_ary_12)
  INTERRUPT_CHECK (26, LABEL_38_11);
  (Wrd5.Obj) = (Rsp [2]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_62;
  (Wrd8.pObj) = (& (Rsp [3]));
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd8.pObj)));
  (Rsp [2]) = (Wrd10.Obj);
  Rdl = (& (Rsp [5]));
  goto binary_25;

DEFLABEL (label_62)
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_12]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.pObj) = (& (Rsp [4]));
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd15.pObj)));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd18.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd19.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd19.Obj);
  Rdl = (& (Rsp [3]));
  goto binary_25;

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_38_12);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_63;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [5]));
  goto pop_return;

DEFLABEL (label_63)
  (Wrd7.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd7.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd12.uLng) == 1))
    goto label_67;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd8.Obj) = ((Wrd10.pObj) [0]);

DEFLABEL (label_66)
  (Rsp [1]) = (Wrd8.Obj);
  (Wrd20.Obj) = (Rsp [2]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 1))
    goto label_65;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd17.Obj) = ((Wrd19.pObj) [1]);

DEFLABEL (label_64)
  (Rsp [2]) = (Wrd17.Obj);
  goto n_ary_12;

DEFLABEL (label_65)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_18]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_38_0]), 1);

DEFLABEL (label_39)
  (Wrd17.Obj) = Rvl;
  goto label_64;

DEFLABEL (label_67)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_17]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_38_1]), 1);

DEFLABEL (label_38)
  (Wrd8.Obj) = Rvl;
  goto label_66;

DEFLABEL (binary_45)
DEFLABEL (binary_25)
  DLINK_INTERRUPT_CHECK (25, LABEL_38_13);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_73;
  (Wrd8.Obj) = (current_block [OBJECT_38_3]);
  if ((Wrd5.Obj) == (Wrd8.Obj))
    goto label_69;

DEFLABEL (label_68)
  Rsp = (& (Rsp [2]));
  goto lose_27;

DEFLABEL (label_69)
  (Wrd10.Obj) = (Rsp [1]);
  if ((Wrd10.Obj) == (Wrd8.Obj))
    goto label_72;
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_68;

DEFLABEL (label_71)
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_70)
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_72)
  Rvl = (current_block [OBJECT_38_2]);
  goto label_70;

DEFLABEL (label_73)
  (Wrd18.Obj) = (Rsp [1]);
  if ((Wrd5.Obj) == (Wrd18.Obj))
    goto label_72;
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd20.uLng) == 1)
    goto label_74;
  if ((Wrd18.Obj) == (current_block [OBJECT_38_3]))
    goto label_71;
  goto label_68;

DEFLABEL (label_74)
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_14]))));
  (* (--Rsp)) = (Wrd29.Obj);
  if (! ((Wrd20.uLng) == 1))
    goto label_83;
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd32.Obj) = ((Wrd31.pObj) [0]);
  (* (--Rsp)) = (Wrd32.Obj);

DEFLABEL (label_82)
  (Wrd46.Obj) = (Rsp [3]);
  (Wrd47.uLng) = (OBJECT_TYPE (Wrd46.Obj));
  if (! ((Wrd47.uLng) == 1))
    goto label_81;
  (Wrd44.pObj) = (OBJECT_ADDRESS (Wrd46.Obj));
  (Wrd45.Obj) = ((Wrd44.pObj) [0]);
  (* (--Rsp)) = (Wrd45.Obj);

DEFLABEL (label_80)
  (Wrd56.Obj) = (Rsp [6]);
  (Wrd57.pObj) = (OBJECT_ADDRESS (Wrd56.Obj));
  (Wrd58.Obj) = ((Wrd57.pObj) [0]);
  (* (--Rsp)) = (Wrd58.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_22)
  INTERRUPT_CHECK (27, LABEL_38_14);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_75;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_75)
  (Wrd12.Obj) = (Rsp [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_79;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd9.Obj) = ((Wrd11.pObj) [1]);

DEFLABEL (label_78)
  (Rsp [0]) = (Wrd9.Obj);
  (Wrd25.Obj) = (Rsp [1]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if (! ((Wrd26.uLng) == 1))
    goto label_77;
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd22.Obj) = ((Wrd24.pObj) [1]);

DEFLABEL (label_76)
  (Rsp [1]) = (Wrd22.Obj);
  goto binary_25;

DEFLABEL (label_77)
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_23]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_38_0]), 1);

DEFLABEL (label_41)
  (Wrd27.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd22.Obj) = Rvl;
  goto label_76;

DEFLABEL (label_79)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_22]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_38_0]), 1);

DEFLABEL (label_40)
  (Wrd14.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd9.Obj) = Rvl;
  goto label_78;

DEFLABEL (label_81)
  (Wrd51.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd51.Obj);
  (Wrd55.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_16]))));
  (* (--Rsp)) = (Wrd55.Obj);
  (* (--Rsp)) = (Wrd46.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_38_1]), 1);

DEFLABEL (label_37)
  (Wrd48.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd48.Obj));
  (* (--Rsp)) = Rvl;
  goto label_80;

DEFLABEL (label_83)
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_15]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_38_1]), 1);

DEFLABEL (label_36)
  (Wrd35.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd35.Obj));
  (* (--Rsp)) = Rvl;
  goto label_82;

DEFLABEL (lose_46)
DEFLABEL (lose_27)
  DLINK_INTERRUPT_CHECK (25, LABEL_38_19);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [1]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_20]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rdl)) = (Rsp [1]);
  (* (--Rdl)) = (Rsp [0]);
  Rsp = Rdl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_38_21]));

DEFLABEL (lambda_47)
DEFLABEL (lambda_26)
  INTERRUPT_CHECK (26, LABEL_38_20);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_38_4]);
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_38_24]));

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_39_4 3
#define LABEL_39_7 5
#define LABEL_39_5 7
#define ENVIRONMENT_LABEL_39_3 16
#define DEBUGGING_LABEL_39_2 15
#define OBJECT_39_1 14
#define OBJECT_39_0 13
#define EXECUTE_CACHE_39_8 9
#define EXECUTE_CACHE_39_6 11
#define FREE_REFERENCES_LABEL_39_0 8
#define NUMBER_OF_LINKER_SECTIONS_39_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_39 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd15;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd12;
  machine_word Wrd6;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_39_4);
      goto list_ref_4;

    case 1:
      current_block = (Rpc - LABEL_39_7);
      goto continuation_2;

    case 2:
      current_block = (Rpc - LABEL_39_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (list_ref_7)
DEFLABEL (list_ref_4)
  INTERRUPT_CHECK (26, LABEL_39_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_39_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_39_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_39_5);
  (* (--Rsp)) = Rvl;
  (Wrd6.uLng) = (OBJECT_TYPE (Rvl));
  if ((Wrd6.uLng) == 1)
    goto label_9;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_39_7]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_39_1]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_39_8]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_39_7);

DEFLABEL (label_9)
  (Wrd12.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd12.Obj);
  Rsp = (& (Rsp [2]));
  (Wrd17.Obj) = (Rsp [0]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_8;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  Rvl = ((Wrd15.pObj) [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_8)
  INVOKE_PRIMITIVE ((current_block [OBJECT_39_0]), 1);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_40_4 3
#define LABEL_40_7 5
#define LABEL_40_5 7
#define ENVIRONMENT_LABEL_40_3 17
#define DEBUGGING_LABEL_40_2 16
#define OBJECT_40_2 15
#define OBJECT_40_1 14
#define OBJECT_40_0 13
#define EXECUTE_CACHE_40_8 9
#define EXECUTE_CACHE_40_6 11
#define FREE_REFERENCES_LABEL_40_0 8
#define NUMBER_OF_LINKER_SECTIONS_40_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_40 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd12;
  machine_word Wrd6;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_40_4);
      goto list_setB_4;

    case 1:
      current_block = (Rpc - LABEL_40_7);
      goto continuation_2;

    case 2:
      current_block = (Rpc - LABEL_40_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (list_setB_7)
DEFLABEL (list_setB_4)
  INTERRUPT_CHECK (26, LABEL_40_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_40_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_40_5);
  (* (--Rsp)) = Rvl;
  (Wrd6.uLng) = (OBJECT_TYPE (Rvl));
  if ((Wrd6.uLng) == 1)
    goto label_9;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_7]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_40_2]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_40_8]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_40_7);

DEFLABEL (label_9)
  (Wrd12.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd12.Obj);
  Rsp = (& (Rsp [2]));
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd19.uLng) == 1))
    goto label_8;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd16.Obj) = (Rsp [1]);
  ((Wrd15.pObj) [0]) = (Wrd16.Obj);
  Rvl = (current_block [OBJECT_40_0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_8)
  INVOKE_PRIMITIVE ((current_block [OBJECT_40_1]), 2);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_41_4 3
#define LABEL_41_5 5
#define LABEL_41_7 7
#define LABEL_41_8 9
#define LABEL_41_9 11
#define ENVIRONMENT_LABEL_41_3 20
#define DEBUGGING_LABEL_41_2 19
#define OBJECT_41_1 18
#define OBJECT_41_0 17
#define EXECUTE_CACHE_41_10 13
#define EXECUTE_CACHE_41_6 15
#define FREE_REFERENCES_LABEL_41_0 12
#define NUMBER_OF_LINKER_SECTIONS_41_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_41 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd23;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd22;
  machine_word Wrd14;
  machine_word Wrd16;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_41_4);
      goto list_tail_9;

    case 1:
      current_block = (Rpc - LABEL_41_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_41_7);
      goto continuation_4;

    case 3:
      current_block = (Rpc - LABEL_41_8);
      goto loop_7;

    case 4:
      current_block = (Rpc - LABEL_41_9);
      goto label_11;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (list_tail_13)
DEFLABEL (list_tail_9)
  INTERRUPT_CHECK (26, LABEL_41_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_41_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_41_5);
  (Wrd5.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd6.Obj);
  goto loop_7;

DEFLABEL (loop_14)
DEFLABEL (loop_7)
  INTERRUPT_CHECK (26, LABEL_41_8);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.Lng) = (FIXNUM_TO_LONG (Wrd5.Obj));
  if (! ((Wrd6.Lng) == 0))
    goto label_15;
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_15)
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if ((Wrd8.uLng) == 1)
    goto label_18;
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_7]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_41_0]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_10]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_41_7);

DEFLABEL (label_18)
  (Wrd17.Obj) = (Rsp [0]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_17;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd14.Obj) = ((Wrd16.pObj) [1]);

DEFLABEL (label_16)
  (Rsp [0]) = (Wrd14.Obj);
  (Wrd24.Obj) = (Rsp [1]);
  (Wrd25.Lng) = (FIXNUM_TO_LONG (Wrd24.Obj));
  (Wrd26.Lng) = ((Wrd25.Lng) - 1L);
  (Wrd23.Obj) = (LONG_TO_FIXNUM (Wrd26.Lng));
  (Rsp [1]) = (Wrd23.Obj);
  goto loop_7;

DEFLABEL (label_17)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_9]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_1]), 1);

DEFLABEL (label_11)
  (Wrd14.Obj) = Rvl;
  goto label_16;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_42_4 3
#define LABEL_42_5 5
#define LABEL_42_7 7
#define LABEL_42_8 9
#define LABEL_42_10 11
#define LABEL_42_9 13
#define LABEL_42_12 15
#define ENVIRONMENT_LABEL_42_3 26
#define DEBUGGING_LABEL_42_2 25
#define OBJECT_42_3 24
#define OBJECT_42_2 23
#define OBJECT_42_1 22
#define OBJECT_42_0 21
#define EXECUTE_CACHE_42_11 17
#define EXECUTE_CACHE_42_6 19
#define FREE_REFERENCES_LABEL_42_0 16
#define NUMBER_OF_LINKER_SECTIONS_42_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_42 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd20;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd36;
  machine_word Wrd43;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd5;
  machine_word Wrd46;
  machine_word Wrd6;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_42_4);
      goto list_head_11;

    case 1:
      current_block = (Rpc - LABEL_42_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_42_7);
      goto continuation_4;

    case 3:
      current_block = (Rpc - LABEL_42_8);
      goto loop_9;

    case 4:
      current_block = (Rpc - LABEL_42_10);
      goto label_13;

    case 5:
      current_block = (Rpc - LABEL_42_9);
      goto continuation_8;

    case 6:
      current_block = (Rpc - LABEL_42_12);
      goto label_14;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (list_head_16)
DEFLABEL (list_head_11)
  INTERRUPT_CHECK (26, LABEL_42_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_42_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_42_5);
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (59, Rsp));
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  Rdl = (& (Rsp [5]));
  goto loop_9;

DEFLABEL (loop_17)
DEFLABEL (loop_9)
  DLINK_INTERRUPT_CHECK (25, LABEL_42_8);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.Lng) = (FIXNUM_TO_LONG (Wrd5.Obj));
  if (! ((Wrd6.Lng) == 0))
    goto label_18;
  Rvl = (current_block [OBJECT_42_1]);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_18)
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if ((Wrd8.uLng) == 1)
    goto label_23;
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_7]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_42_0]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [5]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [1]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_11]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_42_7);
  (Wrd46.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd46.Obj));

DEFLABEL (label_23)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_9]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd23.Obj) = (Rsp [4]);
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd24.pObj)));
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd27.Obj) = (Rsp [4]);
  (Wrd28.Lng) = (FIXNUM_TO_LONG (Wrd27.Obj));
  (Wrd29.Lng) = ((Wrd28.Lng) - 1L);
  (Wrd30.Obj) = (LONG_TO_FIXNUM (Wrd29.Lng));
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd34.Obj) = (Rsp [4]);
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if (! ((Wrd35.uLng) == 1))
    goto label_22;
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd33.Obj) = ((Wrd32.pObj) [1]);
  (* (--Rsp)) = (Wrd33.Obj);

DEFLABEL (label_21)
  Rdl = (& (Rsp [3]));
  goto loop_9;

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_42_9);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd10.Obj) = (Rsp [1]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_20;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [0]);

DEFLABEL (label_19)
  (Wrd20.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd7.Obj);
  (* (Rhp++)) = (Wrd20.Obj);
  (Wrd22.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd22.pObj)));
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_20)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_12]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_42_3]), 1);

DEFLABEL (label_14)
  (Wrd12.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd7.Obj) = Rvl;
  goto label_19;

DEFLABEL (label_22)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_10]))));
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_42_2]), 1);

DEFLABEL (label_13)
  (Wrd36.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd36.Obj));
  (* (--Rsp)) = Rvl;
  goto label_21;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_43_4 3
#define LABEL_43_5 5
#define LABEL_43_6 7
#define ENVIRONMENT_LABEL_43_3 14
#define DEBUGGING_LABEL_43_2 13
#define EXECUTE_CACHE_43_8 9
#define EXECUTE_CACHE_43_7 11
#define FREE_REFERENCES_LABEL_43_0 8
#define NUMBER_OF_LINKER_SECTIONS_43_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_43 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd9;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd15;
  machine_word Wrd19;
  machine_word Wrd17;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_43_4);
      goto sublist_2;

    case 1:
      current_block = (Rpc - LABEL_43_5);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_43_6);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (sublist_6)
DEFLABEL (sublist_2)
  INTERRUPT_CHECK (26, LABEL_43_4);
  (Wrd11.Obj) = (Rsp [2]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd12.uLng) == 26))
    goto label_8;
  (Wrd13.Obj) = (Rsp [1]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd14.uLng) == 26))
    goto label_8;
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd11.Obj));
  (Wrd19.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  (Wrd15.Lng) = ((Wrd17.Lng) - (Wrd19.Lng));
  if (! (LONG_TO_FIXNUM_P (Wrd15.Lng)))
    goto label_8;
  (Wrd10.Obj) = (LONG_TO_FIXNUM (Wrd15.Lng));

DEFLABEL (label_7)
  (Rsp [2]) = (Wrd10.Obj);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_6]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd23.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd24.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd24.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_43_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_43_6);
  (Rsp [1]) = Rvl;
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_43_8]));

DEFLABEL (label_8)
  (Wrd5.Obj) = (Rsp [2]);
  (Wrd6.Obj) = (Rsp [1]);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_5]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rsp)) = (Wrd6.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_INTERFACE_0 (40);

DEFLABEL (label_4)
  (Wrd10.Obj) = Rvl;
  goto label_7;

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_44_4 3
#define LABEL_44_5 5
#define LABEL_44_7 7
#define LABEL_44_8 9
#define LABEL_44_10 11
#define LABEL_44_11 13
#define LABEL_44_12 15
#define LABEL_44_13 17
#define LABEL_44_6 19
#define ENVIRONMENT_LABEL_44_3 29
#define DEBUGGING_LABEL_44_2 28
#define OBJECT_44_4 27
#define OBJECT_44_3 26
#define OBJECT_44_2 25
#define OBJECT_44_1 24
#define OBJECT_44_0 23
#define EXECUTE_CACHE_44_9 21
#define FREE_REFERENCES_LABEL_44_0 20
#define NUMBER_OF_LINKER_SECTIONS_44_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_44 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd12;
  machine_word Wrd40;
  machine_word Wrd31;
  machine_word Wrd51;
  machine_word Wrd43;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd28;
  machine_word Wrd30;
  machine_word Wrd18;
  machine_word Wrd20;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd10;
  machine_word Wrd39;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd29;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd26;
  machine_word Wrd22;
  machine_word Wrd14;
  machine_word Wrd16;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_44_4);
      goto list_copy_19;

    case 1:
      current_block = (Rpc - LABEL_44_5);
      goto label_21;

    case 2:
      current_block = (Rpc - LABEL_44_7);
      goto label_22;

    case 3:
      current_block = (Rpc - LABEL_44_8);
      goto lambda_0;

    case 4:
      current_block = (Rpc - LABEL_44_10);
      goto loop_15;

    case 5:
      current_block = (Rpc - LABEL_44_11);
      goto label_23;

    case 6:
      current_block = (Rpc - LABEL_44_12);
      goto label_25;

    case 7:
      current_block = (Rpc - LABEL_44_13);
      goto label_24;

    case 8:
      current_block = (Rpc - LABEL_44_6);
      goto continuation_6;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (list_copy_27)
DEFLABEL (list_copy_19)
  INTERRUPT_CHECK (26, LABEL_44_4);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_31;
  if ((Wrd5.Obj) == (current_block [OBJECT_44_1]))
    goto label_30;
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, Rsp));
  (* (--Rsp)) = (Wrd10.Obj);
  Rdl = (& (Rsp [2]));
  goto lambda_0;

DEFLABEL (label_30)
  Rvl = (Wrd5.Obj);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_31)
  if (! ((Wrd6.uLng) == 1))
    goto label_36;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd14.Obj) = ((Wrd16.pObj) [0]);

DEFLABEL (label_35)
  (Wrd26.Obj) = (current_block [OBJECT_44_1]);
  (* (Rhp++)) = (Wrd14.Obj);
  (* (Rhp++)) = (Wrd26.Obj);
  (Wrd24.pObj) = (& (Rhp [-2]));
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd24.pObj)));
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_44_6]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd34.Obj) = (Rsp [3]);
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if (! ((Wrd35.uLng) == 1))
    goto label_34;
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd33.Obj) = ((Wrd32.pObj) [1]);
  (* (--Rsp)) = (Wrd33.Obj);

DEFLABEL (label_33)
  goto loop_15;

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_44_6);

DEFLABEL (label_32)
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_34)
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_44_7]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44_2]), 1);

DEFLABEL (label_22)
  (* (--Rsp)) = Rvl;
  goto label_33;

DEFLABEL (label_36)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_44_5]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44_0]), 1);

DEFLABEL (label_21)
  (Wrd14.Obj) = Rvl;
  goto label_35;

DEFLABEL (lambda_28)
DEFLABEL (lambda_0)
  DLINK_INTERRUPT_CHECK (25, LABEL_44_8);
  (Wrd5.Obj) = (current_block [OBJECT_44_3]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd8.Obj) = ((Wrd7.pObj) [0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rdl)) = (Rsp [1]);
  (* (--Rdl)) = (Rsp [0]);
  Rsp = Rdl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_44_9]));

DEFLABEL (loop_29)
DEFLABEL (loop_15)
  INTERRUPT_CHECK (26, LABEL_44_10);
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if ((Wrd8.uLng) == 1)
    goto label_38;
  if ((Wrd7.Obj) == (current_block [OBJECT_44_1]))
    goto label_37;
  (Wrd12.pObj) = (& (Rsp [4]));
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd12.pObj)));
  (Rsp [1]) = (Wrd14.Obj);
  Rdl = (& (Rsp [2]));
  Rsp = (& (Rsp [1]));
  goto lambda_0;

DEFLABEL (label_37)
  Rsp = (& (Rsp [3]));
  goto label_32;

DEFLABEL (label_38)
  if (! ((Wrd8.uLng) == 1))
    goto label_44;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd18.Obj) = ((Wrd20.pObj) [0]);

DEFLABEL (label_43)
  (Wrd30.Obj) = (current_block [OBJECT_44_1]);
  (* (Rhp++)) = (Wrd18.Obj);
  (* (Rhp++)) = (Wrd30.Obj);
  (Wrd28.pObj) = (& (Rhp [-2]));
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd28.pObj)));
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd45.Obj) = (Rsp [2]);
  (Wrd46.uLng) = (OBJECT_TYPE (Wrd45.Obj));
  if (! ((Wrd46.uLng) == 1))
    goto label_42;
  (Wrd43.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  ((Wrd43.pObj) [1]) = (Wrd29.Obj);

DEFLABEL (label_41)
  (Wrd34.Obj) = (Rsp [1]);
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if (! ((Wrd35.uLng) == 1))
    goto label_40;
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd31.Obj) = ((Wrd33.pObj) [1]);

DEFLABEL (label_39)
  (Rsp [1]) = (Wrd31.Obj);
  (Wrd40.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd40.Obj);
  Rsp = (& (Rsp [1]));
  goto loop_15;

DEFLABEL (label_40)
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_44_13]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44_2]), 1);

DEFLABEL (label_24)
  (Wrd31.Obj) = Rvl;
  goto label_39;

DEFLABEL (label_42)
  (Wrd51.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_44_12]))));
  (* (--Rsp)) = (Wrd51.Obj);
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd45.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44_4]), 2);

DEFLABEL (label_25)
  goto label_41;

DEFLABEL (label_44)
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_44_11]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_44_0]), 1);

DEFLABEL (label_23)
  (Wrd18.Obj) = Rvl;
  goto label_43;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_45_4 3
#define LABEL_45_5 5
#define LABEL_45_7 7
#define LABEL_45_6 9
#define LABEL_45_9 11
#define LABEL_45_8 13
#define ENVIRONMENT_LABEL_45_3 17
#define DEBUGGING_LABEL_45_2 16
#define OBJECT_45_1 15
#define OBJECT_45_0 14
#define FREE_REFERENCES_LABEL_45_0 14
#define NUMBER_OF_LINKER_SECTIONS_45_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_45 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd12;
  machine_word Wrd7;
  machine_word Wrd20;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd11;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_45_4);
      goto tree_copy_8;

    case 1:
      current_block = (Rpc - LABEL_45_5);
      goto walk_6;

    case 2:
      current_block = (Rpc - LABEL_45_7);
      goto label_10;

    case 3:
      current_block = (Rpc - LABEL_45_6);
      goto continuation_5;

    case 4:
      current_block = (Rpc - LABEL_45_9);
      goto label_11;

    case 5:
      current_block = (Rpc - LABEL_45_8);
      goto continuation_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (tree_copy_13)
DEFLABEL (tree_copy_8)
  INTERRUPT_CHECK (26, LABEL_45_4);
  goto walk_6;

DEFLABEL (walk_14)
DEFLABEL (walk_6)
  INTERRUPT_CHECK (26, LABEL_45_5);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_15;
  Rvl = (Wrd5.Obj);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_15)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_6]))));
  (* (--Rsp)) = (Wrd11.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_19;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [1]);
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_18)
  goto walk_6;

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_45_6);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd12.uLng) == 1))
    goto label_17;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [0]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_16)
  goto walk_6;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_45_8);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_17)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_9]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_45_1]), 1);

DEFLABEL (label_11)
  (* (--Rsp)) = Rvl;
  goto label_16;

DEFLABEL (label_19)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_7]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_45_0]), 1);

DEFLABEL (label_10)
  (* (--Rsp)) = Rvl;
  goto label_18;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_46_4 3
#define LABEL_46_5 5
#define LABEL_46_6 7
#define LABEL_46_7 9
#define TAG_46_8 3
#define ENVIRONMENT_LABEL_46_3 13
#define DEBUGGING_LABEL_46_2 12
#define OBJECT_46_1 11
#define OBJECT_46_0 10
#define FREE_REFERENCES_LABEL_46_0 10
#define NUMBER_OF_LINKER_SECTIONS_46_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_46 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd27;
  machine_word Wrd28;
  machine_word Wrd24;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd14;
  machine_word Wrd16;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd13;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd9;
  machine_word Wrd8;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_46_4);
      goto car_cdr_4;

    case 1:
      current_block = (Rpc - LABEL_46_5);
      goto label_6;

    case 2:
      current_block = (Rpc - LABEL_46_6);
      goto label_7;

    case 3:
      current_block = (Rpc - LABEL_46_7);
      goto lambda_10;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (car_cdr_9)
DEFLABEL (car_cdr_4)
  INTERRUPT_CHECK (26, LABEL_46_4);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_14;
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [0]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_13)
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_12;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd14.Obj) = ((Wrd16.pObj) [1]);

DEFLABEL (label_11)
  (Rsp [1]) = (Wrd14.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd25.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_46_8);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_46_7])));
  Rhp += 2;
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd25.pObj)));
  Wrd28 = Wrd25;
  ((Wrd28.pObj) [2]) = (Wrd14.Obj);
  (Wrd27.Obj) = (Rsp [0]);
  ((Wrd28.pObj) [3]) = (Wrd27.Obj);
  Rvl = (Wrd24.Obj);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_12)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_6]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_46_1]), 1);

DEFLABEL (label_7)
  (Wrd14.Obj) = Rvl;
  goto label_11;

DEFLABEL (label_14)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46_5]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_46_0]), 1);

DEFLABEL (label_6)
  (* (--Rsp)) = Rvl;
  goto label_13;

DEFLABEL (lambda_10)
  CLOSURE_HEADER (LABEL_46_7);

DEFLABEL (lambda_2)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd7.Obj) = (Rsp [1]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [2]);
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd9.Obj) = ((Wrd8.pObj) [3]);
  (Rsp [1]) = (Wrd9.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_47_4 3
#define LABEL_47_5 5
#define ENVIRONMENT_LABEL_47_3 11
#define DEBUGGING_LABEL_47_2 10
#define OBJECT_47_1 9
#define OBJECT_47_0 8
#define FREE_REFERENCE_47_0 7
#define FREE_REFERENCES_LABEL_47_0 6
#define NUMBER_OF_LINKER_SECTIONS_47_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_47 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd12;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_47_4);
      goto weak_cons_2;

    case 1:
      current_block = (Rpc - LABEL_47_5);
      goto label_4;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (weak_cons_6)
DEFLABEL (weak_cons_2)
  INTERRUPT_CHECK (26, LABEL_47_4);
  (Wrd5.Obj) = (current_block [OBJECT_47_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd6.Obj);
  if ((Wrd6.Obj) == ((SCHEME_OBJECT) 0))
    goto label_8;
  Wrd10 = Wrd6;

DEFLABEL (label_7)
  Rsp = (& (Rsp [1]));
  (Rsp [1]) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_47_1]), 3);

DEFLABEL (label_8)
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_47_0]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_10;
  Wrd12 = Wrd16;

DEFLABEL (label_9)
  Wrd10 = Wrd12;
  goto label_7;

DEFLABEL (label_10)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_47_5])), (Wrd13.pObj));

DEFLABEL (label_4)
  (Wrd12.Obj) = Rvl;
  goto label_9;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_48_4 3
#define ENVIRONMENT_LABEL_48_3 8
#define DEBUGGING_LABEL_48_2 7
#define OBJECT_48_2 6
#define OBJECT_48_1 5
#define OBJECT_48_0 4
#define FREE_REFERENCES_LABEL_48_0 4
#define NUMBER_OF_LINKER_SECTIONS_48_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_48 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd16;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_48_4);
      goto weak_pairP_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (weak_pairP_3)
DEFLABEL (weak_pairP_0)
  INTERRUPT_CHECK (26, LABEL_48_4);
  (Wrd5.Obj) = (current_block [OBJECT_48_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd16.Lng) = (1 << TYPE_CODE_LENGTH);
  if (((unsigned long) 55L) < ((unsigned long) (Wrd16.Lng)))
    goto label_4;
  INVOKE_PRIMITIVE ((current_block [OBJECT_48_2]), 2);

DEFLABEL (label_4)
  (Wrd8.uLng) = (OBJECT_DATUM (Wrd5.Obj));
  (Wrd9.Obj) = (Rsp [1]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd8.Obj) == (Wrd10.Obj))
    goto label_6;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_5;

DEFLABEL (label_6)
  Rvl = (current_block [OBJECT_48_1]);

DEFLABEL (label_5)
DEFLABEL (label_7)
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_49_4 3
#define ENVIRONMENT_LABEL_49_3 5
#define DEBUGGING_LABEL_49_2 4
#define FREE_REFERENCES_LABEL_49_0 4
#define NUMBER_OF_LINKER_SECTIONS_49_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_49 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd7;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_49_4);
      goto weak_pair_carP_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (weak_pair_carP_3)
DEFLABEL (weak_pair_carP_0)
  INTERRUPT_CHECK (26, LABEL_49_4);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  Rvl = ((Wrd7.pObj) [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_50_4 3
#define LABEL_50_5 5
#define ENVIRONMENT_LABEL_50_3 9
#define DEBUGGING_LABEL_50_2 8
#define FREE_REFERENCE_50_0 7
#define FREE_REFERENCES_LABEL_50_0 6
#define NUMBER_OF_LINKER_SECTIONS_50_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_50 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd15;
  machine_word Wrd9;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd5;
  machine_word Wrd7;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_50_4);
      goto weak_car_3;

    case 1:
      current_block = (Rpc - LABEL_50_5);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (weak_car_7)
DEFLABEL (weak_car_3)
  INTERRUPT_CHECK (26, LABEL_50_4);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [0]);
  (Rsp [0]) = (Wrd5.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_50_0]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_12;
  Wrd9 = Wrd13;

DEFLABEL (label_11)
  (Wrd15.Obj) = (Rsp [0]);
  if ((Wrd15.Obj) == (Wrd9.Obj))
    goto label_9;
  Rvl = (Wrd15.Obj);
  goto label_8;

DEFLABEL (label_9)
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_8)
DEFLABEL (label_10)
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_12)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_50_5])), (Wrd10.pObj));

DEFLABEL (label_5)
  (Wrd9.Obj) = Rvl;
  goto label_11;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_51_4 3
#define LABEL_51_5 5
#define ENVIRONMENT_LABEL_51_3 10
#define DEBUGGING_LABEL_51_2 9
#define OBJECT_51_0 8
#define FREE_REFERENCE_51_0 7
#define FREE_REFERENCES_LABEL_51_0 6
#define NUMBER_OF_LINKER_SECTIONS_51_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_51 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd12;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_51_4);
      goto weak_set_carB_2;

    case 1:
      current_block = (Rpc - LABEL_51_5);
      goto label_4;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (weak_set_carB_6)
DEFLABEL (weak_set_carB_2)
  INTERRUPT_CHECK (26, LABEL_51_4);
  (Wrd5.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd5.Obj);
  if ((Wrd5.Obj) == ((SCHEME_OBJECT) 0))
    goto label_8;
  Wrd9 = Wrd5;

DEFLABEL (label_7)
  Rsp = (& (Rsp [1]));
  (Rsp [1]) = (Wrd9.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_51_0]), 2);

DEFLABEL (label_8)
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_51_0]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_10;
  Wrd11 = Wrd15;

DEFLABEL (label_9)
  Wrd9 = Wrd11;
  goto label_7;

DEFLABEL (label_10)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_51_5])), (Wrd12.pObj));

DEFLABEL (label_4)
  (Wrd11.Obj) = Rvl;
  goto label_9;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_52_4 3
#define ENVIRONMENT_LABEL_52_3 5
#define DEBUGGING_LABEL_52_2 4
#define FREE_REFERENCES_LABEL_52_0 4
#define NUMBER_OF_LINKER_SECTIONS_52_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_52 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd7;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_52_4);
      goto weak_cdr_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (weak_cdr_3)
DEFLABEL (weak_cdr_0)
  INTERRUPT_CHECK (26, LABEL_52_4);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  Rvl = ((Wrd7.pObj) [1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_53_4 3
#define ENVIRONMENT_LABEL_53_3 6
#define DEBUGGING_LABEL_53_2 5
#define OBJECT_53_0 4
#define FREE_REFERENCES_LABEL_53_0 4
#define NUMBER_OF_LINKER_SECTIONS_53_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_53 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_53_4);
      goto weak_set_cdrB_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (weak_set_cdrB_3)
DEFLABEL (weak_set_cdrB_0)
  INTERRUPT_CHECK (26, LABEL_53_4);
  INVOKE_PRIMITIVE ((current_block [OBJECT_53_0]), 2);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_54_4 3
#define LABEL_54_5 5
#define LABEL_54_6 7
#define LABEL_54_7 9
#define LABEL_54_10 11
#define ENVIRONMENT_LABEL_54_3 25
#define DEBUGGING_LABEL_54_2 24
#define OBJECT_54_4 23
#define OBJECT_54_3 22
#define OBJECT_54_2 21
#define OBJECT_54_1 20
#define OBJECT_54_0 19
#define EXECUTE_CACHE_54_9 13
#define EXECUTE_CACHE_54_8 15
#define FREE_REFERENCE_54_0 18
#define FREE_REFERENCES_LABEL_54_0 12
#define NUMBER_OF_LINKER_SECTIONS_54_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_54 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd37;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd35;
  machine_word Wrd36;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd24;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd25;
  machine_word Wrd33;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd16;
  machine_word Wrd9;
  machine_word Wrd49;
  machine_word Wrd46;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd44;
  machine_word Wrd41;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_54_4);
      goto weak_list__list_12;

    case 1:
      current_block = (Rpc - LABEL_54_5);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_54_6);
      goto loop_10;

    case 3:
      current_block = (Rpc - LABEL_54_7);
      goto label_15;

    case 4:
      current_block = (Rpc - LABEL_54_10);
      goto label_14;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (weak_list__list_17)
DEFLABEL (weak_list__list_12)
  INTERRUPT_CHECK (26, LABEL_54_4);
  (Wrd5.Obj) = (current_block [OBJECT_54_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd6.Obj);
  goto loop_10;

DEFLABEL (loop_18)
DEFLABEL (loop_10)
  INTERRUPT_CHECK (26, LABEL_54_6);
  (Wrd41.Obj) = (current_block [OBJECT_54_1]);
  (Wrd44.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 55L) < ((unsigned long) (Wrd44.Lng))))
    goto label_30;
  (Wrd6.uLng) = (OBJECT_DATUM (Wrd41.Obj));
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if ((Wrd6.Obj) == (Wrd8.Obj))
    goto label_22;

DEFLABEL (label_21)
  (Wrd9.Obj) = (Rsp [0]);
  if (! ((Wrd9.Obj) == (current_block [OBJECT_54_0])))
    goto label_20;

DEFLABEL (label_19)
  (Wrd16.Obj) = (Rsp [1]);
  (Rsp [2]) = (Wrd16.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_54_8]));

DEFLABEL (label_20)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_54_5]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_54_3]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_54_9]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_54_5);
  goto label_19;

DEFLABEL (label_22)
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [0]);
  (* (--Rsp)) = (Wrd20.Obj);
  if ((Wrd20.Obj) == ((SCHEME_OBJECT) 0))
    goto label_29;
  (Wrd25.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_54_0]));
  (Wrd28.Obj) = ((Wrd25.pObj) [0]);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if ((Wrd29.uLng) == 50)
    goto label_28;
  Wrd24 = Wrd28;

DEFLABEL (label_27)
  (Wrd30.Obj) = (Rsp [0]);
  if ((Wrd30.Obj) == (Wrd24.Obj))
    goto label_24;
  Wrd31 = Wrd30;
  goto label_23;

DEFLABEL (label_24)
  (Wrd31.Obj) = (current_block [OBJECT_54_4]);

DEFLABEL (label_23)
DEFLABEL (label_26)
  (Wrd36.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd31.Obj);
  (* (Rhp++)) = (Wrd36.Obj);
  (Wrd35.pObj) = (& (Rhp [-2]));
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd35.pObj)));

DEFLABEL (label_25)
  Rsp = (& (Rsp [1]));
  (Rsp [1]) = (Wrd33.Obj);
  (Wrd38.Obj) = (Rsp [0]);
  (Wrd39.pObj) = (OBJECT_ADDRESS (Wrd38.Obj));
  (Wrd37.Obj) = ((Wrd39.pObj) [1]);
  (Rsp [0]) = (Wrd37.Obj);
  goto loop_10;

DEFLABEL (label_28)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_54_10])), (Wrd25.pObj));

DEFLABEL (label_14)
  (Wrd24.Obj) = Rvl;
  goto label_27;

DEFLABEL (label_29)
  (Wrd33.Obj) = (Rsp [2]);
  goto label_25;

DEFLABEL (label_30)
  (Wrd46.Obj) = (Rsp [0]);
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_54_7]))));
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd46.Obj);
  (* (--Rsp)) = (Wrd41.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_54_2]), 2);

DEFLABEL (label_15)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_21;
  goto label_22;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_55_4 3
#define LABEL_55_5 5
#define LABEL_55_7 7
#define LABEL_55_8 9
#define LABEL_55_10 11
#define LABEL_55_11 13
#define LABEL_55_9 15
#define LABEL_55_13 17
#define ENVIRONMENT_LABEL_55_3 32
#define DEBUGGING_LABEL_55_2 31
#define OBJECT_55_5 30
#define OBJECT_55_4 29
#define OBJECT_55_3 28
#define OBJECT_55_2 27
#define OBJECT_55_1 26
#define OBJECT_55_0 25
#define EXECUTE_CACHE_55_12 19
#define EXECUTE_CACHE_55_6 21
#define FREE_REFERENCE_55_0 24
#define FREE_REFERENCES_LABEL_55_0 18
#define NUMBER_OF_LINKER_SECTIONS_55_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_55 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd14;
  machine_word Wrd10;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd33;
  machine_word Wrd36;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd37;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_55_4);
      goto list__weak_list_12;

    case 1:
      current_block = (Rpc - LABEL_55_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_55_7);
      goto continuation_4;

    case 3:
      current_block = (Rpc - LABEL_55_8);
      goto loop_10;

    case 4:
      current_block = (Rpc - LABEL_55_10);
      goto label_14;

    case 5:
      current_block = (Rpc - LABEL_55_11);
      goto label_15;

    case 6:
      current_block = (Rpc - LABEL_55_9);
      goto continuation_9;

    case 7:
      current_block = (Rpc - LABEL_55_13);
      goto label_16;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (list__weak_list_18)
DEFLABEL (list__weak_list_12)
  INTERRUPT_CHECK (26, LABEL_55_4);
  (Wrd5.Obj) = (current_block [OBJECT_55_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_55_5]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_55_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_55_5);
  (* (--Rsp)) = Rvl;
  goto loop_10;

DEFLABEL (loop_19)
DEFLABEL (loop_10)
  INTERRUPT_CHECK (26, LABEL_55_8);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_22;
  if (! ((Wrd5.Obj) == (current_block [OBJECT_55_0])))
    goto label_21;

DEFLABEL (label_20)
  Rvl = (Rsp [1]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_21)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_55_7]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_55_4]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_55_12]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_55_7);
  goto label_20;

DEFLABEL (label_22)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_55_9]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd19.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd19.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_30;
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd22.Obj) = ((Wrd21.pObj) [0]);
  (* (--Rsp)) = (Wrd22.Obj);

DEFLABEL (label_29)
  (Wrd29.Obj) = (Rsp [0]);
  if ((Wrd29.Obj) == ((SCHEME_OBJECT) 0))
    goto label_26;
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd29.Obj);

DEFLABEL (label_25)
  (Wrd33.Obj) = (current_block [OBJECT_55_2]);
  (* (--Rsp)) = (Wrd33.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_55_3]), 3);

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_55_9);
  (Rsp [1]) = Rvl;
  (Wrd9.Obj) = (Rsp [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if (! ((Wrd10.uLng) == 1))
    goto label_24;
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [1]);

DEFLABEL (label_23)
  (Rsp [0]) = (Wrd6.Obj);
  goto loop_10;

DEFLABEL (label_24)
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_55_13]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_55_5]), 1);

DEFLABEL (label_16)
  (Wrd6.Obj) = Rvl;
  goto label_23;

DEFLABEL (label_26)
  (Wrd37.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_55_0]));
  (Wrd40.Obj) = ((Wrd37.pObj) [0]);
  (Wrd41.uLng) = (OBJECT_TYPE (Wrd40.Obj));
  if ((Wrd41.uLng) == 50)
    goto label_28;
  Wrd36 = Wrd40;

DEFLABEL (label_27)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd36.Obj);
  goto label_25;

DEFLABEL (label_28)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_55_11])), (Wrd37.pObj));

DEFLABEL (label_15)
  (Wrd36.Obj) = Rvl;
  goto label_27;

DEFLABEL (label_30)
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_55_10]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_55_1]), 1);

DEFLABEL (label_14)
  (* (--Rsp)) = Rvl;
  goto label_29;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_56_4 3
#define LABEL_56_5 5
#define LABEL_56_6 7
#define LABEL_56_7 9
#define ENVIRONMENT_LABEL_56_3 15
#define DEBUGGING_LABEL_56_2 14
#define OBJECT_56_3 13
#define OBJECT_56_2 12
#define OBJECT_56_1 11
#define OBJECT_56_0 10
#define FREE_REFERENCES_LABEL_56_0 10
#define NUMBER_OF_LINKER_SECTIONS_56_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_56 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd31;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd28;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd24;
  machine_word Wrd43;
  machine_word Wrd22;
  machine_word Wrd20;
  machine_word Wrd38;
  machine_word Wrd35;
  machine_word Wrd18;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd10;
  machine_word Wrd55;
  machine_word Wrd52;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd50;
  machine_word Wrd47;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_56_4);
      goto weak_listP_10;

    case 1:
      current_block = (Rpc - LABEL_56_5);
      goto loop_8;

    case 2:
      current_block = (Rpc - LABEL_56_6);
      goto label_13;

    case 3:
      current_block = (Rpc - LABEL_56_7);
      goto label_12;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (weak_listP_15)
DEFLABEL (weak_listP_10)
  INTERRUPT_CHECK (26, LABEL_56_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  goto loop_8;

DEFLABEL (loop_16)
DEFLABEL (loop_8)
  INTERRUPT_CHECK (26, LABEL_56_5);
  (Wrd47.Obj) = (current_block [OBJECT_56_0]);
  (Wrd50.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 55L) < ((unsigned long) (Wrd50.Lng))))
    goto label_29;
  (Wrd6.uLng) = (OBJECT_DATUM (Wrd47.Obj));
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if ((Wrd6.Obj) == (Wrd8.Obj))
    goto label_21;

DEFLABEL (label_20)
  (Wrd10.Obj) = (Rsp [0]);
  if ((Wrd10.Obj) == (current_block [OBJECT_56_2]))
    goto label_18;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_17;

DEFLABEL (label_18)
  Rvl = (current_block [OBJECT_56_3]);

DEFLABEL (label_17)
DEFLABEL (label_19)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_21)
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [1]);
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd18.Obj) = (Rsp [2]);
  if ((Wrd16.Obj) == (Wrd18.Obj))
    goto label_26;
  (Wrd35.Obj) = (current_block [OBJECT_56_0]);
  (Wrd38.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 55L) < ((unsigned long) (Wrd38.Lng))))
    goto label_28;
  (Wrd20.uLng) = (OBJECT_DATUM (Wrd35.Obj));
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd20.Obj) == (Wrd22.Obj)))
    goto label_23;

DEFLABEL (label_22)
  (Wrd29.Obj) = (Rsp [0]);
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd29.Obj));
  (Wrd28.Obj) = ((Wrd30.pObj) [1]);
  (Rsp [1]) = (Wrd28.Obj);
  (Wrd32.Obj) = (Rsp [2]);
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd31.Obj) = ((Wrd33.pObj) [1]);
  (Rsp [2]) = (Wrd31.Obj);
  Rsp = (& (Rsp [1]));
  goto loop_8;

DEFLABEL (label_23)
  (Wrd24.Obj) = (Rsp [0]);
  if ((Wrd24.Obj) == (current_block [OBJECT_56_2]))
    goto label_25;

DEFLABEL (label_26)
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_24;

DEFLABEL (label_25)
  Rvl = (current_block [OBJECT_56_3]);

DEFLABEL (label_24)
DEFLABEL (label_27)
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_28)
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_56_7]))));
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_56_1]), 2);

DEFLABEL (label_12)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_23;
  goto label_22;

DEFLABEL (label_29)
  (Wrd52.Obj) = (Rsp [0]);
  (Wrd55.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_56_6]))));
  (* (--Rsp)) = (Wrd55.Obj);
  (* (--Rsp)) = (Wrd52.Obj);
  (* (--Rsp)) = (Wrd47.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_56_1]), 2);

DEFLABEL (label_13)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_20;
  goto label_21;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_57_4 3
#define LABEL_57_5 5
#define ENVIRONMENT_LABEL_57_3 13
#define DEBUGGING_LABEL_57_2 12
#define OBJECT_57_0 11
#define EXECUTE_CACHE_57_7 7
#define EXECUTE_CACHE_57_6 9
#define FREE_REFERENCES_LABEL_57_0 6
#define NUMBER_OF_LINKER_SECTIONS_57_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_57 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_57_4);
      goto guarantee_weak_list_1;

    case 1:
      current_block = (Rpc - LABEL_57_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (guarantee_weak_list_4)
DEFLABEL (guarantee_weak_list_1)
  INTERRUPT_CHECK (26, LABEL_57_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_57_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_57_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_57_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_5;
  Rvl = (current_block [OBJECT_57_0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_5)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_57_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_58_4 3
#define ENVIRONMENT_LABEL_58_3 11
#define DEBUGGING_LABEL_58_2 10
#define OBJECT_58_2 9
#define OBJECT_58_1 8
#define OBJECT_58_0 7
#define EXECUTE_CACHE_58_5 5
#define FREE_REFERENCES_LABEL_58_0 4
#define NUMBER_OF_LINKER_SECTIONS_58_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_58 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_58_4);
      goto error_not_weak_list_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (error_not_weak_list_5)
DEFLABEL (error_not_weak_list_2)
  INTERRUPT_CHECK (26, LABEL_58_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_58_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [2]);
  if ((Wrd7.Obj) == (current_block [OBJECT_58_1]))
    goto label_7;
  Wrd9 = Wrd7;
  goto label_6;

DEFLABEL (label_7)
  (Wrd9.Obj) = (current_block [OBJECT_58_2]);

DEFLABEL (label_6)
DEFLABEL (label_8)
  (Rsp [2]) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_58_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_59_4 3
#define LABEL_59_5 5
#define LABEL_59_6 7
#define LABEL_59_7 9
#define LABEL_59_8 11
#define ENVIRONMENT_LABEL_59_3 22
#define DEBUGGING_LABEL_59_2 21
#define OBJECT_59_3 20
#define OBJECT_59_2 19
#define OBJECT_59_1 18
#define OBJECT_59_0 17
#define EXECUTE_CACHE_59_9 13
#define FREE_REFERENCE_59_0 16
#define FREE_REFERENCES_LABEL_59_0 12
#define NUMBER_OF_LINKER_SECTIONS_59_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_59 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd15;
  machine_word Wrd9;
  machine_word Wrd35;
  machine_word Wrd32;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd30;
  machine_word Wrd27;
  machine_word Wrd10;
  machine_word Wrd13;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd14;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_59_4);
      goto weak_memq_12;

    case 1:
      current_block = (Rpc - LABEL_59_5);
      goto label_14;

    case 2:
      current_block = (Rpc - LABEL_59_6);
      goto continuation_5;

    case 3:
      current_block = (Rpc - LABEL_59_7);
      goto loop_9;

    case 4:
      current_block = (Rpc - LABEL_59_8);
      goto label_15;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (weak_memq_17)
DEFLABEL (weak_memq_12)
  INTERRUPT_CHECK (26, LABEL_59_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  if ((Wrd5.Obj) == ((SCHEME_OBJECT) 0))
    goto label_20;
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd5.Obj);

DEFLABEL (label_19)
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  goto loop_9;

DEFLABEL (label_20)
  (Wrd14.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_59_0]));
  (Wrd17.Obj) = ((Wrd14.pObj) [0]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if ((Wrd18.uLng) == 50)
    goto label_22;
  Wrd13 = Wrd17;

DEFLABEL (label_21)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd13.Obj);
  goto label_19;

DEFLABEL (label_22)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_59_5])), (Wrd14.pObj));

DEFLABEL (label_14)
  (Wrd13.Obj) = Rvl;
  goto label_21;

DEFLABEL (loop_18)
DEFLABEL (loop_9)
  INTERRUPT_CHECK (26, LABEL_59_7);
  (Wrd27.Obj) = (current_block [OBJECT_59_0]);
  (Wrd30.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 55L) < ((unsigned long) (Wrd30.Lng))))
    goto label_28;
  (Wrd6.uLng) = (OBJECT_DATUM (Wrd27.Obj));
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if ((Wrd6.Obj) == (Wrd8.Obj))
    goto label_26;

DEFLABEL (label_25)
  (Wrd9.Obj) = (Rsp [0]);
  if ((Wrd9.Obj) == (current_block [OBJECT_59_2]))
    goto label_24;
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_59_6]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_59_3]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_59_9]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_59_6);

DEFLABEL (label_24)
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_23)
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_26)
  (Wrd19.Obj) = (Rsp [0]);
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd18.Obj) = ((Wrd20.pObj) [0]);
  (Wrd21.Obj) = (Rsp [1]);
  if ((Wrd21.Obj) == (Wrd18.Obj))
    goto label_27;
  (Wrd22.Obj) = ((Wrd20.pObj) [1]);
  (Rsp [0]) = (Wrd22.Obj);
  goto loop_9;

DEFLABEL (label_27)
  Rvl = (Wrd19.Obj);
  goto label_23;

DEFLABEL (label_28)
  (Wrd32.Obj) = (Rsp [0]);
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_59_8]))));
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_59_1]), 2);

DEFLABEL (label_15)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_25;
  goto label_26;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_60_4 3
#define LABEL_60_5 5
#define LABEL_60_6 7
#define LABEL_60_7 9
#define LABEL_60_10 11
#define LABEL_60_11 13
#define LABEL_60_12 15
#define LABEL_60_9 17
#define ENVIRONMENT_LABEL_60_3 27
#define DEBUGGING_LABEL_60_2 26
#define OBJECT_60_4 25
#define OBJECT_60_3 24
#define OBJECT_60_2 23
#define OBJECT_60_1 22
#define OBJECT_60_0 21
#define EXECUTE_CACHE_60_8 19
#define FREE_REFERENCES_LABEL_60_0 18
#define NUMBER_OF_LINKER_SECTIONS_60_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_60 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd37;
  machine_word Wrd34;
  machine_word Wrd14;
  machine_word Wrd54;
  machine_word Wrd51;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd49;
  machine_word Wrd61;
  machine_word Wrd64;
  machine_word Wrd63;
  machine_word Wrd41;
  machine_word Wrd38;
  machine_word Wrd35;
  machine_word Wrd31;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd21;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd47;
  machine_word Wrd55;
  machine_word Wrd50;
  machine_word Wrd52;
  machine_word Wrd8;
  machine_word Wrd46;
  machine_word Wrd43;
  machine_word Wrd57;
  machine_word Wrd7;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_60_4);
      goto weak_delqB_20;

    case 1:
      current_block = (Rpc - LABEL_60_5);
      goto continuation_2;

    case 2:
      current_block = (Rpc - LABEL_60_6);
      goto lambda_9;

    case 3:
      current_block = (Rpc - LABEL_60_7);
      goto label_22;

    case 4:
      current_block = (Rpc - LABEL_60_10);
      goto continuation_17;

    case 5:
      current_block = (Rpc - LABEL_60_11);
      goto lambda_18;

    case 6:
      current_block = (Rpc - LABEL_60_12);
      goto label_23;

    case 7:
      current_block = (Rpc - LABEL_60_9);
      goto continuation_7;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (weak_delqB_25)
DEFLABEL (weak_delqB_20)
  INTERRUPT_CHECK (26, LABEL_60_4);
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (59, Rsp));
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  Rdl = (& (Rsp [4]));
  goto lambda_9;

DEFLABEL (lambda_26)
DEFLABEL (lambda_9)
  DLINK_INTERRUPT_CHECK (25, LABEL_60_6);
  (Wrd43.Obj) = (current_block [OBJECT_60_0]);
  (Wrd46.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 55L) < ((unsigned long) (Wrd46.Lng))))
    goto label_35;
  (Wrd6.uLng) = (OBJECT_DATUM (Wrd43.Obj));
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if ((Wrd6.Obj) == (Wrd8.Obj))
    goto label_31;

DEFLABEL (label_30)
  (Wrd9.Obj) = (Rsp [0]);
  if (! ((Wrd9.Obj) == (current_block [OBJECT_60_2])))
    goto label_29;

DEFLABEL (label_28)
  Rvl = (current_block [OBJECT_60_2]);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_29)
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_60_5]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (current_block [OBJECT_60_3]);
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (Rsp [4]);
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd19.Obj) = ((Wrd18.pObj) [1]);
  (* (--Rsp)) = (Wrd19.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_60_8]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_60_5);
  (Wrd57.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd57.Obj));
  goto label_28;

DEFLABEL (label_31)
  (Wrd22.Obj) = (Rsp [0]);
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
  (Wrd21.Obj) = ((Wrd23.pObj) [0]);
  (Wrd24.Obj) = (Rsp [1]);
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  if (! ((Wrd26.Obj) == (Wrd21.Obj)))
    goto label_33;

DEFLABEL (label_32)
  (Wrd32.Obj) = (Rsp [0]);
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd31.Obj) = ((Wrd33.pObj) [1]);
  (Rsp [0]) = (Wrd31.Obj);
  goto lambda_9;

DEFLABEL (label_33)
  if ((Wrd21.Obj) == ((SCHEME_OBJECT) 0))
    goto label_32;
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd35.Obj);
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_60_9]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (Wrd41.Obj) = ((Wrd23.pObj) [1]);
  (* (--Rsp)) = (Wrd41.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  goto lambda_18;

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_60_9);

DEFLABEL (label_34)
  (Wrd57.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd57.Obj));
  Rvl = (Rsp [0]);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_35)
  (Wrd52.Obj) = (Rsp [0]);
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd50.Obj);
  (Wrd55.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_60_7]))));
  (* (--Rsp)) = (Wrd55.Obj);
  (* (--Rsp)) = (Wrd52.Obj);
  (* (--Rsp)) = (Wrd43.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_60_1]), 2);

DEFLABEL (label_22)
  (Wrd47.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd47.Obj));
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_30;
  goto label_31;

DEFLABEL (lambda_27)
DEFLABEL (lambda_18)
  INTERRUPT_CHECK (26, LABEL_60_11);
  (Wrd46.Obj) = (current_block [OBJECT_60_0]);
  (Wrd49.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 55L) < ((unsigned long) (Wrd49.Lng))))
    goto label_42;
  (Wrd9.uLng) = (OBJECT_DATUM (Wrd46.Obj));
  (Wrd10.Obj) = (Rsp [1]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd9.Obj) == (Wrd11.Obj))
    goto label_38;

DEFLABEL (label_37)
  (Wrd12.Obj) = (Rsp [1]);
  if ((Wrd12.Obj) == (current_block [OBJECT_60_2]))
    goto label_36;
  (Wrd15.Obj) = (Rsp [5]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd14.Obj) = ((Wrd16.pObj) [1]);
  (Rsp [0]) = (Wrd14.Obj);
  (Wrd17.Obj) = (current_block [OBJECT_60_3]);
  (Rsp [1]) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_60_8]));

DEFLABEL (label_36)
  Rsp = (& (Rsp [3]));
  goto label_34;

DEFLABEL (label_38)
  (Wrd22.Obj) = (Rsp [1]);
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
  (Wrd21.Obj) = ((Wrd23.pObj) [0]);
  (Wrd24.Obj) = (Rsp [5]);
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  if (! ((Wrd26.Obj) == (Wrd21.Obj)))
    goto label_41;

DEFLABEL (label_40)
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_60_10]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd34.Obj) = (Rsp [6]);
  (Wrd35.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd35.pObj)));
  (* (--Rsp)) = (Wrd37.Obj);
  (Wrd38.Obj) = (Rsp [3]);
  (Wrd39.pObj) = (OBJECT_ADDRESS (Wrd38.Obj));
  (Wrd40.Obj) = ((Wrd39.pObj) [1]);
  (* (--Rsp)) = (Wrd40.Obj);
  Rdl = (& (Rsp [2]));
  goto lambda_9;

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_60_10);
  (Rsp [1]) = Rvl;
  (Wrd63.Obj) = (Rsp [0]);
  (Wrd64.uLng) = (OBJECT_TYPE (Wrd63.Obj));
  if ((Wrd64.uLng) == 1)
    goto label_39;
  INVOKE_PRIMITIVE ((current_block [OBJECT_60_4]), 2);

DEFLABEL (label_39)
  (Wrd61.pObj) = (OBJECT_ADDRESS (Wrd63.Obj));
  ((Wrd61.pObj) [1]) = Rvl;
  goto label_36;

DEFLABEL (label_41)
  if ((Wrd21.Obj) == ((SCHEME_OBJECT) 0))
    goto label_40;
  (Rsp [0]) = (Wrd22.Obj);
  (Wrd43.Obj) = ((Wrd23.pObj) [1]);
  (Rsp [1]) = (Wrd43.Obj);
  goto lambda_18;

DEFLABEL (label_42)
  (Wrd51.Obj) = (Rsp [1]);
  (Wrd54.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_60_12]))));
  (* (--Rsp)) = (Wrd54.Obj);
  (* (--Rsp)) = (Wrd51.Obj);
  (* (--Rsp)) = (Wrd46.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_60_1]), 2);

DEFLABEL (label_23)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_37;
  goto label_38;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_61_4 3
#define LABEL_61_5 5
#define LABEL_61_7 7
#define LABEL_61_8 9
#define LABEL_61_9 11
#define ENVIRONMENT_LABEL_61_3 22
#define DEBUGGING_LABEL_61_2 21
#define OBJECT_61_3 20
#define OBJECT_61_2 19
#define OBJECT_61_1 18
#define OBJECT_61_0 17
#define EXECUTE_CACHE_61_10 13
#define EXECUTE_CACHE_61_6 15
#define FREE_REFERENCES_LABEL_61_0 12
#define NUMBER_OF_LINKER_SECTIONS_61_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_61 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd17;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd19;
  machine_word Wrd16;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_61_4);
      goto decode_general_car_cdr_9;

    case 1:
      current_block = (Rpc - LABEL_61_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_61_7);
      goto do_loop_7;

    case 3:
      current_block = (Rpc - LABEL_61_8);
      goto label_11;

    case 4:
      current_block = (Rpc - LABEL_61_9);
      goto continuation_4;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (decode_general_car_cdr_13)
DEFLABEL (decode_general_car_cdr_9)
  INTERRUPT_CHECK (26, LABEL_61_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_61_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_61_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_61_5);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_61_0]);
  (Rsp [1]) = (Wrd6.Obj);
  goto do_loop_7;

DEFLABEL (do_loop_14)
DEFLABEL (do_loop_7)
  INTERRUPT_CHECK (26, LABEL_61_7);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd6.uLng) == 26))
    goto label_20;
  if (! ((Wrd5.Obj) == (current_block [OBJECT_61_1])))
    goto label_16;

DEFLABEL (label_15)
  Rvl = (Rsp [1]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_16)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_61_9]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_61_10]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_61_9);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_18;
  (Wrd7.Obj) = (current_block [OBJECT_61_3]);
  goto label_17;

DEFLABEL (label_18)
  (Wrd7.Obj) = (current_block [OBJECT_61_2]);

DEFLABEL (label_17)
DEFLABEL (label_19)
  (Wrd11.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd7.Obj);
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd10.pObj) = (& (Rhp [-2]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd10.pObj)));
  (Rsp [1]) = (Wrd8.Obj);
  (Wrd13.Obj) = (Rsp [0]);
  (Wrd14.Lng) = (FIXNUM_TO_LONG (Wrd13.Obj));
  (Wrd17.Lng) = ((long) (RIGHT_SHIFT_UNSIGNED (((unsigned long) (Wrd14.Lng)), 1)));
  (Wrd12.Obj) = (LONG_TO_FIXNUM (Wrd17.Lng));
  (Rsp [0]) = (Wrd12.Obj);
  goto do_loop_7;

DEFLABEL (label_20)
  (Wrd16.Obj) = (current_block [OBJECT_61_1]);
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_61_8]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_INTERFACE_0 (36);

DEFLABEL (label_11)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_16;
  goto label_15;

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_62_4 3
#define LABEL_62_5 5
#define LABEL_62_6 7
#define LABEL_62_7 9
#define LABEL_62_8 11
#define LABEL_62_9 13
#define LABEL_62_10 15
#define LABEL_62_11 17
#define ENVIRONMENT_LABEL_62_3 31
#define DEBUGGING_LABEL_62_2 30
#define OBJECT_62_8 29
#define OBJECT_62_7 28
#define OBJECT_62_6 27
#define OBJECT_62_5 26
#define OBJECT_62_4 25
#define OBJECT_62_3 24
#define OBJECT_62_2 23
#define OBJECT_62_1 22
#define OBJECT_62_0 21
#define EXECUTE_CACHE_62_12 19
#define FREE_REFERENCES_LABEL_62_0 18
#define NUMBER_OF_LINKER_SECTIONS_62_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_62 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd37;
  machine_word Wrd29;
  machine_word Wrd31;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd28;
  machine_word Wrd73;
  machine_word Wrd65;
  machine_word Wrd67;
  machine_word Wrd69;
  machine_word Wrd68;
  machine_word Wrd58;
  machine_word Wrd59;
  machine_word Wrd62;
  machine_word Wrd64;
  machine_word Wrd63;
  machine_word Wrd61;
  machine_word Wrd60;
  machine_word Wrd53;
  machine_word Wrd44;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd45;
  machine_word Wrd48;
  machine_word Wrd50;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd39;
  machine_word Wrd75;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd14;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_62_4);
      goto encode_general_car_cdr_14;

    case 1:
      current_block = (Rpc - LABEL_62_5);
      goto continuation_6;

    case 2:
      current_block = (Rpc - LABEL_62_6);
      goto do_loop_12;

    case 3:
      current_block = (Rpc - LABEL_62_7);
      goto label_16;

    case 4:
      current_block = (Rpc - LABEL_62_8);
      goto label_18;

    case 5:
      current_block = (Rpc - LABEL_62_9);
      goto label_19;

    case 6:
      current_block = (Rpc - LABEL_62_10);
      goto label_20;

    case 7:
      current_block = (Rpc - LABEL_62_11);
      goto label_17;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (encode_general_car_cdr_22)
DEFLABEL (encode_general_car_cdr_14)
  INTERRUPT_CHECK (26, LABEL_62_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_62_0]);
  (Rsp [1]) = (Wrd6.Obj);
  goto do_loop_12;

DEFLABEL (do_loop_23)
DEFLABEL (do_loop_12)
  INTERRUPT_CHECK (26, LABEL_62_6);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_25;
  (Wrd7.Obj) = (Rsp [1]);
  (Wrd8.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if ((Wrd8.uLng) == 26)
    goto label_24;
  (Wrd9.Obj) = (current_block [OBJECT_62_8]);
  (Rsp [0]) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_62_12]));

DEFLABEL (label_24)
  Rvl = (Wrd7.Obj);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_25)
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_5]))));
  (* (--Rsp)) = (Wrd14.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_38;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (* (--Rsp)) = (Wrd17.Obj);

DEFLABEL (label_37)
  (Wrd24.Obj) = (Rsp [0]);
  if ((Wrd24.Obj) == (current_block [OBJECT_62_2]))
    goto label_36;
  if ((Wrd24.Obj) == (current_block [OBJECT_62_3]))
    goto label_28;
  (Wrd28.Obj) = (current_block [OBJECT_62_7]);
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd32.Obj) = (Rsp [3]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd33.uLng) == 1))
    goto label_27;
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd29.Obj) = ((Wrd31.pObj) [0]);

DEFLABEL (label_26)
  (Rsp [1]) = (Wrd29.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_62_12]));

DEFLABEL (label_27)
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_11]))));
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_1]), 1);

DEFLABEL (label_17)
  (Wrd29.Obj) = Rvl;
  goto label_26;

DEFLABEL (label_28)
  (Wrd39.Obj) = (current_block [OBJECT_62_4]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd39.Obj);

DEFLABEL (label_35)
  (Wrd46.Obj) = (Rsp [2]);
  (Wrd47.uLng) = (OBJECT_TYPE (Wrd46.Obj));
  if (! ((Wrd47.uLng) == 26))
    goto label_34;
  (Wrd50.Lng) = (FIXNUM_TO_LONG (Wrd46.Obj));
  if (multiply_with_overflow ((Wrd50.Lng), 2, (& (Wrd48.Lng))))
    goto label_34;
  (Wrd45.Obj) = (LONG_TO_FIXNUM (Wrd48.Lng));

DEFLABEL (label_33)
  (Wrd53.Obj) = (* (Rsp++));
  (Wrd60.uLng) = (OBJECT_TYPE (Wrd45.Obj));
  if (! ((Wrd60.uLng) == 26))
    goto label_32;
  (Wrd61.uLng) = (OBJECT_TYPE (Wrd53.Obj));
  if (! ((Wrd61.uLng) == 26))
    goto label_32;
  (Wrd63.Lng) = (FIXNUM_TO_LONG (Wrd45.Obj));
  (Wrd64.Lng) = (FIXNUM_TO_LONG (Wrd53.Obj));
  (Wrd62.Lng) = ((Wrd63.Lng) + (Wrd64.Lng));
  if (! (LONG_TO_FIXNUM_P (Wrd62.Lng)))
    goto label_32;
  (Wrd59.Obj) = (LONG_TO_FIXNUM (Wrd62.Lng));

DEFLABEL (label_31)
  (Rsp [1]) = (Wrd59.Obj);
  (Wrd68.Obj) = (Rsp [0]);
  (Wrd69.uLng) = (OBJECT_TYPE (Wrd68.Obj));
  if (! ((Wrd69.uLng) == 1))
    goto label_30;
  (Wrd67.pObj) = (OBJECT_ADDRESS (Wrd68.Obj));
  (Wrd65.Obj) = ((Wrd67.pObj) [1]);

DEFLABEL (label_29)
  (Rsp [0]) = (Wrd65.Obj);
  goto do_loop_12;

DEFLABEL (label_30)
  (Wrd73.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_10]))));
  (* (--Rsp)) = (Wrd73.Obj);
  (* (--Rsp)) = (Wrd68.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_6]), 1);

DEFLABEL (label_20)
  (Wrd65.Obj) = Rvl;
  goto label_29;

DEFLABEL (label_32)
  (Wrd58.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_9]))));
  (* (--Rsp)) = (Wrd58.Obj);
  (* (--Rsp)) = (Wrd53.Obj);
  (* (--Rsp)) = (Wrd45.Obj);
  INVOKE_INTERFACE_0 (43);

DEFLABEL (label_19)
  (Wrd59.Obj) = Rvl;
  goto label_31;

DEFLABEL (label_34)
  (Wrd40.Obj) = (Rsp [2]);
  (Wrd41.Obj) = (current_block [OBJECT_62_5]);
  (Wrd44.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_8]))));
  (* (--Rsp)) = (Wrd44.Obj);
  (* (--Rsp)) = (Wrd41.Obj);
  (* (--Rsp)) = (Wrd40.Obj);
  INVOKE_INTERFACE_0 (41);

DEFLABEL (label_18)
  (Wrd45.Obj) = Rvl;
  goto label_33;

DEFLABEL (label_36)
  (Wrd75.Obj) = (current_block [OBJECT_62_0]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd75.Obj);
  goto label_35;

DEFLABEL (label_38)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_7]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_62_1]), 1);

DEFLABEL (label_16)
  (* (--Rsp)) = Rvl;
  goto label_37;

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_62_5);
  (* (--Rsp)) = Rvl;
  goto label_35;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_63_4 3
#define ENVIRONMENT_LABEL_63_3 10
#define DEBUGGING_LABEL_63_2 9
#define OBJECT_63_1 8
#define OBJECT_63_0 7
#define EXECUTE_CACHE_63_5 5
#define FREE_REFERENCES_LABEL_63_0 4
#define NUMBER_OF_LINKER_SECTIONS_63_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_63 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd11;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_63_4);
      goto safe_car_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (safe_car_4)
DEFLABEL (safe_car_1)
  INTERRUPT_CHECK (26, LABEL_63_4);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_5;
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_63_1]);
  (Rsp [1]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_63_5]));

DEFLABEL (label_5)
  if (! ((Wrd6.uLng) == 1))
    goto label_6;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  Rvl = ((Wrd11.pObj) [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_6)
  INVOKE_PRIMITIVE ((current_block [OBJECT_63_0]), 1);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_64_4 3
#define ENVIRONMENT_LABEL_64_3 10
#define DEBUGGING_LABEL_64_2 9
#define OBJECT_64_1 8
#define OBJECT_64_0 7
#define EXECUTE_CACHE_64_5 5
#define FREE_REFERENCES_LABEL_64_0 4
#define NUMBER_OF_LINKER_SECTIONS_64_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_64 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd11;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_64_4);
      goto safe_cdr_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (safe_cdr_4)
DEFLABEL (safe_cdr_1)
  INTERRUPT_CHECK (26, LABEL_64_4);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_5;
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_64_1]);
  (Rsp [1]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_5]));

DEFLABEL (label_5)
  if (! ((Wrd6.uLng) == 1))
    goto label_6;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  Rvl = ((Wrd11.pObj) [1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_6)
  INVOKE_PRIMITIVE ((current_block [OBJECT_64_0]), 1);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_65_5 3
#define LABEL_65_4 5
#define ENVIRONMENT_LABEL_65_3 12
#define DEBUGGING_LABEL_65_2 11
#define OBJECT_65_1 10
#define OBJECT_65_0 9
#define EXECUTE_CACHE_65_6 7
#define FREE_REFERENCES_LABEL_65_0 6
#define NUMBER_OF_LINKER_SECTIONS_65_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_65 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd22;
  machine_word Wrd25;
  machine_word Wrd20;
  machine_word Wrd16;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_65_5);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_65_4);
      goto caar_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (caar_8)
DEFLABEL (caar_5)
  INTERRUPT_CHECK (26, LABEL_65_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_65_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if ((Wrd10.uLng) == 1)
    goto label_10;
  (* (--Rsp)) = (Wrd8.Obj);

DEFLABEL (label_9)
  (Wrd22.Obj) = (current_block [OBJECT_65_1]);
  (Rsp [1]) = (Wrd22.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_65_6]));

DEFLABEL (label_10)
  if ((Wrd10.uLng) == 1)
    goto label_12;

DEFLABEL (label_11)
  INVOKE_PRIMITIVE ((current_block [OBJECT_65_0]), 1);

DEFLABEL (label_12)
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd14.Obj) = ((Wrd16.pObj) [0]);
  Rsp = (& (Rsp [2]));

DEFLABEL (label_14)
  (Rsp [0]) = (Wrd14.Obj);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd20.uLng) == 1)
    goto label_13;
  (* (--Rsp)) = (Wrd14.Obj);
  goto label_9;

DEFLABEL (label_13)
  if (! ((Wrd20.uLng) == 1))
    goto label_11;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  Rvl = ((Wrd25.pObj) [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_65_5);
  (Wrd14.Obj) = Rvl;
  goto label_14;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_66_5 3
#define LABEL_66_4 5
#define ENVIRONMENT_LABEL_66_3 14
#define DEBUGGING_LABEL_66_2 13
#define OBJECT_66_3 12
#define OBJECT_66_2 11
#define OBJECT_66_1 10
#define OBJECT_66_0 9
#define EXECUTE_CACHE_66_6 7
#define FREE_REFERENCES_LABEL_66_0 6
#define NUMBER_OF_LINKER_SECTIONS_66_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_66 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd12;
  machine_word Wrd22;
  machine_word Wrd25;
  machine_word Wrd20;
  machine_word Wrd16;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_66_5);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_66_4);
      goto cadr_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (cadr_8)
DEFLABEL (cadr_5)
  INTERRUPT_CHECK (26, LABEL_66_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_66_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if ((Wrd10.uLng) == 1)
    goto label_9;
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_66_3]);
  (Rsp [1]) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_66_6]));

DEFLABEL (label_9)
  if ((Wrd10.uLng) == 1)
    goto label_10;
  INVOKE_PRIMITIVE ((current_block [OBJECT_66_2]), 1);

DEFLABEL (label_10)
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd14.Obj) = ((Wrd16.pObj) [1]);
  Rsp = (& (Rsp [2]));

DEFLABEL (label_13)
  (Rsp [0]) = (Wrd14.Obj);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd20.uLng) == 1)
    goto label_11;
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd22.Obj) = (current_block [OBJECT_66_1]);
  (Rsp [1]) = (Wrd22.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_66_6]));

DEFLABEL (label_11)
  if (! ((Wrd20.uLng) == 1))
    goto label_12;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  Rvl = ((Wrd25.pObj) [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_12)
  INVOKE_PRIMITIVE ((current_block [OBJECT_66_0]), 1);

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_66_5);
  (Wrd14.Obj) = Rvl;
  goto label_13;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_67_5 3
#define LABEL_67_4 5
#define ENVIRONMENT_LABEL_67_3 14
#define DEBUGGING_LABEL_67_2 13
#define OBJECT_67_3 12
#define OBJECT_67_2 11
#define OBJECT_67_1 10
#define OBJECT_67_0 9
#define EXECUTE_CACHE_67_6 7
#define FREE_REFERENCES_LABEL_67_0 6
#define NUMBER_OF_LINKER_SECTIONS_67_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_67 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd12;
  machine_word Wrd22;
  machine_word Wrd25;
  machine_word Wrd20;
  machine_word Wrd16;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_67_5);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_67_4);
      goto cdar_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (cdar_8)
DEFLABEL (cdar_5)
  INTERRUPT_CHECK (26, LABEL_67_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if ((Wrd10.uLng) == 1)
    goto label_9;
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_67_3]);
  (Rsp [1]) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_6]));

DEFLABEL (label_9)
  if ((Wrd10.uLng) == 1)
    goto label_10;
  INVOKE_PRIMITIVE ((current_block [OBJECT_67_2]), 1);

DEFLABEL (label_10)
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd14.Obj) = ((Wrd16.pObj) [0]);
  Rsp = (& (Rsp [2]));

DEFLABEL (label_13)
  (Rsp [0]) = (Wrd14.Obj);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd20.uLng) == 1)
    goto label_11;
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd22.Obj) = (current_block [OBJECT_67_1]);
  (Rsp [1]) = (Wrd22.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_6]));

DEFLABEL (label_11)
  if (! ((Wrd20.uLng) == 1))
    goto label_12;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  Rvl = ((Wrd25.pObj) [1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_12)
  INVOKE_PRIMITIVE ((current_block [OBJECT_67_0]), 1);

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_67_5);
  (Wrd14.Obj) = Rvl;
  goto label_13;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_68_5 3
#define LABEL_68_4 5
#define ENVIRONMENT_LABEL_68_3 12
#define DEBUGGING_LABEL_68_2 11
#define OBJECT_68_1 10
#define OBJECT_68_0 9
#define EXECUTE_CACHE_68_6 7
#define FREE_REFERENCES_LABEL_68_0 6
#define NUMBER_OF_LINKER_SECTIONS_68_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_68 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd22;
  machine_word Wrd25;
  machine_word Wrd20;
  machine_word Wrd16;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_68_5);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_68_4);
      goto cddr_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (cddr_8)
DEFLABEL (cddr_5)
  INTERRUPT_CHECK (26, LABEL_68_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_68_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if ((Wrd10.uLng) == 1)
    goto label_10;
  (* (--Rsp)) = (Wrd8.Obj);

DEFLABEL (label_9)
  (Wrd22.Obj) = (current_block [OBJECT_68_1]);
  (Rsp [1]) = (Wrd22.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_68_6]));

DEFLABEL (label_10)
  if ((Wrd10.uLng) == 1)
    goto label_12;

DEFLABEL (label_11)
  INVOKE_PRIMITIVE ((current_block [OBJECT_68_0]), 1);

DEFLABEL (label_12)
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd14.Obj) = ((Wrd16.pObj) [1]);
  Rsp = (& (Rsp [2]));

DEFLABEL (label_14)
  (Rsp [0]) = (Wrd14.Obj);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd20.uLng) == 1)
    goto label_13;
  (* (--Rsp)) = (Wrd14.Obj);
  goto label_9;

DEFLABEL (label_13)
  if (! ((Wrd20.uLng) == 1))
    goto label_11;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  Rvl = ((Wrd25.pObj) [1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_68_5);
  (Wrd14.Obj) = Rvl;
  goto label_14;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_69_5 3
#define LABEL_69_6 5
#define LABEL_69_4 7
#define ENVIRONMENT_LABEL_69_3 14
#define DEBUGGING_LABEL_69_2 13
#define OBJECT_69_1 12
#define OBJECT_69_0 11
#define EXECUTE_CACHE_69_7 9
#define FREE_REFERENCES_LABEL_69_0 8
#define NUMBER_OF_LINKER_SECTIONS_69_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_69 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd35;
  machine_word Wrd38;
  machine_word Wrd33;
  machine_word Wrd29;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd17;
  machine_word Wrd19;
  machine_word Wrd13;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  machine_word Wrd27;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_69_5);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_69_6);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_69_4);
      goto caaar_8;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (caaar_11)
DEFLABEL (caaar_8)
  INTERRUPT_CHECK (26, LABEL_69_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_69_6]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_69_5]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if ((Wrd13.uLng) == 1)
    goto label_13;
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_12)
  (Wrd35.Obj) = (current_block [OBJECT_69_1]);
  (Rsp [1]) = (Wrd35.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_69_7]));

DEFLABEL (label_13)
  if ((Wrd13.uLng) == 1)
    goto label_15;

DEFLABEL (label_14)
  INVOKE_PRIMITIVE ((current_block [OBJECT_69_0]), 1);

DEFLABEL (label_15)
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd17.Obj) = ((Wrd19.pObj) [0]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd17.Obj);

DEFLABEL (label_19)
  (Wrd22.Obj) = (Rsp [0]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if ((Wrd23.uLng) == 1)
    goto label_16;
  (* (--Rsp)) = (Wrd22.Obj);
  goto label_12;

DEFLABEL (label_16)
  if (! ((Wrd23.uLng) == 1))
    goto label_14;
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
  (Wrd27.Obj) = ((Wrd29.pObj) [0]);
  Rsp = (& (Rsp [2]));

DEFLABEL (label_18)
  (Rsp [0]) = (Wrd27.Obj);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if ((Wrd33.uLng) == 1)
    goto label_17;
  (* (--Rsp)) = (Wrd27.Obj);
  goto label_12;

DEFLABEL (label_17)
  if (! ((Wrd33.uLng) == 1))
    goto label_14;
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  Rvl = ((Wrd38.pObj) [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_69_5);
  (* (--Rsp)) = Rvl;
  goto label_19;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_69_6);
  (Wrd27.Obj) = Rvl;
  goto label_18;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_70_5 3
#define LABEL_70_6 5
#define LABEL_70_4 7
#define ENVIRONMENT_LABEL_70_3 16
#define DEBUGGING_LABEL_70_2 15
#define OBJECT_70_3 14
#define OBJECT_70_2 13
#define OBJECT_70_1 12
#define OBJECT_70_0 11
#define EXECUTE_CACHE_70_7 9
#define FREE_REFERENCES_LABEL_70_0 8
#define NUMBER_OF_LINKER_SECTIONS_70_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_70 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd15;
  machine_word Wrd35;
  machine_word Wrd38;
  machine_word Wrd33;
  machine_word Wrd29;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd17;
  machine_word Wrd19;
  machine_word Wrd13;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  machine_word Wrd27;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_70_5);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_70_6);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_70_4);
      goto caadr_8;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (caadr_11)
DEFLABEL (caadr_8)
  INTERRUPT_CHECK (26, LABEL_70_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_70_6]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_70_5]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if ((Wrd13.uLng) == 1)
    goto label_12;
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd15.Obj) = (current_block [OBJECT_70_3]);
  (Rsp [1]) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_70_7]));

DEFLABEL (label_12)
  if ((Wrd13.uLng) == 1)
    goto label_13;
  INVOKE_PRIMITIVE ((current_block [OBJECT_70_2]), 1);

DEFLABEL (label_13)
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd17.Obj) = ((Wrd19.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd17.Obj);

DEFLABEL (label_20)
  (Wrd22.Obj) = (Rsp [0]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if ((Wrd23.uLng) == 1)
    goto label_15;
  (* (--Rsp)) = (Wrd22.Obj);

DEFLABEL (label_14)
  (Wrd35.Obj) = (current_block [OBJECT_70_1]);
  (Rsp [1]) = (Wrd35.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_70_7]));

DEFLABEL (label_15)
  if ((Wrd23.uLng) == 1)
    goto label_17;

DEFLABEL (label_16)
  INVOKE_PRIMITIVE ((current_block [OBJECT_70_0]), 1);

DEFLABEL (label_17)
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
  (Wrd27.Obj) = ((Wrd29.pObj) [0]);
  Rsp = (& (Rsp [2]));

DEFLABEL (label_19)
  (Rsp [0]) = (Wrd27.Obj);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if ((Wrd33.uLng) == 1)
    goto label_18;
  (* (--Rsp)) = (Wrd27.Obj);
  goto label_14;

DEFLABEL (label_18)
  if (! ((Wrd33.uLng) == 1))
    goto label_16;
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  Rvl = ((Wrd38.pObj) [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_70_5);
  (* (--Rsp)) = Rvl;
  goto label_20;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_70_6);
  (Wrd27.Obj) = Rvl;
  goto label_19;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_71_5 3
#define LABEL_71_6 5
#define LABEL_71_4 7
#define ENVIRONMENT_LABEL_71_3 16
#define DEBUGGING_LABEL_71_2 15
#define OBJECT_71_3 14
#define OBJECT_71_2 13
#define OBJECT_71_1 12
#define OBJECT_71_0 11
#define EXECUTE_CACHE_71_7 9
#define FREE_REFERENCES_LABEL_71_0 8
#define NUMBER_OF_LINKER_SECTIONS_71_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_71 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd35;
  machine_word Wrd25;
  machine_word Wrd38;
  machine_word Wrd33;
  machine_word Wrd29;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd17;
  machine_word Wrd19;
  machine_word Wrd13;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  machine_word Wrd27;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_71_5);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_71_6);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_71_4);
      goto cadar_8;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (cadar_11)
DEFLABEL (cadar_8)
  INTERRUPT_CHECK (26, LABEL_71_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_71_6]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_71_5]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if ((Wrd13.uLng) == 1)
    goto label_13;
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_12)
  (Wrd35.Obj) = (current_block [OBJECT_71_3]);
  (Rsp [1]) = (Wrd35.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_71_7]));

DEFLABEL (label_13)
  if ((Wrd13.uLng) == 1)
    goto label_15;

DEFLABEL (label_14)
  INVOKE_PRIMITIVE ((current_block [OBJECT_71_2]), 1);

DEFLABEL (label_15)
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd17.Obj) = ((Wrd19.pObj) [0]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd17.Obj);

DEFLABEL (label_20)
  (Wrd22.Obj) = (Rsp [0]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if ((Wrd23.uLng) == 1)
    goto label_16;
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd25.Obj) = (current_block [OBJECT_71_1]);
  (Rsp [1]) = (Wrd25.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_71_7]));

DEFLABEL (label_16)
  if ((Wrd23.uLng) == 1)
    goto label_17;
  INVOKE_PRIMITIVE ((current_block [OBJECT_71_0]), 1);

DEFLABEL (label_17)
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
  (Wrd27.Obj) = ((Wrd29.pObj) [1]);
  Rsp = (& (Rsp [2]));

DEFLABEL (label_19)
  (Rsp [0]) = (Wrd27.Obj);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if ((Wrd33.uLng) == 1)
    goto label_18;
  (* (--Rsp)) = (Wrd27.Obj);
  goto label_12;

DEFLABEL (label_18)
  if (! ((Wrd33.uLng) == 1))
    goto label_14;
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  Rvl = ((Wrd38.pObj) [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_71_5);
  (* (--Rsp)) = Rvl;
  goto label_20;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_71_6);
  (Wrd27.Obj) = Rvl;
  goto label_19;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_72_5 3
#define LABEL_72_6 5
#define LABEL_72_4 7
#define ENVIRONMENT_LABEL_72_3 16
#define DEBUGGING_LABEL_72_2 15
#define OBJECT_72_3 14
#define OBJECT_72_2 13
#define OBJECT_72_1 12
#define OBJECT_72_0 11
#define EXECUTE_CACHE_72_7 9
#define FREE_REFERENCES_LABEL_72_0 8
#define NUMBER_OF_LINKER_SECTIONS_72_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_72 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd25;
  machine_word Wrd35;
  machine_word Wrd38;
  machine_word Wrd33;
  machine_word Wrd29;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd17;
  machine_word Wrd19;
  machine_word Wrd13;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  machine_word Wrd27;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_72_5);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_72_6);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_72_4);
      goto caddr_8;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (caddr_11)
DEFLABEL (caddr_8)
  INTERRUPT_CHECK (26, LABEL_72_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_72_6]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_72_5]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if ((Wrd13.uLng) == 1)
    goto label_13;
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_12)
  (Wrd25.Obj) = (current_block [OBJECT_72_3]);
  (Rsp [1]) = (Wrd25.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_72_7]));

DEFLABEL (label_13)
  if ((Wrd13.uLng) == 1)
    goto label_15;

DEFLABEL (label_14)
  INVOKE_PRIMITIVE ((current_block [OBJECT_72_2]), 1);

DEFLABEL (label_15)
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd17.Obj) = ((Wrd19.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd17.Obj);

DEFLABEL (label_20)
  (Wrd22.Obj) = (Rsp [0]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if ((Wrd23.uLng) == 1)
    goto label_16;
  (* (--Rsp)) = (Wrd22.Obj);
  goto label_12;

DEFLABEL (label_16)
  if (! ((Wrd23.uLng) == 1))
    goto label_14;
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
  (Wrd27.Obj) = ((Wrd29.pObj) [1]);
  Rsp = (& (Rsp [2]));

DEFLABEL (label_19)
  (Rsp [0]) = (Wrd27.Obj);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if ((Wrd33.uLng) == 1)
    goto label_17;
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd35.Obj) = (current_block [OBJECT_72_1]);
  (Rsp [1]) = (Wrd35.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_72_7]));

DEFLABEL (label_17)
  if (! ((Wrd33.uLng) == 1))
    goto label_18;
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  Rvl = ((Wrd38.pObj) [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_18)
  INVOKE_PRIMITIVE ((current_block [OBJECT_72_0]), 1);

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_72_5);
  (* (--Rsp)) = Rvl;
  goto label_20;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_72_6);
  (Wrd27.Obj) = Rvl;
  goto label_19;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_73_5 3
#define LABEL_73_6 5
#define LABEL_73_4 7
#define ENVIRONMENT_LABEL_73_3 16
#define DEBUGGING_LABEL_73_2 15
#define OBJECT_73_3 14
#define OBJECT_73_2 13
#define OBJECT_73_1 12
#define OBJECT_73_0 11
#define EXECUTE_CACHE_73_7 9
#define FREE_REFERENCES_LABEL_73_0 8
#define NUMBER_OF_LINKER_SECTIONS_73_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_73 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd25;
  machine_word Wrd35;
  machine_word Wrd38;
  machine_word Wrd33;
  machine_word Wrd29;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd17;
  machine_word Wrd19;
  machine_word Wrd13;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  machine_word Wrd27;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_73_5);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_73_6);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_73_4);
      goto cdaar_8;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (cdaar_11)
DEFLABEL (cdaar_8)
  INTERRUPT_CHECK (26, LABEL_73_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_73_6]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_73_5]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if ((Wrd13.uLng) == 1)
    goto label_13;
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_12)
  (Wrd25.Obj) = (current_block [OBJECT_73_3]);
  (Rsp [1]) = (Wrd25.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_73_7]));

DEFLABEL (label_13)
  if ((Wrd13.uLng) == 1)
    goto label_15;

DEFLABEL (label_14)
  INVOKE_PRIMITIVE ((current_block [OBJECT_73_2]), 1);

DEFLABEL (label_15)
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd17.Obj) = ((Wrd19.pObj) [0]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd17.Obj);

DEFLABEL (label_20)
  (Wrd22.Obj) = (Rsp [0]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if ((Wrd23.uLng) == 1)
    goto label_16;
  (* (--Rsp)) = (Wrd22.Obj);
  goto label_12;

DEFLABEL (label_16)
  if (! ((Wrd23.uLng) == 1))
    goto label_14;
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
  (Wrd27.Obj) = ((Wrd29.pObj) [0]);
  Rsp = (& (Rsp [2]));

DEFLABEL (label_19)
  (Rsp [0]) = (Wrd27.Obj);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if ((Wrd33.uLng) == 1)
    goto label_17;
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd35.Obj) = (current_block [OBJECT_73_1]);
  (Rsp [1]) = (Wrd35.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_73_7]));

DEFLABEL (label_17)
  if (! ((Wrd33.uLng) == 1))
    goto label_18;
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  Rvl = ((Wrd38.pObj) [1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_18)
  INVOKE_PRIMITIVE ((current_block [OBJECT_73_0]), 1);

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_73_5);
  (* (--Rsp)) = Rvl;
  goto label_20;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_73_6);
  (Wrd27.Obj) = Rvl;
  goto label_19;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_74_5 3
#define LABEL_74_6 5
#define LABEL_74_4 7
#define ENVIRONMENT_LABEL_74_3 16
#define DEBUGGING_LABEL_74_2 15
#define OBJECT_74_3 14
#define OBJECT_74_2 13
#define OBJECT_74_1 12
#define OBJECT_74_0 11
#define EXECUTE_CACHE_74_7 9
#define FREE_REFERENCES_LABEL_74_0 8
#define NUMBER_OF_LINKER_SECTIONS_74_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_74 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd35;
  machine_word Wrd25;
  machine_word Wrd38;
  machine_word Wrd33;
  machine_word Wrd29;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd17;
  machine_word Wrd19;
  machine_word Wrd13;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  machine_word Wrd27;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_74_5);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_74_6);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_74_4);
      goto cdadr_8;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (cdadr_11)
DEFLABEL (cdadr_8)
  INTERRUPT_CHECK (26, LABEL_74_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_74_6]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_74_5]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if ((Wrd13.uLng) == 1)
    goto label_13;
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_12)
  (Wrd35.Obj) = (current_block [OBJECT_74_3]);
  (Rsp [1]) = (Wrd35.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_74_7]));

DEFLABEL (label_13)
  if ((Wrd13.uLng) == 1)
    goto label_15;

DEFLABEL (label_14)
  INVOKE_PRIMITIVE ((current_block [OBJECT_74_2]), 1);

DEFLABEL (label_15)
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd17.Obj) = ((Wrd19.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd17.Obj);

DEFLABEL (label_20)
  (Wrd22.Obj) = (Rsp [0]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if ((Wrd23.uLng) == 1)
    goto label_16;
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd25.Obj) = (current_block [OBJECT_74_1]);
  (Rsp [1]) = (Wrd25.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_74_7]));

DEFLABEL (label_16)
  if ((Wrd23.uLng) == 1)
    goto label_17;
  INVOKE_PRIMITIVE ((current_block [OBJECT_74_0]), 1);

DEFLABEL (label_17)
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
  (Wrd27.Obj) = ((Wrd29.pObj) [0]);
  Rsp = (& (Rsp [2]));

DEFLABEL (label_19)
  (Rsp [0]) = (Wrd27.Obj);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if ((Wrd33.uLng) == 1)
    goto label_18;
  (* (--Rsp)) = (Wrd27.Obj);
  goto label_12;

DEFLABEL (label_18)
  if (! ((Wrd33.uLng) == 1))
    goto label_14;
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  Rvl = ((Wrd38.pObj) [1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_74_5);
  (* (--Rsp)) = Rvl;
  goto label_20;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_74_6);
  (Wrd27.Obj) = Rvl;
  goto label_19;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_75_5 3
#define LABEL_75_6 5
#define LABEL_75_4 7
#define ENVIRONMENT_LABEL_75_3 16
#define DEBUGGING_LABEL_75_2 15
#define OBJECT_75_3 14
#define OBJECT_75_2 13
#define OBJECT_75_1 12
#define OBJECT_75_0 11
#define EXECUTE_CACHE_75_7 9
#define FREE_REFERENCES_LABEL_75_0 8
#define NUMBER_OF_LINKER_SECTIONS_75_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_75 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd15;
  machine_word Wrd35;
  machine_word Wrd38;
  machine_word Wrd33;
  machine_word Wrd29;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd17;
  machine_word Wrd19;
  machine_word Wrd13;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  machine_word Wrd27;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_75_5);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_75_6);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_75_4);
      goto cddar_8;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (cddar_11)
DEFLABEL (cddar_8)
  INTERRUPT_CHECK (26, LABEL_75_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_75_6]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_75_5]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if ((Wrd13.uLng) == 1)
    goto label_12;
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd15.Obj) = (current_block [OBJECT_75_3]);
  (Rsp [1]) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_75_7]));

DEFLABEL (label_12)
  if ((Wrd13.uLng) == 1)
    goto label_13;
  INVOKE_PRIMITIVE ((current_block [OBJECT_75_2]), 1);

DEFLABEL (label_13)
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd17.Obj) = ((Wrd19.pObj) [0]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd17.Obj);

DEFLABEL (label_20)
  (Wrd22.Obj) = (Rsp [0]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if ((Wrd23.uLng) == 1)
    goto label_15;
  (* (--Rsp)) = (Wrd22.Obj);

DEFLABEL (label_14)
  (Wrd35.Obj) = (current_block [OBJECT_75_1]);
  (Rsp [1]) = (Wrd35.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_75_7]));

DEFLABEL (label_15)
  if ((Wrd23.uLng) == 1)
    goto label_17;

DEFLABEL (label_16)
  INVOKE_PRIMITIVE ((current_block [OBJECT_75_0]), 1);

DEFLABEL (label_17)
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
  (Wrd27.Obj) = ((Wrd29.pObj) [1]);
  Rsp = (& (Rsp [2]));

DEFLABEL (label_19)
  (Rsp [0]) = (Wrd27.Obj);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if ((Wrd33.uLng) == 1)
    goto label_18;
  (* (--Rsp)) = (Wrd27.Obj);
  goto label_14;

DEFLABEL (label_18)
  if (! ((Wrd33.uLng) == 1))
    goto label_16;
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  Rvl = ((Wrd38.pObj) [1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_75_5);
  (* (--Rsp)) = Rvl;
  goto label_20;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_75_6);
  (Wrd27.Obj) = Rvl;
  goto label_19;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_76_5 3
#define LABEL_76_6 5
#define LABEL_76_4 7
#define ENVIRONMENT_LABEL_76_3 14
#define DEBUGGING_LABEL_76_2 13
#define OBJECT_76_1 12
#define OBJECT_76_0 11
#define EXECUTE_CACHE_76_7 9
#define FREE_REFERENCES_LABEL_76_0 8
#define NUMBER_OF_LINKER_SECTIONS_76_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_76 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd35;
  machine_word Wrd38;
  machine_word Wrd33;
  machine_word Wrd29;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd17;
  machine_word Wrd19;
  machine_word Wrd13;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  machine_word Wrd27;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_76_5);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_76_6);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_76_4);
      goto cdddr_8;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (cdddr_11)
DEFLABEL (cdddr_8)
  INTERRUPT_CHECK (26, LABEL_76_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_76_6]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_76_5]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if ((Wrd13.uLng) == 1)
    goto label_13;
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_12)
  (Wrd35.Obj) = (current_block [OBJECT_76_1]);
  (Rsp [1]) = (Wrd35.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_76_7]));

DEFLABEL (label_13)
  if ((Wrd13.uLng) == 1)
    goto label_15;

DEFLABEL (label_14)
  INVOKE_PRIMITIVE ((current_block [OBJECT_76_0]), 1);

DEFLABEL (label_15)
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd17.Obj) = ((Wrd19.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd17.Obj);

DEFLABEL (label_19)
  (Wrd22.Obj) = (Rsp [0]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if ((Wrd23.uLng) == 1)
    goto label_16;
  (* (--Rsp)) = (Wrd22.Obj);
  goto label_12;

DEFLABEL (label_16)
  if (! ((Wrd23.uLng) == 1))
    goto label_14;
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
  (Wrd27.Obj) = ((Wrd29.pObj) [1]);
  Rsp = (& (Rsp [2]));

DEFLABEL (label_18)
  (Rsp [0]) = (Wrd27.Obj);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if ((Wrd33.uLng) == 1)
    goto label_17;
  (* (--Rsp)) = (Wrd27.Obj);
  goto label_12;

DEFLABEL (label_17)
  if (! ((Wrd33.uLng) == 1))
    goto label_14;
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  Rvl = ((Wrd38.pObj) [1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_76_5);
  (* (--Rsp)) = Rvl;
  goto label_19;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_76_6);
  (Wrd27.Obj) = Rvl;
  goto label_18;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_77_5 3
#define LABEL_77_6 5
#define LABEL_77_7 7
#define LABEL_77_4 9
#define ENVIRONMENT_LABEL_77_3 16
#define DEBUGGING_LABEL_77_2 15
#define OBJECT_77_1 14
#define OBJECT_77_0 13
#define EXECUTE_CACHE_77_8 11
#define FREE_REFERENCES_LABEL_77_0 10
#define NUMBER_OF_LINKER_SECTIONS_77_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_77 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd48;
  machine_word Wrd51;
  machine_word Wrd46;
  machine_word Wrd42;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd30;
  machine_word Wrd32;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd20;
  machine_word Wrd22;
  machine_word Wrd16;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd7;
  machine_word Wrd40;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_77_5);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_77_6);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_77_7);
      goto continuation_6;

    case 3:
      current_block = (Rpc - LABEL_77_4);
      goto caaaar_11;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (caaaar_14)
DEFLABEL (caaaar_11)
  INTERRUPT_CHECK (26, LABEL_77_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_77_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_77_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_77_5]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd16.uLng) == 1)
    goto label_16;
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_15)
  (Wrd48.Obj) = (current_block [OBJECT_77_1]);
  (Rsp [1]) = (Wrd48.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_77_8]));

DEFLABEL (label_16)
  if ((Wrd16.uLng) == 1)
    goto label_18;

DEFLABEL (label_17)
  INVOKE_PRIMITIVE ((current_block [OBJECT_77_0]), 1);

DEFLABEL (label_18)
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd20.Obj) = ((Wrd22.pObj) [0]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd20.Obj);

DEFLABEL (label_24)
  (Wrd25.Obj) = (Rsp [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 1)
    goto label_19;
  (* (--Rsp)) = (Wrd25.Obj);
  goto label_15;

DEFLABEL (label_19)
  if (! ((Wrd26.uLng) == 1))
    goto label_17;
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd30.Obj) = ((Wrd32.pObj) [0]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd30.Obj);

DEFLABEL (label_23)
  (Wrd35.Obj) = (Rsp [0]);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if ((Wrd36.uLng) == 1)
    goto label_20;
  (* (--Rsp)) = (Wrd35.Obj);
  goto label_15;

DEFLABEL (label_20)
  if (! ((Wrd36.uLng) == 1))
    goto label_17;
  (Wrd42.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd40.Obj) = ((Wrd42.pObj) [0]);
  Rsp = (& (Rsp [2]));

DEFLABEL (label_22)
  (Rsp [0]) = (Wrd40.Obj);
  (Wrd46.uLng) = (OBJECT_TYPE (Wrd40.Obj));
  if ((Wrd46.uLng) == 1)
    goto label_21;
  (* (--Rsp)) = (Wrd40.Obj);
  goto label_15;

DEFLABEL (label_21)
  if (! ((Wrd46.uLng) == 1))
    goto label_17;
  (Wrd51.pObj) = (OBJECT_ADDRESS (Wrd40.Obj));
  Rvl = ((Wrd51.pObj) [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_77_5);
  (* (--Rsp)) = Rvl;
  goto label_24;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_77_6);
  (* (--Rsp)) = Rvl;
  goto label_23;

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_77_7);
  (Wrd40.Obj) = Rvl;
  goto label_22;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_78_5 3
#define LABEL_78_6 5
#define LABEL_78_7 7
#define LABEL_78_4 9
#define ENVIRONMENT_LABEL_78_3 18
#define DEBUGGING_LABEL_78_2 17
#define OBJECT_78_3 16
#define OBJECT_78_2 15
#define OBJECT_78_1 14
#define OBJECT_78_0 13
#define EXECUTE_CACHE_78_8 11
#define FREE_REFERENCES_LABEL_78_0 10
#define NUMBER_OF_LINKER_SECTIONS_78_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_78 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd18;
  machine_word Wrd48;
  machine_word Wrd51;
  machine_word Wrd46;
  machine_word Wrd42;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd30;
  machine_word Wrd32;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd20;
  machine_word Wrd22;
  machine_word Wrd16;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd7;
  machine_word Wrd40;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_78_5);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_78_6);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_78_7);
      goto continuation_6;

    case 3:
      current_block = (Rpc - LABEL_78_4);
      goto caaadr_11;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (caaadr_14)
DEFLABEL (caaadr_11)
  INTERRUPT_CHECK (26, LABEL_78_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_78_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_78_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_78_5]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd16.uLng) == 1)
    goto label_15;
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd18.Obj) = (current_block [OBJECT_78_3]);
  (Rsp [1]) = (Wrd18.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_78_8]));

DEFLABEL (label_15)
  if ((Wrd16.uLng) == 1)
    goto label_16;
  INVOKE_PRIMITIVE ((current_block [OBJECT_78_2]), 1);

DEFLABEL (label_16)
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd20.Obj) = ((Wrd22.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd20.Obj);

DEFLABEL (label_25)
  (Wrd25.Obj) = (Rsp [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 1)
    goto label_18;
  (* (--Rsp)) = (Wrd25.Obj);

DEFLABEL (label_17)
  (Wrd48.Obj) = (current_block [OBJECT_78_1]);
  (Rsp [1]) = (Wrd48.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_78_8]));

DEFLABEL (label_18)
  if ((Wrd26.uLng) == 1)
    goto label_20;

DEFLABEL (label_19)
  INVOKE_PRIMITIVE ((current_block [OBJECT_78_0]), 1);

DEFLABEL (label_20)
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd30.Obj) = ((Wrd32.pObj) [0]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd30.Obj);

DEFLABEL (label_24)
  (Wrd35.Obj) = (Rsp [0]);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if ((Wrd36.uLng) == 1)
    goto label_21;
  (* (--Rsp)) = (Wrd35.Obj);
  goto label_17;

DEFLABEL (label_21)
  if (! ((Wrd36.uLng) == 1))
    goto label_19;
  (Wrd42.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd40.Obj) = ((Wrd42.pObj) [0]);
  Rsp = (& (Rsp [2]));

DEFLABEL (label_23)
  (Rsp [0]) = (Wrd40.Obj);
  (Wrd46.uLng) = (OBJECT_TYPE (Wrd40.Obj));
  if ((Wrd46.uLng) == 1)
    goto label_22;
  (* (--Rsp)) = (Wrd40.Obj);
  goto label_17;

DEFLABEL (label_22)
  if (! ((Wrd46.uLng) == 1))
    goto label_19;
  (Wrd51.pObj) = (OBJECT_ADDRESS (Wrd40.Obj));
  Rvl = ((Wrd51.pObj) [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_78_5);
  (* (--Rsp)) = Rvl;
  goto label_25;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_78_6);
  (* (--Rsp)) = Rvl;
  goto label_24;

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_78_7);
  (Wrd40.Obj) = Rvl;
  goto label_23;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_79_5 3
#define LABEL_79_6 5
#define LABEL_79_7 7
#define LABEL_79_4 9
#define ENVIRONMENT_LABEL_79_3 18
#define DEBUGGING_LABEL_79_2 17
#define OBJECT_79_3 16
#define OBJECT_79_2 15
#define OBJECT_79_1 14
#define OBJECT_79_0 13
#define EXECUTE_CACHE_79_8 11
#define FREE_REFERENCES_LABEL_79_0 10
#define NUMBER_OF_LINKER_SECTIONS_79_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_79 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd48;
  machine_word Wrd28;
  machine_word Wrd51;
  machine_word Wrd46;
  machine_word Wrd42;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd30;
  machine_word Wrd32;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd20;
  machine_word Wrd22;
  machine_word Wrd16;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd7;
  machine_word Wrd40;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_79_5);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_79_6);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_79_7);
      goto continuation_6;

    case 3:
      current_block = (Rpc - LABEL_79_4);
      goto caadar_11;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (caadar_14)
DEFLABEL (caadar_11)
  INTERRUPT_CHECK (26, LABEL_79_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_79_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_79_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_79_5]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd16.uLng) == 1)
    goto label_16;
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_15)
  (Wrd48.Obj) = (current_block [OBJECT_79_3]);
  (Rsp [1]) = (Wrd48.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_79_8]));

DEFLABEL (label_16)
  if ((Wrd16.uLng) == 1)
    goto label_18;

DEFLABEL (label_17)
  INVOKE_PRIMITIVE ((current_block [OBJECT_79_2]), 1);

DEFLABEL (label_18)
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd20.Obj) = ((Wrd22.pObj) [0]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd20.Obj);

DEFLABEL (label_25)
  (Wrd25.Obj) = (Rsp [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 1)
    goto label_19;
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd28.Obj) = (current_block [OBJECT_79_1]);
  (Rsp [1]) = (Wrd28.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_79_8]));

DEFLABEL (label_19)
  if ((Wrd26.uLng) == 1)
    goto label_20;
  INVOKE_PRIMITIVE ((current_block [OBJECT_79_0]), 1);

DEFLABEL (label_20)
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd30.Obj) = ((Wrd32.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd30.Obj);

DEFLABEL (label_24)
  (Wrd35.Obj) = (Rsp [0]);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if ((Wrd36.uLng) == 1)
    goto label_21;
  (* (--Rsp)) = (Wrd35.Obj);
  goto label_15;

DEFLABEL (label_21)
  if (! ((Wrd36.uLng) == 1))
    goto label_17;
  (Wrd42.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd40.Obj) = ((Wrd42.pObj) [0]);
  Rsp = (& (Rsp [2]));

DEFLABEL (label_23)
  (Rsp [0]) = (Wrd40.Obj);
  (Wrd46.uLng) = (OBJECT_TYPE (Wrd40.Obj));
  if ((Wrd46.uLng) == 1)
    goto label_22;
  (* (--Rsp)) = (Wrd40.Obj);
  goto label_15;

DEFLABEL (label_22)
  if (! ((Wrd46.uLng) == 1))
    goto label_17;
  (Wrd51.pObj) = (OBJECT_ADDRESS (Wrd40.Obj));
  Rvl = ((Wrd51.pObj) [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_79_5);
  (* (--Rsp)) = Rvl;
  goto label_25;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_79_6);
  (* (--Rsp)) = Rvl;
  goto label_24;

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_79_7);
  (Wrd40.Obj) = Rvl;
  goto label_23;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_80_5 3
#define LABEL_80_6 5
#define LABEL_80_7 7
#define LABEL_80_4 9
#define ENVIRONMENT_LABEL_80_3 18
#define DEBUGGING_LABEL_80_2 17
#define OBJECT_80_3 16
#define OBJECT_80_2 15
#define OBJECT_80_1 14
#define OBJECT_80_0 13
#define EXECUTE_CACHE_80_8 11
#define FREE_REFERENCES_LABEL_80_0 10
#define NUMBER_OF_LINKER_SECTIONS_80_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_80 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd28;
  machine_word Wrd48;
  machine_word Wrd51;
  machine_word Wrd46;
  machine_word Wrd42;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd30;
  machine_word Wrd32;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd20;
  machine_word Wrd22;
  machine_word Wrd16;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd7;
  machine_word Wrd40;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_80_5);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_80_6);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_80_7);
      goto continuation_6;

    case 3:
      current_block = (Rpc - LABEL_80_4);
      goto caaddr_11;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (caaddr_14)
DEFLABEL (caaddr_11)
  INTERRUPT_CHECK (26, LABEL_80_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_80_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_80_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_80_5]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd16.uLng) == 1)
    goto label_16;
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_15)
  (Wrd28.Obj) = (current_block [OBJECT_80_3]);
  (Rsp [1]) = (Wrd28.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_80_8]));

DEFLABEL (label_16)
  if ((Wrd16.uLng) == 1)
    goto label_18;

DEFLABEL (label_17)
  INVOKE_PRIMITIVE ((current_block [OBJECT_80_2]), 1);

DEFLABEL (label_18)
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd20.Obj) = ((Wrd22.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd20.Obj);

DEFLABEL (label_27)
  (Wrd25.Obj) = (Rsp [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 1)
    goto label_19;
  (* (--Rsp)) = (Wrd25.Obj);
  goto label_15;

DEFLABEL (label_19)
  if (! ((Wrd26.uLng) == 1))
    goto label_17;
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd30.Obj) = ((Wrd32.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd30.Obj);

DEFLABEL (label_26)
  (Wrd35.Obj) = (Rsp [0]);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if ((Wrd36.uLng) == 1)
    goto label_21;
  (* (--Rsp)) = (Wrd35.Obj);

DEFLABEL (label_20)
  (Wrd48.Obj) = (current_block [OBJECT_80_1]);
  (Rsp [1]) = (Wrd48.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_80_8]));

DEFLABEL (label_21)
  if ((Wrd36.uLng) == 1)
    goto label_23;

DEFLABEL (label_22)
  INVOKE_PRIMITIVE ((current_block [OBJECT_80_0]), 1);

DEFLABEL (label_23)
  (Wrd42.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd40.Obj) = ((Wrd42.pObj) [0]);
  Rsp = (& (Rsp [2]));

DEFLABEL (label_25)
  (Rsp [0]) = (Wrd40.Obj);
  (Wrd46.uLng) = (OBJECT_TYPE (Wrd40.Obj));
  if ((Wrd46.uLng) == 1)
    goto label_24;
  (* (--Rsp)) = (Wrd40.Obj);
  goto label_20;

DEFLABEL (label_24)
  if (! ((Wrd46.uLng) == 1))
    goto label_22;
  (Wrd51.pObj) = (OBJECT_ADDRESS (Wrd40.Obj));
  Rvl = ((Wrd51.pObj) [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_80_5);
  (* (--Rsp)) = Rvl;
  goto label_27;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_80_6);
  (* (--Rsp)) = Rvl;
  goto label_26;

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_80_7);
  (Wrd40.Obj) = Rvl;
  goto label_25;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_81_5 3
#define LABEL_81_6 5
#define LABEL_81_7 7
#define LABEL_81_4 9
#define ENVIRONMENT_LABEL_81_3 18
#define DEBUGGING_LABEL_81_2 17
#define OBJECT_81_3 16
#define OBJECT_81_2 15
#define OBJECT_81_1 14
#define OBJECT_81_0 13
#define EXECUTE_CACHE_81_8 11
#define FREE_REFERENCES_LABEL_81_0 10
#define NUMBER_OF_LINKER_SECTIONS_81_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_81 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd48;
  machine_word Wrd38;
  machine_word Wrd51;
  machine_word Wrd46;
  machine_word Wrd42;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd30;
  machine_word Wrd32;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd20;
  machine_word Wrd22;
  machine_word Wrd16;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd7;
  machine_word Wrd40;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_81_5);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_81_6);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_81_7);
      goto continuation_6;

    case 3:
      current_block = (Rpc - LABEL_81_4);
      goto cadaar_11;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (cadaar_14)
DEFLABEL (cadaar_11)
  INTERRUPT_CHECK (26, LABEL_81_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_81_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_81_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_81_5]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd16.uLng) == 1)
    goto label_16;
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_15)
  (Wrd48.Obj) = (current_block [OBJECT_81_3]);
  (Rsp [1]) = (Wrd48.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_81_8]));

DEFLABEL (label_16)
  if ((Wrd16.uLng) == 1)
    goto label_18;

DEFLABEL (label_17)
  INVOKE_PRIMITIVE ((current_block [OBJECT_81_2]), 1);

DEFLABEL (label_18)
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd20.Obj) = ((Wrd22.pObj) [0]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd20.Obj);

DEFLABEL (label_25)
  (Wrd25.Obj) = (Rsp [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 1)
    goto label_19;
  (* (--Rsp)) = (Wrd25.Obj);
  goto label_15;

DEFLABEL (label_19)
  if (! ((Wrd26.uLng) == 1))
    goto label_17;
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd30.Obj) = ((Wrd32.pObj) [0]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd30.Obj);

DEFLABEL (label_24)
  (Wrd35.Obj) = (Rsp [0]);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if ((Wrd36.uLng) == 1)
    goto label_20;
  (* (--Rsp)) = (Wrd35.Obj);
  (Wrd38.Obj) = (current_block [OBJECT_81_1]);
  (Rsp [1]) = (Wrd38.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_81_8]));

DEFLABEL (label_20)
  if ((Wrd36.uLng) == 1)
    goto label_21;
  INVOKE_PRIMITIVE ((current_block [OBJECT_81_0]), 1);

DEFLABEL (label_21)
  (Wrd42.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd40.Obj) = ((Wrd42.pObj) [1]);
  Rsp = (& (Rsp [2]));

DEFLABEL (label_23)
  (Rsp [0]) = (Wrd40.Obj);
  (Wrd46.uLng) = (OBJECT_TYPE (Wrd40.Obj));
  if ((Wrd46.uLng) == 1)
    goto label_22;
  (* (--Rsp)) = (Wrd40.Obj);
  goto label_15;

DEFLABEL (label_22)
  if (! ((Wrd46.uLng) == 1))
    goto label_17;
  (Wrd51.pObj) = (OBJECT_ADDRESS (Wrd40.Obj));
  Rvl = ((Wrd51.pObj) [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_81_5);
  (* (--Rsp)) = Rvl;
  goto label_25;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_81_6);
  (* (--Rsp)) = Rvl;
  goto label_24;

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_81_7);
  (Wrd40.Obj) = Rvl;
  goto label_23;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_82_5 3
#define LABEL_82_6 5
#define LABEL_82_7 7
#define LABEL_82_4 9
#define ENVIRONMENT_LABEL_82_3 18
#define DEBUGGING_LABEL_82_2 17
#define OBJECT_82_3 16
#define OBJECT_82_2 15
#define OBJECT_82_1 14
#define OBJECT_82_0 13
#define EXECUTE_CACHE_82_8 11
#define FREE_REFERENCES_LABEL_82_0 10
#define NUMBER_OF_LINKER_SECTIONS_82_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_82 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd38;
  machine_word Wrd48;
  machine_word Wrd51;
  machine_word Wrd46;
  machine_word Wrd42;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd30;
  machine_word Wrd32;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd20;
  machine_word Wrd22;
  machine_word Wrd16;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd7;
  machine_word Wrd40;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_82_5);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_82_6);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_82_7);
      goto continuation_6;

    case 3:
      current_block = (Rpc - LABEL_82_4);
      goto cadadr_11;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (cadadr_14)
DEFLABEL (cadadr_11)
  INTERRUPT_CHECK (26, LABEL_82_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82_5]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd16.uLng) == 1)
    goto label_16;
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_15)
  (Wrd38.Obj) = (current_block [OBJECT_82_3]);
  (Rsp [1]) = (Wrd38.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_82_8]));

DEFLABEL (label_16)
  if ((Wrd16.uLng) == 1)
    goto label_18;

DEFLABEL (label_17)
  INVOKE_PRIMITIVE ((current_block [OBJECT_82_2]), 1);

DEFLABEL (label_18)
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd20.Obj) = ((Wrd22.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd20.Obj);

DEFLABEL (label_27)
  (Wrd25.Obj) = (Rsp [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 1)
    goto label_20;
  (* (--Rsp)) = (Wrd25.Obj);

DEFLABEL (label_19)
  (Wrd48.Obj) = (current_block [OBJECT_82_1]);
  (Rsp [1]) = (Wrd48.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_82_8]));

DEFLABEL (label_20)
  if ((Wrd26.uLng) == 1)
    goto label_22;

DEFLABEL (label_21)
  INVOKE_PRIMITIVE ((current_block [OBJECT_82_0]), 1);

DEFLABEL (label_22)
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd30.Obj) = ((Wrd32.pObj) [0]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd30.Obj);

DEFLABEL (label_26)
  (Wrd35.Obj) = (Rsp [0]);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if ((Wrd36.uLng) == 1)
    goto label_23;
  (* (--Rsp)) = (Wrd35.Obj);
  goto label_15;

DEFLABEL (label_23)
  if (! ((Wrd36.uLng) == 1))
    goto label_17;
  (Wrd42.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd40.Obj) = ((Wrd42.pObj) [1]);
  Rsp = (& (Rsp [2]));

DEFLABEL (label_25)
  (Rsp [0]) = (Wrd40.Obj);
  (Wrd46.uLng) = (OBJECT_TYPE (Wrd40.Obj));
  if ((Wrd46.uLng) == 1)
    goto label_24;
  (* (--Rsp)) = (Wrd40.Obj);
  goto label_19;

DEFLABEL (label_24)
  if (! ((Wrd46.uLng) == 1))
    goto label_21;
  (Wrd51.pObj) = (OBJECT_ADDRESS (Wrd40.Obj));
  Rvl = ((Wrd51.pObj) [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_82_5);
  (* (--Rsp)) = Rvl;
  goto label_27;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_82_6);
  (* (--Rsp)) = Rvl;
  goto label_26;

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_82_7);
  (Wrd40.Obj) = Rvl;
  goto label_25;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_83_5 3
#define LABEL_83_6 5
#define LABEL_83_7 7
#define LABEL_83_4 9
#define ENVIRONMENT_LABEL_83_3 18
#define DEBUGGING_LABEL_83_2 17
#define OBJECT_83_3 16
#define OBJECT_83_2 15
#define OBJECT_83_1 14
#define OBJECT_83_0 13
#define EXECUTE_CACHE_83_8 11
#define FREE_REFERENCES_LABEL_83_0 10
#define NUMBER_OF_LINKER_SECTIONS_83_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_83 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd48;
  machine_word Wrd38;
  machine_word Wrd51;
  machine_word Wrd46;
  machine_word Wrd42;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd30;
  machine_word Wrd32;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd20;
  machine_word Wrd22;
  machine_word Wrd16;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd7;
  machine_word Wrd40;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_83_5);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_83_6);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_83_7);
      goto continuation_6;

    case 3:
      current_block = (Rpc - LABEL_83_4);
      goto caddar_11;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (caddar_14)
DEFLABEL (caddar_11)
  INTERRUPT_CHECK (26, LABEL_83_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_83_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_83_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_83_5]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd16.uLng) == 1)
    goto label_16;
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_15)
  (Wrd48.Obj) = (current_block [OBJECT_83_3]);
  (Rsp [1]) = (Wrd48.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_83_8]));

DEFLABEL (label_16)
  if ((Wrd16.uLng) == 1)
    goto label_18;

DEFLABEL (label_17)
  INVOKE_PRIMITIVE ((current_block [OBJECT_83_2]), 1);

DEFLABEL (label_18)
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd20.Obj) = ((Wrd22.pObj) [0]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd20.Obj);

DEFLABEL (label_27)
  (Wrd25.Obj) = (Rsp [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 1)
    goto label_20;
  (* (--Rsp)) = (Wrd25.Obj);

DEFLABEL (label_19)
  (Wrd38.Obj) = (current_block [OBJECT_83_1]);
  (Rsp [1]) = (Wrd38.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_83_8]));

DEFLABEL (label_20)
  if ((Wrd26.uLng) == 1)
    goto label_22;

DEFLABEL (label_21)
  INVOKE_PRIMITIVE ((current_block [OBJECT_83_0]), 1);

DEFLABEL (label_22)
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd30.Obj) = ((Wrd32.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd30.Obj);

DEFLABEL (label_26)
  (Wrd35.Obj) = (Rsp [0]);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if ((Wrd36.uLng) == 1)
    goto label_23;
  (* (--Rsp)) = (Wrd35.Obj);
  goto label_19;

DEFLABEL (label_23)
  if (! ((Wrd36.uLng) == 1))
    goto label_21;
  (Wrd42.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd40.Obj) = ((Wrd42.pObj) [1]);
  Rsp = (& (Rsp [2]));

DEFLABEL (label_25)
  (Rsp [0]) = (Wrd40.Obj);
  (Wrd46.uLng) = (OBJECT_TYPE (Wrd40.Obj));
  if ((Wrd46.uLng) == 1)
    goto label_24;
  (* (--Rsp)) = (Wrd40.Obj);
  goto label_15;

DEFLABEL (label_24)
  if (! ((Wrd46.uLng) == 1))
    goto label_17;
  (Wrd51.pObj) = (OBJECT_ADDRESS (Wrd40.Obj));
  Rvl = ((Wrd51.pObj) [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_83_5);
  (* (--Rsp)) = Rvl;
  goto label_27;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_83_6);
  (* (--Rsp)) = Rvl;
  goto label_26;

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_83_7);
  (Wrd40.Obj) = Rvl;
  goto label_25;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_84_5 3
#define LABEL_84_6 5
#define LABEL_84_7 7
#define LABEL_84_4 9
#define ENVIRONMENT_LABEL_84_3 18
#define DEBUGGING_LABEL_84_2 17
#define OBJECT_84_3 16
#define OBJECT_84_2 15
#define OBJECT_84_1 14
#define OBJECT_84_0 13
#define EXECUTE_CACHE_84_8 11
#define FREE_REFERENCES_LABEL_84_0 10
#define NUMBER_OF_LINKER_SECTIONS_84_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_84 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd38;
  machine_word Wrd48;
  machine_word Wrd51;
  machine_word Wrd46;
  machine_word Wrd42;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd30;
  machine_word Wrd32;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd20;
  machine_word Wrd22;
  machine_word Wrd16;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd7;
  machine_word Wrd40;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_84_5);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_84_6);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_84_7);
      goto continuation_6;

    case 3:
      current_block = (Rpc - LABEL_84_4);
      goto cadddr_11;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (cadddr_14)
DEFLABEL (cadddr_11)
  INTERRUPT_CHECK (26, LABEL_84_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_84_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_84_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_84_5]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd16.uLng) == 1)
    goto label_16;
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_15)
  (Wrd38.Obj) = (current_block [OBJECT_84_3]);
  (Rsp [1]) = (Wrd38.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_84_8]));

DEFLABEL (label_16)
  if ((Wrd16.uLng) == 1)
    goto label_18;

DEFLABEL (label_17)
  INVOKE_PRIMITIVE ((current_block [OBJECT_84_2]), 1);

DEFLABEL (label_18)
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd20.Obj) = ((Wrd22.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd20.Obj);

DEFLABEL (label_25)
  (Wrd25.Obj) = (Rsp [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 1)
    goto label_19;
  (* (--Rsp)) = (Wrd25.Obj);
  goto label_15;

DEFLABEL (label_19)
  if (! ((Wrd26.uLng) == 1))
    goto label_17;
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd30.Obj) = ((Wrd32.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd30.Obj);

DEFLABEL (label_24)
  (Wrd35.Obj) = (Rsp [0]);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if ((Wrd36.uLng) == 1)
    goto label_20;
  (* (--Rsp)) = (Wrd35.Obj);
  goto label_15;

DEFLABEL (label_20)
  if (! ((Wrd36.uLng) == 1))
    goto label_17;
  (Wrd42.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd40.Obj) = ((Wrd42.pObj) [1]);
  Rsp = (& (Rsp [2]));

DEFLABEL (label_23)
  (Rsp [0]) = (Wrd40.Obj);
  (Wrd46.uLng) = (OBJECT_TYPE (Wrd40.Obj));
  if ((Wrd46.uLng) == 1)
    goto label_21;
  (* (--Rsp)) = (Wrd40.Obj);
  (Wrd48.Obj) = (current_block [OBJECT_84_1]);
  (Rsp [1]) = (Wrd48.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_84_8]));

DEFLABEL (label_21)
  if (! ((Wrd46.uLng) == 1))
    goto label_22;
  (Wrd51.pObj) = (OBJECT_ADDRESS (Wrd40.Obj));
  Rvl = ((Wrd51.pObj) [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_22)
  INVOKE_PRIMITIVE ((current_block [OBJECT_84_0]), 1);

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_84_5);
  (* (--Rsp)) = Rvl;
  goto label_25;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_84_6);
  (* (--Rsp)) = Rvl;
  goto label_24;

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_84_7);
  (Wrd40.Obj) = Rvl;
  goto label_23;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_85_5 3
#define LABEL_85_6 5
#define LABEL_85_7 7
#define LABEL_85_4 9
#define ENVIRONMENT_LABEL_85_3 18
#define DEBUGGING_LABEL_85_2 17
#define OBJECT_85_3 16
#define OBJECT_85_2 15
#define OBJECT_85_1 14
#define OBJECT_85_0 13
#define EXECUTE_CACHE_85_8 11
#define FREE_REFERENCES_LABEL_85_0 10
#define NUMBER_OF_LINKER_SECTIONS_85_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_85 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd38;
  machine_word Wrd48;
  machine_word Wrd51;
  machine_word Wrd46;
  machine_word Wrd42;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd30;
  machine_word Wrd32;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd20;
  machine_word Wrd22;
  machine_word Wrd16;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd7;
  machine_word Wrd40;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_85_5);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_85_6);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_85_7);
      goto continuation_6;

    case 3:
      current_block = (Rpc - LABEL_85_4);
      goto cdaaar_11;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (cdaaar_14)
DEFLABEL (cdaaar_11)
  INTERRUPT_CHECK (26, LABEL_85_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_85_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_85_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_85_5]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd16.uLng) == 1)
    goto label_16;
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_15)
  (Wrd38.Obj) = (current_block [OBJECT_85_3]);
  (Rsp [1]) = (Wrd38.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_85_8]));

DEFLABEL (label_16)
  if ((Wrd16.uLng) == 1)
    goto label_18;

DEFLABEL (label_17)
  INVOKE_PRIMITIVE ((current_block [OBJECT_85_2]), 1);

DEFLABEL (label_18)
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd20.Obj) = ((Wrd22.pObj) [0]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd20.Obj);

DEFLABEL (label_25)
  (Wrd25.Obj) = (Rsp [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 1)
    goto label_19;
  (* (--Rsp)) = (Wrd25.Obj);
  goto label_15;

DEFLABEL (label_19)
  if (! ((Wrd26.uLng) == 1))
    goto label_17;
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd30.Obj) = ((Wrd32.pObj) [0]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd30.Obj);

DEFLABEL (label_24)
  (Wrd35.Obj) = (Rsp [0]);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if ((Wrd36.uLng) == 1)
    goto label_20;
  (* (--Rsp)) = (Wrd35.Obj);
  goto label_15;

DEFLABEL (label_20)
  if (! ((Wrd36.uLng) == 1))
    goto label_17;
  (Wrd42.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd40.Obj) = ((Wrd42.pObj) [0]);
  Rsp = (& (Rsp [2]));

DEFLABEL (label_23)
  (Rsp [0]) = (Wrd40.Obj);
  (Wrd46.uLng) = (OBJECT_TYPE (Wrd40.Obj));
  if ((Wrd46.uLng) == 1)
    goto label_21;
  (* (--Rsp)) = (Wrd40.Obj);
  (Wrd48.Obj) = (current_block [OBJECT_85_1]);
  (Rsp [1]) = (Wrd48.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_85_8]));

DEFLABEL (label_21)
  if (! ((Wrd46.uLng) == 1))
    goto label_22;
  (Wrd51.pObj) = (OBJECT_ADDRESS (Wrd40.Obj));
  Rvl = ((Wrd51.pObj) [1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_22)
  INVOKE_PRIMITIVE ((current_block [OBJECT_85_0]), 1);

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_85_5);
  (* (--Rsp)) = Rvl;
  goto label_25;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_85_6);
  (* (--Rsp)) = Rvl;
  goto label_24;

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_85_7);
  (Wrd40.Obj) = Rvl;
  goto label_23;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_86_5 3
#define LABEL_86_6 5
#define LABEL_86_7 7
#define LABEL_86_4 9
#define ENVIRONMENT_LABEL_86_3 18
#define DEBUGGING_LABEL_86_2 17
#define OBJECT_86_3 16
#define OBJECT_86_2 15
#define OBJECT_86_1 14
#define OBJECT_86_0 13
#define EXECUTE_CACHE_86_8 11
#define FREE_REFERENCES_LABEL_86_0 10
#define NUMBER_OF_LINKER_SECTIONS_86_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_86 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd48;
  machine_word Wrd38;
  machine_word Wrd51;
  machine_word Wrd46;
  machine_word Wrd42;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd30;
  machine_word Wrd32;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd20;
  machine_word Wrd22;
  machine_word Wrd16;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd7;
  machine_word Wrd40;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_86_5);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_86_6);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_86_7);
      goto continuation_6;

    case 3:
      current_block = (Rpc - LABEL_86_4);
      goto cdaadr_11;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (cdaadr_14)
DEFLABEL (cdaadr_11)
  INTERRUPT_CHECK (26, LABEL_86_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_86_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_86_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_86_5]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd16.uLng) == 1)
    goto label_16;
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_15)
  (Wrd48.Obj) = (current_block [OBJECT_86_3]);
  (Rsp [1]) = (Wrd48.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_86_8]));

DEFLABEL (label_16)
  if ((Wrd16.uLng) == 1)
    goto label_18;

DEFLABEL (label_17)
  INVOKE_PRIMITIVE ((current_block [OBJECT_86_2]), 1);

DEFLABEL (label_18)
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd20.Obj) = ((Wrd22.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd20.Obj);

DEFLABEL (label_27)
  (Wrd25.Obj) = (Rsp [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 1)
    goto label_20;
  (* (--Rsp)) = (Wrd25.Obj);

DEFLABEL (label_19)
  (Wrd38.Obj) = (current_block [OBJECT_86_1]);
  (Rsp [1]) = (Wrd38.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_86_8]));

DEFLABEL (label_20)
  if ((Wrd26.uLng) == 1)
    goto label_22;

DEFLABEL (label_21)
  INVOKE_PRIMITIVE ((current_block [OBJECT_86_0]), 1);

DEFLABEL (label_22)
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd30.Obj) = ((Wrd32.pObj) [0]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd30.Obj);

DEFLABEL (label_26)
  (Wrd35.Obj) = (Rsp [0]);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if ((Wrd36.uLng) == 1)
    goto label_23;
  (* (--Rsp)) = (Wrd35.Obj);
  goto label_19;

DEFLABEL (label_23)
  if (! ((Wrd36.uLng) == 1))
    goto label_21;
  (Wrd42.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd40.Obj) = ((Wrd42.pObj) [0]);
  Rsp = (& (Rsp [2]));

DEFLABEL (label_25)
  (Rsp [0]) = (Wrd40.Obj);
  (Wrd46.uLng) = (OBJECT_TYPE (Wrd40.Obj));
  if ((Wrd46.uLng) == 1)
    goto label_24;
  (* (--Rsp)) = (Wrd40.Obj);
  goto label_15;

DEFLABEL (label_24)
  if (! ((Wrd46.uLng) == 1))
    goto label_17;
  (Wrd51.pObj) = (OBJECT_ADDRESS (Wrd40.Obj));
  Rvl = ((Wrd51.pObj) [1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_86_5);
  (* (--Rsp)) = Rvl;
  goto label_27;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_86_6);
  (* (--Rsp)) = Rvl;
  goto label_26;

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_86_7);
  (Wrd40.Obj) = Rvl;
  goto label_25;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_87_5 3
#define LABEL_87_6 5
#define LABEL_87_7 7
#define LABEL_87_4 9
#define ENVIRONMENT_LABEL_87_3 18
#define DEBUGGING_LABEL_87_2 17
#define OBJECT_87_3 16
#define OBJECT_87_2 15
#define OBJECT_87_1 14
#define OBJECT_87_0 13
#define EXECUTE_CACHE_87_8 11
#define FREE_REFERENCES_LABEL_87_0 10
#define NUMBER_OF_LINKER_SECTIONS_87_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_87 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd38;
  machine_word Wrd48;
  machine_word Wrd51;
  machine_word Wrd46;
  machine_word Wrd42;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd30;
  machine_word Wrd32;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd20;
  machine_word Wrd22;
  machine_word Wrd16;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd7;
  machine_word Wrd40;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_87_5);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_87_6);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_87_7);
      goto continuation_6;

    case 3:
      current_block = (Rpc - LABEL_87_4);
      goto cdadar_11;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (cdadar_14)
DEFLABEL (cdadar_11)
  INTERRUPT_CHECK (26, LABEL_87_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_87_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_87_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_87_5]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd16.uLng) == 1)
    goto label_16;
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_15)
  (Wrd38.Obj) = (current_block [OBJECT_87_3]);
  (Rsp [1]) = (Wrd38.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_87_8]));

DEFLABEL (label_16)
  if ((Wrd16.uLng) == 1)
    goto label_18;

DEFLABEL (label_17)
  INVOKE_PRIMITIVE ((current_block [OBJECT_87_2]), 1);

DEFLABEL (label_18)
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd20.Obj) = ((Wrd22.pObj) [0]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd20.Obj);

DEFLABEL (label_27)
  (Wrd25.Obj) = (Rsp [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 1)
    goto label_20;
  (* (--Rsp)) = (Wrd25.Obj);

DEFLABEL (label_19)
  (Wrd48.Obj) = (current_block [OBJECT_87_1]);
  (Rsp [1]) = (Wrd48.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_87_8]));

DEFLABEL (label_20)
  if ((Wrd26.uLng) == 1)
    goto label_22;

DEFLABEL (label_21)
  INVOKE_PRIMITIVE ((current_block [OBJECT_87_0]), 1);

DEFLABEL (label_22)
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd30.Obj) = ((Wrd32.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd30.Obj);

DEFLABEL (label_26)
  (Wrd35.Obj) = (Rsp [0]);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if ((Wrd36.uLng) == 1)
    goto label_23;
  (* (--Rsp)) = (Wrd35.Obj);
  goto label_15;

DEFLABEL (label_23)
  if (! ((Wrd36.uLng) == 1))
    goto label_17;
  (Wrd42.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd40.Obj) = ((Wrd42.pObj) [0]);
  Rsp = (& (Rsp [2]));

DEFLABEL (label_25)
  (Rsp [0]) = (Wrd40.Obj);
  (Wrd46.uLng) = (OBJECT_TYPE (Wrd40.Obj));
  if ((Wrd46.uLng) == 1)
    goto label_24;
  (* (--Rsp)) = (Wrd40.Obj);
  goto label_19;

DEFLABEL (label_24)
  if (! ((Wrd46.uLng) == 1))
    goto label_21;
  (Wrd51.pObj) = (OBJECT_ADDRESS (Wrd40.Obj));
  Rvl = ((Wrd51.pObj) [1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_87_5);
  (* (--Rsp)) = Rvl;
  goto label_27;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_87_6);
  (* (--Rsp)) = Rvl;
  goto label_26;

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_87_7);
  (Wrd40.Obj) = Rvl;
  goto label_25;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_88_5 3
#define LABEL_88_6 5
#define LABEL_88_7 7
#define LABEL_88_4 9
#define ENVIRONMENT_LABEL_88_3 18
#define DEBUGGING_LABEL_88_2 17
#define OBJECT_88_3 16
#define OBJECT_88_2 15
#define OBJECT_88_1 14
#define OBJECT_88_0 13
#define EXECUTE_CACHE_88_8 11
#define FREE_REFERENCES_LABEL_88_0 10
#define NUMBER_OF_LINKER_SECTIONS_88_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_88 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd48;
  machine_word Wrd38;
  machine_word Wrd51;
  machine_word Wrd46;
  machine_word Wrd42;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd30;
  machine_word Wrd32;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd20;
  machine_word Wrd22;
  machine_word Wrd16;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd7;
  machine_word Wrd40;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_88_5);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_88_6);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_88_7);
      goto continuation_6;

    case 3:
      current_block = (Rpc - LABEL_88_4);
      goto cdaddr_11;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (cdaddr_14)
DEFLABEL (cdaddr_11)
  INTERRUPT_CHECK (26, LABEL_88_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_88_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_88_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_88_5]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd16.uLng) == 1)
    goto label_16;
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_15)
  (Wrd48.Obj) = (current_block [OBJECT_88_3]);
  (Rsp [1]) = (Wrd48.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_88_8]));

DEFLABEL (label_16)
  if ((Wrd16.uLng) == 1)
    goto label_18;

DEFLABEL (label_17)
  INVOKE_PRIMITIVE ((current_block [OBJECT_88_2]), 1);

DEFLABEL (label_18)
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd20.Obj) = ((Wrd22.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd20.Obj);

DEFLABEL (label_25)
  (Wrd25.Obj) = (Rsp [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 1)
    goto label_19;
  (* (--Rsp)) = (Wrd25.Obj);
  goto label_15;

DEFLABEL (label_19)
  if (! ((Wrd26.uLng) == 1))
    goto label_17;
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd30.Obj) = ((Wrd32.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd30.Obj);

DEFLABEL (label_24)
  (Wrd35.Obj) = (Rsp [0]);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if ((Wrd36.uLng) == 1)
    goto label_20;
  (* (--Rsp)) = (Wrd35.Obj);
  (Wrd38.Obj) = (current_block [OBJECT_88_1]);
  (Rsp [1]) = (Wrd38.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_88_8]));

DEFLABEL (label_20)
  if ((Wrd36.uLng) == 1)
    goto label_21;
  INVOKE_PRIMITIVE ((current_block [OBJECT_88_0]), 1);

DEFLABEL (label_21)
  (Wrd42.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd40.Obj) = ((Wrd42.pObj) [0]);
  Rsp = (& (Rsp [2]));

DEFLABEL (label_23)
  (Rsp [0]) = (Wrd40.Obj);
  (Wrd46.uLng) = (OBJECT_TYPE (Wrd40.Obj));
  if ((Wrd46.uLng) == 1)
    goto label_22;
  (* (--Rsp)) = (Wrd40.Obj);
  goto label_15;

DEFLABEL (label_22)
  if (! ((Wrd46.uLng) == 1))
    goto label_17;
  (Wrd51.pObj) = (OBJECT_ADDRESS (Wrd40.Obj));
  Rvl = ((Wrd51.pObj) [1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_88_5);
  (* (--Rsp)) = Rvl;
  goto label_25;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_88_6);
  (* (--Rsp)) = Rvl;
  goto label_24;

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_88_7);
  (Wrd40.Obj) = Rvl;
  goto label_23;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_89_5 3
#define LABEL_89_6 5
#define LABEL_89_7 7
#define LABEL_89_4 9
#define ENVIRONMENT_LABEL_89_3 18
#define DEBUGGING_LABEL_89_2 17
#define OBJECT_89_3 16
#define OBJECT_89_2 15
#define OBJECT_89_1 14
#define OBJECT_89_0 13
#define EXECUTE_CACHE_89_8 11
#define FREE_REFERENCES_LABEL_89_0 10
#define NUMBER_OF_LINKER_SECTIONS_89_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_89 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd28;
  machine_word Wrd48;
  machine_word Wrd51;
  machine_word Wrd46;
  machine_word Wrd42;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd30;
  machine_word Wrd32;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd20;
  machine_word Wrd22;
  machine_word Wrd16;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd7;
  machine_word Wrd40;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_89_5);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_89_6);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_89_7);
      goto continuation_6;

    case 3:
      current_block = (Rpc - LABEL_89_4);
      goto cddaar_11;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (cddaar_14)
DEFLABEL (cddaar_11)
  INTERRUPT_CHECK (26, LABEL_89_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_89_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_89_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_89_5]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd16.uLng) == 1)
    goto label_16;
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_15)
  (Wrd28.Obj) = (current_block [OBJECT_89_3]);
  (Rsp [1]) = (Wrd28.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_89_8]));

DEFLABEL (label_16)
  if ((Wrd16.uLng) == 1)
    goto label_18;

DEFLABEL (label_17)
  INVOKE_PRIMITIVE ((current_block [OBJECT_89_2]), 1);

DEFLABEL (label_18)
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd20.Obj) = ((Wrd22.pObj) [0]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd20.Obj);

DEFLABEL (label_27)
  (Wrd25.Obj) = (Rsp [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 1)
    goto label_19;
  (* (--Rsp)) = (Wrd25.Obj);
  goto label_15;

DEFLABEL (label_19)
  if (! ((Wrd26.uLng) == 1))
    goto label_17;
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd30.Obj) = ((Wrd32.pObj) [0]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd30.Obj);

DEFLABEL (label_26)
  (Wrd35.Obj) = (Rsp [0]);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if ((Wrd36.uLng) == 1)
    goto label_21;
  (* (--Rsp)) = (Wrd35.Obj);

DEFLABEL (label_20)
  (Wrd48.Obj) = (current_block [OBJECT_89_1]);
  (Rsp [1]) = (Wrd48.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_89_8]));

DEFLABEL (label_21)
  if ((Wrd36.uLng) == 1)
    goto label_23;

DEFLABEL (label_22)
  INVOKE_PRIMITIVE ((current_block [OBJECT_89_0]), 1);

DEFLABEL (label_23)
  (Wrd42.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd40.Obj) = ((Wrd42.pObj) [1]);
  Rsp = (& (Rsp [2]));

DEFLABEL (label_25)
  (Rsp [0]) = (Wrd40.Obj);
  (Wrd46.uLng) = (OBJECT_TYPE (Wrd40.Obj));
  if ((Wrd46.uLng) == 1)
    goto label_24;
  (* (--Rsp)) = (Wrd40.Obj);
  goto label_20;

DEFLABEL (label_24)
  if (! ((Wrd46.uLng) == 1))
    goto label_22;
  (Wrd51.pObj) = (OBJECT_ADDRESS (Wrd40.Obj));
  Rvl = ((Wrd51.pObj) [1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_89_5);
  (* (--Rsp)) = Rvl;
  goto label_27;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_89_6);
  (* (--Rsp)) = Rvl;
  goto label_26;

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_89_7);
  (Wrd40.Obj) = Rvl;
  goto label_25;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_90_5 3
#define LABEL_90_6 5
#define LABEL_90_7 7
#define LABEL_90_4 9
#define ENVIRONMENT_LABEL_90_3 18
#define DEBUGGING_LABEL_90_2 17
#define OBJECT_90_3 16
#define OBJECT_90_2 15
#define OBJECT_90_1 14
#define OBJECT_90_0 13
#define EXECUTE_CACHE_90_8 11
#define FREE_REFERENCES_LABEL_90_0 10
#define NUMBER_OF_LINKER_SECTIONS_90_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_90 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd48;
  machine_word Wrd28;
  machine_word Wrd51;
  machine_word Wrd46;
  machine_word Wrd42;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd30;
  machine_word Wrd32;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd20;
  machine_word Wrd22;
  machine_word Wrd16;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd7;
  machine_word Wrd40;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_90_5);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_90_6);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_90_7);
      goto continuation_6;

    case 3:
      current_block = (Rpc - LABEL_90_4);
      goto cddadr_11;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (cddadr_14)
DEFLABEL (cddadr_11)
  INTERRUPT_CHECK (26, LABEL_90_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_90_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_90_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_90_5]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd16.uLng) == 1)
    goto label_16;
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_15)
  (Wrd48.Obj) = (current_block [OBJECT_90_3]);
  (Rsp [1]) = (Wrd48.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_90_8]));

DEFLABEL (label_16)
  if ((Wrd16.uLng) == 1)
    goto label_18;

DEFLABEL (label_17)
  INVOKE_PRIMITIVE ((current_block [OBJECT_90_2]), 1);

DEFLABEL (label_18)
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd20.Obj) = ((Wrd22.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd20.Obj);

DEFLABEL (label_25)
  (Wrd25.Obj) = (Rsp [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 1)
    goto label_19;
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd28.Obj) = (current_block [OBJECT_90_1]);
  (Rsp [1]) = (Wrd28.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_90_8]));

DEFLABEL (label_19)
  if ((Wrd26.uLng) == 1)
    goto label_20;
  INVOKE_PRIMITIVE ((current_block [OBJECT_90_0]), 1);

DEFLABEL (label_20)
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd30.Obj) = ((Wrd32.pObj) [0]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd30.Obj);

DEFLABEL (label_24)
  (Wrd35.Obj) = (Rsp [0]);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if ((Wrd36.uLng) == 1)
    goto label_21;
  (* (--Rsp)) = (Wrd35.Obj);
  goto label_15;

DEFLABEL (label_21)
  if (! ((Wrd36.uLng) == 1))
    goto label_17;
  (Wrd42.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd40.Obj) = ((Wrd42.pObj) [1]);
  Rsp = (& (Rsp [2]));

DEFLABEL (label_23)
  (Rsp [0]) = (Wrd40.Obj);
  (Wrd46.uLng) = (OBJECT_TYPE (Wrd40.Obj));
  if ((Wrd46.uLng) == 1)
    goto label_22;
  (* (--Rsp)) = (Wrd40.Obj);
  goto label_15;

DEFLABEL (label_22)
  if (! ((Wrd46.uLng) == 1))
    goto label_17;
  (Wrd51.pObj) = (OBJECT_ADDRESS (Wrd40.Obj));
  Rvl = ((Wrd51.pObj) [1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_90_5);
  (* (--Rsp)) = Rvl;
  goto label_25;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_90_6);
  (* (--Rsp)) = Rvl;
  goto label_24;

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_90_7);
  (Wrd40.Obj) = Rvl;
  goto label_23;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_91_5 3
#define LABEL_91_6 5
#define LABEL_91_7 7
#define LABEL_91_4 9
#define ENVIRONMENT_LABEL_91_3 18
#define DEBUGGING_LABEL_91_2 17
#define OBJECT_91_3 16
#define OBJECT_91_2 15
#define OBJECT_91_1 14
#define OBJECT_91_0 13
#define EXECUTE_CACHE_91_8 11
#define FREE_REFERENCES_LABEL_91_0 10
#define NUMBER_OF_LINKER_SECTIONS_91_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_91 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd18;
  machine_word Wrd48;
  machine_word Wrd51;
  machine_word Wrd46;
  machine_word Wrd42;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd30;
  machine_word Wrd32;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd20;
  machine_word Wrd22;
  machine_word Wrd16;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd7;
  machine_word Wrd40;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_91_5);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_91_6);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_91_7);
      goto continuation_6;

    case 3:
      current_block = (Rpc - LABEL_91_4);
      goto cdddar_11;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (cdddar_14)
DEFLABEL (cdddar_11)
  INTERRUPT_CHECK (26, LABEL_91_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_91_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_91_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_91_5]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd16.uLng) == 1)
    goto label_15;
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd18.Obj) = (current_block [OBJECT_91_3]);
  (Rsp [1]) = (Wrd18.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_91_8]));

DEFLABEL (label_15)
  if ((Wrd16.uLng) == 1)
    goto label_16;
  INVOKE_PRIMITIVE ((current_block [OBJECT_91_2]), 1);

DEFLABEL (label_16)
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd20.Obj) = ((Wrd22.pObj) [0]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd20.Obj);

DEFLABEL (label_25)
  (Wrd25.Obj) = (Rsp [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 1)
    goto label_18;
  (* (--Rsp)) = (Wrd25.Obj);

DEFLABEL (label_17)
  (Wrd48.Obj) = (current_block [OBJECT_91_1]);
  (Rsp [1]) = (Wrd48.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_91_8]));

DEFLABEL (label_18)
  if ((Wrd26.uLng) == 1)
    goto label_20;

DEFLABEL (label_19)
  INVOKE_PRIMITIVE ((current_block [OBJECT_91_0]), 1);

DEFLABEL (label_20)
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd30.Obj) = ((Wrd32.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd30.Obj);

DEFLABEL (label_24)
  (Wrd35.Obj) = (Rsp [0]);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if ((Wrd36.uLng) == 1)
    goto label_21;
  (* (--Rsp)) = (Wrd35.Obj);
  goto label_17;

DEFLABEL (label_21)
  if (! ((Wrd36.uLng) == 1))
    goto label_19;
  (Wrd42.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd40.Obj) = ((Wrd42.pObj) [1]);
  Rsp = (& (Rsp [2]));

DEFLABEL (label_23)
  (Rsp [0]) = (Wrd40.Obj);
  (Wrd46.uLng) = (OBJECT_TYPE (Wrd40.Obj));
  if ((Wrd46.uLng) == 1)
    goto label_22;
  (* (--Rsp)) = (Wrd40.Obj);
  goto label_17;

DEFLABEL (label_22)
  if (! ((Wrd46.uLng) == 1))
    goto label_19;
  (Wrd51.pObj) = (OBJECT_ADDRESS (Wrd40.Obj));
  Rvl = ((Wrd51.pObj) [1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_91_5);
  (* (--Rsp)) = Rvl;
  goto label_25;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_91_6);
  (* (--Rsp)) = Rvl;
  goto label_24;

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_91_7);
  (Wrd40.Obj) = Rvl;
  goto label_23;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_92_5 3
#define LABEL_92_6 5
#define LABEL_92_7 7
#define LABEL_92_4 9
#define ENVIRONMENT_LABEL_92_3 16
#define DEBUGGING_LABEL_92_2 15
#define OBJECT_92_1 14
#define OBJECT_92_0 13
#define EXECUTE_CACHE_92_8 11
#define FREE_REFERENCES_LABEL_92_0 10
#define NUMBER_OF_LINKER_SECTIONS_92_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_92 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd48;
  machine_word Wrd51;
  machine_word Wrd46;
  machine_word Wrd42;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd30;
  machine_word Wrd32;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd20;
  machine_word Wrd22;
  machine_word Wrd16;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd7;
  machine_word Wrd40;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_92_5);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_92_6);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_92_7);
      goto continuation_6;

    case 3:
      current_block = (Rpc - LABEL_92_4);
      goto cddddr_11;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (cddddr_14)
DEFLABEL (cddddr_11)
  INTERRUPT_CHECK (26, LABEL_92_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_92_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_92_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_92_5]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd16.uLng) == 1)
    goto label_16;
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_15)
  (Wrd48.Obj) = (current_block [OBJECT_92_1]);
  (Rsp [1]) = (Wrd48.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_92_8]));

DEFLABEL (label_16)
  if ((Wrd16.uLng) == 1)
    goto label_18;

DEFLABEL (label_17)
  INVOKE_PRIMITIVE ((current_block [OBJECT_92_0]), 1);

DEFLABEL (label_18)
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd20.Obj) = ((Wrd22.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd20.Obj);

DEFLABEL (label_24)
  (Wrd25.Obj) = (Rsp [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 1)
    goto label_19;
  (* (--Rsp)) = (Wrd25.Obj);
  goto label_15;

DEFLABEL (label_19)
  if (! ((Wrd26.uLng) == 1))
    goto label_17;
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd30.Obj) = ((Wrd32.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd30.Obj);

DEFLABEL (label_23)
  (Wrd35.Obj) = (Rsp [0]);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if ((Wrd36.uLng) == 1)
    goto label_20;
  (* (--Rsp)) = (Wrd35.Obj);
  goto label_15;

DEFLABEL (label_20)
  if (! ((Wrd36.uLng) == 1))
    goto label_17;
  (Wrd42.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd40.Obj) = ((Wrd42.pObj) [1]);
  Rsp = (& (Rsp [2]));

DEFLABEL (label_22)
  (Rsp [0]) = (Wrd40.Obj);
  (Wrd46.uLng) = (OBJECT_TYPE (Wrd40.Obj));
  if ((Wrd46.uLng) == 1)
    goto label_21;
  (* (--Rsp)) = (Wrd40.Obj);
  goto label_15;

DEFLABEL (label_21)
  if (! ((Wrd46.uLng) == 1))
    goto label_17;
  (Wrd51.pObj) = (OBJECT_ADDRESS (Wrd40.Obj));
  Rvl = ((Wrd51.pObj) [1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_92_5);
  (* (--Rsp)) = Rvl;
  goto label_24;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_92_6);
  (* (--Rsp)) = Rvl;
  goto label_23;

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_92_7);
  (Wrd40.Obj) = Rvl;
  goto label_22;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_93_4 3
#define ENVIRONMENT_LABEL_93_3 10
#define DEBUGGING_LABEL_93_2 9
#define OBJECT_93_1 8
#define OBJECT_93_0 7
#define EXECUTE_CACHE_93_5 5
#define FREE_REFERENCES_LABEL_93_0 4
#define NUMBER_OF_LINKER_SECTIONS_93_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_93 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd11;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_93_4);
      goto first_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (first_5)
DEFLABEL (first_2)
  INTERRUPT_CHECK (26, LABEL_93_4);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_6;
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_93_1]);
  (Rsp [1]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_93_5]));

DEFLABEL (label_6)
  if (! ((Wrd6.uLng) == 1))
    goto label_7;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  Rvl = ((Wrd11.pObj) [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_7)
  INVOKE_PRIMITIVE ((current_block [OBJECT_93_0]), 1);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_94_5 3
#define LABEL_94_4 5
#define ENVIRONMENT_LABEL_94_3 14
#define DEBUGGING_LABEL_94_2 13
#define OBJECT_94_3 12
#define OBJECT_94_2 11
#define OBJECT_94_1 10
#define OBJECT_94_0 9
#define EXECUTE_CACHE_94_6 7
#define FREE_REFERENCES_LABEL_94_0 6
#define NUMBER_OF_LINKER_SECTIONS_94_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_94 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd12;
  machine_word Wrd22;
  machine_word Wrd25;
  machine_word Wrd20;
  machine_word Wrd16;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd14;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_94_5);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_94_4);
      goto second_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (second_8)
DEFLABEL (second_5)
  INTERRUPT_CHECK (26, LABEL_94_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_94_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if ((Wrd10.uLng) == 1)
    goto label_9;
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_94_3]);
  (Rsp [1]) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_94_6]));

DEFLABEL (label_9)
  if ((Wrd10.uLng) == 1)
    goto label_10;
  INVOKE_PRIMITIVE ((current_block [OBJECT_94_2]), 1);

DEFLABEL (label_10)
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd14.Obj) = ((Wrd16.pObj) [1]);
  Rsp = (& (Rsp [2]));

DEFLABEL (label_13)
  (Rsp [0]) = (Wrd14.Obj);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd20.uLng) == 1)
    goto label_11;
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd22.Obj) = (current_block [OBJECT_94_1]);
  (Rsp [1]) = (Wrd22.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_94_6]));

DEFLABEL (label_11)
  if (! ((Wrd20.uLng) == 1))
    goto label_12;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  Rvl = ((Wrd25.pObj) [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_12)
  INVOKE_PRIMITIVE ((current_block [OBJECT_94_0]), 1);

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_94_5);
  (Wrd14.Obj) = Rvl;
  goto label_13;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_95_5 3
#define LABEL_95_6 5
#define LABEL_95_4 7
#define ENVIRONMENT_LABEL_95_3 16
#define DEBUGGING_LABEL_95_2 15
#define OBJECT_95_3 14
#define OBJECT_95_2 13
#define OBJECT_95_1 12
#define OBJECT_95_0 11
#define EXECUTE_CACHE_95_7 9
#define FREE_REFERENCES_LABEL_95_0 8
#define NUMBER_OF_LINKER_SECTIONS_95_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_95 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd25;
  machine_word Wrd35;
  machine_word Wrd38;
  machine_word Wrd33;
  machine_word Wrd29;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd17;
  machine_word Wrd19;
  machine_word Wrd13;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  machine_word Wrd27;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_95_5);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_95_6);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_95_4);
      goto third_8;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (third_11)
DEFLABEL (third_8)
  INTERRUPT_CHECK (26, LABEL_95_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_95_6]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_95_5]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if ((Wrd13.uLng) == 1)
    goto label_13;
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_12)
  (Wrd25.Obj) = (current_block [OBJECT_95_3]);
  (Rsp [1]) = (Wrd25.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_95_7]));

DEFLABEL (label_13)
  if ((Wrd13.uLng) == 1)
    goto label_15;

DEFLABEL (label_14)
  INVOKE_PRIMITIVE ((current_block [OBJECT_95_2]), 1);

DEFLABEL (label_15)
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd17.Obj) = ((Wrd19.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd17.Obj);

DEFLABEL (label_20)
  (Wrd22.Obj) = (Rsp [0]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if ((Wrd23.uLng) == 1)
    goto label_16;
  (* (--Rsp)) = (Wrd22.Obj);
  goto label_12;

DEFLABEL (label_16)
  if (! ((Wrd23.uLng) == 1))
    goto label_14;
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
  (Wrd27.Obj) = ((Wrd29.pObj) [1]);
  Rsp = (& (Rsp [2]));

DEFLABEL (label_19)
  (Rsp [0]) = (Wrd27.Obj);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if ((Wrd33.uLng) == 1)
    goto label_17;
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd35.Obj) = (current_block [OBJECT_95_1]);
  (Rsp [1]) = (Wrd35.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_95_7]));

DEFLABEL (label_17)
  if (! ((Wrd33.uLng) == 1))
    goto label_18;
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  Rvl = ((Wrd38.pObj) [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_18)
  INVOKE_PRIMITIVE ((current_block [OBJECT_95_0]), 1);

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_95_5);
  (* (--Rsp)) = Rvl;
  goto label_20;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_95_6);
  (Wrd27.Obj) = Rvl;
  goto label_19;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_96_5 3
#define LABEL_96_6 5
#define LABEL_96_7 7
#define LABEL_96_4 9
#define ENVIRONMENT_LABEL_96_3 18
#define DEBUGGING_LABEL_96_2 17
#define OBJECT_96_3 16
#define OBJECT_96_2 15
#define OBJECT_96_1 14
#define OBJECT_96_0 13
#define EXECUTE_CACHE_96_8 11
#define FREE_REFERENCES_LABEL_96_0 10
#define NUMBER_OF_LINKER_SECTIONS_96_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_96 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd38;
  machine_word Wrd48;
  machine_word Wrd51;
  machine_word Wrd46;
  machine_word Wrd42;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd30;
  machine_word Wrd32;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd20;
  machine_word Wrd22;
  machine_word Wrd16;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd7;
  machine_word Wrd40;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_96_5);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_96_6);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_96_7);
      goto continuation_6;

    case 3:
      current_block = (Rpc - LABEL_96_4);
      goto fourth_11;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (fourth_14)
DEFLABEL (fourth_11)
  INTERRUPT_CHECK (26, LABEL_96_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_96_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_96_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_96_5]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd16.uLng) == 1)
    goto label_16;
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_15)
  (Wrd38.Obj) = (current_block [OBJECT_96_3]);
  (Rsp [1]) = (Wrd38.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_96_8]));

DEFLABEL (label_16)
  if ((Wrd16.uLng) == 1)
    goto label_18;

DEFLABEL (label_17)
  INVOKE_PRIMITIVE ((current_block [OBJECT_96_2]), 1);

DEFLABEL (label_18)
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd20.Obj) = ((Wrd22.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd20.Obj);

DEFLABEL (label_25)
  (Wrd25.Obj) = (Rsp [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 1)
    goto label_19;
  (* (--Rsp)) = (Wrd25.Obj);
  goto label_15;

DEFLABEL (label_19)
  if (! ((Wrd26.uLng) == 1))
    goto label_17;
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd30.Obj) = ((Wrd32.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd30.Obj);

DEFLABEL (label_24)
  (Wrd35.Obj) = (Rsp [0]);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if ((Wrd36.uLng) == 1)
    goto label_20;
  (* (--Rsp)) = (Wrd35.Obj);
  goto label_15;

DEFLABEL (label_20)
  if (! ((Wrd36.uLng) == 1))
    goto label_17;
  (Wrd42.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd40.Obj) = ((Wrd42.pObj) [1]);
  Rsp = (& (Rsp [2]));

DEFLABEL (label_23)
  (Rsp [0]) = (Wrd40.Obj);
  (Wrd46.uLng) = (OBJECT_TYPE (Wrd40.Obj));
  if ((Wrd46.uLng) == 1)
    goto label_21;
  (* (--Rsp)) = (Wrd40.Obj);
  (Wrd48.Obj) = (current_block [OBJECT_96_1]);
  (Rsp [1]) = (Wrd48.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_96_8]));

DEFLABEL (label_21)
  if (! ((Wrd46.uLng) == 1))
    goto label_22;
  (Wrd51.pObj) = (OBJECT_ADDRESS (Wrd40.Obj));
  Rvl = ((Wrd51.pObj) [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_22)
  INVOKE_PRIMITIVE ((current_block [OBJECT_96_0]), 1);

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_96_5);
  (* (--Rsp)) = Rvl;
  goto label_25;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_96_6);
  (* (--Rsp)) = Rvl;
  goto label_24;

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_96_7);
  (Wrd40.Obj) = Rvl;
  goto label_23;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_97_5 3
#define LABEL_97_6 5
#define LABEL_97_7 7
#define LABEL_97_8 9
#define LABEL_97_4 11
#define ENVIRONMENT_LABEL_97_3 20
#define DEBUGGING_LABEL_97_2 19
#define OBJECT_97_3 18
#define OBJECT_97_2 17
#define OBJECT_97_1 16
#define OBJECT_97_0 15
#define EXECUTE_CACHE_97_9 13
#define FREE_REFERENCES_LABEL_97_0 12
#define NUMBER_OF_LINKER_SECTIONS_97_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_97 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd51;
  machine_word Wrd61;
  machine_word Wrd64;
  machine_word Wrd59;
  machine_word Wrd55;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd43;
  machine_word Wrd45;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd33;
  machine_word Wrd35;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd23;
  machine_word Wrd25;
  machine_word Wrd19;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd7;
  machine_word Wrd53;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_97_5);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_97_6);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_97_7);
      goto continuation_6;

    case 3:
      current_block = (Rpc - LABEL_97_8);
      goto continuation_9;

    case 4:
      current_block = (Rpc - LABEL_97_4);
      goto fifth_14;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (fifth_17)
DEFLABEL (fifth_14)
  INTERRUPT_CHECK (26, LABEL_97_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_97_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_97_7]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_97_6]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_97_5]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if ((Wrd19.uLng) == 1)
    goto label_19;
  (* (--Rsp)) = (Wrd17.Obj);

DEFLABEL (label_18)
  (Wrd51.Obj) = (current_block [OBJECT_97_3]);
  (Rsp [1]) = (Wrd51.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_97_9]));

DEFLABEL (label_19)
  if ((Wrd19.uLng) == 1)
    goto label_21;

DEFLABEL (label_20)
  INVOKE_PRIMITIVE ((current_block [OBJECT_97_2]), 1);

DEFLABEL (label_21)
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd23.Obj) = ((Wrd25.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd23.Obj);

DEFLABEL (label_30)
  (Wrd28.Obj) = (Rsp [0]);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if ((Wrd29.uLng) == 1)
    goto label_22;
  (* (--Rsp)) = (Wrd28.Obj);
  goto label_18;

DEFLABEL (label_22)
  if (! ((Wrd29.uLng) == 1))
    goto label_20;
  (Wrd35.pObj) = (OBJECT_ADDRESS (Wrd28.Obj));
  (Wrd33.Obj) = ((Wrd35.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd33.Obj);

DEFLABEL (label_29)
  (Wrd38.Obj) = (Rsp [0]);
  (Wrd39.uLng) = (OBJECT_TYPE (Wrd38.Obj));
  if ((Wrd39.uLng) == 1)
    goto label_23;
  (* (--Rsp)) = (Wrd38.Obj);
  goto label_18;

DEFLABEL (label_23)
  if (! ((Wrd39.uLng) == 1))
    goto label_20;
  (Wrd45.pObj) = (OBJECT_ADDRESS (Wrd38.Obj));
  (Wrd43.Obj) = ((Wrd45.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd43.Obj);

DEFLABEL (label_28)
  (Wrd48.Obj) = (Rsp [0]);
  (Wrd49.uLng) = (OBJECT_TYPE (Wrd48.Obj));
  if ((Wrd49.uLng) == 1)
    goto label_24;
  (* (--Rsp)) = (Wrd48.Obj);
  goto label_18;

DEFLABEL (label_24)
  if (! ((Wrd49.uLng) == 1))
    goto label_20;
  (Wrd55.pObj) = (OBJECT_ADDRESS (Wrd48.Obj));
  (Wrd53.Obj) = ((Wrd55.pObj) [1]);
  Rsp = (& (Rsp [2]));

DEFLABEL (label_27)
  (Rsp [0]) = (Wrd53.Obj);
  (Wrd59.uLng) = (OBJECT_TYPE (Wrd53.Obj));
  if ((Wrd59.uLng) == 1)
    goto label_25;
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd61.Obj) = (current_block [OBJECT_97_1]);
  (Rsp [1]) = (Wrd61.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_97_9]));

DEFLABEL (label_25)
  if (! ((Wrd59.uLng) == 1))
    goto label_26;
  (Wrd64.pObj) = (OBJECT_ADDRESS (Wrd53.Obj));
  Rvl = ((Wrd64.pObj) [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_26)
  INVOKE_PRIMITIVE ((current_block [OBJECT_97_0]), 1);

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_97_5);
  (* (--Rsp)) = Rvl;
  goto label_30;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_97_6);
  (* (--Rsp)) = Rvl;
  goto label_29;

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_97_7);
  (* (--Rsp)) = Rvl;
  goto label_28;

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_97_8);
  (Wrd53.Obj) = Rvl;
  goto label_27;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_98_5 3
#define LABEL_98_6 5
#define LABEL_98_7 7
#define LABEL_98_8 9
#define LABEL_98_9 11
#define LABEL_98_4 13
#define ENVIRONMENT_LABEL_98_3 22
#define DEBUGGING_LABEL_98_2 21
#define OBJECT_98_3 20
#define OBJECT_98_2 19
#define OBJECT_98_1 18
#define OBJECT_98_0 17
#define EXECUTE_CACHE_98_10 15
#define FREE_REFERENCES_LABEL_98_0 14
#define NUMBER_OF_LINKER_SECTIONS_98_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_98 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd64;
  machine_word Wrd74;
  machine_word Wrd77;
  machine_word Wrd72;
  machine_word Wrd68;
  machine_word Wrd62;
  machine_word Wrd61;
  machine_word Wrd56;
  machine_word Wrd58;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd46;
  machine_word Wrd48;
  machine_word Wrd42;
  machine_word Wrd41;
  machine_word Wrd36;
  machine_word Wrd38;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd26;
  machine_word Wrd28;
  machine_word Wrd22;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd7;
  machine_word Wrd66;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_98_5);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_98_6);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_98_7);
      goto continuation_6;

    case 3:
      current_block = (Rpc - LABEL_98_8);
      goto continuation_9;

    case 4:
      current_block = (Rpc - LABEL_98_9);
      goto continuation_12;

    case 5:
      current_block = (Rpc - LABEL_98_4);
      goto sixth_17;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (sixth_20)
DEFLABEL (sixth_17)
  INTERRUPT_CHECK (26, LABEL_98_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_98_9]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_98_8]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_98_7]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_98_6]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_98_5]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd20.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if ((Wrd22.uLng) == 1)
    goto label_22;
  (* (--Rsp)) = (Wrd20.Obj);

DEFLABEL (label_21)
  (Wrd64.Obj) = (current_block [OBJECT_98_3]);
  (Rsp [1]) = (Wrd64.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_98_10]));

DEFLABEL (label_22)
  if ((Wrd22.uLng) == 1)
    goto label_24;

DEFLABEL (label_23)
  INVOKE_PRIMITIVE ((current_block [OBJECT_98_2]), 1);

DEFLABEL (label_24)
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd26.Obj) = ((Wrd28.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd26.Obj);

DEFLABEL (label_35)
  (Wrd31.Obj) = (Rsp [0]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if ((Wrd32.uLng) == 1)
    goto label_25;
  (* (--Rsp)) = (Wrd31.Obj);
  goto label_21;

DEFLABEL (label_25)
  if (! ((Wrd32.uLng) == 1))
    goto label_23;
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd31.Obj));
  (Wrd36.Obj) = ((Wrd38.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd36.Obj);

DEFLABEL (label_34)
  (Wrd41.Obj) = (Rsp [0]);
  (Wrd42.uLng) = (OBJECT_TYPE (Wrd41.Obj));
  if ((Wrd42.uLng) == 1)
    goto label_26;
  (* (--Rsp)) = (Wrd41.Obj);
  goto label_21;

DEFLABEL (label_26)
  if (! ((Wrd42.uLng) == 1))
    goto label_23;
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd41.Obj));
  (Wrd46.Obj) = ((Wrd48.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd46.Obj);

DEFLABEL (label_33)
  (Wrd51.Obj) = (Rsp [0]);
  (Wrd52.uLng) = (OBJECT_TYPE (Wrd51.Obj));
  if ((Wrd52.uLng) == 1)
    goto label_27;
  (* (--Rsp)) = (Wrd51.Obj);
  goto label_21;

DEFLABEL (label_27)
  if (! ((Wrd52.uLng) == 1))
    goto label_23;
  (Wrd58.pObj) = (OBJECT_ADDRESS (Wrd51.Obj));
  (Wrd56.Obj) = ((Wrd58.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd56.Obj);

DEFLABEL (label_32)
  (Wrd61.Obj) = (Rsp [0]);
  (Wrd62.uLng) = (OBJECT_TYPE (Wrd61.Obj));
  if ((Wrd62.uLng) == 1)
    goto label_28;
  (* (--Rsp)) = (Wrd61.Obj);
  goto label_21;

DEFLABEL (label_28)
  if (! ((Wrd62.uLng) == 1))
    goto label_23;
  (Wrd68.pObj) = (OBJECT_ADDRESS (Wrd61.Obj));
  (Wrd66.Obj) = ((Wrd68.pObj) [1]);
  Rsp = (& (Rsp [2]));

DEFLABEL (label_31)
  (Rsp [0]) = (Wrd66.Obj);
  (Wrd72.uLng) = (OBJECT_TYPE (Wrd66.Obj));
  if ((Wrd72.uLng) == 1)
    goto label_29;
  (* (--Rsp)) = (Wrd66.Obj);
  (Wrd74.Obj) = (current_block [OBJECT_98_1]);
  (Rsp [1]) = (Wrd74.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_98_10]));

DEFLABEL (label_29)
  if (! ((Wrd72.uLng) == 1))
    goto label_30;
  (Wrd77.pObj) = (OBJECT_ADDRESS (Wrd66.Obj));
  Rvl = ((Wrd77.pObj) [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_30)
  INVOKE_PRIMITIVE ((current_block [OBJECT_98_0]), 1);

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_98_5);
  (* (--Rsp)) = Rvl;
  goto label_35;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_98_6);
  (* (--Rsp)) = Rvl;
  goto label_34;

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_98_7);
  (* (--Rsp)) = Rvl;
  goto label_33;

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_98_8);
  (* (--Rsp)) = Rvl;
  goto label_32;

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_98_9);
  (Wrd66.Obj) = Rvl;
  goto label_31;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_99_5 3
#define LABEL_99_6 5
#define LABEL_99_7 7
#define LABEL_99_8 9
#define LABEL_99_9 11
#define LABEL_99_10 13
#define LABEL_99_4 15
#define ENVIRONMENT_LABEL_99_3 24
#define DEBUGGING_LABEL_99_2 23
#define OBJECT_99_3 22
#define OBJECT_99_2 21
#define OBJECT_99_1 20
#define OBJECT_99_0 19
#define EXECUTE_CACHE_99_11 17
#define FREE_REFERENCES_LABEL_99_0 16
#define NUMBER_OF_LINKER_SECTIONS_99_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_99 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd77;
  machine_word Wrd87;
  machine_word Wrd90;
  machine_word Wrd85;
  machine_word Wrd81;
  machine_word Wrd75;
  machine_word Wrd74;
  machine_word Wrd69;
  machine_word Wrd71;
  machine_word Wrd65;
  machine_word Wrd64;
  machine_word Wrd59;
  machine_word Wrd61;
  machine_word Wrd55;
  machine_word Wrd54;
  machine_word Wrd49;
  machine_word Wrd51;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd39;
  machine_word Wrd41;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd29;
  machine_word Wrd31;
  machine_word Wrd25;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd7;
  machine_word Wrd79;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_99_5);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_99_6);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_99_7);
      goto continuation_6;

    case 3:
      current_block = (Rpc - LABEL_99_8);
      goto continuation_9;

    case 4:
      current_block = (Rpc - LABEL_99_9);
      goto continuation_12;

    case 5:
      current_block = (Rpc - LABEL_99_10);
      goto continuation_15;

    case 6:
      current_block = (Rpc - LABEL_99_4);
      goto seventh_20;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (seventh_23)
DEFLABEL (seventh_20)
  INTERRUPT_CHECK (26, LABEL_99_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_99_10]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_99_9]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_99_8]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_99_7]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_99_6]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_99_5]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd23.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd25.uLng) == 1)
    goto label_25;
  (* (--Rsp)) = (Wrd23.Obj);

DEFLABEL (label_24)
  (Wrd77.Obj) = (current_block [OBJECT_99_3]);
  (Rsp [1]) = (Wrd77.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_99_11]));

DEFLABEL (label_25)
  if ((Wrd25.uLng) == 1)
    goto label_27;

DEFLABEL (label_26)
  INVOKE_PRIMITIVE ((current_block [OBJECT_99_2]), 1);

DEFLABEL (label_27)
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd29.Obj) = ((Wrd31.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd29.Obj);

DEFLABEL (label_40)
  (Wrd34.Obj) = (Rsp [0]);
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if ((Wrd35.uLng) == 1)
    goto label_28;
  (* (--Rsp)) = (Wrd34.Obj);
  goto label_24;

DEFLABEL (label_28)
  if (! ((Wrd35.uLng) == 1))
    goto label_26;
  (Wrd41.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd39.Obj) = ((Wrd41.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd39.Obj);

DEFLABEL (label_39)
  (Wrd44.Obj) = (Rsp [0]);
  (Wrd45.uLng) = (OBJECT_TYPE (Wrd44.Obj));
  if ((Wrd45.uLng) == 1)
    goto label_29;
  (* (--Rsp)) = (Wrd44.Obj);
  goto label_24;

DEFLABEL (label_29)
  if (! ((Wrd45.uLng) == 1))
    goto label_26;
  (Wrd51.pObj) = (OBJECT_ADDRESS (Wrd44.Obj));
  (Wrd49.Obj) = ((Wrd51.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd49.Obj);

DEFLABEL (label_38)
  (Wrd54.Obj) = (Rsp [0]);
  (Wrd55.uLng) = (OBJECT_TYPE (Wrd54.Obj));
  if ((Wrd55.uLng) == 1)
    goto label_30;
  (* (--Rsp)) = (Wrd54.Obj);
  goto label_24;

DEFLABEL (label_30)
  if (! ((Wrd55.uLng) == 1))
    goto label_26;
  (Wrd61.pObj) = (OBJECT_ADDRESS (Wrd54.Obj));
  (Wrd59.Obj) = ((Wrd61.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd59.Obj);

DEFLABEL (label_37)
  (Wrd64.Obj) = (Rsp [0]);
  (Wrd65.uLng) = (OBJECT_TYPE (Wrd64.Obj));
  if ((Wrd65.uLng) == 1)
    goto label_31;
  (* (--Rsp)) = (Wrd64.Obj);
  goto label_24;

DEFLABEL (label_31)
  if (! ((Wrd65.uLng) == 1))
    goto label_26;
  (Wrd71.pObj) = (OBJECT_ADDRESS (Wrd64.Obj));
  (Wrd69.Obj) = ((Wrd71.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd69.Obj);

DEFLABEL (label_36)
  (Wrd74.Obj) = (Rsp [0]);
  (Wrd75.uLng) = (OBJECT_TYPE (Wrd74.Obj));
  if ((Wrd75.uLng) == 1)
    goto label_32;
  (* (--Rsp)) = (Wrd74.Obj);
  goto label_24;

DEFLABEL (label_32)
  if (! ((Wrd75.uLng) == 1))
    goto label_26;
  (Wrd81.pObj) = (OBJECT_ADDRESS (Wrd74.Obj));
  (Wrd79.Obj) = ((Wrd81.pObj) [1]);
  Rsp = (& (Rsp [2]));

DEFLABEL (label_35)
  (Rsp [0]) = (Wrd79.Obj);
  (Wrd85.uLng) = (OBJECT_TYPE (Wrd79.Obj));
  if ((Wrd85.uLng) == 1)
    goto label_33;
  (* (--Rsp)) = (Wrd79.Obj);
  (Wrd87.Obj) = (current_block [OBJECT_99_1]);
  (Rsp [1]) = (Wrd87.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_99_11]));

DEFLABEL (label_33)
  if (! ((Wrd85.uLng) == 1))
    goto label_34;
  (Wrd90.pObj) = (OBJECT_ADDRESS (Wrd79.Obj));
  Rvl = ((Wrd90.pObj) [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_34)
  INVOKE_PRIMITIVE ((current_block [OBJECT_99_0]), 1);

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_99_5);
  (* (--Rsp)) = Rvl;
  goto label_40;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_99_6);
  (* (--Rsp)) = Rvl;
  goto label_39;

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_99_7);
  (* (--Rsp)) = Rvl;
  goto label_38;

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_99_8);
  (* (--Rsp)) = Rvl;
  goto label_37;

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_99_9);
  (* (--Rsp)) = Rvl;
  goto label_36;

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_99_10);
  (Wrd79.Obj) = Rvl;
  goto label_35;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_100_5 3
#define LABEL_100_6 5
#define LABEL_100_7 7
#define LABEL_100_8 9
#define LABEL_100_9 11
#define LABEL_100_10 13
#define LABEL_100_11 15
#define LABEL_100_4 17
#define ENVIRONMENT_LABEL_100_3 26
#define DEBUGGING_LABEL_100_2 25
#define OBJECT_100_3 24
#define OBJECT_100_2 23
#define OBJECT_100_1 22
#define OBJECT_100_0 21
#define EXECUTE_CACHE_100_12 19
#define FREE_REFERENCES_LABEL_100_0 18
#define NUMBER_OF_LINKER_SECTIONS_100_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_100 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd90;
  machine_word Wrd100;
  machine_word Wrd103;
  machine_word Wrd98;
  machine_word Wrd94;
  machine_word Wrd88;
  machine_word Wrd87;
  machine_word Wrd82;
  machine_word Wrd84;
  machine_word Wrd78;
  machine_word Wrd77;
  machine_word Wrd72;
  machine_word Wrd74;
  machine_word Wrd68;
  machine_word Wrd67;
  machine_word Wrd62;
  machine_word Wrd64;
  machine_word Wrd58;
  machine_word Wrd57;
  machine_word Wrd52;
  machine_word Wrd54;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd42;
  machine_word Wrd44;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd32;
  machine_word Wrd34;
  machine_word Wrd28;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd7;
  machine_word Wrd92;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_100_5);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_100_6);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_100_7);
      goto continuation_6;

    case 3:
      current_block = (Rpc - LABEL_100_8);
      goto continuation_9;

    case 4:
      current_block = (Rpc - LABEL_100_9);
      goto continuation_12;

    case 5:
      current_block = (Rpc - LABEL_100_10);
      goto continuation_15;

    case 6:
      current_block = (Rpc - LABEL_100_11);
      goto continuation_18;

    case 7:
      current_block = (Rpc - LABEL_100_4);
      goto eighth_23;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (eighth_26)
DEFLABEL (eighth_23)
  INTERRUPT_CHECK (26, LABEL_100_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100_11]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100_10]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100_9]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100_8]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100_7]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100_6]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100_5]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd26.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if ((Wrd28.uLng) == 1)
    goto label_28;
  (* (--Rsp)) = (Wrd26.Obj);

DEFLABEL (label_27)
  (Wrd90.Obj) = (current_block [OBJECT_100_3]);
  (Rsp [1]) = (Wrd90.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_100_12]));

DEFLABEL (label_28)
  if ((Wrd28.uLng) == 1)
    goto label_30;

DEFLABEL (label_29)
  INVOKE_PRIMITIVE ((current_block [OBJECT_100_2]), 1);

DEFLABEL (label_30)
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd32.Obj) = ((Wrd34.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd32.Obj);

DEFLABEL (label_45)
  (Wrd37.Obj) = (Rsp [0]);
  (Wrd38.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if ((Wrd38.uLng) == 1)
    goto label_31;
  (* (--Rsp)) = (Wrd37.Obj);
  goto label_27;

DEFLABEL (label_31)
  if (! ((Wrd38.uLng) == 1))
    goto label_29;
  (Wrd44.pObj) = (OBJECT_ADDRESS (Wrd37.Obj));
  (Wrd42.Obj) = ((Wrd44.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd42.Obj);

DEFLABEL (label_44)
  (Wrd47.Obj) = (Rsp [0]);
  (Wrd48.uLng) = (OBJECT_TYPE (Wrd47.Obj));
  if ((Wrd48.uLng) == 1)
    goto label_32;
  (* (--Rsp)) = (Wrd47.Obj);
  goto label_27;

DEFLABEL (label_32)
  if (! ((Wrd48.uLng) == 1))
    goto label_29;
  (Wrd54.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  (Wrd52.Obj) = ((Wrd54.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd52.Obj);

DEFLABEL (label_43)
  (Wrd57.Obj) = (Rsp [0]);
  (Wrd58.uLng) = (OBJECT_TYPE (Wrd57.Obj));
  if ((Wrd58.uLng) == 1)
    goto label_33;
  (* (--Rsp)) = (Wrd57.Obj);
  goto label_27;

DEFLABEL (label_33)
  if (! ((Wrd58.uLng) == 1))
    goto label_29;
  (Wrd64.pObj) = (OBJECT_ADDRESS (Wrd57.Obj));
  (Wrd62.Obj) = ((Wrd64.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd62.Obj);

DEFLABEL (label_42)
  (Wrd67.Obj) = (Rsp [0]);
  (Wrd68.uLng) = (OBJECT_TYPE (Wrd67.Obj));
  if ((Wrd68.uLng) == 1)
    goto label_34;
  (* (--Rsp)) = (Wrd67.Obj);
  goto label_27;

DEFLABEL (label_34)
  if (! ((Wrd68.uLng) == 1))
    goto label_29;
  (Wrd74.pObj) = (OBJECT_ADDRESS (Wrd67.Obj));
  (Wrd72.Obj) = ((Wrd74.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd72.Obj);

DEFLABEL (label_41)
  (Wrd77.Obj) = (Rsp [0]);
  (Wrd78.uLng) = (OBJECT_TYPE (Wrd77.Obj));
  if ((Wrd78.uLng) == 1)
    goto label_35;
  (* (--Rsp)) = (Wrd77.Obj);
  goto label_27;

DEFLABEL (label_35)
  if (! ((Wrd78.uLng) == 1))
    goto label_29;
  (Wrd84.pObj) = (OBJECT_ADDRESS (Wrd77.Obj));
  (Wrd82.Obj) = ((Wrd84.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd82.Obj);

DEFLABEL (label_40)
  (Wrd87.Obj) = (Rsp [0]);
  (Wrd88.uLng) = (OBJECT_TYPE (Wrd87.Obj));
  if ((Wrd88.uLng) == 1)
    goto label_36;
  (* (--Rsp)) = (Wrd87.Obj);
  goto label_27;

DEFLABEL (label_36)
  if (! ((Wrd88.uLng) == 1))
    goto label_29;
  (Wrd94.pObj) = (OBJECT_ADDRESS (Wrd87.Obj));
  (Wrd92.Obj) = ((Wrd94.pObj) [1]);
  Rsp = (& (Rsp [2]));

DEFLABEL (label_39)
  (Rsp [0]) = (Wrd92.Obj);
  (Wrd98.uLng) = (OBJECT_TYPE (Wrd92.Obj));
  if ((Wrd98.uLng) == 1)
    goto label_37;
  (* (--Rsp)) = (Wrd92.Obj);
  (Wrd100.Obj) = (current_block [OBJECT_100_1]);
  (Rsp [1]) = (Wrd100.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_100_12]));

DEFLABEL (label_37)
  if (! ((Wrd98.uLng) == 1))
    goto label_38;
  (Wrd103.pObj) = (OBJECT_ADDRESS (Wrd92.Obj));
  Rvl = ((Wrd103.pObj) [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_38)
  INVOKE_PRIMITIVE ((current_block [OBJECT_100_0]), 1);

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_100_5);
  (* (--Rsp)) = Rvl;
  goto label_45;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_100_6);
  (* (--Rsp)) = Rvl;
  goto label_44;

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_100_7);
  (* (--Rsp)) = Rvl;
  goto label_43;

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_100_8);
  (* (--Rsp)) = Rvl;
  goto label_42;

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_100_9);
  (* (--Rsp)) = Rvl;
  goto label_41;

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_100_10);
  (* (--Rsp)) = Rvl;
  goto label_40;

DEFLABEL (continuation_18)
  INTERRUPT_CHECK (27, LABEL_100_11);
  (Wrd92.Obj) = Rvl;
  goto label_39;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_101_5 3
#define LABEL_101_6 5
#define LABEL_101_7 7
#define LABEL_101_8 9
#define LABEL_101_9 11
#define LABEL_101_10 13
#define LABEL_101_11 15
#define LABEL_101_12 17
#define LABEL_101_4 19
#define ENVIRONMENT_LABEL_101_3 28
#define DEBUGGING_LABEL_101_2 27
#define OBJECT_101_3 26
#define OBJECT_101_2 25
#define OBJECT_101_1 24
#define OBJECT_101_0 23
#define EXECUTE_CACHE_101_13 21
#define FREE_REFERENCES_LABEL_101_0 20
#define NUMBER_OF_LINKER_SECTIONS_101_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_101 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd103;
  machine_word Wrd113;
  machine_word Wrd116;
  machine_word Wrd111;
  machine_word Wrd107;
  machine_word Wrd101;
  machine_word Wrd100;
  machine_word Wrd95;
  machine_word Wrd97;
  machine_word Wrd91;
  machine_word Wrd90;
  machine_word Wrd85;
  machine_word Wrd87;
  machine_word Wrd81;
  machine_word Wrd80;
  machine_word Wrd75;
  machine_word Wrd77;
  machine_word Wrd71;
  machine_word Wrd70;
  machine_word Wrd65;
  machine_word Wrd67;
  machine_word Wrd61;
  machine_word Wrd60;
  machine_word Wrd55;
  machine_word Wrd57;
  machine_word Wrd51;
  machine_word Wrd50;
  machine_word Wrd45;
  machine_word Wrd47;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd35;
  machine_word Wrd37;
  machine_word Wrd31;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd7;
  machine_word Wrd105;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_101_5);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_101_6);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_101_7);
      goto continuation_6;

    case 3:
      current_block = (Rpc - LABEL_101_8);
      goto continuation_9;

    case 4:
      current_block = (Rpc - LABEL_101_9);
      goto continuation_12;

    case 5:
      current_block = (Rpc - LABEL_101_10);
      goto continuation_15;

    case 6:
      current_block = (Rpc - LABEL_101_11);
      goto continuation_18;

    case 7:
      current_block = (Rpc - LABEL_101_12);
      goto continuation_21;

    case 8:
      current_block = (Rpc - LABEL_101_4);
      goto ninth_26;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (ninth_29)
DEFLABEL (ninth_26)
  INTERRUPT_CHECK (26, LABEL_101_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_101_12]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_101_11]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_101_10]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_101_9]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_101_8]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_101_7]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_101_6]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_101_5]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd29.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd29.Obj));
  if ((Wrd31.uLng) == 1)
    goto label_31;
  (* (--Rsp)) = (Wrd29.Obj);

DEFLABEL (label_30)
  (Wrd103.Obj) = (current_block [OBJECT_101_3]);
  (Rsp [1]) = (Wrd103.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_101_13]));

DEFLABEL (label_31)
  if ((Wrd31.uLng) == 1)
    goto label_33;

DEFLABEL (label_32)
  INVOKE_PRIMITIVE ((current_block [OBJECT_101_2]), 1);

DEFLABEL (label_33)
  (Wrd37.pObj) = (OBJECT_ADDRESS (Wrd29.Obj));
  (Wrd35.Obj) = ((Wrd37.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd35.Obj);

DEFLABEL (label_50)
  (Wrd40.Obj) = (Rsp [0]);
  (Wrd41.uLng) = (OBJECT_TYPE (Wrd40.Obj));
  if ((Wrd41.uLng) == 1)
    goto label_34;
  (* (--Rsp)) = (Wrd40.Obj);
  goto label_30;

DEFLABEL (label_34)
  if (! ((Wrd41.uLng) == 1))
    goto label_32;
  (Wrd47.pObj) = (OBJECT_ADDRESS (Wrd40.Obj));
  (Wrd45.Obj) = ((Wrd47.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd45.Obj);

DEFLABEL (label_49)
  (Wrd50.Obj) = (Rsp [0]);
  (Wrd51.uLng) = (OBJECT_TYPE (Wrd50.Obj));
  if ((Wrd51.uLng) == 1)
    goto label_35;
  (* (--Rsp)) = (Wrd50.Obj);
  goto label_30;

DEFLABEL (label_35)
  if (! ((Wrd51.uLng) == 1))
    goto label_32;
  (Wrd57.pObj) = (OBJECT_ADDRESS (Wrd50.Obj));
  (Wrd55.Obj) = ((Wrd57.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd55.Obj);

DEFLABEL (label_48)
  (Wrd60.Obj) = (Rsp [0]);
  (Wrd61.uLng) = (OBJECT_TYPE (Wrd60.Obj));
  if ((Wrd61.uLng) == 1)
    goto label_36;
  (* (--Rsp)) = (Wrd60.Obj);
  goto label_30;

DEFLABEL (label_36)
  if (! ((Wrd61.uLng) == 1))
    goto label_32;
  (Wrd67.pObj) = (OBJECT_ADDRESS (Wrd60.Obj));
  (Wrd65.Obj) = ((Wrd67.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd65.Obj);

DEFLABEL (label_47)
  (Wrd70.Obj) = (Rsp [0]);
  (Wrd71.uLng) = (OBJECT_TYPE (Wrd70.Obj));
  if ((Wrd71.uLng) == 1)
    goto label_37;
  (* (--Rsp)) = (Wrd70.Obj);
  goto label_30;

DEFLABEL (label_37)
  if (! ((Wrd71.uLng) == 1))
    goto label_32;
  (Wrd77.pObj) = (OBJECT_ADDRESS (Wrd70.Obj));
  (Wrd75.Obj) = ((Wrd77.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd75.Obj);

DEFLABEL (label_46)
  (Wrd80.Obj) = (Rsp [0]);
  (Wrd81.uLng) = (OBJECT_TYPE (Wrd80.Obj));
  if ((Wrd81.uLng) == 1)
    goto label_38;
  (* (--Rsp)) = (Wrd80.Obj);
  goto label_30;

DEFLABEL (label_38)
  if (! ((Wrd81.uLng) == 1))
    goto label_32;
  (Wrd87.pObj) = (OBJECT_ADDRESS (Wrd80.Obj));
  (Wrd85.Obj) = ((Wrd87.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd85.Obj);

DEFLABEL (label_45)
  (Wrd90.Obj) = (Rsp [0]);
  (Wrd91.uLng) = (OBJECT_TYPE (Wrd90.Obj));
  if ((Wrd91.uLng) == 1)
    goto label_39;
  (* (--Rsp)) = (Wrd90.Obj);
  goto label_30;

DEFLABEL (label_39)
  if (! ((Wrd91.uLng) == 1))
    goto label_32;
  (Wrd97.pObj) = (OBJECT_ADDRESS (Wrd90.Obj));
  (Wrd95.Obj) = ((Wrd97.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd95.Obj);

DEFLABEL (label_44)
  (Wrd100.Obj) = (Rsp [0]);
  (Wrd101.uLng) = (OBJECT_TYPE (Wrd100.Obj));
  if ((Wrd101.uLng) == 1)
    goto label_40;
  (* (--Rsp)) = (Wrd100.Obj);
  goto label_30;

DEFLABEL (label_40)
  if (! ((Wrd101.uLng) == 1))
    goto label_32;
  (Wrd107.pObj) = (OBJECT_ADDRESS (Wrd100.Obj));
  (Wrd105.Obj) = ((Wrd107.pObj) [1]);
  Rsp = (& (Rsp [2]));

DEFLABEL (label_43)
  (Rsp [0]) = (Wrd105.Obj);
  (Wrd111.uLng) = (OBJECT_TYPE (Wrd105.Obj));
  if ((Wrd111.uLng) == 1)
    goto label_41;
  (* (--Rsp)) = (Wrd105.Obj);
  (Wrd113.Obj) = (current_block [OBJECT_101_1]);
  (Rsp [1]) = (Wrd113.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_101_13]));

DEFLABEL (label_41)
  if (! ((Wrd111.uLng) == 1))
    goto label_42;
  (Wrd116.pObj) = (OBJECT_ADDRESS (Wrd105.Obj));
  Rvl = ((Wrd116.pObj) [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_42)
  INVOKE_PRIMITIVE ((current_block [OBJECT_101_0]), 1);

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_101_5);
  (* (--Rsp)) = Rvl;
  goto label_50;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_101_6);
  (* (--Rsp)) = Rvl;
  goto label_49;

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_101_7);
  (* (--Rsp)) = Rvl;
  goto label_48;

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_101_8);
  (* (--Rsp)) = Rvl;
  goto label_47;

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_101_9);
  (* (--Rsp)) = Rvl;
  goto label_46;

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_101_10);
  (* (--Rsp)) = Rvl;
  goto label_45;

DEFLABEL (continuation_18)
  INTERRUPT_CHECK (27, LABEL_101_11);
  (* (--Rsp)) = Rvl;
  goto label_44;

DEFLABEL (continuation_21)
  INTERRUPT_CHECK (27, LABEL_101_12);
  (Wrd105.Obj) = Rvl;
  goto label_43;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_102_5 3
#define LABEL_102_6 5
#define LABEL_102_7 7
#define LABEL_102_8 9
#define LABEL_102_9 11
#define LABEL_102_10 13
#define LABEL_102_11 15
#define LABEL_102_12 17
#define LABEL_102_13 19
#define LABEL_102_4 21
#define ENVIRONMENT_LABEL_102_3 30
#define DEBUGGING_LABEL_102_2 29
#define OBJECT_102_3 28
#define OBJECT_102_2 27
#define OBJECT_102_1 26
#define OBJECT_102_0 25
#define EXECUTE_CACHE_102_14 23
#define FREE_REFERENCES_LABEL_102_0 22
#define NUMBER_OF_LINKER_SECTIONS_102_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_102 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd116;
  machine_word Wrd126;
  machine_word Wrd129;
  machine_word Wrd124;
  machine_word Wrd120;
  machine_word Wrd114;
  machine_word Wrd113;
  machine_word Wrd108;
  machine_word Wrd110;
  machine_word Wrd104;
  machine_word Wrd103;
  machine_word Wrd98;
  machine_word Wrd100;
  machine_word Wrd94;
  machine_word Wrd93;
  machine_word Wrd88;
  machine_word Wrd90;
  machine_word Wrd84;
  machine_word Wrd83;
  machine_word Wrd78;
  machine_word Wrd80;
  machine_word Wrd74;
  machine_word Wrd73;
  machine_word Wrd68;
  machine_word Wrd70;
  machine_word Wrd64;
  machine_word Wrd63;
  machine_word Wrd58;
  machine_word Wrd60;
  machine_word Wrd54;
  machine_word Wrd53;
  machine_word Wrd48;
  machine_word Wrd50;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd38;
  machine_word Wrd40;
  machine_word Wrd34;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd28;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd7;
  machine_word Wrd118;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_102_5);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_102_6);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_102_7);
      goto continuation_6;

    case 3:
      current_block = (Rpc - LABEL_102_8);
      goto continuation_9;

    case 4:
      current_block = (Rpc - LABEL_102_9);
      goto continuation_12;

    case 5:
      current_block = (Rpc - LABEL_102_10);
      goto continuation_15;

    case 6:
      current_block = (Rpc - LABEL_102_11);
      goto continuation_18;

    case 7:
      current_block = (Rpc - LABEL_102_12);
      goto continuation_21;

    case 8:
      current_block = (Rpc - LABEL_102_13);
      goto continuation_24;

    case 9:
      current_block = (Rpc - LABEL_102_4);
      goto tenth_29;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (tenth_32)
DEFLABEL (tenth_29)
  INTERRUPT_CHECK (26, LABEL_102_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_102_13]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_102_12]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_102_11]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_102_10]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_102_9]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_102_8]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_102_7]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_102_6]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_102_5]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (Wrd32.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd32.Obj);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if ((Wrd34.uLng) == 1)
    goto label_34;
  (* (--Rsp)) = (Wrd32.Obj);

DEFLABEL (label_33)
  (Wrd116.Obj) = (current_block [OBJECT_102_3]);
  (Rsp [1]) = (Wrd116.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_102_14]));

DEFLABEL (label_34)
  if ((Wrd34.uLng) == 1)
    goto label_36;

DEFLABEL (label_35)
  INVOKE_PRIMITIVE ((current_block [OBJECT_102_2]), 1);

DEFLABEL (label_36)
  (Wrd40.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd38.Obj) = ((Wrd40.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd38.Obj);

DEFLABEL (label_55)
  (Wrd43.Obj) = (Rsp [0]);
  (Wrd44.uLng) = (OBJECT_TYPE (Wrd43.Obj));
  if ((Wrd44.uLng) == 1)
    goto label_37;
  (* (--Rsp)) = (Wrd43.Obj);
  goto label_33;

DEFLABEL (label_37)
  if (! ((Wrd44.uLng) == 1))
    goto label_35;
  (Wrd50.pObj) = (OBJECT_ADDRESS (Wrd43.Obj));
  (Wrd48.Obj) = ((Wrd50.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd48.Obj);

DEFLABEL (label_54)
  (Wrd53.Obj) = (Rsp [0]);
  (Wrd54.uLng) = (OBJECT_TYPE (Wrd53.Obj));
  if ((Wrd54.uLng) == 1)
    goto label_38;
  (* (--Rsp)) = (Wrd53.Obj);
  goto label_33;

DEFLABEL (label_38)
  if (! ((Wrd54.uLng) == 1))
    goto label_35;
  (Wrd60.pObj) = (OBJECT_ADDRESS (Wrd53.Obj));
  (Wrd58.Obj) = ((Wrd60.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd58.Obj);

DEFLABEL (label_53)
  (Wrd63.Obj) = (Rsp [0]);
  (Wrd64.uLng) = (OBJECT_TYPE (Wrd63.Obj));
  if ((Wrd64.uLng) == 1)
    goto label_39;
  (* (--Rsp)) = (Wrd63.Obj);
  goto label_33;

DEFLABEL (label_39)
  if (! ((Wrd64.uLng) == 1))
    goto label_35;
  (Wrd70.pObj) = (OBJECT_ADDRESS (Wrd63.Obj));
  (Wrd68.Obj) = ((Wrd70.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd68.Obj);

DEFLABEL (label_52)
  (Wrd73.Obj) = (Rsp [0]);
  (Wrd74.uLng) = (OBJECT_TYPE (Wrd73.Obj));
  if ((Wrd74.uLng) == 1)
    goto label_40;
  (* (--Rsp)) = (Wrd73.Obj);
  goto label_33;

DEFLABEL (label_40)
  if (! ((Wrd74.uLng) == 1))
    goto label_35;
  (Wrd80.pObj) = (OBJECT_ADDRESS (Wrd73.Obj));
  (Wrd78.Obj) = ((Wrd80.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd78.Obj);

DEFLABEL (label_51)
  (Wrd83.Obj) = (Rsp [0]);
  (Wrd84.uLng) = (OBJECT_TYPE (Wrd83.Obj));
  if ((Wrd84.uLng) == 1)
    goto label_41;
  (* (--Rsp)) = (Wrd83.Obj);
  goto label_33;

DEFLABEL (label_41)
  if (! ((Wrd84.uLng) == 1))
    goto label_35;
  (Wrd90.pObj) = (OBJECT_ADDRESS (Wrd83.Obj));
  (Wrd88.Obj) = ((Wrd90.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd88.Obj);

DEFLABEL (label_50)
  (Wrd93.Obj) = (Rsp [0]);
  (Wrd94.uLng) = (OBJECT_TYPE (Wrd93.Obj));
  if ((Wrd94.uLng) == 1)
    goto label_42;
  (* (--Rsp)) = (Wrd93.Obj);
  goto label_33;

DEFLABEL (label_42)
  if (! ((Wrd94.uLng) == 1))
    goto label_35;
  (Wrd100.pObj) = (OBJECT_ADDRESS (Wrd93.Obj));
  (Wrd98.Obj) = ((Wrd100.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd98.Obj);

DEFLABEL (label_49)
  (Wrd103.Obj) = (Rsp [0]);
  (Wrd104.uLng) = (OBJECT_TYPE (Wrd103.Obj));
  if ((Wrd104.uLng) == 1)
    goto label_43;
  (* (--Rsp)) = (Wrd103.Obj);
  goto label_33;

DEFLABEL (label_43)
  if (! ((Wrd104.uLng) == 1))
    goto label_35;
  (Wrd110.pObj) = (OBJECT_ADDRESS (Wrd103.Obj));
  (Wrd108.Obj) = ((Wrd110.pObj) [1]);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd108.Obj);

DEFLABEL (label_48)
  (Wrd113.Obj) = (Rsp [0]);
  (Wrd114.uLng) = (OBJECT_TYPE (Wrd113.Obj));
  if ((Wrd114.uLng) == 1)
    goto label_44;
  (* (--Rsp)) = (Wrd113.Obj);
  goto label_33;

DEFLABEL (label_44)
  if (! ((Wrd114.uLng) == 1))
    goto label_35;
  (Wrd120.pObj) = (OBJECT_ADDRESS (Wrd113.Obj));
  (Wrd118.Obj) = ((Wrd120.pObj) [1]);
  Rsp = (& (Rsp [2]));

DEFLABEL (label_47)
  (Rsp [0]) = (Wrd118.Obj);
  (Wrd124.uLng) = (OBJECT_TYPE (Wrd118.Obj));
  if ((Wrd124.uLng) == 1)
    goto label_45;
  (* (--Rsp)) = (Wrd118.Obj);
  (Wrd126.Obj) = (current_block [OBJECT_102_1]);
  (Rsp [1]) = (Wrd126.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_102_14]));

DEFLABEL (label_45)
  if (! ((Wrd124.uLng) == 1))
    goto label_46;
  (Wrd129.pObj) = (OBJECT_ADDRESS (Wrd118.Obj));
  Rvl = ((Wrd129.pObj) [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_46)
  INVOKE_PRIMITIVE ((current_block [OBJECT_102_0]), 1);

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_102_5);
  (* (--Rsp)) = Rvl;
  goto label_55;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_102_6);
  (* (--Rsp)) = Rvl;
  goto label_54;

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_102_7);
  (* (--Rsp)) = Rvl;
  goto label_53;

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_102_8);
  (* (--Rsp)) = Rvl;
  goto label_52;

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_102_9);
  (* (--Rsp)) = Rvl;
  goto label_51;

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_102_10);
  (* (--Rsp)) = Rvl;
  goto label_50;

DEFLABEL (continuation_18)
  INTERRUPT_CHECK (27, LABEL_102_11);
  (* (--Rsp)) = Rvl;
  goto label_49;

DEFLABEL (continuation_21)
  INTERRUPT_CHECK (27, LABEL_102_12);
  (* (--Rsp)) = Rvl;
  goto label_48;

DEFLABEL (continuation_24)
  INTERRUPT_CHECK (27, LABEL_102_13);
  (Wrd118.Obj) = Rvl;
  goto label_47;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_103_4 3
#define ENVIRONMENT_LABEL_103_3 8
#define DEBUGGING_LABEL_103_2 7
#define EXECUTE_CACHE_103_5 5
#define FREE_REFERENCES_LABEL_103_0 4
#define NUMBER_OF_LINKER_SECTIONS_103_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_103 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_103_4);
      goto append_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (append_3)
DEFLABEL (append_0)
  INTERRUPT_CHECK (26, LABEL_103_4);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_103_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_104_4 3
#define ENVIRONMENT_LABEL_104_3 8
#define DEBUGGING_LABEL_104_2 7
#define EXECUTE_CACHE_104_5 5
#define FREE_REFERENCES_LABEL_104_0 4
#define NUMBER_OF_LINKER_SECTIONS_104_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_104 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_104_4);
      goto appendB_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (appendB_3)
DEFLABEL (appendB_0)
  INTERRUPT_CHECK (26, LABEL_104_4);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_104_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_105_4 3
#define LABEL_105_5 5
#define LABEL_105_7 7
#define LABEL_105_8 9
#define LABEL_105_9 11
#define LABEL_105_10 13
#define LABEL_105_11 15
#define LABEL_105_12 17
#define LABEL_105_13 19
#define LABEL_105_14 21
#define LABEL_105_15 23
#define LABEL_105_16 25
#define LABEL_105_17 27
#define LABEL_105_18 29
#define LABEL_105_19 31
#define LABEL_105_20 33
#define LABEL_105_21 35
#define ENVIRONMENT_LABEL_105_3 47
#define DEBUGGING_LABEL_105_2 46
#define OBJECT_105_4 45
#define OBJECT_105_3 44
#define OBJECT_105_2 43
#define OBJECT_105_1 42
#define OBJECT_105_0 41
#define EXECUTE_CACHE_105_22 37
#define EXECUTE_CACHE_105_6 39
#define FREE_REFERENCES_LABEL_105_0 36
#define NUMBER_OF_LINKER_SECTIONS_105_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_105 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd26;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd45;
  machine_word Wrd37;
  machine_word Wrd39;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd71;
  machine_word Wrd70;
  machine_word Wrd64;
  machine_word Wrd63;
  machine_word Wrd66;
  machine_word Wrd65;
  machine_word Wrd61;
  machine_word Wrd57;
  machine_word Wrd56;
  machine_word Wrd54;
  machine_word Wrd46;
  machine_word Wrd48;
  machine_word Wrd20;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd36;
  machine_word Wrd85;
  machine_word Wrd77;
  machine_word Wrd79;
  machine_word Wrd81;
  machine_word Wrd80;
  machine_word Wrd90;
  machine_word Wrd93;
  machine_word Wrd92;
  machine_word Wrd87;
  machine_word Wrd116;
  machine_word Wrd108;
  machine_word Wrd110;
  machine_word Wrd112;
  machine_word Wrd111;
  machine_word Wrd107;
  machine_word Wrd127;
  machine_word Wrd119;
  machine_word Wrd122;
  machine_word Wrd121;
  machine_word Wrd105;
  machine_word Wrd104;
  machine_word Wrd102;
  machine_word Wrd94;
  machine_word Wrd96;
  machine_word Wrd74;
  machine_word Wrd73;
  machine_word Wrd27;
  machine_word Wrd19;
  machine_word Wrd21;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd18;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_105_4);
      goto Z__append_32;

    case 1:
      current_block = (Rpc - LABEL_105_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_105_7);
      goto label_34;

    case 3:
      current_block = (Rpc - LABEL_105_8);
      goto label_35;

    case 4:
      current_block = (Rpc - LABEL_105_9);
      goto loop_24;

    case 5:
      current_block = (Rpc - LABEL_105_10);
      goto label_42;

    case 6:
      current_block = (Rpc - LABEL_105_11);
      goto label_44;

    case 7:
      current_block = (Rpc - LABEL_105_12);
      goto label_43;

    case 8:
      current_block = (Rpc - LABEL_105_13);
      goto label_41;

    case 9:
      current_block = (Rpc - LABEL_105_14);
      goto continuation_14;

    case 10:
      current_block = (Rpc - LABEL_105_15);
      goto continuation_7;

    case 11:
      current_block = (Rpc - LABEL_105_16);
      goto loop_29;

    case 12:
      current_block = (Rpc - LABEL_105_17);
      goto label_36;

    case 13:
      current_block = (Rpc - LABEL_105_18);
      goto label_39;

    case 14:
      current_block = (Rpc - LABEL_105_19);
      goto label_40;

    case 15:
      current_block = (Rpc - LABEL_105_20);
      goto label_38;

    case 16:
      current_block = (Rpc - LABEL_105_21);
      goto label_37;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (Z__append_46)
DEFLABEL (Z__append_32)
  INTERRUPT_CHECK (26, LABEL_105_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_105_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_105_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_105_5);
  (Rsp [0]) = Rvl;
  (Wrd7.uLng) = (OBJECT_TYPE (Rvl));
  if ((Wrd7.uLng) == 1)
    goto label_49;
  Rvl = (current_block [OBJECT_105_2]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_49)
  if (! ((Wrd7.uLng) == 1))
    goto label_53;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_52)
  (Wrd22.Obj) = (Rsp [1]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if (! ((Wrd23.uLng) == 1))
    goto label_51;
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
  (Wrd19.Obj) = ((Wrd21.pObj) [1]);

DEFLABEL (label_50)
  (Rsp [1]) = (Wrd19.Obj);
  goto loop_29;

DEFLABEL (label_51)
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_105_8]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_105_1]), 1);

DEFLABEL (label_35)
  (Wrd19.Obj) = Rvl;
  goto label_50;

DEFLABEL (label_53)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_105_7]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_105_0]), 1);

DEFLABEL (label_34)
  (* (--Rsp)) = Rvl;
  goto label_52;

DEFLABEL (loop_48)
DEFLABEL (loop_29)
  INTERRUPT_CHECK (26, LABEL_105_16);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_54;
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_54)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_105_15]))));
  (* (--Rsp)) = (Wrd11.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_68;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_67)
  (Wrd21.Obj) = (Rsp [0]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if ((Wrd22.uLng) == 1)
    goto label_61;
  if ((Wrd21.Obj) == (current_block [OBJECT_105_2]))
    goto label_57;
  (Wrd28.Obj) = (Rsp [3]);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if (! ((Wrd29.uLng) == 1))
    goto label_56;
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd28.Obj));
  (Wrd27.Obj) = ((Wrd26.pObj) [0]);
  (* (--Rsp)) = (Wrd27.Obj);

DEFLABEL (label_55)
  (Wrd34.Obj) = (current_block [OBJECT_105_4]);
  (Rsp [1]) = (Wrd34.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_105_22]));

DEFLABEL (label_56)
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_105_21]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_105_0]), 1);

DEFLABEL (label_37)
  (* (--Rsp)) = Rvl;
  goto label_55;

DEFLABEL (label_57)
  (Wrd36.Obj) = (Rsp [2]);
  Rsp = (& (Rsp [2]));

DEFLABEL (label_60)
  (Rsp [0]) = (Wrd36.Obj);
  (Wrd40.Obj) = (Rsp [1]);
  (Wrd41.uLng) = (OBJECT_TYPE (Wrd40.Obj));
  if (! ((Wrd41.uLng) == 1))
    goto label_59;
  (Wrd39.pObj) = (OBJECT_ADDRESS (Wrd40.Obj));
  (Wrd37.Obj) = ((Wrd39.pObj) [1]);

DEFLABEL (label_58)
  (Rsp [1]) = (Wrd37.Obj);
  goto loop_29;

DEFLABEL (label_59)
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_105_20]))));
  (* (--Rsp)) = (Wrd45.Obj);
  (* (--Rsp)) = (Wrd40.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_105_1]), 1);

DEFLABEL (label_38)
  (Wrd37.Obj) = Rvl;
  goto label_58;

DEFLABEL (label_61)
  if (! ((Wrd22.uLng) == 1))
    goto label_66;
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd46.Obj) = ((Wrd48.pObj) [0]);

DEFLABEL (label_65)
  (* (Rhp++)) = (Wrd46.Obj);
  (* (Rhp++)) = ((SCHEME_OBJECT) 0);
  (Wrd56.pObj) = (& (Rhp [-2]));
  (Wrd57.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd56.pObj)));
  (* (--Rsp)) = (Wrd57.Obj);
  (Wrd61.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_105_14]))));
  (* (--Rsp)) = (Wrd61.Obj);
  (Wrd65.Obj) = (Rsp [2]);
  (Wrd66.uLng) = (OBJECT_TYPE (Wrd65.Obj));
  if (! ((Wrd66.uLng) == 1))
    goto label_64;
  (Wrd63.pObj) = (OBJECT_ADDRESS (Wrd65.Obj));
  (Wrd64.Obj) = ((Wrd63.pObj) [1]);
  (* (--Rsp)) = (Wrd64.Obj);

DEFLABEL (label_63)
  (Wrd71.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd71.Obj);
  goto loop_24;

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_105_14);

DEFLABEL (label_62)
  (Wrd36.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [3]));
  goto label_60;

DEFLABEL (label_64)
  (Wrd70.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_105_19]))));
  (* (--Rsp)) = (Wrd70.Obj);
  (* (--Rsp)) = (Wrd65.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_105_1]), 1);

DEFLABEL (label_40)
  (* (--Rsp)) = Rvl;
  goto label_63;

DEFLABEL (label_66)
  (Wrd54.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_105_18]))));
  (* (--Rsp)) = (Wrd54.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_105_0]), 1);

DEFLABEL (label_39)
  (Wrd46.Obj) = Rvl;
  goto label_65;

DEFLABEL (label_68)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_105_17]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_105_0]), 1);

DEFLABEL (label_36)
  (* (--Rsp)) = Rvl;
  goto label_67;

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_105_15);
  (Wrd36.Obj) = Rvl;
  goto label_60;

DEFLABEL (loop_47)
DEFLABEL (loop_24)
  INTERRUPT_CHECK (26, LABEL_105_9);
  (Wrd73.Obj) = (Rsp [1]);
  (Wrd74.uLng) = (OBJECT_TYPE (Wrd73.Obj));
  if ((Wrd74.uLng) == 1)
    goto label_73;
  if ((Wrd73.Obj) == (current_block [OBJECT_105_2]))
    goto label_71;
  (Wrd80.Obj) = (Rsp [7]);
  (Wrd81.uLng) = (OBJECT_TYPE (Wrd80.Obj));
  if (! ((Wrd81.uLng) == 1))
    goto label_70;
  (Wrd79.pObj) = (OBJECT_ADDRESS (Wrd80.Obj));
  (Wrd77.Obj) = ((Wrd79.pObj) [0]);

DEFLABEL (label_69)
  (Rsp [0]) = (Wrd77.Obj);
  goto label_55;

DEFLABEL (label_70)
  (Wrd85.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_105_13]))));
  (* (--Rsp)) = (Wrd85.Obj);
  (* (--Rsp)) = (Wrd80.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_105_0]), 1);

DEFLABEL (label_41)
  (Wrd77.Obj) = Rvl;
  goto label_69;

DEFLABEL (label_71)
  (Wrd87.Obj) = (Rsp [6]);
  (Rsp [1]) = (Wrd87.Obj);
  (Wrd92.Obj) = (Rsp [0]);
  (Wrd93.uLng) = (OBJECT_TYPE (Wrd92.Obj));
  if ((Wrd93.uLng) == 1)
    goto label_72;
  INVOKE_PRIMITIVE ((current_block [OBJECT_105_3]), 2);

DEFLABEL (label_72)
  (Wrd90.pObj) = (OBJECT_ADDRESS (Wrd92.Obj));
  ((Wrd90.pObj) [1]) = (Wrd87.Obj);
  Rsp = (& (Rsp [3]));
  goto label_62;

DEFLABEL (label_73)
  if (! ((Wrd74.uLng) == 1))
    goto label_79;
  (Wrd96.pObj) = (OBJECT_ADDRESS (Wrd73.Obj));
  (Wrd94.Obj) = ((Wrd96.pObj) [0]);

DEFLABEL (label_78)
  (* (Rhp++)) = (Wrd94.Obj);
  (* (Rhp++)) = ((SCHEME_OBJECT) 0);
  (Wrd104.pObj) = (& (Rhp [-2]));
  (Wrd105.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd104.pObj)));
  (* (--Rsp)) = (Wrd105.Obj);
  (Wrd121.Obj) = (Rsp [1]);
  (Wrd122.uLng) = (OBJECT_TYPE (Wrd121.Obj));
  if (! ((Wrd122.uLng) == 1))
    goto label_77;
  (Wrd119.pObj) = (OBJECT_ADDRESS (Wrd121.Obj));
  ((Wrd119.pObj) [1]) = (Wrd105.Obj);

DEFLABEL (label_76)
  (Wrd107.Obj) = (Rsp [0]);
  (Rsp [1]) = (Wrd107.Obj);
  (Wrd111.Obj) = (Rsp [2]);
  (Wrd112.uLng) = (OBJECT_TYPE (Wrd111.Obj));
  if (! ((Wrd112.uLng) == 1))
    goto label_75;
  (Wrd110.pObj) = (OBJECT_ADDRESS (Wrd111.Obj));
  (Wrd108.Obj) = ((Wrd110.pObj) [1]);

DEFLABEL (label_74)
  (Rsp [2]) = (Wrd108.Obj);
  Rsp = (& (Rsp [1]));
  goto loop_24;

DEFLABEL (label_75)
  (Wrd116.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_105_12]))));
  (* (--Rsp)) = (Wrd116.Obj);
  (* (--Rsp)) = (Wrd111.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_105_1]), 1);

DEFLABEL (label_43)
  (Wrd108.Obj) = Rvl;
  goto label_74;

DEFLABEL (label_77)
  (Wrd127.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_105_11]))));
  (* (--Rsp)) = (Wrd127.Obj);
  (* (--Rsp)) = (Wrd105.Obj);
  (* (--Rsp)) = (Wrd121.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_105_3]), 2);

DEFLABEL (label_44)
  goto label_76;

DEFLABEL (label_79)
  (Wrd102.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_105_10]))));
  (* (--Rsp)) = (Wrd102.Obj);
  (* (--Rsp)) = (Wrd73.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_105_0]), 1);

DEFLABEL (label_42)
  (Wrd94.Obj) = Rvl;
  goto label_78;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_106_4 3
#define LABEL_106_5 5
#define LABEL_106_6 7
#define LABEL_106_7 9
#define LABEL_106_8 11
#define LABEL_106_10 13
#define LABEL_106_11 15
#define LABEL_106_12 17
#define LABEL_106_13 19
#define LABEL_106_14 21
#define LABEL_106_9 23
#define LABEL_106_16 25
#define LABEL_106_18 27
#define ENVIRONMENT_LABEL_106_3 39
#define DEBUGGING_LABEL_106_2 38
#define OBJECT_106_4 37
#define OBJECT_106_3 36
#define OBJECT_106_2 35
#define OBJECT_106_1 34
#define OBJECT_106_0 33
#define EXECUTE_CACHE_106_17 29
#define EXECUTE_CACHE_106_15 31
#define FREE_REFERENCES_LABEL_106_0 28
#define NUMBER_OF_LINKER_SECTIONS_106_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_106 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd20;
  machine_word Wrd15;
  machine_word Wrd7;
  machine_word Wrd11;
  machine_word Wrd27;
  machine_word Wrd36;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd55;
  machine_word Wrd62;
  machine_word Wrd58;
  machine_word Wrd50;
  machine_word Wrd52;
  machine_word Wrd54;
  machine_word Wrd53;
  machine_word Wrd42;
  machine_word Wrd49;
  machine_word Wrd45;
  machine_word Wrd37;
  machine_word Wrd39;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd90;
  machine_word Wrd97;
  machine_word Wrd93;
  machine_word Wrd87;
  machine_word Wrd86;
  machine_word Wrd89;
  machine_word Wrd88;
  machine_word Wrd77;
  machine_word Wrd84;
  machine_word Wrd74;
  machine_word Wrd73;
  machine_word Wrd71;
  machine_word Wrd69;
  machine_word Wrd68;
  machine_word Wrd67;
  machine_word Wrd64;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd99;
  machine_word Wrd28;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd19;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd10;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_106_4);
      goto Z__appendB_18;

    case 1:
      current_block = (Rpc - LABEL_106_5);
      goto label_20;

    case 2:
      current_block = (Rpc - LABEL_106_6);
      goto label_21;

    case 3:
      current_block = (Rpc - LABEL_106_7);
      goto continuation_8;

    case 4:
      current_block = (Rpc - LABEL_106_8);
      goto loop_16;

    case 5:
      current_block = (Rpc - LABEL_106_10);
      goto label_25;

    case 6:
      current_block = (Rpc - LABEL_106_11);
      goto label_26;

    case 7:
      current_block = (Rpc - LABEL_106_12);
      goto label_23;

    case 8:
      current_block = (Rpc - LABEL_106_13);
      goto label_24;

    case 9:
      current_block = (Rpc - LABEL_106_14);
      goto label_22;

    case 10:
      current_block = (Rpc - LABEL_106_9);
      goto continuation_14;

    case 11:
      current_block = (Rpc - LABEL_106_16);
      goto continuation_11;

    case 12:
      current_block = (Rpc - LABEL_106_18);
      goto label_27;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (Z__appendB_29)
DEFLABEL (Z__appendB_18)
  INTERRUPT_CHECK (26, LABEL_106_4);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_31;
  Rvl = (current_block [OBJECT_106_2]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_31)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, Rsp));
  (* (--Rsp)) = (Wrd10.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_35;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [1]);
  (* (--Rsp)) = (Wrd13.Obj);

DEFLABEL (label_34)
  (Wrd23.Obj) = (Rsp [2]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd24.uLng) == 1))
    goto label_33;
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd22.Obj) = ((Wrd21.pObj) [0]);
  (* (--Rsp)) = (Wrd22.Obj);

DEFLABEL (label_32)
  Rdl = (& (Rsp [4]));
  goto loop_16;

DEFLABEL (label_33)
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_106_6]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_106_1]), 1);

DEFLABEL (label_21)
  (* (--Rsp)) = Rvl;
  goto label_32;

DEFLABEL (label_35)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_106_5]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_106_0]), 1);

DEFLABEL (label_20)
  (* (--Rsp)) = Rvl;
  goto label_34;

DEFLABEL (loop_30)
DEFLABEL (loop_16)
  DLINK_INTERRUPT_CHECK (25, LABEL_106_8);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_36;
  Rvl = (Rsp [0]);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_36)
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if ((Wrd9.uLng) == 1)
    goto label_44;
  if ((Wrd8.Obj) == (current_block [OBJECT_106_2]))
    goto label_41;
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_106_7]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (current_block [OBJECT_106_3]);
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd23.Obj) = (Rsp [5]);
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd25.Obj) = ((Wrd24.pObj) [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if (! ((Wrd26.uLng) == 1))
    goto label_43;
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd22.Obj) = ((Wrd21.pObj) [0]);
  (* (--Rsp)) = (Wrd22.Obj);

DEFLABEL (label_42)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_106_15]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_106_7);
  (Wrd99.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd99.Obj));

DEFLABEL (label_41)
  (Wrd40.Obj) = (Rsp [1]);
  (Wrd41.uLng) = (OBJECT_TYPE (Wrd40.Obj));
  if (! ((Wrd41.uLng) == 1))
    goto label_40;
  (Wrd39.pObj) = (OBJECT_ADDRESS (Wrd40.Obj));
  (Wrd37.Obj) = ((Wrd39.pObj) [0]);

DEFLABEL (label_39)
  (Rsp [0]) = (Wrd37.Obj);
  (Wrd53.Obj) = (Rsp [1]);
  (Wrd54.uLng) = (OBJECT_TYPE (Wrd53.Obj));
  if (! ((Wrd54.uLng) == 1))
    goto label_38;
  (Wrd52.pObj) = (OBJECT_ADDRESS (Wrd53.Obj));
  (Wrd50.Obj) = ((Wrd52.pObj) [1]);

DEFLABEL (label_37)
  (Rsp [1]) = (Wrd50.Obj);
  goto loop_16;

DEFLABEL (label_38)
  (Wrd58.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd58.Obj);
  (Wrd62.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_106_13]))));
  (* (--Rsp)) = (Wrd62.Obj);
  (* (--Rsp)) = (Wrd53.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_106_0]), 1);

DEFLABEL (label_24)
  (Wrd55.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd55.Obj));
  (Wrd50.Obj) = Rvl;
  goto label_37;

DEFLABEL (label_40)
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd45.Obj);
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_106_12]))));
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd40.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_106_1]), 1);

DEFLABEL (label_23)
  (Wrd42.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd42.Obj));
  (Wrd37.Obj) = Rvl;
  goto label_39;

DEFLABEL (label_43)
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_106_14]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_106_1]), 1);

DEFLABEL (label_22)
  (Wrd27.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd27.Obj));
  (* (--Rsp)) = Rvl;
  goto label_42;

DEFLABEL (label_44)
  (Wrd64.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd64.Obj);
  (Wrd67.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_106_9]))));
  (* (--Rsp)) = (Wrd67.Obj);
  (Wrd68.Obj) = (Rsp [4]);
  (Wrd69.pObj) = (OBJECT_ADDRESS (Wrd68.Obj));
  (Wrd71.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd69.pObj)));
  (* (--Rsp)) = (Wrd71.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_50;
  (Wrd73.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd74.Obj) = ((Wrd73.pObj) [1]);
  (* (--Rsp)) = (Wrd74.Obj);

DEFLABEL (label_49)
  (Wrd88.Obj) = (Rsp [5]);
  (Wrd89.uLng) = (OBJECT_TYPE (Wrd88.Obj));
  if (! ((Wrd89.uLng) == 1))
    goto label_48;
  (Wrd86.pObj) = (OBJECT_ADDRESS (Wrd88.Obj));
  (Wrd87.Obj) = ((Wrd86.pObj) [0]);
  (* (--Rsp)) = (Wrd87.Obj);

DEFLABEL (label_47)
  Rdl = (& (Rsp [3]));
  goto loop_16;

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_106_9);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_106_16]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_106_17]));

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_106_16);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = (* (Rsp++));
  (Wrd11.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd11.uLng) == 1))
    goto label_46;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Rvl));
  ((Wrd10.pObj) [1]) = (Wrd7.Obj);

DEFLABEL (label_45)
  Rvl = (Rsp [0]);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_46)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_106_18]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_106_4]), 2);

DEFLABEL (label_27)
  (Wrd12.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd12.Obj));
  goto label_45;

DEFLABEL (label_48)
  (Wrd93.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd93.Obj);
  (Wrd97.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_106_11]))));
  (* (--Rsp)) = (Wrd97.Obj);
  (* (--Rsp)) = (Wrd88.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_106_1]), 1);

DEFLABEL (label_26)
  (Wrd90.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd90.Obj));
  (* (--Rsp)) = Rvl;
  goto label_47;

DEFLABEL (label_50)
  (* (--Rsp)) = (Wrd64.Obj);
  (Wrd84.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_106_10]))));
  (* (--Rsp)) = (Wrd84.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_106_0]), 1);

DEFLABEL (label_25)
  (Wrd77.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd77.Obj));
  (* (--Rsp)) = Rvl;
  goto label_49;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_107_4 3
#define ENVIRONMENT_LABEL_107_3 9
#define DEBUGGING_LABEL_107_2 8
#define OBJECT_107_0 7
#define EXECUTE_CACHE_107_5 5
#define FREE_REFERENCES_LABEL_107_0 4
#define NUMBER_OF_LINKER_SECTIONS_107_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_107 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_107_4);
      goto reverse_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (reverse_3)
DEFLABEL (reverse_0)
  INTERRUPT_CHECK (26, LABEL_107_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_107_0]);
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_107_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_108_4 3
#define ENVIRONMENT_LABEL_108_3 9
#define DEBUGGING_LABEL_108_2 8
#define OBJECT_108_0 7
#define EXECUTE_CACHE_108_5 5
#define FREE_REFERENCES_LABEL_108_0 4
#define NUMBER_OF_LINKER_SECTIONS_108_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_108 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_108_4);
      goto reverseB_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (reverseB_3)
DEFLABEL (reverseB_0)
  INTERRUPT_CHECK (26, LABEL_108_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_108_0]);
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_108_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_109_4 3
#define LABEL_109_5 5
#define LABEL_109_6 7
#define LABEL_109_7 9
#define LABEL_109_8 11
#define ENVIRONMENT_LABEL_109_3 20
#define DEBUGGING_LABEL_109_2 19
#define OBJECT_109_3 18
#define OBJECT_109_2 17
#define OBJECT_109_1 16
#define OBJECT_109_0 15
#define EXECUTE_CACHE_109_9 13
#define FREE_REFERENCES_LABEL_109_0 12
#define NUMBER_OF_LINKER_SECTIONS_109_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_109 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd37;
  machine_word Wrd29;
  machine_word Wrd31;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd25;
  machine_word Wrd27;
  machine_word Wrd28;
  machine_word Wrd24;
  machine_word Wrd16;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_109_4);
      goto reverse__9;

    case 1:
      current_block = (Rpc - LABEL_109_5);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_109_6);
      goto loop_7;

    case 3:
      current_block = (Rpc - LABEL_109_7);
      goto label_11;

    case 4:
      current_block = (Rpc - LABEL_109_8);
      goto label_12;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (reverse__14)
DEFLABEL (reverse__9)
  INTERRUPT_CHECK (26, LABEL_109_4);
  (Wrd5.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd6.Obj);
  goto loop_7;

DEFLABEL (loop_15)
DEFLABEL (loop_7)
  INTERRUPT_CHECK (26, LABEL_109_6);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_18;
  if (! ((Wrd5.Obj) == (current_block [OBJECT_109_2])))
    goto label_17;

DEFLABEL (label_16)
  Rvl = (Rsp [1]);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_17)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_109_5]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_109_3]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_109_9]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_109_5);
  goto label_16;

DEFLABEL (label_18)
  if (! ((Wrd6.uLng) == 1))
    goto label_22;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd16.Obj) = ((Wrd18.pObj) [0]);

DEFLABEL (label_21)
  (Wrd28.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd16.Obj);
  (* (Rhp++)) = (Wrd28.Obj);
  (Wrd27.pObj) = (& (Rhp [-2]));
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd27.pObj)));
  (Rsp [1]) = (Wrd25.Obj);
  (Wrd32.Obj) = (Rsp [0]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd33.uLng) == 1))
    goto label_20;
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd29.Obj) = ((Wrd31.pObj) [1]);

DEFLABEL (label_19)
  (Rsp [0]) = (Wrd29.Obj);
  goto loop_7;

DEFLABEL (label_20)
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_109_8]))));
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_109_1]), 1);

DEFLABEL (label_12)
  (Wrd29.Obj) = Rvl;
  goto label_19;

DEFLABEL (label_22)
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_109_7]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_109_0]), 1);

DEFLABEL (label_11)
  (Wrd16.Obj) = Rvl;
  goto label_21;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_110_4 3
#define LABEL_110_5 5
#define LABEL_110_6 7
#define LABEL_110_7 9
#define LABEL_110_8 11
#define ENVIRONMENT_LABEL_110_3 20
#define DEBUGGING_LABEL_110_2 19
#define OBJECT_110_3 18
#define OBJECT_110_2 17
#define OBJECT_110_1 16
#define OBJECT_110_0 15
#define EXECUTE_CACHE_110_9 13
#define FREE_REFERENCES_LABEL_110_0 12
#define NUMBER_OF_LINKER_SECTIONS_110_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_110 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd37;
  machine_word Wrd34;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd24;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_110_4);
      goto reverse_B_9;

    case 1:
      current_block = (Rpc - LABEL_110_5);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_110_6);
      goto loop_7;

    case 3:
      current_block = (Rpc - LABEL_110_7);
      goto label_11;

    case 4:
      current_block = (Rpc - LABEL_110_8);
      goto label_12;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (reverse_B_14)
DEFLABEL (reverse_B_9)
  INTERRUPT_CHECK (26, LABEL_110_4);
  (Wrd5.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd6.Obj);
  goto loop_7;

DEFLABEL (loop_15)
DEFLABEL (loop_7)
  INTERRUPT_CHECK (26, LABEL_110_6);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_18;
  if (! ((Wrd5.Obj) == (current_block [OBJECT_110_2])))
    goto label_17;

DEFLABEL (label_16)
  Rvl = (Rsp [1]);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_17)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_110_5]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_110_3]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_110_9]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_110_5);
  goto label_16;

DEFLABEL (label_18)
  if (! ((Wrd6.uLng) == 1))
    goto label_22;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [1]);
  (* (--Rsp)) = (Wrd18.Obj);

DEFLABEL (label_21)
  (Wrd31.Obj) = (Rsp [1]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if (! ((Wrd32.uLng) == 1))
    goto label_20;
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd31.Obj));
  (Wrd30.Obj) = (Rsp [2]);
  ((Wrd29.pObj) [1]) = (Wrd30.Obj);

DEFLABEL (label_19)
  (Wrd25.Obj) = (Rsp [1]);
  (Rsp [2]) = (Wrd25.Obj);
  (Wrd26.Obj) = (Rsp [0]);
  (Rsp [1]) = (Wrd26.Obj);
  Rsp = (& (Rsp [1]));
  goto loop_7;

DEFLABEL (label_20)
  (Wrd34.Obj) = (Rsp [2]);
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_110_8]))));
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd31.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_110_1]), 2);

DEFLABEL (label_12)
  goto label_19;

DEFLABEL (label_22)
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_110_7]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_110_0]), 1);

DEFLABEL (label_11)
  (* (--Rsp)) = Rvl;
  goto label_21;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_111_5 3
#define LABEL_111_6 5
#define LABEL_111_4 7
#define LABEL_111_7 9
#define LABEL_111_9 11
#define LABEL_111_11 13
#define LABEL_111_12 15
#define LABEL_111_14 17
#define LABEL_111_15 19
#define LABEL_111_13 21
#define LABEL_111_18 23
#define LABEL_111_10 25
#define LABEL_111_20 27
#define LABEL_111_21 29
#define LABEL_111_22 31
#define LABEL_111_23 33
#define LABEL_111_24 35
#define LABEL_111_25 37
#define LABEL_111_26 39
#define LABEL_111_27 41
#define LABEL_111_28 43
#define LABEL_111_29 45
#define LABEL_111_8 47
#define LABEL_111_33 49
#define LABEL_111_34 51
#define LABEL_111_36 53
#define LABEL_111_17 55
#define LABEL_111_37 57
#define LABEL_111_39 59
#define LABEL_111_40 61
#define LABEL_111_19 63
#define LABEL_111_35 65
#define LABEL_111_41 67
#define LABEL_111_42 69
#define LABEL_111_38 71
#define LABEL_111_43 73
#define LABEL_111_44 75
#define LABEL_111_45 77
#define LABEL_111_30 79
#define LABEL_111_46 81
#define LABEL_111_31 83
#define LABEL_111_47 85
#define ENVIRONMENT_LABEL_111_3 99
#define DEBUGGING_LABEL_111_2 98
#define OBJECT_111_6 97
#define OBJECT_111_5 96
#define OBJECT_111_4 95
#define OBJECT_111_3 94
#define OBJECT_111_2 93
#define OBJECT_111_1 92
#define OBJECT_111_0 91
#define EXECUTE_CACHE_111_32 87
#define EXECUTE_CACHE_111_16 89
#define FREE_REFERENCES_LABEL_111_0 86
#define NUMBER_OF_LINKER_SECTIONS_111_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_111 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd33;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd19;
  machine_word Wrd11;
  machine_word Wrd20;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd88;
  machine_word Wrd90;
  machine_word Wrd83;
  machine_word Wrd77;
  machine_word Wrd78;
  machine_word Wrd79;
  machine_word Wrd68;
  machine_word Wrd72;
  machine_word Wrd71;
  machine_word Wrd64;
  machine_word Wrd67;
  machine_word Wrd57;
  machine_word Wrd58;
  machine_word Wrd48;
  machine_word Wrd25;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd22;
  machine_word Wrd15;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd12;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd16;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd21;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd62;
  machine_word Wrd60;
  machine_word Wrd59;
  machine_word Wrd66;
  machine_word Wrd63;
  machine_word Wrd56;
  machine_word Wrd53;
  machine_word Wrd92;
  machine_word Wrd91;
  machine_word Wrd85;
  machine_word Wrd84;
  machine_word Wrd87;
  machine_word Wrd86;
  machine_word Wrd82;
  machine_word Wrd76;
  machine_word Wrd75;
  machine_word Wrd73;
  machine_word Wrd70;
  machine_word Wrd69;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd50;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd105;
  machine_word Wrd100;
  machine_word Wrd99;
  machine_word Wrd102;
  machine_word Wrd101;
  machine_word Wrd95;
  machine_word Wrd94;
  machine_word Wrd97;
  machine_word Wrd96;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd32;
  machine_word Wrd34;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_111_5);
      goto continuation_32;

    case 1:
      current_block = (Rpc - LABEL_111_6);
      goto continuation_7;

    case 2:
      current_block = (Rpc - LABEL_111_4);
      goto map_89;

    case 3:
      current_block = (Rpc - LABEL_111_7);
      goto label_92;

    case 4:
      current_block = (Rpc - LABEL_111_9);
      goto label_93;

    case 5:
      current_block = (Rpc - LABEL_111_11);
      goto label_94;

    case 6:
      current_block = (Rpc - LABEL_111_12);
      goto label_95;

    case 7:
      current_block = (Rpc - LABEL_111_14);
      goto label_91;

    case 8:
      current_block = (Rpc - LABEL_111_15);
      goto bad_end_88;

    case 9:
      current_block = (Rpc - LABEL_111_13);
      goto continuation_9;

    case 10:
      current_block = (Rpc - LABEL_111_18);
      goto label_96;

    case 11:
      current_block = (Rpc - LABEL_111_10);
      goto continuation_35;

    case 12:
      current_block = (Rpc - LABEL_111_20);
      goto label_97;

    case 13:
      current_block = (Rpc - LABEL_111_21);
      goto label_98;

    case 14:
      current_block = (Rpc - LABEL_111_22);
      goto split_81;

    case 15:
      current_block = (Rpc - LABEL_111_23);
      goto label_102;

    case 16:
      current_block = (Rpc - LABEL_111_24);
      goto label_104;

    case 17:
      current_block = (Rpc - LABEL_111_25);
      goto label_105;

    case 18:
      current_block = (Rpc - LABEL_111_26);
      goto label_106;

    case 19:
      current_block = (Rpc - LABEL_111_27);
      goto label_107;

    case 20:
      current_block = (Rpc - LABEL_111_28);
      goto label_108;

    case 21:
      current_block = (Rpc - LABEL_111_29);
      goto label_103;

    case 22:
      current_block = (Rpc - LABEL_111_8);
      goto continuation_60;

    case 23:
      current_block = (Rpc - LABEL_111_33);
      goto loop_83;

    case 24:
      current_block = (Rpc - LABEL_111_34);
      goto loop_22;

    case 25:
      current_block = (Rpc - LABEL_111_36);
      goto label_99;

    case 26:
      current_block = (Rpc - LABEL_111_17);
      goto continuation_12;

    case 27:
      current_block = (Rpc - LABEL_111_37);
      goto loop_55;

    case 28:
      current_block = (Rpc - LABEL_111_39);
      goto label_100;

    case 29:
      current_block = (Rpc - LABEL_111_40);
      goto label_101;

    case 30:
      current_block = (Rpc - LABEL_111_19);
      goto continuation_39;

    case 31:
      current_block = (Rpc - LABEL_111_35);
      goto continuation_17;

    case 32:
      current_block = (Rpc - LABEL_111_41);
      goto label_110;

    case 33:
      current_block = (Rpc - LABEL_111_42);
      goto label_109;

    case 34:
      current_block = (Rpc - LABEL_111_38);
      goto continuation_49;

    case 35:
      current_block = (Rpc - LABEL_111_43);
      goto label_113;

    case 36:
      current_block = (Rpc - LABEL_111_44);
      goto label_111;

    case 37:
      current_block = (Rpc - LABEL_111_45);
      goto label_112;

    case 38:
      current_block = (Rpc - LABEL_111_30);
      goto continuation_65;

    case 39:
      current_block = (Rpc - LABEL_111_46);
      goto label_114;

    case 40:
      current_block = (Rpc - LABEL_111_31);
      goto continuation_64;

    case 41:
      current_block = (Rpc - LABEL_111_47);
      goto continuation_68;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (map_116)
DEFLABEL (map_89)
  INTERRUPT_CHECK (26, LABEL_111_4);
  (Wrd5.Obj) = (Rsp [2]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_130;
  (Wrd7.Obj) = (Rsp [1]);
  (Wrd8.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if ((Wrd8.uLng) == 1)
    goto label_124;
  if (! ((Wrd7.Obj) == (current_block [OBJECT_111_2])))
    goto label_123;

DEFLABEL (label_122)
  Rvl = (current_block [OBJECT_111_2]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_123)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_111_6]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.pObj) = (& (Rsp [1]));
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd14.pObj)));
  (* (--Rsp)) = (Wrd16.Obj);
  goto bad_end_88;

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_111_6);
  goto label_122;

DEFLABEL (label_124)
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_111_13]))));
  (* (--Rsp)) = (Wrd21.Obj);
  if (! ((Wrd8.uLng) == 1))
    goto label_129;
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd24.Obj) = ((Wrd23.pObj) [0]);
  (* (--Rsp)) = (Wrd24.Obj);

DEFLABEL (label_128)
  (Wrd31.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd31.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_111_13);
  (Wrd9.Obj) = (current_block [OBJECT_111_2]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_111_17]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd17.Obj) = (Rsp [4]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_127;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [1]);
  (* (--Rsp)) = (Wrd16.Obj);

DEFLABEL (label_126)
  goto loop_22;

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_111_17);

DEFLABEL (label_125)
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_127)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_111_18]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_111_0]), 1);

DEFLABEL (label_96)
  (* (--Rsp)) = Rvl;
  goto label_126;

DEFLABEL (label_129)
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_111_14]))));
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_111_3]), 1);

DEFLABEL (label_91)
  (* (--Rsp)) = Rvl;
  goto label_128;

DEFLABEL (label_130)
  if (! ((Wrd6.uLng) == 1))
    goto label_151;
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd32.Obj) = ((Wrd34.pObj) [1]);

DEFLABEL (label_150)
  (Wrd41.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd41.uLng) == 1))
    goto label_133;
  (Wrd96.Obj) = (Rsp [1]);
  (Wrd97.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd96.Obj);
  (* (Rhp++)) = (Wrd97.Obj);
  (Wrd94.pObj) = (& (Rhp [-2]));
  (Wrd95.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd94.pObj)));
  (* (--Rsp)) = (Wrd95.Obj);
  (Wrd101.Obj) = (current_block [OBJECT_111_1]);
  (Wrd102.Obj) = (current_block [OBJECT_111_2]);
  (* (Rhp++)) = (Wrd101.Obj);
  (* (Rhp++)) = (Wrd102.Obj);
  (Wrd99.pObj) = (& (Rhp [-2]));
  (Wrd100.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd99.pObj)));
  (* (--Rsp)) = (Wrd100.Obj);
  (Wrd105.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_111_8]))));
  (* (--Rsp)) = (Wrd105.Obj);
  (* (--Rsp)) = (Wrd100.Obj);
  (* (--Rsp)) = (Wrd95.Obj);
  goto loop_83;

DEFLABEL (continuation_60)
  INTERRUPT_CHECK (27, LABEL_111_8);

DEFLABEL (label_132)
  (Wrd5.Obj) = (Rsp [0]);
  (Rsp [4]) = (Wrd5.Obj);
  Rsp = (& (Rsp [4]));
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_131;
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  Rvl = ((Wrd8.pObj) [1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_131)
  INVOKE_PRIMITIVE ((current_block [OBJECT_111_0]), 1);

DEFLABEL (label_133)
  (Wrd45.Obj) = (Rsp [2]);
  (Wrd46.uLng) = (OBJECT_TYPE (Wrd45.Obj));
  if (! ((Wrd46.uLng) == 1))
    goto label_149;
  (Wrd43.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd44.Obj) = ((Wrd43.pObj) [0]);
  (* (--Rsp)) = (Wrd44.Obj);

DEFLABEL (label_148)
  (Wrd51.Obj) = (Rsp [2]);
  (Wrd52.uLng) = (OBJECT_TYPE (Wrd51.Obj));
  if ((Wrd52.uLng) == 1)
    goto label_138;

DEFLABEL (label_137)
  (Wrd53.Obj) = (Rsp [2]);
  if ((Wrd53.Obj) == (current_block [OBJECT_111_2]))
    goto label_136;
  (Wrd56.uLng) = (OBJECT_TYPE (Wrd53.Obj));
  if ((Wrd56.uLng) == 1)
    goto label_136;

DEFLABEL (label_135)
  (Wrd59.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_111_5]))));
  (* (--Rsp)) = (Wrd59.Obj);
  (Wrd60.pObj) = (& (Rsp [2]));
  (Wrd62.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd60.pObj)));
  (* (--Rsp)) = (Wrd62.Obj);
  goto bad_end_88;

DEFLABEL (continuation_32)
  INTERRUPT_CHECK (27, LABEL_111_5);

DEFLABEL (label_134)
  Rvl = (current_block [OBJECT_111_2]);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_136)
  (Wrd63.Obj) = (Rsp [0]);
  if ((Wrd63.Obj) == (current_block [OBJECT_111_2]))
    goto label_134;
  (Wrd66.uLng) = (OBJECT_TYPE (Wrd63.Obj));
  if ((Wrd66.uLng) == 1)
    goto label_134;
  goto label_135;

DEFLABEL (label_138)
  (Wrd69.Obj) = (Rsp [0]);
  (Wrd70.uLng) = (OBJECT_TYPE (Wrd69.Obj));
  if (! ((Wrd70.uLng) == 1))
    goto label_137;
  (Wrd73.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_111_10]))));
  (* (--Rsp)) = (Wrd73.Obj);
  if (! ((Wrd70.uLng) == 1))
    goto label_147;
  (Wrd75.pObj) = (OBJECT_ADDRESS (Wrd69.Obj));
  (Wrd76.Obj) = ((Wrd75.pObj) [0]);
  (* (--Rsp)) = (Wrd76.Obj);

DEFLABEL (label_146)
  (Wrd86.Obj) = (Rsp [4]);
  (Wrd87.uLng) = (OBJECT_TYPE (Wrd86.Obj));
  if (! ((Wrd87.uLng) == 1))
    goto label_145;
  (Wrd84.pObj) = (OBJECT_ADDRESS (Wrd86.Obj));
  (Wrd85.Obj) = ((Wrd84.pObj) [0]);
  (* (--Rsp)) = (Wrd85.Obj);

DEFLABEL (label_144)
  (Wrd92.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd92.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_35)
  INTERRUPT_CHECK (27, LABEL_111_10);
  (Wrd9.Obj) = (current_block [OBJECT_111_2]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_111_19]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd17.Obj) = (Rsp [3]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_143;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [1]);
  (* (--Rsp)) = (Wrd16.Obj);

DEFLABEL (label_142)
  (Wrd26.Obj) = (Rsp [6]);
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if (! ((Wrd27.uLng) == 1))
    goto label_141;
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd25.Obj) = ((Wrd24.pObj) [1]);
  (* (--Rsp)) = (Wrd25.Obj);

DEFLABEL (label_140)
  goto loop_55;

DEFLABEL (continuation_39)
  INTERRUPT_CHECK (27, LABEL_111_19);

DEFLABEL (label_139)
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [5]));
  goto pop_return;

DEFLABEL (label_141)
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_111_21]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_111_0]), 1);

DEFLABEL (label_98)
  (* (--Rsp)) = Rvl;
  goto label_140;

DEFLABEL (label_143)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_111_20]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_111_0]), 1);

DEFLABEL (label_97)
  (* (--Rsp)) = Rvl;
  goto label_142;

DEFLABEL (label_145)
  (Wrd91.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_111_12]))));
  (* (--Rsp)) = (Wrd91.Obj);
  (* (--Rsp)) = (Wrd86.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_111_3]), 1);

DEFLABEL (label_95)
  (* (--Rsp)) = Rvl;
  goto label_144;

DEFLABEL (label_147)
  (Wrd82.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_111_11]))));
  (* (--Rsp)) = (Wrd82.Obj);
  (* (--Rsp)) = (Wrd69.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_111_3]), 1);

DEFLABEL (label_94)
  (* (--Rsp)) = Rvl;
  goto label_146;

DEFLABEL (label_149)
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_111_9]))));
  (* (--Rsp)) = (Wrd50.Obj);
  (* (--Rsp)) = (Wrd45.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_111_3]), 1);

DEFLABEL (label_93)
  (* (--Rsp)) = Rvl;
  goto label_148;

DEFLABEL (label_151)
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_111_7]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_111_0]), 1);

DEFLABEL (label_92)
  (Wrd32.Obj) = Rvl;
  goto label_150;

DEFLABEL (bad_end_117)
DEFLABEL (bad_end_88)
  INTERRUPT_CHECK (26, LABEL_111_15);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [1]);
  (Wrd13.Obj) = ((Wrd9.pObj) [2]);
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd13.Obj);
  (Wrd6.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd6.pObj)));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_111_4]);
  (Rsp [1]) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_111_16]));

DEFLABEL (loop_119)
DEFLABEL (loop_83)
  INTERRUPT_CHECK (26, LABEL_111_33);
  (Wrd5.Obj) = (current_block [OBJECT_111_2]);
  (* (--Rsp)) = (Wrd5.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd7.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  goto split_81;

DEFLABEL (loop_120)
DEFLABEL (loop_22)
  INTERRUPT_CHECK (26, LABEL_111_34);
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if ((Wrd8.uLng) == 1)
    goto label_153;
  if ((Wrd7.Obj) == (current_block [OBJECT_111_2]))
    goto label_152;
  (Wrd12.pObj) = (& (Rsp [4]));
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd12.pObj)));
  (Rsp [1]) = (Wrd14.Obj);
  Rsp = (& (Rsp [1]));
  goto bad_end_88;

DEFLABEL (label_152)
  Rsp = (& (Rsp [3]));
  goto label_125;

DEFLABEL (label_153)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_111_35]))));
  (* (--Rsp)) = (Wrd19.Obj);
  if (! ((Wrd8.uLng) == 1))
    goto label_159;
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd22.Obj) = ((Wrd21.pObj) [0]);
  (* (--Rsp)) = (Wrd22.Obj);

DEFLABEL (label_158)
  (Wrd29.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd29.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_111_35);
  (Wrd9.Obj) = (current_block [OBJECT_111_2]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd24.Obj) = (Rsp [2]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if (! ((Wrd25.uLng) == 1))
    goto label_157;
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  ((Wrd22.pObj) [1]) = (Wrd8.Obj);

DEFLABEL (label_156)
  (Wrd13.Obj) = (Rsp [1]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd14.uLng) == 1))
    goto label_155;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd10.Obj) = ((Wrd12.pObj) [1]);

DEFLABEL (label_154)
  (Rsp [1]) = (Wrd10.Obj);
  (Wrd19.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd19.Obj);
  Rsp = (& (Rsp [1]));
  goto loop_22;

DEFLABEL (label_155)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_111_42]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd13.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_111_0]), 1);

DEFLABEL (label_109)
  (Wrd10.Obj) = Rvl;
  goto label_154;

DEFLABEL (label_157)
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_111_41]))));
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_111_5]), 2);

DEFLABEL (label_110)
  goto label_156;

DEFLABEL (label_159)
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_111_36]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_111_3]), 1);

DEFLABEL (label_99)
  (* (--Rsp)) = Rvl;
  goto label_158;

DEFLABEL (loop_121)
DEFLABEL (loop_55)
  INTERRUPT_CHECK (26, LABEL_111_37);
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if ((Wrd8.uLng) == 1)
    goto label_164;

DEFLABEL (label_163)
  (Wrd9.Obj) = (Rsp [0]);
  if ((Wrd9.Obj) == (current_block [OBJECT_111_2]))
    goto label_161;
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd12.uLng) == 1)
    goto label_161;

DEFLABEL (label_160)
  (Wrd14.pObj) = (& (Rsp [6]));
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd14.pObj)));
  (Rsp [2]) = (Wrd16.Obj);
  Rsp = (& (Rsp [2]));
  goto bad_end_88;

DEFLABEL (label_161)
  (Wrd18.Obj) = (Rsp [1]);
  if ((Wrd18.Obj) == (current_block [OBJECT_111_2]))
    goto label_162;
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd21.uLng) == 1))
    goto label_160;

DEFLABEL (label_162)
  Rsp = (& (Rsp [4]));
  goto label_139;

DEFLABEL (label_164)
  (Wrd23.Obj) = (Rsp [1]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd24.uLng) == 1))
    goto label_163;
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_111_38]))));
  (* (--Rsp)) = (Wrd27.Obj);
  if (! ((Wrd24.uLng) == 1))
    goto label_174;
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd30.Obj) = ((Wrd29.pObj) [0]);
  (* (--Rsp)) = (Wrd30.Obj);

DEFLABEL (label_173)
  (Wrd40.Obj) = (Rsp [2]);
  (Wrd41.uLng) = (OBJECT_TYPE (Wrd40.Obj));
  if (! ((Wrd41.uLng) == 1))
    goto label_172;
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd40.Obj));
  (Wrd39.Obj) = ((Wrd38.pObj) [0]);
  (* (--Rsp)) = (Wrd39.Obj);

DEFLABEL (label_171)
  (Wrd46.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd46.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_49)
  INTERRUPT_CHECK (27, LABEL_111_38);
  (Wrd9.Obj) = (current_block [OBJECT_111_2]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd33.Obj) = (Rsp [3]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if (! ((Wrd34.uLng) == 1))
    goto label_170;
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  ((Wrd31.pObj) [1]) = (Wrd8.Obj);

DEFLABEL (label_169)
  (Wrd13.Obj) = (Rsp [1]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd14.uLng) == 1))
    goto label_168;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd10.Obj) = ((Wrd12.pObj) [1]);

DEFLABEL (label_167)
  (Rsp [1]) = (Wrd10.Obj);
  (Wrd22.Obj) = (Rsp [2]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if (! ((Wrd23.uLng) == 1))
    goto label_166;
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
  (Wrd19.Obj) = ((Wrd21.pObj) [1]);

DEFLABEL (label_165)
  (Rsp [2]) = (Wrd19.Obj);
  (Wrd28.Obj) = (Rsp [0]);
  (Rsp [3]) = (Wrd28.Obj);
  Rsp = (& (Rsp [1]));
  goto loop_55;

DEFLABEL (label_166)
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_111_45]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_111_0]), 1);

DEFLABEL (label_112)
  (Wrd19.Obj) = Rvl;
  goto label_165;

DEFLABEL (label_168)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_111_44]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd13.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_111_0]), 1);

DEFLABEL (label_111)
  (Wrd10.Obj) = Rvl;
  goto label_167;

DEFLABEL (label_170)
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_111_43]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_111_5]), 2);

DEFLABEL (label_113)
  goto label_169;

DEFLABEL (label_172)
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_111_40]))));
  (* (--Rsp)) = (Wrd45.Obj);
  (* (--Rsp)) = (Wrd40.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_111_3]), 1);

DEFLABEL (label_101)
  (* (--Rsp)) = Rvl;
  goto label_171;

DEFLABEL (label_174)
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_111_39]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_111_3]), 1);

DEFLABEL (label_100)
  (* (--Rsp)) = Rvl;
  goto label_173;

DEFLABEL (split_118)
DEFLABEL (split_81)
  INTERRUPT_CHECK (26, LABEL_111_22);
  (Wrd13.Obj) = (Rsp [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 1)
    goto label_177;
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_111_30]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_111_31]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd21.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd21.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_111_32]));

DEFLABEL (continuation_64)
  INTERRUPT_CHECK (27, LABEL_111_31);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [10]);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_111_6]), 2);

DEFLABEL (continuation_65)
  INTERRUPT_CHECK (27, LABEL_111_30);
  (Wrd9.Obj) = (current_block [OBJECT_111_2]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd17.Obj) = (Rsp [5]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_176;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  ((Wrd15.pObj) [1]) = (Wrd8.Obj);

DEFLABEL (label_175)
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_111_47]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_111_32]));

DEFLABEL (continuation_68)
  INTERRUPT_CHECK (27, LABEL_111_47);
  (Rsp [4]) = Rvl;
  (Wrd6.Obj) = (Rsp [0]);
  (Rsp [5]) = (Wrd6.Obj);
  Rsp = (& (Rsp [4]));
  goto loop_83;

DEFLABEL (label_176)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_111_46]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_111_5]), 2);

DEFLABEL (label_114)
  goto label_175;

DEFLABEL (label_177)
  if (! ((Wrd14.uLng) == 1))
    goto label_193;
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd22.Obj) = ((Wrd24.pObj) [0]);

DEFLABEL (label_192)
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if ((Wrd31.uLng) == 1)
    goto label_181;
  (Wrd35.Obj) = (Rsp [0]);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if (! ((Wrd36.uLng) == 1))
    goto label_180;
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd32.Obj) = ((Wrd34.pObj) [0]);

DEFLABEL (label_179)
  if ((Wrd32.Obj) == (current_block [OBJECT_111_2]))
    goto label_178;
  (Wrd43.pObj) = (& (Rsp [8]));
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd43.pObj)));
  (Rsp [4]) = (Wrd45.Obj);
  Rsp = (& (Rsp [4]));
  goto bad_end_88;

DEFLABEL (label_178)
  Rsp = (& (Rsp [6]));
  goto label_132;

DEFLABEL (label_180)
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_111_29]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_111_3]), 1);

DEFLABEL (label_103)
  (Wrd32.Obj) = Rvl;
  goto label_179;

DEFLABEL (label_181)
  (Wrd51.Obj) = (Rsp [0]);
  (Wrd52.uLng) = (OBJECT_TYPE (Wrd51.Obj));
  if (! ((Wrd52.uLng) == 1))
    goto label_191;
  (Wrd50.pObj) = (OBJECT_ADDRESS (Wrd51.Obj));
  (Wrd48.Obj) = ((Wrd50.pObj) [0]);

DEFLABEL (label_190)
  (Wrd59.uLng) = (OBJECT_TYPE (Wrd48.Obj));
  if (! ((Wrd59.uLng) == 1))
    goto label_189;
  (Wrd58.pObj) = (OBJECT_ADDRESS (Wrd48.Obj));
  (Wrd57.Obj) = ((Wrd58.pObj) [0]);

DEFLABEL (label_188)
  (Wrd67.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd57.Obj);
  (* (Rhp++)) = (Wrd67.Obj);
  (Wrd66.pObj) = (& (Rhp [-2]));
  (Wrd64.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd66.pObj)));
  (Rsp [1]) = (Wrd64.Obj);
  (Wrd71.Obj) = (Rsp [0]);
  (Wrd72.uLng) = (OBJECT_TYPE (Wrd71.Obj));
  if (! ((Wrd72.uLng) == 1))
    goto label_187;
  (Wrd70.pObj) = (OBJECT_ADDRESS (Wrd71.Obj));
  (Wrd68.Obj) = ((Wrd70.pObj) [0]);

DEFLABEL (label_186)
  (Wrd79.uLng) = (OBJECT_TYPE (Wrd68.Obj));
  if (! ((Wrd79.uLng) == 1))
    goto label_185;
  (Wrd78.pObj) = (OBJECT_ADDRESS (Wrd68.Obj));
  (Wrd77.Obj) = ((Wrd78.pObj) [1]);

DEFLABEL (label_184)
  (Wrd87.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd77.Obj);
  (* (Rhp++)) = (Wrd87.Obj);
  (Wrd86.pObj) = (& (Rhp [-2]));
  (Wrd84.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd86.pObj)));
  (Rsp [2]) = (Wrd84.Obj);
  (Wrd91.Obj) = (Rsp [0]);
  (Wrd92.uLng) = (OBJECT_TYPE (Wrd91.Obj));
  if (! ((Wrd92.uLng) == 1))
    goto label_183;
  (Wrd90.pObj) = (OBJECT_ADDRESS (Wrd91.Obj));
  (Wrd88.Obj) = ((Wrd90.pObj) [1]);

DEFLABEL (label_182)
  (Rsp [0]) = (Wrd88.Obj);
  goto split_81;

DEFLABEL (label_183)
  (Wrd96.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_111_28]))));
  (* (--Rsp)) = (Wrd96.Obj);
  (* (--Rsp)) = (Wrd91.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_111_0]), 1);

DEFLABEL (label_108)
  (Wrd88.Obj) = Rvl;
  goto label_182;

DEFLABEL (label_185)
  (Wrd83.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_111_27]))));
  (* (--Rsp)) = (Wrd83.Obj);
  (* (--Rsp)) = (Wrd68.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_111_0]), 1);

DEFLABEL (label_107)
  (Wrd77.Obj) = Rvl;
  goto label_184;

DEFLABEL (label_187)
  (Wrd76.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_111_26]))));
  (* (--Rsp)) = (Wrd76.Obj);
  (* (--Rsp)) = (Wrd71.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_111_3]), 1);

DEFLABEL (label_106)
  (Wrd68.Obj) = Rvl;
  goto label_186;

DEFLABEL (label_189)
  (Wrd63.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_111_25]))));
  (* (--Rsp)) = (Wrd63.Obj);
  (* (--Rsp)) = (Wrd48.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_111_3]), 1);

DEFLABEL (label_105)
  (Wrd57.Obj) = Rvl;
  goto label_188;

DEFLABEL (label_191)
  (Wrd56.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_111_24]))));
  (* (--Rsp)) = (Wrd56.Obj);
  (* (--Rsp)) = (Wrd51.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_111_3]), 1);

DEFLABEL (label_104)
  (Wrd48.Obj) = Rvl;
  goto label_190;

DEFLABEL (label_193)
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_111_23]))));
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd13.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_111_3]), 1);

DEFLABEL (label_102)
  (Wrd22.Obj) = Rvl;
  goto label_192;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_112_4 3
#define LABEL_112_5 5
#define TAG_112_6 1
#define LABEL_112_8 7
#define ENVIRONMENT_LABEL_112_3 17
#define DEBUGGING_LABEL_112_2 16
#define OBJECT_112_0 15
#define EXECUTE_CACHE_112_10 9
#define EXECUTE_CACHE_112_9 11
#define EXECUTE_CACHE_112_7 13
#define FREE_REFERENCES_LABEL_112_0 8
#define NUMBER_OF_LINKER_SECTIONS_112_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_112 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd7;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_112_4);
      goto mapper_error_2;

    case 1:
      current_block = (Rpc - LABEL_112_5);
      goto lambda_6;

    case 2:
      current_block = (Rpc - LABEL_112_8);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (mapper_error_5)
DEFLABEL (mapper_error_2)
  INTERRUPT_CHECK (26, LABEL_112_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_112_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_112_5])));
  Rhp += 1;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  Wrd9 = Wrd8;
  (Wrd10.Obj) = (Rsp [1]);
  ((Wrd9.pObj) [2]) = (Wrd10.Obj);
  (Rsp [0]) = (Wrd7.Obj);
  (Rsp [1]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_112_7]));

DEFLABEL (lambda_6)
  CLOSURE_HEADER (LABEL_112_5);

DEFLABEL (lambda_1)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_112_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_112_9]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_112_8);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_7;
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [2]);
  (Wrd10.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd10.Obj);
  (Rsp [1]) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_112_10]));

DEFLABEL (label_7)
  Rvl = (current_block [OBJECT_112_0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_113_4 3
#define LABEL_113_5 5
#define LABEL_113_6 7
#define LABEL_113_7 9
#define LABEL_113_8 11
#define LABEL_113_10 13
#define LABEL_113_11 15
#define LABEL_113_12 17
#define LABEL_113_14 19
#define LABEL_113_15 21
#define LABEL_113_16 23
#define LABEL_113_17 25
#define LABEL_113_9 27
#define LABEL_113_19 29
#define LABEL_113_13 31
#define LABEL_113_20 33
#define LABEL_113_21 35
#define LABEL_113_22 37
#define LABEL_113_23 39
#define LABEL_113_24 41
#define LABEL_113_25 43
#define LABEL_113_26 45
#define LABEL_113_27 47
#define LABEL_113_28 49
#define LABEL_113_29 51
#define LABEL_113_30 53
#define LABEL_113_31 55
#define LABEL_113_32 57
#define LABEL_113_34 59
#define ENVIRONMENT_LABEL_113_3 72
#define DEBUGGING_LABEL_113_2 71
#define OBJECT_113_5 70
#define OBJECT_113_4 69
#define OBJECT_113_3 68
#define OBJECT_113_2 67
#define OBJECT_113_1 66
#define OBJECT_113_0 65
#define EXECUTE_CACHE_113_33 61
#define EXECUTE_CACHE_113_18 63
#define FREE_REFERENCES_LABEL_113_0 60
#define NUMBER_OF_LINKER_SECTIONS_113_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_113 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd37;
  machine_word Wrd90;
  machine_word Wrd82;
  machine_word Wrd84;
  machine_word Wrd86;
  machine_word Wrd85;
  machine_word Wrd78;
  machine_word Wrd80;
  machine_word Wrd81;
  machine_word Wrd77;
  machine_word Wrd71;
  machine_word Wrd72;
  machine_word Wrd73;
  machine_word Wrd70;
  machine_word Wrd62;
  machine_word Wrd64;
  machine_word Wrd66;
  machine_word Wrd65;
  machine_word Wrd58;
  machine_word Wrd60;
  machine_word Wrd61;
  machine_word Wrd57;
  machine_word Wrd51;
  machine_word Wrd52;
  machine_word Wrd53;
  machine_word Wrd50;
  machine_word Wrd42;
  machine_word Wrd44;
  machine_word Wrd18;
  machine_word Wrd9;
  machine_word Wrd13;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd36;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd14;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd28;
  machine_word Wrd7;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd8;
  machine_word Wrd10;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_113_4);
      goto for_each_47;

    case 1:
      current_block = (Rpc - LABEL_113_5);
      goto label_49;

    case 2:
      current_block = (Rpc - LABEL_113_6);
      goto label_50;

    case 3:
      current_block = (Rpc - LABEL_113_7);
      goto continuation_7;

    case 4:
      current_block = (Rpc - LABEL_113_8);
      goto map_1_11;

    case 5:
      current_block = (Rpc - LABEL_113_10);
      goto label_51;

    case 6:
      current_block = (Rpc - LABEL_113_11);
      goto continuation_18;

    case 7:
      current_block = (Rpc - LABEL_113_12);
      goto map_2_24;

    case 8:
      current_block = (Rpc - LABEL_113_14);
      goto label_52;

    case 9:
      current_block = (Rpc - LABEL_113_15);
      goto label_53;

    case 10:
      current_block = (Rpc - LABEL_113_16);
      goto map_n_44;

    case 11:
      current_block = (Rpc - LABEL_113_17);
      goto bad_end_46;

    case 12:
      current_block = (Rpc - LABEL_113_9);
      goto continuation_9;

    case 13:
      current_block = (Rpc - LABEL_113_19);
      goto label_54;

    case 14:
      current_block = (Rpc - LABEL_113_13);
      goto continuation_21;

    case 15:
      current_block = (Rpc - LABEL_113_20);
      goto label_55;

    case 16:
      current_block = (Rpc - LABEL_113_21);
      goto label_56;

    case 17:
      current_block = (Rpc - LABEL_113_22);
      goto continuation_34;

    case 18:
      current_block = (Rpc - LABEL_113_23);
      goto split_42;

    case 19:
      current_block = (Rpc - LABEL_113_24);
      goto label_57;

    case 20:
      current_block = (Rpc - LABEL_113_25);
      goto label_59;

    case 21:
      current_block = (Rpc - LABEL_113_26);
      goto label_60;

    case 22:
      current_block = (Rpc - LABEL_113_27);
      goto label_61;

    case 23:
      current_block = (Rpc - LABEL_113_28);
      goto label_62;

    case 24:
      current_block = (Rpc - LABEL_113_29);
      goto label_63;

    case 25:
      current_block = (Rpc - LABEL_113_30);
      goto label_58;

    case 26:
      current_block = (Rpc - LABEL_113_31);
      goto continuation_28;

    case 27:
      current_block = (Rpc - LABEL_113_32);
      goto continuation_27;

    case 28:
      current_block = (Rpc - LABEL_113_34);
      goto continuation_29;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (for_each_65)
DEFLABEL (for_each_47)
  INTERRUPT_CHECK (26, LABEL_113_4);
  (Wrd5.Obj) = (Rsp [2]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_71;
  (Wrd7.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd7.Obj);
  goto map_1_11;

DEFLABEL (label_71)
  if (! ((Wrd6.uLng) == 1))
    goto label_76;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd8.Obj) = ((Wrd10.pObj) [1]);

DEFLABEL (label_75)
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd17.uLng) == 1))
    goto label_72;
  (Wrd31.Obj) = (Rsp [1]);
  (Wrd32.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd31.Obj);
  (* (Rhp++)) = (Wrd32.Obj);
  (Wrd29.pObj) = (& (Rhp [-2]));
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd29.pObj)));
  (* (--Rsp)) = (Wrd30.Obj);
  goto map_n_44;

DEFLABEL (label_72)
  (Wrd21.Obj) = (Rsp [2]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if (! ((Wrd22.uLng) == 1))
    goto label_74;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [0]);
  (* (--Rsp)) = (Wrd20.Obj);

DEFLABEL (label_73)
  (Wrd27.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd27.Obj);
  goto map_2_24;

DEFLABEL (label_74)
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_6]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_113_1]), 1);

DEFLABEL (label_50)
  (* (--Rsp)) = Rvl;
  goto label_73;

DEFLABEL (label_76)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_5]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_113_0]), 1);

DEFLABEL (label_49)
  (Wrd8.Obj) = Rvl;
  goto label_75;

DEFLABEL (map_1_66)
DEFLABEL (map_1_11)
  INTERRUPT_CHECK (26, LABEL_113_8);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_79;
  if (! ((Wrd5.Obj) == (current_block [OBJECT_113_2])))
    goto label_78;

DEFLABEL (label_77)
  Rvl = (current_block [OBJECT_113_3]);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_78)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_7]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.pObj) = (& (Rsp [2]));
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd12.pObj)));
  (* (--Rsp)) = (Wrd14.Obj);
  goto bad_end_46;

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_113_7);
  goto label_77;

DEFLABEL (label_79)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_9]))));
  (* (--Rsp)) = (Wrd19.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_83;
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd22.Obj) = ((Wrd21.pObj) [0]);
  (* (--Rsp)) = (Wrd22.Obj);

DEFLABEL (label_82)
  (Wrd29.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd29.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_113_9);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_81;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [1]);

DEFLABEL (label_80)
  (Rsp [0]) = (Wrd5.Obj);
  goto map_1_11;

DEFLABEL (label_81)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_19]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_113_0]), 1);

DEFLABEL (label_54)
  (Wrd5.Obj) = Rvl;
  goto label_80;

DEFLABEL (label_83)
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_10]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_113_1]), 1);

DEFLABEL (label_51)
  (* (--Rsp)) = Rvl;
  goto label_82;

DEFLABEL (map_2_67)
DEFLABEL (map_2_24)
  INTERRUPT_CHECK (26, LABEL_113_12);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_88;

DEFLABEL (label_87)
  (Wrd7.Obj) = (Rsp [0]);
  if ((Wrd7.Obj) == (current_block [OBJECT_113_2]))
    goto label_86;
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if ((Wrd10.uLng) == 1)
    goto label_86;

DEFLABEL (label_85)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_11]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.pObj) = (& (Rsp [3]));
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd14.pObj)));
  (* (--Rsp)) = (Wrd16.Obj);
  goto bad_end_46;

DEFLABEL (continuation_18)
  INTERRUPT_CHECK (27, LABEL_113_11);

DEFLABEL (label_84)
  Rvl = (current_block [OBJECT_113_3]);
  Rsp = (& (Rsp [5]));
  goto pop_return;

DEFLABEL (label_86)
  (Wrd17.Obj) = (Rsp [1]);
  if ((Wrd17.Obj) == (current_block [OBJECT_113_2]))
    goto label_84;
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if ((Wrd20.uLng) == 1)
    goto label_84;
  goto label_85;

DEFLABEL (label_88)
  (Wrd23.Obj) = (Rsp [1]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd24.uLng) == 1))
    goto label_87;
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_13]))));
  (* (--Rsp)) = (Wrd27.Obj);
  if (! ((Wrd24.uLng) == 1))
    goto label_96;
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd30.Obj) = ((Wrd29.pObj) [0]);
  (* (--Rsp)) = (Wrd30.Obj);

DEFLABEL (label_95)
  (Wrd40.Obj) = (Rsp [2]);
  (Wrd41.uLng) = (OBJECT_TYPE (Wrd40.Obj));
  if (! ((Wrd41.uLng) == 1))
    goto label_94;
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd40.Obj));
  (Wrd39.Obj) = ((Wrd38.pObj) [0]);
  (* (--Rsp)) = (Wrd39.Obj);

DEFLABEL (label_93)
  (Wrd46.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd46.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_21)
  INTERRUPT_CHECK (27, LABEL_113_13);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_92;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [1]);

DEFLABEL (label_91)
  (Rsp [0]) = (Wrd5.Obj);
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_90;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd14.Obj) = ((Wrd16.pObj) [1]);

DEFLABEL (label_89)
  (Rsp [1]) = (Wrd14.Obj);
  goto map_2_24;

DEFLABEL (label_90)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_21]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_113_0]), 1);

DEFLABEL (label_56)
  (Wrd14.Obj) = Rvl;
  goto label_89;

DEFLABEL (label_92)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_20]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_113_0]), 1);

DEFLABEL (label_55)
  (Wrd5.Obj) = Rvl;
  goto label_91;

DEFLABEL (label_94)
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_15]))));
  (* (--Rsp)) = (Wrd45.Obj);
  (* (--Rsp)) = (Wrd40.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_113_1]), 1);

DEFLABEL (label_53)
  (* (--Rsp)) = Rvl;
  goto label_93;

DEFLABEL (label_96)
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_14]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_113_1]), 1);

DEFLABEL (label_52)
  (* (--Rsp)) = Rvl;
  goto label_95;

DEFLABEL (map_n_68)
DEFLABEL (map_n_44)
  INTERRUPT_CHECK (26, LABEL_113_16);
  (Wrd5.Obj) = (current_block [OBJECT_113_2]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Rsp [2]) = (Wrd5.Obj);
  goto split_42;

DEFLABEL (bad_end_69)
DEFLABEL (bad_end_46)
  INTERRUPT_CHECK (26, LABEL_113_17);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [1]);
  (Wrd13.Obj) = ((Wrd9.pObj) [2]);
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd13.Obj);
  (Wrd6.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd6.pObj)));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_113_4]);
  (Rsp [1]) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_18]));

DEFLABEL (split_70)
DEFLABEL (split_42)
  INTERRUPT_CHECK (26, LABEL_113_23);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_97;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_31]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_32]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_33]));

DEFLABEL (continuation_27)
  INTERRUPT_CHECK (27, LABEL_113_32);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_113_5]), 2);

DEFLABEL (continuation_28)
  INTERRUPT_CHECK (27, LABEL_113_31);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_34]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113_33]));

DEFLABEL (continuation_29)
  INTERRUPT_CHECK (27, LABEL_113_34);
  (Rsp [2]) = Rvl;
  Rsp = (& (Rsp [2]));
  goto map_n_44;

DEFLABEL (label_97)
  if (! ((Wrd6.uLng) == 1))
    goto label_114;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd14.Obj) = ((Wrd16.pObj) [0]);

DEFLABEL (label_113)
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd23.uLng) == 1)
    goto label_102;
  (Wrd27.Obj) = (Rsp [0]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if (! ((Wrd28.uLng) == 1))
    goto label_101;
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd24.Obj) = ((Wrd26.pObj) [0]);

DEFLABEL (label_100)
  if (! ((Wrd24.Obj) == (current_block [OBJECT_113_2])))
    goto label_99;

DEFLABEL (label_98)
  Rvl = (current_block [OBJECT_113_3]);
  Rsp = (& (Rsp [6]));
  goto pop_return;

DEFLABEL (label_99)
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_22]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (Wrd37.pObj) = (& (Rsp [4]));
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd37.pObj)));
  (* (--Rsp)) = (Wrd39.Obj);
  goto bad_end_46;

DEFLABEL (continuation_34)
  INTERRUPT_CHECK (27, LABEL_113_22);
  goto label_98;

DEFLABEL (label_101)
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_30]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_113_1]), 1);

DEFLABEL (label_58)
  (Wrd24.Obj) = Rvl;
  goto label_100;

DEFLABEL (label_102)
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.uLng) = (OBJECT_TYPE (Wrd45.Obj));
  if (! ((Wrd46.uLng) == 1))
    goto label_112;
  (Wrd44.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd42.Obj) = ((Wrd44.pObj) [0]);

DEFLABEL (label_111)
  (Wrd53.uLng) = (OBJECT_TYPE (Wrd42.Obj));
  if (! ((Wrd53.uLng) == 1))
    goto label_110;
  (Wrd52.pObj) = (OBJECT_ADDRESS (Wrd42.Obj));
  (Wrd51.Obj) = ((Wrd52.pObj) [0]);

DEFLABEL (label_109)
  (Wrd61.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd51.Obj);
  (* (Rhp++)) = (Wrd61.Obj);
  (Wrd60.pObj) = (& (Rhp [-2]));
  (Wrd58.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd60.pObj)));
  (Rsp [1]) = (Wrd58.Obj);
  (Wrd65.Obj) = (Rsp [0]);
  (Wrd66.uLng) = (OBJECT_TYPE (Wrd65.Obj));
  if (! ((Wrd66.uLng) == 1))
    goto label_108;
  (Wrd64.pObj) = (OBJECT_ADDRESS (Wrd65.Obj));
  (Wrd62.Obj) = ((Wrd64.pObj) [0]);

DEFLABEL (label_107)
  (Wrd73.uLng) = (OBJECT_TYPE (Wrd62.Obj));
  if (! ((Wrd73.uLng) == 1))
    goto label_106;
  (Wrd72.pObj) = (OBJECT_ADDRESS (Wrd62.Obj));
  (Wrd71.Obj) = ((Wrd72.pObj) [1]);

DEFLABEL (label_105)
  (Wrd81.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd71.Obj);
  (* (Rhp++)) = (Wrd81.Obj);
  (Wrd80.pObj) = (& (Rhp [-2]));
  (Wrd78.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd80.pObj)));
  (Rsp [2]) = (Wrd78.Obj);
  (Wrd85.Obj) = (Rsp [0]);
  (Wrd86.uLng) = (OBJECT_TYPE (Wrd85.Obj));
  if (! ((Wrd86.uLng) == 1))
    goto label_104;
  (Wrd84.pObj) = (OBJECT_ADDRESS (Wrd85.Obj));
  (Wrd82.Obj) = ((Wrd84.pObj) [1]);

DEFLABEL (label_103)
  (Rsp [0]) = (Wrd82.Obj);
  goto split_42;

DEFLABEL (label_104)
  (Wrd90.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_29]))));
  (* (--Rsp)) = (Wrd90.Obj);
  (* (--Rsp)) = (Wrd85.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_113_0]), 1);

DEFLABEL (label_63)
  (Wrd82.Obj) = Rvl;
  goto label_103;

DEFLABEL (label_106)
  (Wrd77.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_28]))));
  (* (--Rsp)) = (Wrd77.Obj);
  (* (--Rsp)) = (Wrd62.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_113_0]), 1);

DEFLABEL (label_62)
  (Wrd71.Obj) = Rvl;
  goto label_105;

DEFLABEL (label_108)
  (Wrd70.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_27]))));
  (* (--Rsp)) = (Wrd70.Obj);
  (* (--Rsp)) = (Wrd65.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_113_1]), 1);

DEFLABEL (label_61)
  (Wrd62.Obj) = Rvl;
  goto label_107;

DEFLABEL (label_110)
  (Wrd57.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_26]))));
  (* (--Rsp)) = (Wrd57.Obj);
  (* (--Rsp)) = (Wrd42.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_113_1]), 1);

DEFLABEL (label_60)
  (Wrd51.Obj) = Rvl;
  goto label_109;

DEFLABEL (label_112)
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_25]))));
  (* (--Rsp)) = (Wrd50.Obj);
  (* (--Rsp)) = (Wrd45.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_113_1]), 1);

DEFLABEL (label_59)
  (Wrd42.Obj) = Rvl;
  goto label_111;

DEFLABEL (label_114)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_113_24]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_113_1]), 1);

DEFLABEL (label_57)
  (Wrd14.Obj) = Rvl;
  goto label_113;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_114_4 3
#define LABEL_114_5 5
#define LABEL_114_6 7
#define LABEL_114_7 9
#define LABEL_114_8 11
#define LABEL_114_10 13
#define LABEL_114_11 15
#define LABEL_114_12 17
#define LABEL_114_14 19
#define LABEL_114_15 21
#define LABEL_114_16 23
#define LABEL_114_17 25
#define LABEL_114_9 27
#define LABEL_114_20 29
#define LABEL_114_13 31
#define LABEL_114_22 33
#define LABEL_114_23 35
#define LABEL_114_24 37
#define LABEL_114_25 39
#define LABEL_114_26 41
#define LABEL_114_27 43
#define LABEL_114_28 45
#define LABEL_114_29 47
#define LABEL_114_30 49
#define LABEL_114_31 51
#define LABEL_114_32 53
#define LABEL_114_19 55
#define LABEL_114_21 57
#define LABEL_114_33 59
#define LABEL_114_34 61
#define LABEL_114_36 63
#define LABEL_114_37 65
#define ENVIRONMENT_LABEL_114_3 77
#define DEBUGGING_LABEL_114_2 76
#define OBJECT_114_4 75
#define OBJECT_114_3 74
#define OBJECT_114_2 73
#define OBJECT_114_1 72
#define OBJECT_114_0 71
#define EXECUTE_CACHE_114_35 67
#define EXECUTE_CACHE_114_18 69
#define FREE_REFERENCES_LABEL_114_0 66
#define NUMBER_OF_LINKER_SECTIONS_114_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_114 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd21;
  machine_word Wrd58;
  machine_word Wrd51;
  machine_word Wrd60;
  machine_word Wrd41;
  machine_word Wrd48;
  machine_word Wrd36;
  machine_word Wrd123;
  machine_word Wrd130;
  machine_word Wrd126;
  machine_word Wrd118;
  machine_word Wrd120;
  machine_word Wrd122;
  machine_word Wrd121;
  machine_word Wrd114;
  machine_word Wrd116;
  machine_word Wrd117;
  machine_word Wrd106;
  machine_word Wrd113;
  machine_word Wrd109;
  machine_word Wrd103;
  machine_word Wrd104;
  machine_word Wrd105;
  machine_word Wrd95;
  machine_word Wrd102;
  machine_word Wrd98;
  machine_word Wrd90;
  machine_word Wrd92;
  machine_word Wrd94;
  machine_word Wrd93;
  machine_word Wrd86;
  machine_word Wrd88;
  machine_word Wrd89;
  machine_word Wrd78;
  machine_word Wrd85;
  machine_word Wrd81;
  machine_word Wrd75;
  machine_word Wrd76;
  machine_word Wrd77;
  machine_word Wrd67;
  machine_word Wrd74;
  machine_word Wrd70;
  machine_word Wrd62;
  machine_word Wrd64;
  machine_word Wrd66;
  machine_word Wrd131;
  machine_word Wrd16;
  machine_word Wrd12;
  machine_word Wrd23;
  machine_word Wrd7;
  machine_word Wrd56;
  machine_word Wrd63;
  machine_word Wrd59;
  machine_word Wrd53;
  machine_word Wrd52;
  machine_word Wrd55;
  machine_word Wrd54;
  machine_word Wrd43;
  machine_word Wrd50;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd28;
  machine_word Wrd65;
  machine_word Wrd17;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd10;
  machine_word Wrd18;
  machine_word Wrd42;
  machine_word Wrd29;
  machine_word Wrd44;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd22;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd35;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd11;
  machine_word Wrd13;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_114_4);
      goto map__50;

    case 1:
      current_block = (Rpc - LABEL_114_5);
      goto label_52;

    case 2:
      current_block = (Rpc - LABEL_114_6);
      goto label_53;

    case 3:
      current_block = (Rpc - LABEL_114_7);
      goto continuation_7;

    case 4:
      current_block = (Rpc - LABEL_114_8);
      goto map_1_12;

    case 5:
      current_block = (Rpc - LABEL_114_10);
      goto label_54;

    case 6:
      current_block = (Rpc - LABEL_114_11);
      goto continuation_19;

    case 7:
      current_block = (Rpc - LABEL_114_12);
      goto map_2_26;

    case 8:
      current_block = (Rpc - LABEL_114_14);
      goto label_55;

    case 9:
      current_block = (Rpc - LABEL_114_15);
      goto label_56;

    case 10:
      current_block = (Rpc - LABEL_114_16);
      goto map_n_47;

    case 11:
      current_block = (Rpc - LABEL_114_17);
      goto bad_end_49;

    case 12:
      current_block = (Rpc - LABEL_114_9);
      goto continuation_11;

    case 13:
      current_block = (Rpc - LABEL_114_20);
      goto label_57;

    case 14:
      current_block = (Rpc - LABEL_114_13);
      goto continuation_25;

    case 15:
      current_block = (Rpc - LABEL_114_22);
      goto label_58;

    case 16:
      current_block = (Rpc - LABEL_114_23);
      goto label_59;

    case 17:
      current_block = (Rpc - LABEL_114_24);
      goto continuation_37;

    case 18:
      current_block = (Rpc - LABEL_114_25);
      goto split_45;

    case 19:
      current_block = (Rpc - LABEL_114_26);
      goto label_60;

    case 20:
      current_block = (Rpc - LABEL_114_27);
      goto label_62;

    case 21:
      current_block = (Rpc - LABEL_114_28);
      goto label_63;

    case 22:
      current_block = (Rpc - LABEL_114_29);
      goto label_64;

    case 23:
      current_block = (Rpc - LABEL_114_30);
      goto label_65;

    case 24:
      current_block = (Rpc - LABEL_114_31);
      goto label_66;

    case 25:
      current_block = (Rpc - LABEL_114_32);
      goto label_61;

    case 26:
      current_block = (Rpc - LABEL_114_19);
      goto continuation_9;

    case 27:
      current_block = (Rpc - LABEL_114_21);
      goto continuation_22;

    case 28:
      current_block = (Rpc - LABEL_114_33);
      goto continuation_32;

    case 29:
      current_block = (Rpc - LABEL_114_34);
      goto continuation_31;

    case 30:
      current_block = (Rpc - LABEL_114_36);
      goto continuation_30;

    case 31:
      current_block = (Rpc - LABEL_114_37);
      goto continuation_29;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (map__68)
DEFLABEL (map__50)
  INTERRUPT_CHECK (26, LABEL_114_4);
  (Wrd5.Obj) = (Rsp [3]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_74;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rsp));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  Rdl = (& (Rsp [6]));
  goto map_1_12;

DEFLABEL (label_74)
  if (! ((Wrd6.uLng) == 1))
    goto label_79;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd11.Obj) = ((Wrd13.pObj) [1]);

DEFLABEL (label_78)
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd20.uLng) == 1))
    goto label_75;
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (59, Rsp));
  (* (--Rsp)) = (Wrd35.Obj);
  (Wrd39.Obj) = (Rsp [3]);
  (Wrd40.Obj) = (Rsp [4]);
  (* (Rhp++)) = (Wrd39.Obj);
  (* (Rhp++)) = (Wrd40.Obj);
  (Wrd37.pObj) = (& (Rhp [-2]));
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd37.pObj)));
  (* (--Rsp)) = (Wrd38.Obj);
  Rdl = (& (Rsp [6]));
  goto map_n_47;

DEFLABEL (label_75)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (59, Rsp));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd26.Obj) = (Rsp [4]);
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if (! ((Wrd27.uLng) == 1))
    goto label_77;
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd25.Obj) = ((Wrd24.pObj) [0]);
  (* (--Rsp)) = (Wrd25.Obj);

DEFLABEL (label_76)
  (Wrd32.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd32.Obj);
  Rdl = (& (Rsp [7]));
  goto map_2_26;

DEFLABEL (label_77)
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_6]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_114_1]), 1);

DEFLABEL (label_53)
  (* (--Rsp)) = Rvl;
  goto label_76;

DEFLABEL (label_79)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_5]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_114_0]), 1);

DEFLABEL (label_52)
  (Wrd11.Obj) = Rvl;
  goto label_78;

DEFLABEL (map_1_69)
DEFLABEL (map_1_12)
  DLINK_INTERRUPT_CHECK (25, LABEL_114_8);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_82;
  if (! ((Wrd5.Obj) == (current_block [OBJECT_114_2])))
    goto label_81;

DEFLABEL (label_80)
  (Wrd18.Obj) = (Rsp [1]);
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  Rvl = ((Wrd19.pObj) [0]);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_81)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_7]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd15.pObj)));
  (* (--Rsp)) = (Wrd17.Obj);
  goto bad_end_49;

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_114_7);
  (Wrd44.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd44.Obj));
  goto label_80;

DEFLABEL (label_82)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_9]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd26.Obj) = (Rsp [3]);
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd27.pObj)));
  (* (--Rsp)) = (Wrd29.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_86;
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd32.Obj) = ((Wrd31.pObj) [1]);
  (* (--Rsp)) = (Wrd32.Obj);

DEFLABEL (label_85)
  Rdl = (& (Rsp [2]));
  goto map_1_12;

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_114_9);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_19]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd15.Obj) = (Rsp [3]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 1))
    goto label_84;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_83)
  (Wrd25.Obj) = (Rsp [5]);
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd27.Obj) = ((Wrd26.pObj) [1]);
  (* (--Rsp)) = (Wrd27.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_114_19);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd7.Obj);
  (Wrd10.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd10.pObj)));
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_84)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_20]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd15.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_114_1]), 1);

DEFLABEL (label_57)
  (Wrd17.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd17.Obj));
  (* (--Rsp)) = Rvl;
  goto label_83;

DEFLABEL (label_86)
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_10]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_114_0]), 1);

DEFLABEL (label_54)
  (Wrd35.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd35.Obj));
  (* (--Rsp)) = Rvl;
  goto label_85;

DEFLABEL (map_2_70)
DEFLABEL (map_2_26)
  DLINK_INTERRUPT_CHECK (25, LABEL_114_12);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_91;

DEFLABEL (label_90)
  (Wrd7.Obj) = (Rsp [0]);
  if ((Wrd7.Obj) == (current_block [OBJECT_114_2]))
    goto label_89;
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if ((Wrd10.uLng) == 1)
    goto label_89;

DEFLABEL (label_88)
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_11]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (Rsp [4]);
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd17.pObj)));
  (* (--Rsp)) = (Wrd19.Obj);
  goto bad_end_49;

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_114_11);
  (Wrd65.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd65.Obj));

DEFLABEL (label_87)
  (Wrd24.Obj) = (Rsp [2]);
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  Rvl = ((Wrd25.pObj) [0]);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_89)
  (Wrd20.Obj) = (Rsp [1]);
  if ((Wrd20.Obj) == (current_block [OBJECT_114_2]))
    goto label_87;
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if ((Wrd23.uLng) == 1)
    goto label_87;
  goto label_88;

DEFLABEL (label_91)
  (Wrd27.Obj) = (Rsp [1]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if (! ((Wrd28.uLng) == 1))
    goto label_90;
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_13]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd34.Obj) = (Rsp [4]);
  (Wrd35.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd35.pObj)));
  (* (--Rsp)) = (Wrd37.Obj);
  if (! ((Wrd28.uLng) == 1))
    goto label_99;
  (Wrd39.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd40.Obj) = ((Wrd39.pObj) [1]);
  (* (--Rsp)) = (Wrd40.Obj);

DEFLABEL (label_98)
  (Wrd54.Obj) = (Rsp [4]);
  (Wrd55.uLng) = (OBJECT_TYPE (Wrd54.Obj));
  if (! ((Wrd55.uLng) == 1))
    goto label_97;
  (Wrd52.pObj) = (OBJECT_ADDRESS (Wrd54.Obj));
  (Wrd53.Obj) = ((Wrd52.pObj) [1]);
  (* (--Rsp)) = (Wrd53.Obj);

DEFLABEL (label_96)
  Rdl = (& (Rsp [3]));
  goto map_2_26;

DEFLABEL (continuation_25)
  INTERRUPT_CHECK (27, LABEL_114_13);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_21]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd15.Obj) = (Rsp [4]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 1))
    goto label_95;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_94)
  (Wrd28.Obj) = (Rsp [4]);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if (! ((Wrd29.uLng) == 1))
    goto label_93;
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd28.Obj));
  (Wrd27.Obj) = ((Wrd26.pObj) [0]);
  (* (--Rsp)) = (Wrd27.Obj);

DEFLABEL (label_92)
  (Wrd38.Obj) = (Rsp [7]);
  (Wrd39.pObj) = (OBJECT_ADDRESS (Wrd38.Obj));
  (Wrd40.Obj) = ((Wrd39.pObj) [1]);
  (* (--Rsp)) = (Wrd40.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_22)
  INTERRUPT_CHECK (27, LABEL_114_21);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd7.Obj);
  (Wrd10.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd10.pObj)));
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_93)
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_23]))));
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_114_1]), 1);

DEFLABEL (label_59)
  (Wrd30.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd30.Obj));
  (* (--Rsp)) = Rvl;
  goto label_92;

DEFLABEL (label_95)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_22]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd15.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_114_1]), 1);

DEFLABEL (label_58)
  (Wrd17.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd17.Obj));
  (* (--Rsp)) = Rvl;
  goto label_94;

DEFLABEL (label_97)
  (Wrd59.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd59.Obj);
  (Wrd63.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_15]))));
  (* (--Rsp)) = (Wrd63.Obj);
  (* (--Rsp)) = (Wrd54.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_114_0]), 1);

DEFLABEL (label_56)
  (Wrd56.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd56.Obj));
  (* (--Rsp)) = Rvl;
  goto label_96;

DEFLABEL (label_99)
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_14]))));
  (* (--Rsp)) = (Wrd50.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_114_0]), 1);

DEFLABEL (label_55)
  (Wrd43.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd43.Obj));
  (* (--Rsp)) = Rvl;
  goto label_98;

DEFLABEL (map_n_71)
DEFLABEL (map_n_47)
  DLINK_INTERRUPT_CHECK (25, LABEL_114_16);
  (Wrd5.Obj) = (current_block [OBJECT_114_2]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Rsp [2]) = (Wrd5.Obj);
  goto split_45;

DEFLABEL (bad_end_72)
DEFLABEL (bad_end_49)
  INTERRUPT_CHECK (26, LABEL_114_17);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [2]);
  (Wrd13.Obj) = ((Wrd9.pObj) [3]);
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd13.Obj);
  (Wrd6.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd6.pObj)));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_114_3]);
  (Rsp [1]) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_114_18]));

DEFLABEL (split_73)
DEFLABEL (split_45)
  DLINK_INTERRUPT_CHECK (25, LABEL_114_25);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_100;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_33]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [5]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd13.pObj)));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_34]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd21.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd21.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_114_35]));

DEFLABEL (continuation_31)
  INTERRUPT_CHECK (27, LABEL_114_34);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  Rdl = (& (Rsp [2]));
  goto map_n_47;

DEFLABEL (continuation_32)
  INTERRUPT_CHECK (27, LABEL_114_33);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_36]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_37]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_114_35]));

DEFLABEL (continuation_29)
  INTERRUPT_CHECK (27, LABEL_114_37);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (Rsp [7]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [1]);
  (* (--Rsp)) = (Wrd9.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_114_4]), 2);

DEFLABEL (continuation_30)
  INTERRUPT_CHECK (27, LABEL_114_36);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd7.Obj);
  (Wrd10.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd10.pObj)));
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_100)
  if (! ((Wrd6.uLng) == 1))
    goto label_117;
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd22.Obj) = ((Wrd24.pObj) [0]);

DEFLABEL (label_116)
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if ((Wrd35.uLng) == 1)
    goto label_105;
  (Wrd39.Obj) = (Rsp [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if (! ((Wrd40.uLng) == 1))
    goto label_104;
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd39.Obj));
  (Wrd36.Obj) = ((Wrd38.pObj) [0]);

DEFLABEL (label_103)
  if (! ((Wrd36.Obj) == (current_block [OBJECT_114_2])))
    goto label_102;

DEFLABEL (label_101)
  (Wrd59.Obj) = (Rsp [3]);
  (Wrd60.pObj) = (OBJECT_ADDRESS (Wrd59.Obj));
  Rvl = ((Wrd60.pObj) [0]);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_102)
  (Wrd51.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd51.Obj);
  (Wrd54.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_24]))));
  (* (--Rsp)) = (Wrd54.Obj);
  (Wrd55.Obj) = (Rsp [5]);
  (Wrd56.pObj) = (OBJECT_ADDRESS (Wrd55.Obj));
  (Wrd58.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd56.pObj)));
  (* (--Rsp)) = (Wrd58.Obj);
  goto bad_end_49;

DEFLABEL (continuation_37)
  INTERRUPT_CHECK (27, LABEL_114_24);
  (Wrd131.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd131.Obj));
  goto label_101;

DEFLABEL (label_104)
  (Wrd44.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd44.Obj);
  (Wrd48.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_32]))));
  (* (--Rsp)) = (Wrd48.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_114_1]), 1);

DEFLABEL (label_61)
  (Wrd41.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd41.Obj));
  (Wrd36.Obj) = Rvl;
  goto label_103;

DEFLABEL (label_105)
  (Wrd65.Obj) = (Rsp [0]);
  (Wrd66.uLng) = (OBJECT_TYPE (Wrd65.Obj));
  if (! ((Wrd66.uLng) == 1))
    goto label_115;
  (Wrd64.pObj) = (OBJECT_ADDRESS (Wrd65.Obj));
  (Wrd62.Obj) = ((Wrd64.pObj) [0]);

DEFLABEL (label_114)
  (Wrd77.uLng) = (OBJECT_TYPE (Wrd62.Obj));
  if (! ((Wrd77.uLng) == 1))
    goto label_113;
  (Wrd76.pObj) = (OBJECT_ADDRESS (Wrd62.Obj));
  (Wrd75.Obj) = ((Wrd76.pObj) [0]);

DEFLABEL (label_112)
  (Wrd89.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd75.Obj);
  (* (Rhp++)) = (Wrd89.Obj);
  (Wrd88.pObj) = (& (Rhp [-2]));
  (Wrd86.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd88.pObj)));
  (Rsp [1]) = (Wrd86.Obj);
  (Wrd93.Obj) = (Rsp [0]);
  (Wrd94.uLng) = (OBJECT_TYPE (Wrd93.Obj));
  if (! ((Wrd94.uLng) == 1))
    goto label_111;
  (Wrd92.pObj) = (OBJECT_ADDRESS (Wrd93.Obj));
  (Wrd90.Obj) = ((Wrd92.pObj) [0]);

DEFLABEL (label_110)
  (Wrd105.uLng) = (OBJECT_TYPE (Wrd90.Obj));
  if (! ((Wrd105.uLng) == 1))
    goto label_109;
  (Wrd104.pObj) = (OBJECT_ADDRESS (Wrd90.Obj));
  (Wrd103.Obj) = ((Wrd104.pObj) [1]);

DEFLABEL (label_108)
  (Wrd117.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd103.Obj);
  (* (Rhp++)) = (Wrd117.Obj);
  (Wrd116.pObj) = (& (Rhp [-2]));
  (Wrd114.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd116.pObj)));
  (Rsp [2]) = (Wrd114.Obj);
  (Wrd121.Obj) = (Rsp [0]);
  (Wrd122.uLng) = (OBJECT_TYPE (Wrd121.Obj));
  if (! ((Wrd122.uLng) == 1))
    goto label_107;
  (Wrd120.pObj) = (OBJECT_ADDRESS (Wrd121.Obj));
  (Wrd118.Obj) = ((Wrd120.pObj) [1]);

DEFLABEL (label_106)
  (Rsp [0]) = (Wrd118.Obj);
  goto split_45;

DEFLABEL (label_107)
  (Wrd126.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd126.Obj);
  (Wrd130.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_31]))));
  (* (--Rsp)) = (Wrd130.Obj);
  (* (--Rsp)) = (Wrd121.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_114_0]), 1);

DEFLABEL (label_66)
  (Wrd123.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd123.Obj));
  (Wrd118.Obj) = Rvl;
  goto label_106;

DEFLABEL (label_109)
  (Wrd109.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd109.Obj);
  (Wrd113.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_30]))));
  (* (--Rsp)) = (Wrd113.Obj);
  (* (--Rsp)) = (Wrd90.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_114_0]), 1);

DEFLABEL (label_65)
  (Wrd106.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd106.Obj));
  (Wrd103.Obj) = Rvl;
  goto label_108;

DEFLABEL (label_111)
  (Wrd98.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd98.Obj);
  (Wrd102.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_29]))));
  (* (--Rsp)) = (Wrd102.Obj);
  (* (--Rsp)) = (Wrd93.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_114_1]), 1);

DEFLABEL (label_64)
  (Wrd95.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd95.Obj));
  (Wrd90.Obj) = Rvl;
  goto label_110;

DEFLABEL (label_113)
  (Wrd81.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd81.Obj);
  (Wrd85.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_28]))));
  (* (--Rsp)) = (Wrd85.Obj);
  (* (--Rsp)) = (Wrd62.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_114_1]), 1);

DEFLABEL (label_63)
  (Wrd78.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd78.Obj));
  (Wrd75.Obj) = Rvl;
  goto label_112;

DEFLABEL (label_115)
  (Wrd70.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd70.Obj);
  (Wrd74.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_27]))));
  (* (--Rsp)) = (Wrd74.Obj);
  (* (--Rsp)) = (Wrd65.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_114_1]), 1);

DEFLABEL (label_62)
  (Wrd67.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd67.Obj));
  (Wrd62.Obj) = Rvl;
  goto label_114;

DEFLABEL (label_117)
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_26]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_114_1]), 1);

DEFLABEL (label_60)
  (Wrd27.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd22.Obj) = Rvl;
  goto label_116;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_115_4 3
#define LABEL_115_5 5
#define LABEL_115_6 7
#define LABEL_115_7 9
#define LABEL_115_8 11
#define LABEL_115_10 13
#define LABEL_115_11 15
#define LABEL_115_12 17
#define LABEL_115_14 19
#define LABEL_115_15 21
#define LABEL_115_16 23
#define LABEL_115_17 25
#define LABEL_115_9 27
#define LABEL_115_20 29
#define LABEL_115_13 31
#define LABEL_115_22 33
#define LABEL_115_23 35
#define LABEL_115_24 37
#define LABEL_115_25 39
#define LABEL_115_26 41
#define LABEL_115_27 43
#define LABEL_115_28 45
#define LABEL_115_29 47
#define LABEL_115_30 49
#define LABEL_115_31 51
#define LABEL_115_32 53
#define LABEL_115_19 55
#define LABEL_115_21 57
#define LABEL_115_33 59
#define LABEL_115_34 61
#define LABEL_115_37 63
#define LABEL_115_38 65
#define ENVIRONMENT_LABEL_115_3 79
#define DEBUGGING_LABEL_115_2 78
#define OBJECT_115_4 77
#define OBJECT_115_3 76
#define OBJECT_115_2 75
#define OBJECT_115_1 74
#define OBJECT_115_0 73
#define EXECUTE_CACHE_115_36 67
#define EXECUTE_CACHE_115_35 69
#define EXECUTE_CACHE_115_18 71
#define FREE_REFERENCES_LABEL_115_0 66
#define NUMBER_OF_LINKER_SECTIONS_115_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_115 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd21;
  machine_word Wrd58;
  machine_word Wrd56;
  machine_word Wrd55;
  machine_word Wrd44;
  machine_word Wrd36;
  machine_word Wrd121;
  machine_word Wrd128;
  machine_word Wrd124;
  machine_word Wrd116;
  machine_word Wrd118;
  machine_word Wrd120;
  machine_word Wrd119;
  machine_word Wrd112;
  machine_word Wrd114;
  machine_word Wrd115;
  machine_word Wrd104;
  machine_word Wrd111;
  machine_word Wrd107;
  machine_word Wrd101;
  machine_word Wrd102;
  machine_word Wrd103;
  machine_word Wrd93;
  machine_word Wrd100;
  machine_word Wrd96;
  machine_word Wrd88;
  machine_word Wrd90;
  machine_word Wrd92;
  machine_word Wrd91;
  machine_word Wrd84;
  machine_word Wrd86;
  machine_word Wrd87;
  machine_word Wrd76;
  machine_word Wrd83;
  machine_word Wrd79;
  machine_word Wrd73;
  machine_word Wrd74;
  machine_word Wrd75;
  machine_word Wrd65;
  machine_word Wrd72;
  machine_word Wrd68;
  machine_word Wrd60;
  machine_word Wrd62;
  machine_word Wrd64;
  machine_word Wrd34;
  machine_word Wrd129;
  machine_word Wrd16;
  machine_word Wrd12;
  machine_word Wrd7;
  machine_word Wrd54;
  machine_word Wrd61;
  machine_word Wrd57;
  machine_word Wrd51;
  machine_word Wrd50;
  machine_word Wrd53;
  machine_word Wrd52;
  machine_word Wrd41;
  machine_word Wrd48;
  machine_word Wrd28;
  machine_word Wrd63;
  machine_word Wrd17;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd10;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd23;
  machine_word Wrd42;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd22;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd35;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd11;
  machine_word Wrd13;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_115_4);
      goto append_map_50;

    case 1:
      current_block = (Rpc - LABEL_115_5);
      goto label_52;

    case 2:
      current_block = (Rpc - LABEL_115_6);
      goto label_53;

    case 3:
      current_block = (Rpc - LABEL_115_7);
      goto continuation_7;

    case 4:
      current_block = (Rpc - LABEL_115_8);
      goto map_1_12;

    case 5:
      current_block = (Rpc - LABEL_115_10);
      goto label_54;

    case 6:
      current_block = (Rpc - LABEL_115_11);
      goto continuation_19;

    case 7:
      current_block = (Rpc - LABEL_115_12);
      goto map_2_26;

    case 8:
      current_block = (Rpc - LABEL_115_14);
      goto label_55;

    case 9:
      current_block = (Rpc - LABEL_115_15);
      goto label_56;

    case 10:
      current_block = (Rpc - LABEL_115_16);
      goto map_n_47;

    case 11:
      current_block = (Rpc - LABEL_115_17);
      goto bad_end_49;

    case 12:
      current_block = (Rpc - LABEL_115_9);
      goto continuation_11;

    case 13:
      current_block = (Rpc - LABEL_115_20);
      goto label_57;

    case 14:
      current_block = (Rpc - LABEL_115_13);
      goto continuation_25;

    case 15:
      current_block = (Rpc - LABEL_115_22);
      goto label_58;

    case 16:
      current_block = (Rpc - LABEL_115_23);
      goto label_59;

    case 17:
      current_block = (Rpc - LABEL_115_24);
      goto continuation_37;

    case 18:
      current_block = (Rpc - LABEL_115_25);
      goto split_45;

    case 19:
      current_block = (Rpc - LABEL_115_26);
      goto label_60;

    case 20:
      current_block = (Rpc - LABEL_115_27);
      goto label_62;

    case 21:
      current_block = (Rpc - LABEL_115_28);
      goto label_63;

    case 22:
      current_block = (Rpc - LABEL_115_29);
      goto label_64;

    case 23:
      current_block = (Rpc - LABEL_115_30);
      goto label_65;

    case 24:
      current_block = (Rpc - LABEL_115_31);
      goto label_66;

    case 25:
      current_block = (Rpc - LABEL_115_32);
      goto label_61;

    case 26:
      current_block = (Rpc - LABEL_115_19);
      goto continuation_9;

    case 27:
      current_block = (Rpc - LABEL_115_21);
      goto continuation_22;

    case 28:
      current_block = (Rpc - LABEL_115_33);
      goto continuation_32;

    case 29:
      current_block = (Rpc - LABEL_115_34);
      goto continuation_31;

    case 30:
      current_block = (Rpc - LABEL_115_37);
      goto continuation_30;

    case 31:
      current_block = (Rpc - LABEL_115_38);
      goto continuation_29;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (append_map_68)
DEFLABEL (append_map_50)
  INTERRUPT_CHECK (26, LABEL_115_4);
  (Wrd5.Obj) = (Rsp [2]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_74;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rsp));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  Rdl = (& (Rsp [5]));
  goto map_1_12;

DEFLABEL (label_74)
  if (! ((Wrd6.uLng) == 1))
    goto label_79;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd11.Obj) = ((Wrd13.pObj) [1]);

DEFLABEL (label_78)
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd20.uLng) == 1))
    goto label_75;
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (59, Rsp));
  (* (--Rsp)) = (Wrd35.Obj);
  (Wrd39.Obj) = (Rsp [2]);
  (Wrd40.Obj) = (Rsp [3]);
  (* (Rhp++)) = (Wrd39.Obj);
  (* (Rhp++)) = (Wrd40.Obj);
  (Wrd37.pObj) = (& (Rhp [-2]));
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd37.pObj)));
  (* (--Rsp)) = (Wrd38.Obj);
  Rdl = (& (Rsp [5]));
  goto map_n_47;

DEFLABEL (label_75)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (59, Rsp));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd26.Obj) = (Rsp [3]);
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if (! ((Wrd27.uLng) == 1))
    goto label_77;
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd25.Obj) = ((Wrd24.pObj) [0]);
  (* (--Rsp)) = (Wrd25.Obj);

DEFLABEL (label_76)
  (Wrd32.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd32.Obj);
  Rdl = (& (Rsp [6]));
  goto map_2_26;

DEFLABEL (label_77)
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_115_6]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_115_1]), 1);

DEFLABEL (label_53)
  (* (--Rsp)) = Rvl;
  goto label_76;

DEFLABEL (label_79)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_115_5]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_115_0]), 1);

DEFLABEL (label_52)
  (Wrd11.Obj) = Rvl;
  goto label_78;

DEFLABEL (map_1_69)
DEFLABEL (map_1_12)
  DLINK_INTERRUPT_CHECK (25, LABEL_115_8);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_82;
  if (! ((Wrd5.Obj) == (current_block [OBJECT_115_2])))
    goto label_81;

DEFLABEL (label_80)
  Rvl = (current_block [OBJECT_115_2]);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_81)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_115_7]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd15.pObj)));
  (* (--Rsp)) = (Wrd17.Obj);
  goto bad_end_49;

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_115_7);
  (Wrd42.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd42.Obj));
  goto label_80;

DEFLABEL (label_82)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_115_9]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd24.Obj) = (Rsp [3]);
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd25.pObj)));
  (* (--Rsp)) = (Wrd27.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_86;
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd30.Obj) = ((Wrd29.pObj) [1]);
  (* (--Rsp)) = (Wrd30.Obj);

DEFLABEL (label_85)
  Rdl = (& (Rsp [2]));
  goto map_1_12;

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_115_9);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_115_19]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd15.Obj) = (Rsp [3]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 1))
    goto label_84;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_83)
  (Wrd25.Obj) = (Rsp [5]);
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd27.Obj) = ((Wrd26.pObj) [0]);
  (* (--Rsp)) = (Wrd27.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_115_19);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (* (--Rdl)) = (Rsp [1]);
  (* (--Rdl)) = (Rsp [0]);
  Rsp = Rdl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_115_36]));

DEFLABEL (label_84)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_115_20]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd15.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_115_1]), 1);

DEFLABEL (label_57)
  (Wrd17.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd17.Obj));
  (* (--Rsp)) = Rvl;
  goto label_83;

DEFLABEL (label_86)
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_115_10]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_115_0]), 1);

DEFLABEL (label_54)
  (Wrd33.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd33.Obj));
  (* (--Rsp)) = Rvl;
  goto label_85;

DEFLABEL (map_2_70)
DEFLABEL (map_2_26)
  DLINK_INTERRUPT_CHECK (25, LABEL_115_12);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_91;

DEFLABEL (label_90)
  (Wrd7.Obj) = (Rsp [0]);
  if ((Wrd7.Obj) == (current_block [OBJECT_115_2]))
    goto label_89;
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if ((Wrd10.uLng) == 1)
    goto label_89;

DEFLABEL (label_88)
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_115_11]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (Rsp [4]);
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd17.pObj)));
  (* (--Rsp)) = (Wrd19.Obj);
  goto bad_end_49;

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_115_11);
  (Wrd63.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd63.Obj));

DEFLABEL (label_87)
  Rvl = (current_block [OBJECT_115_2]);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_89)
  (Wrd20.Obj) = (Rsp [1]);
  if ((Wrd20.Obj) == (current_block [OBJECT_115_2]))
    goto label_87;
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if ((Wrd23.uLng) == 1)
    goto label_87;
  goto label_88;

DEFLABEL (label_91)
  (Wrd25.Obj) = (Rsp [1]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if (! ((Wrd26.uLng) == 1))
    goto label_90;
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_115_13]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (Wrd32.Obj) = (Rsp [4]);
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd33.pObj)));
  (* (--Rsp)) = (Wrd35.Obj);
  if (! ((Wrd26.uLng) == 1))
    goto label_99;
  (Wrd37.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd38.Obj) = ((Wrd37.pObj) [1]);
  (* (--Rsp)) = (Wrd38.Obj);

DEFLABEL (label_98)
  (Wrd52.Obj) = (Rsp [4]);
  (Wrd53.uLng) = (OBJECT_TYPE (Wrd52.Obj));
  if (! ((Wrd53.uLng) == 1))
    goto label_97;
  (Wrd50.pObj) = (OBJECT_ADDRESS (Wrd52.Obj));
  (Wrd51.Obj) = ((Wrd50.pObj) [1]);
  (* (--Rsp)) = (Wrd51.Obj);

DEFLABEL (label_96)
  Rdl = (& (Rsp [3]));
  goto map_2_26;

DEFLABEL (continuation_25)
  INTERRUPT_CHECK (27, LABEL_115_13);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_115_21]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd15.Obj) = (Rsp [4]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 1))
    goto label_95;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_94)
  (Wrd28.Obj) = (Rsp [4]);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if (! ((Wrd29.uLng) == 1))
    goto label_93;
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd28.Obj));
  (Wrd27.Obj) = ((Wrd26.pObj) [0]);
  (* (--Rsp)) = (Wrd27.Obj);

DEFLABEL (label_92)
  (Wrd38.Obj) = (Rsp [7]);
  (Wrd39.pObj) = (OBJECT_ADDRESS (Wrd38.Obj));
  (Wrd40.Obj) = ((Wrd39.pObj) [0]);
  (* (--Rsp)) = (Wrd40.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_22)
  INTERRUPT_CHECK (27, LABEL_115_21);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (* (--Rdl)) = (Rsp [1]);
  (* (--Rdl)) = (Rsp [0]);
  Rsp = Rdl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_115_36]));

DEFLABEL (label_93)
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_115_23]))));
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_115_1]), 1);

DEFLABEL (label_59)
  (Wrd30.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd30.Obj));
  (* (--Rsp)) = Rvl;
  goto label_92;

DEFLABEL (label_95)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_115_22]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd15.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_115_1]), 1);

DEFLABEL (label_58)
  (Wrd17.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd17.Obj));
  (* (--Rsp)) = Rvl;
  goto label_94;

DEFLABEL (label_97)
  (Wrd57.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd57.Obj);
  (Wrd61.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_115_15]))));
  (* (--Rsp)) = (Wrd61.Obj);
  (* (--Rsp)) = (Wrd52.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_115_0]), 1);

DEFLABEL (label_56)
  (Wrd54.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd54.Obj));
  (* (--Rsp)) = Rvl;
  goto label_96;

DEFLABEL (label_99)
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd48.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_115_14]))));
  (* (--Rsp)) = (Wrd48.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_115_0]), 1);

DEFLABEL (label_55)
  (Wrd41.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd41.Obj));
  (* (--Rsp)) = Rvl;
  goto label_98;

DEFLABEL (map_n_71)
DEFLABEL (map_n_47)
  DLINK_INTERRUPT_CHECK (25, LABEL_115_16);
  (Wrd5.Obj) = (current_block [OBJECT_115_2]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Rsp [2]) = (Wrd5.Obj);
  goto split_45;

DEFLABEL (bad_end_72)
DEFLABEL (bad_end_49)
  INTERRUPT_CHECK (26, LABEL_115_17);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [1]);
  (Wrd13.Obj) = ((Wrd9.pObj) [2]);
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd13.Obj);
  (Wrd6.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd6.pObj)));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_115_3]);
  (Rsp [1]) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_115_18]));

DEFLABEL (split_73)
DEFLABEL (split_45)
  DLINK_INTERRUPT_CHECK (25, LABEL_115_25);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_100;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_115_33]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [5]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd13.pObj)));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_115_34]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd21.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd21.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_115_35]));

DEFLABEL (continuation_31)
  INTERRUPT_CHECK (27, LABEL_115_34);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  Rdl = (& (Rsp [2]));
  goto map_n_47;

DEFLABEL (continuation_32)
  INTERRUPT_CHECK (27, LABEL_115_33);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_115_37]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_115_38]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_115_35]));

DEFLABEL (continuation_29)
  INTERRUPT_CHECK (27, LABEL_115_38);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (Rsp [7]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_115_4]), 2);

DEFLABEL (continuation_30)
  INTERRUPT_CHECK (27, LABEL_115_37);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (* (--Rdl)) = (Rsp [1]);
  (* (--Rdl)) = (Rsp [0]);
  Rsp = Rdl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_115_36]));

DEFLABEL (label_100)
  if (! ((Wrd6.uLng) == 1))
    goto label_117;
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd22.Obj) = ((Wrd24.pObj) [0]);

DEFLABEL (label_116)
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if ((Wrd35.uLng) == 1)
    goto label_105;
  (Wrd39.Obj) = (Rsp [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if (! ((Wrd40.uLng) == 1))
    goto label_104;
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd39.Obj));
  (Wrd36.Obj) = ((Wrd38.pObj) [0]);

DEFLABEL (label_103)
  if (! ((Wrd36.Obj) == (current_block [OBJECT_115_2])))
    goto label_102;

DEFLABEL (label_101)
  Rvl = (current_block [OBJECT_115_2]);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_102)
  (Wrd51.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd51.Obj);
  (Wrd54.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_115_24]))));
  (* (--Rsp)) = (Wrd54.Obj);
  (Wrd55.Obj) = (Rsp [5]);
  (Wrd56.pObj) = (OBJECT_ADDRESS (Wrd55.Obj));
  (Wrd58.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd56.pObj)));
  (* (--Rsp)) = (Wrd58.Obj);
  goto bad_end_49;

DEFLABEL (continuation_37)
  INTERRUPT_CHECK (27, LABEL_115_24);
  (Wrd129.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd129.Obj));
  goto label_101;

DEFLABEL (label_104)
  (Wrd44.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd44.Obj);
  (Wrd48.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_115_32]))));
  (* (--Rsp)) = (Wrd48.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_115_1]), 1);

DEFLABEL (label_61)
  (Wrd41.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd41.Obj));
  (Wrd36.Obj) = Rvl;
  goto label_103;

DEFLABEL (label_105)
  (Wrd63.Obj) = (Rsp [0]);
  (Wrd64.uLng) = (OBJECT_TYPE (Wrd63.Obj));
  if (! ((Wrd64.uLng) == 1))
    goto label_115;
  (Wrd62.pObj) = (OBJECT_ADDRESS (Wrd63.Obj));
  (Wrd60.Obj) = ((Wrd62.pObj) [0]);

DEFLABEL (label_114)
  (Wrd75.uLng) = (OBJECT_TYPE (Wrd60.Obj));
  if (! ((Wrd75.uLng) == 1))
    goto label_113;
  (Wrd74.pObj) = (OBJECT_ADDRESS (Wrd60.Obj));
  (Wrd73.Obj) = ((Wrd74.pObj) [0]);

DEFLABEL (label_112)
  (Wrd87.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd73.Obj);
  (* (Rhp++)) = (Wrd87.Obj);
  (Wrd86.pObj) = (& (Rhp [-2]));
  (Wrd84.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd86.pObj)));
  (Rsp [1]) = (Wrd84.Obj);
  (Wrd91.Obj) = (Rsp [0]);
  (Wrd92.uLng) = (OBJECT_TYPE (Wrd91.Obj));
  if (! ((Wrd92.uLng) == 1))
    goto label_111;
  (Wrd90.pObj) = (OBJECT_ADDRESS (Wrd91.Obj));
  (Wrd88.Obj) = ((Wrd90.pObj) [0]);

DEFLABEL (label_110)
  (Wrd103.uLng) = (OBJECT_TYPE (Wrd88.Obj));
  if (! ((Wrd103.uLng) == 1))
    goto label_109;
  (Wrd102.pObj) = (OBJECT_ADDRESS (Wrd88.Obj));
  (Wrd101.Obj) = ((Wrd102.pObj) [1]);

DEFLABEL (label_108)
  (Wrd115.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd101.Obj);
  (* (Rhp++)) = (Wrd115.Obj);
  (Wrd114.pObj) = (& (Rhp [-2]));
  (Wrd112.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd114.pObj)));
  (Rsp [2]) = (Wrd112.Obj);
  (Wrd119.Obj) = (Rsp [0]);
  (Wrd120.uLng) = (OBJECT_TYPE (Wrd119.Obj));
  if (! ((Wrd120.uLng) == 1))
    goto label_107;
  (Wrd118.pObj) = (OBJECT_ADDRESS (Wrd119.Obj));
  (Wrd116.Obj) = ((Wrd118.pObj) [1]);

DEFLABEL (label_106)
  (Rsp [0]) = (Wrd116.Obj);
  goto split_45;

DEFLABEL (label_107)
  (Wrd124.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd124.Obj);
  (Wrd128.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_115_31]))));
  (* (--Rsp)) = (Wrd128.Obj);
  (* (--Rsp)) = (Wrd119.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_115_0]), 1);

DEFLABEL (label_66)
  (Wrd121.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd121.Obj));
  (Wrd116.Obj) = Rvl;
  goto label_106;

DEFLABEL (label_109)
  (Wrd107.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd107.Obj);
  (Wrd111.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_115_30]))));
  (* (--Rsp)) = (Wrd111.Obj);
  (* (--Rsp)) = (Wrd88.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_115_0]), 1);

DEFLABEL (label_65)
  (Wrd104.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd104.Obj));
  (Wrd101.Obj) = Rvl;
  goto label_108;

DEFLABEL (label_111)
  (Wrd96.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd96.Obj);
  (Wrd100.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_115_29]))));
  (* (--Rsp)) = (Wrd100.Obj);
  (* (--Rsp)) = (Wrd91.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_115_1]), 1);

DEFLABEL (label_64)
  (Wrd93.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd93.Obj));
  (Wrd88.Obj) = Rvl;
  goto label_110;

DEFLABEL (label_113)
  (Wrd79.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd79.Obj);
  (Wrd83.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_115_28]))));
  (* (--Rsp)) = (Wrd83.Obj);
  (* (--Rsp)) = (Wrd60.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_115_1]), 1);

DEFLABEL (label_63)
  (Wrd76.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd76.Obj));
  (Wrd73.Obj) = Rvl;
  goto label_112;

DEFLABEL (label_115)
  (Wrd68.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd68.Obj);
  (Wrd72.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_115_27]))));
  (* (--Rsp)) = (Wrd72.Obj);
  (* (--Rsp)) = (Wrd63.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_115_1]), 1);

DEFLABEL (label_62)
  (Wrd65.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd65.Obj));
  (Wrd60.Obj) = Rvl;
  goto label_114;

DEFLABEL (label_117)
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_115_26]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_115_1]), 1);

DEFLABEL (label_60)
  (Wrd27.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd22.Obj) = Rvl;
  goto label_116;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_116_4 3
#define LABEL_116_5 5
#define LABEL_116_6 7
#define LABEL_116_7 9
#define LABEL_116_8 11
#define LABEL_116_10 13
#define LABEL_116_11 15
#define LABEL_116_12 17
#define LABEL_116_14 19
#define LABEL_116_15 21
#define LABEL_116_16 23
#define LABEL_116_17 25
#define LABEL_116_9 27
#define LABEL_116_20 29
#define LABEL_116_13 31
#define LABEL_116_22 33
#define LABEL_116_23 35
#define LABEL_116_24 37
#define LABEL_116_25 39
#define LABEL_116_26 41
#define LABEL_116_27 43
#define LABEL_116_28 45
#define LABEL_116_29 47
#define LABEL_116_30 49
#define LABEL_116_31 51
#define LABEL_116_32 53
#define LABEL_116_19 55
#define LABEL_116_21 57
#define LABEL_116_33 59
#define LABEL_116_34 61
#define LABEL_116_37 63
#define LABEL_116_38 65
#define ENVIRONMENT_LABEL_116_3 79
#define DEBUGGING_LABEL_116_2 78
#define OBJECT_116_4 77
#define OBJECT_116_3 76
#define OBJECT_116_2 75
#define OBJECT_116_1 74
#define OBJECT_116_0 73
#define EXECUTE_CACHE_116_36 67
#define EXECUTE_CACHE_116_35 69
#define EXECUTE_CACHE_116_18 71
#define FREE_REFERENCES_LABEL_116_0 66
#define NUMBER_OF_LINKER_SECTIONS_116_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_116 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd21;
  machine_word Wrd58;
  machine_word Wrd51;
  machine_word Wrd60;
  machine_word Wrd41;
  machine_word Wrd48;
  machine_word Wrd36;
  machine_word Wrd123;
  machine_word Wrd130;
  machine_word Wrd126;
  machine_word Wrd118;
  machine_word Wrd120;
  machine_word Wrd122;
  machine_word Wrd121;
  machine_word Wrd114;
  machine_word Wrd116;
  machine_word Wrd117;
  machine_word Wrd106;
  machine_word Wrd113;
  machine_word Wrd109;
  machine_word Wrd103;
  machine_word Wrd104;
  machine_word Wrd105;
  machine_word Wrd95;
  machine_word Wrd102;
  machine_word Wrd98;
  machine_word Wrd90;
  machine_word Wrd92;
  machine_word Wrd94;
  machine_word Wrd93;
  machine_word Wrd86;
  machine_word Wrd88;
  machine_word Wrd89;
  machine_word Wrd78;
  machine_word Wrd85;
  machine_word Wrd81;
  machine_word Wrd75;
  machine_word Wrd76;
  machine_word Wrd77;
  machine_word Wrd67;
  machine_word Wrd74;
  machine_word Wrd70;
  machine_word Wrd62;
  machine_word Wrd64;
  machine_word Wrd66;
  machine_word Wrd131;
  machine_word Wrd16;
  machine_word Wrd12;
  machine_word Wrd23;
  machine_word Wrd7;
  machine_word Wrd56;
  machine_word Wrd63;
  machine_word Wrd59;
  machine_word Wrd53;
  machine_word Wrd52;
  machine_word Wrd55;
  machine_word Wrd54;
  machine_word Wrd43;
  machine_word Wrd50;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd28;
  machine_word Wrd65;
  machine_word Wrd17;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd10;
  machine_word Wrd18;
  machine_word Wrd42;
  machine_word Wrd29;
  machine_word Wrd44;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd22;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd35;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd11;
  machine_word Wrd13;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_116_4);
      goto append_map__50;

    case 1:
      current_block = (Rpc - LABEL_116_5);
      goto label_52;

    case 2:
      current_block = (Rpc - LABEL_116_6);
      goto label_53;

    case 3:
      current_block = (Rpc - LABEL_116_7);
      goto continuation_7;

    case 4:
      current_block = (Rpc - LABEL_116_8);
      goto map_1_12;

    case 5:
      current_block = (Rpc - LABEL_116_10);
      goto label_54;

    case 6:
      current_block = (Rpc - LABEL_116_11);
      goto continuation_19;

    case 7:
      current_block = (Rpc - LABEL_116_12);
      goto map_2_26;

    case 8:
      current_block = (Rpc - LABEL_116_14);
      goto label_55;

    case 9:
      current_block = (Rpc - LABEL_116_15);
      goto label_56;

    case 10:
      current_block = (Rpc - LABEL_116_16);
      goto map_n_47;

    case 11:
      current_block = (Rpc - LABEL_116_17);
      goto bad_end_49;

    case 12:
      current_block = (Rpc - LABEL_116_9);
      goto continuation_11;

    case 13:
      current_block = (Rpc - LABEL_116_20);
      goto label_57;

    case 14:
      current_block = (Rpc - LABEL_116_13);
      goto continuation_25;

    case 15:
      current_block = (Rpc - LABEL_116_22);
      goto label_58;

    case 16:
      current_block = (Rpc - LABEL_116_23);
      goto label_59;

    case 17:
      current_block = (Rpc - LABEL_116_24);
      goto continuation_37;

    case 18:
      current_block = (Rpc - LABEL_116_25);
      goto split_45;

    case 19:
      current_block = (Rpc - LABEL_116_26);
      goto label_60;

    case 20:
      current_block = (Rpc - LABEL_116_27);
      goto label_62;

    case 21:
      current_block = (Rpc - LABEL_116_28);
      goto label_63;

    case 22:
      current_block = (Rpc - LABEL_116_29);
      goto label_64;

    case 23:
      current_block = (Rpc - LABEL_116_30);
      goto label_65;

    case 24:
      current_block = (Rpc - LABEL_116_31);
      goto label_66;

    case 25:
      current_block = (Rpc - LABEL_116_32);
      goto label_61;

    case 26:
      current_block = (Rpc - LABEL_116_19);
      goto continuation_9;

    case 27:
      current_block = (Rpc - LABEL_116_21);
      goto continuation_22;

    case 28:
      current_block = (Rpc - LABEL_116_33);
      goto continuation_32;

    case 29:
      current_block = (Rpc - LABEL_116_34);
      goto continuation_31;

    case 30:
      current_block = (Rpc - LABEL_116_37);
      goto continuation_30;

    case 31:
      current_block = (Rpc - LABEL_116_38);
      goto continuation_29;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (append_map__68)
DEFLABEL (append_map__50)
  INTERRUPT_CHECK (26, LABEL_116_4);
  (Wrd5.Obj) = (Rsp [3]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_74;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rsp));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  Rdl = (& (Rsp [6]));
  goto map_1_12;

DEFLABEL (label_74)
  if (! ((Wrd6.uLng) == 1))
    goto label_79;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd11.Obj) = ((Wrd13.pObj) [1]);

DEFLABEL (label_78)
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd20.uLng) == 1))
    goto label_75;
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (59, Rsp));
  (* (--Rsp)) = (Wrd35.Obj);
  (Wrd39.Obj) = (Rsp [3]);
  (Wrd40.Obj) = (Rsp [4]);
  (* (Rhp++)) = (Wrd39.Obj);
  (* (Rhp++)) = (Wrd40.Obj);
  (Wrd37.pObj) = (& (Rhp [-2]));
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd37.pObj)));
  (* (--Rsp)) = (Wrd38.Obj);
  Rdl = (& (Rsp [6]));
  goto map_n_47;

DEFLABEL (label_75)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (59, Rsp));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd26.Obj) = (Rsp [4]);
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if (! ((Wrd27.uLng) == 1))
    goto label_77;
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd25.Obj) = ((Wrd24.pObj) [0]);
  (* (--Rsp)) = (Wrd25.Obj);

DEFLABEL (label_76)
  (Wrd32.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd32.Obj);
  Rdl = (& (Rsp [7]));
  goto map_2_26;

DEFLABEL (label_77)
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_116_6]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_116_1]), 1);

DEFLABEL (label_53)
  (* (--Rsp)) = Rvl;
  goto label_76;

DEFLABEL (label_79)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_116_5]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_116_0]), 1);

DEFLABEL (label_52)
  (Wrd11.Obj) = Rvl;
  goto label_78;

DEFLABEL (map_1_69)
DEFLABEL (map_1_12)
  DLINK_INTERRUPT_CHECK (25, LABEL_116_8);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_82;
  if (! ((Wrd5.Obj) == (current_block [OBJECT_116_2])))
    goto label_81;

DEFLABEL (label_80)
  (Wrd18.Obj) = (Rsp [1]);
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  Rvl = ((Wrd19.pObj) [0]);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_81)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_116_7]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd15.pObj)));
  (* (--Rsp)) = (Wrd17.Obj);
  goto bad_end_49;

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_116_7);
  (Wrd44.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd44.Obj));
  goto label_80;

DEFLABEL (label_82)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_116_9]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd26.Obj) = (Rsp [3]);
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd27.pObj)));
  (* (--Rsp)) = (Wrd29.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_86;
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd32.Obj) = ((Wrd31.pObj) [1]);
  (* (--Rsp)) = (Wrd32.Obj);

DEFLABEL (label_85)
  Rdl = (& (Rsp [2]));
  goto map_1_12;

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_116_9);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_116_19]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd15.Obj) = (Rsp [3]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 1))
    goto label_84;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_83)
  (Wrd25.Obj) = (Rsp [5]);
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd27.Obj) = ((Wrd26.pObj) [1]);
  (* (--Rsp)) = (Wrd27.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_116_19);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (* (--Rdl)) = (Rsp [1]);
  (* (--Rdl)) = (Rsp [0]);
  Rsp = Rdl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_116_36]));

DEFLABEL (label_84)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_116_20]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd15.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_116_1]), 1);

DEFLABEL (label_57)
  (Wrd17.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd17.Obj));
  (* (--Rsp)) = Rvl;
  goto label_83;

DEFLABEL (label_86)
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_116_10]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_116_0]), 1);

DEFLABEL (label_54)
  (Wrd35.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd35.Obj));
  (* (--Rsp)) = Rvl;
  goto label_85;

DEFLABEL (map_2_70)
DEFLABEL (map_2_26)
  DLINK_INTERRUPT_CHECK (25, LABEL_116_12);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_91;

DEFLABEL (label_90)
  (Wrd7.Obj) = (Rsp [0]);
  if ((Wrd7.Obj) == (current_block [OBJECT_116_2]))
    goto label_89;
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if ((Wrd10.uLng) == 1)
    goto label_89;

DEFLABEL (label_88)
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_116_11]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (Rsp [4]);
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd17.pObj)));
  (* (--Rsp)) = (Wrd19.Obj);
  goto bad_end_49;

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_116_11);
  (Wrd65.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd65.Obj));

DEFLABEL (label_87)
  (Wrd24.Obj) = (Rsp [2]);
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  Rvl = ((Wrd25.pObj) [0]);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_89)
  (Wrd20.Obj) = (Rsp [1]);
  if ((Wrd20.Obj) == (current_block [OBJECT_116_2]))
    goto label_87;
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if ((Wrd23.uLng) == 1)
    goto label_87;
  goto label_88;

DEFLABEL (label_91)
  (Wrd27.Obj) = (Rsp [1]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if (! ((Wrd28.uLng) == 1))
    goto label_90;
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_116_13]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd34.Obj) = (Rsp [4]);
  (Wrd35.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd35.pObj)));
  (* (--Rsp)) = (Wrd37.Obj);
  if (! ((Wrd28.uLng) == 1))
    goto label_99;
  (Wrd39.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd40.Obj) = ((Wrd39.pObj) [1]);
  (* (--Rsp)) = (Wrd40.Obj);

DEFLABEL (label_98)
  (Wrd54.Obj) = (Rsp [4]);
  (Wrd55.uLng) = (OBJECT_TYPE (Wrd54.Obj));
  if (! ((Wrd55.uLng) == 1))
    goto label_97;
  (Wrd52.pObj) = (OBJECT_ADDRESS (Wrd54.Obj));
  (Wrd53.Obj) = ((Wrd52.pObj) [1]);
  (* (--Rsp)) = (Wrd53.Obj);

DEFLABEL (label_96)
  Rdl = (& (Rsp [3]));
  goto map_2_26;

DEFLABEL (continuation_25)
  INTERRUPT_CHECK (27, LABEL_116_13);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_116_21]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd15.Obj) = (Rsp [4]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 1))
    goto label_95;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_94)
  (Wrd28.Obj) = (Rsp [4]);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if (! ((Wrd29.uLng) == 1))
    goto label_93;
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd28.Obj));
  (Wrd27.Obj) = ((Wrd26.pObj) [0]);
  (* (--Rsp)) = (Wrd27.Obj);

DEFLABEL (label_92)
  (Wrd38.Obj) = (Rsp [7]);
  (Wrd39.pObj) = (OBJECT_ADDRESS (Wrd38.Obj));
  (Wrd40.Obj) = ((Wrd39.pObj) [1]);
  (* (--Rsp)) = (Wrd40.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_22)
  INTERRUPT_CHECK (27, LABEL_116_21);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (* (--Rdl)) = (Rsp [1]);
  (* (--Rdl)) = (Rsp [0]);
  Rsp = Rdl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_116_36]));

DEFLABEL (label_93)
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_116_23]))));
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_116_1]), 1);

DEFLABEL (label_59)
  (Wrd30.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd30.Obj));
  (* (--Rsp)) = Rvl;
  goto label_92;

DEFLABEL (label_95)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_116_22]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd15.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_116_1]), 1);

DEFLABEL (label_58)
  (Wrd17.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd17.Obj));
  (* (--Rsp)) = Rvl;
  goto label_94;

DEFLABEL (label_97)
  (Wrd59.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd59.Obj);
  (Wrd63.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_116_15]))));
  (* (--Rsp)) = (Wrd63.Obj);
  (* (--Rsp)) = (Wrd54.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_116_0]), 1);

DEFLABEL (label_56)
  (Wrd56.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd56.Obj));
  (* (--Rsp)) = Rvl;
  goto label_96;

DEFLABEL (label_99)
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_116_14]))));
  (* (--Rsp)) = (Wrd50.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_116_0]), 1);

DEFLABEL (label_55)
  (Wrd43.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd43.Obj));
  (* (--Rsp)) = Rvl;
  goto label_98;

DEFLABEL (map_n_71)
DEFLABEL (map_n_47)
  DLINK_INTERRUPT_CHECK (25, LABEL_116_16);
  (Wrd5.Obj) = (current_block [OBJECT_116_2]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Rsp [2]) = (Wrd5.Obj);
  goto split_45;

DEFLABEL (bad_end_72)
DEFLABEL (bad_end_49)
  INTERRUPT_CHECK (26, LABEL_116_17);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [2]);
  (Wrd13.Obj) = ((Wrd9.pObj) [3]);
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd13.Obj);
  (Wrd6.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd6.pObj)));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_116_3]);
  (Rsp [1]) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_116_18]));

DEFLABEL (split_73)
DEFLABEL (split_45)
  DLINK_INTERRUPT_CHECK (25, LABEL_116_25);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_100;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_116_33]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [5]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd13.pObj)));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_116_34]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd21.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd21.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_116_35]));

DEFLABEL (continuation_31)
  INTERRUPT_CHECK (27, LABEL_116_34);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  Rdl = (& (Rsp [2]));
  goto map_n_47;

DEFLABEL (continuation_32)
  INTERRUPT_CHECK (27, LABEL_116_33);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_116_37]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_116_38]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_116_35]));

DEFLABEL (continuation_29)
  INTERRUPT_CHECK (27, LABEL_116_38);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (Rsp [7]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [1]);
  (* (--Rsp)) = (Wrd9.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_116_4]), 2);

DEFLABEL (continuation_30)
  INTERRUPT_CHECK (27, LABEL_116_37);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (* (--Rdl)) = (Rsp [1]);
  (* (--Rdl)) = (Rsp [0]);
  Rsp = Rdl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_116_36]));

DEFLABEL (label_100)
  if (! ((Wrd6.uLng) == 1))
    goto label_117;
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd22.Obj) = ((Wrd24.pObj) [0]);

DEFLABEL (label_116)
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if ((Wrd35.uLng) == 1)
    goto label_105;
  (Wrd39.Obj) = (Rsp [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if (! ((Wrd40.uLng) == 1))
    goto label_104;
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd39.Obj));
  (Wrd36.Obj) = ((Wrd38.pObj) [0]);

DEFLABEL (label_103)
  if (! ((Wrd36.Obj) == (current_block [OBJECT_116_2])))
    goto label_102;

DEFLABEL (label_101)
  (Wrd59.Obj) = (Rsp [3]);
  (Wrd60.pObj) = (OBJECT_ADDRESS (Wrd59.Obj));
  Rvl = ((Wrd60.pObj) [0]);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_102)
  (Wrd51.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd51.Obj);
  (Wrd54.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_116_24]))));
  (* (--Rsp)) = (Wrd54.Obj);
  (Wrd55.Obj) = (Rsp [5]);
  (Wrd56.pObj) = (OBJECT_ADDRESS (Wrd55.Obj));
  (Wrd58.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd56.pObj)));
  (* (--Rsp)) = (Wrd58.Obj);
  goto bad_end_49;

DEFLABEL (continuation_37)
  INTERRUPT_CHECK (27, LABEL_116_24);
  (Wrd131.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd131.Obj));
  goto label_101;

DEFLABEL (label_104)
  (Wrd44.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd44.Obj);
  (Wrd48.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_116_32]))));
  (* (--Rsp)) = (Wrd48.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_116_1]), 1);

DEFLABEL (label_61)
  (Wrd41.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd41.Obj));
  (Wrd36.Obj) = Rvl;
  goto label_103;

DEFLABEL (label_105)
  (Wrd65.Obj) = (Rsp [0]);
  (Wrd66.uLng) = (OBJECT_TYPE (Wrd65.Obj));
  if (! ((Wrd66.uLng) == 1))
    goto label_115;
  (Wrd64.pObj) = (OBJECT_ADDRESS (Wrd65.Obj));
  (Wrd62.Obj) = ((Wrd64.pObj) [0]);

DEFLABEL (label_114)
  (Wrd77.uLng) = (OBJECT_TYPE (Wrd62.Obj));
  if (! ((Wrd77.uLng) == 1))
    goto label_113;
  (Wrd76.pObj) = (OBJECT_ADDRESS (Wrd62.Obj));
  (Wrd75.Obj) = ((Wrd76.pObj) [0]);

DEFLABEL (label_112)
  (Wrd89.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd75.Obj);
  (* (Rhp++)) = (Wrd89.Obj);
  (Wrd88.pObj) = (& (Rhp [-2]));
  (Wrd86.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd88.pObj)));
  (Rsp [1]) = (Wrd86.Obj);
  (Wrd93.Obj) = (Rsp [0]);
  (Wrd94.uLng) = (OBJECT_TYPE (Wrd93.Obj));
  if (! ((Wrd94.uLng) == 1))
    goto label_111;
  (Wrd92.pObj) = (OBJECT_ADDRESS (Wrd93.Obj));
  (Wrd90.Obj) = ((Wrd92.pObj) [0]);

DEFLABEL (label_110)
  (Wrd105.uLng) = (OBJECT_TYPE (Wrd90.Obj));
  if (! ((Wrd105.uLng) == 1))
    goto label_109;
  (Wrd104.pObj) = (OBJECT_ADDRESS (Wrd90.Obj));
  (Wrd103.Obj) = ((Wrd104.pObj) [1]);

DEFLABEL (label_108)
  (Wrd117.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd103.Obj);
  (* (Rhp++)) = (Wrd117.Obj);
  (Wrd116.pObj) = (& (Rhp [-2]));
  (Wrd114.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd116.pObj)));
  (Rsp [2]) = (Wrd114.Obj);
  (Wrd121.Obj) = (Rsp [0]);
  (Wrd122.uLng) = (OBJECT_TYPE (Wrd121.Obj));
  if (! ((Wrd122.uLng) == 1))
    goto label_107;
  (Wrd120.pObj) = (OBJECT_ADDRESS (Wrd121.Obj));
  (Wrd118.Obj) = ((Wrd120.pObj) [1]);

DEFLABEL (label_106)
  (Rsp [0]) = (Wrd118.Obj);
  goto split_45;

DEFLABEL (label_107)
  (Wrd126.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd126.Obj);
  (Wrd130.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_116_31]))));
  (* (--Rsp)) = (Wrd130.Obj);
  (* (--Rsp)) = (Wrd121.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_116_0]), 1);

DEFLABEL (label_66)
  (Wrd123.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd123.Obj));
  (Wrd118.Obj) = Rvl;
  goto label_106;

DEFLABEL (label_109)
  (Wrd109.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd109.Obj);
  (Wrd113.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_116_30]))));
  (* (--Rsp)) = (Wrd113.Obj);
  (* (--Rsp)) = (Wrd90.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_116_0]), 1);

DEFLABEL (label_65)
  (Wrd106.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd106.Obj));
  (Wrd103.Obj) = Rvl;
  goto label_108;

DEFLABEL (label_111)
  (Wrd98.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd98.Obj);
  (Wrd102.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_116_29]))));
  (* (--Rsp)) = (Wrd102.Obj);
  (* (--Rsp)) = (Wrd93.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_116_1]), 1);

DEFLABEL (label_64)
  (Wrd95.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd95.Obj));
  (Wrd90.Obj) = Rvl;
  goto label_110;

DEFLABEL (label_113)
  (Wrd81.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd81.Obj);
  (Wrd85.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_116_28]))));
  (* (--Rsp)) = (Wrd85.Obj);
  (* (--Rsp)) = (Wrd62.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_116_1]), 1);

DEFLABEL (label_63)
  (Wrd78.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd78.Obj));
  (Wrd75.Obj) = Rvl;
  goto label_112;

DEFLABEL (label_115)
  (Wrd70.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd70.Obj);
  (Wrd74.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_116_27]))));
  (* (--Rsp)) = (Wrd74.Obj);
  (* (--Rsp)) = (Wrd65.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_116_1]), 1);

DEFLABEL (label_62)
  (Wrd67.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd67.Obj));
  (Wrd62.Obj) = Rvl;
  goto label_114;

DEFLABEL (label_117)
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_116_26]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_116_1]), 1);

DEFLABEL (label_60)
  (Wrd27.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd22.Obj) = Rvl;
  goto label_116;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_117_4 3
#define LABEL_117_5 5
#define LABEL_117_6 7
#define LABEL_117_7 9
#define LABEL_117_8 11
#define LABEL_117_10 13
#define LABEL_117_11 15
#define LABEL_117_12 17
#define LABEL_117_14 19
#define LABEL_117_15 21
#define LABEL_117_16 23
#define LABEL_117_17 25
#define LABEL_117_9 27
#define LABEL_117_20 29
#define LABEL_117_13 31
#define LABEL_117_22 33
#define LABEL_117_23 35
#define LABEL_117_24 37
#define LABEL_117_25 39
#define LABEL_117_26 41
#define LABEL_117_27 43
#define LABEL_117_28 45
#define LABEL_117_29 47
#define LABEL_117_30 49
#define LABEL_117_31 51
#define LABEL_117_32 53
#define LABEL_117_19 55
#define LABEL_117_21 57
#define LABEL_117_33 59
#define LABEL_117_34 61
#define LABEL_117_37 63
#define LABEL_117_38 65
#define ENVIRONMENT_LABEL_117_3 79
#define DEBUGGING_LABEL_117_2 78
#define OBJECT_117_4 77
#define OBJECT_117_3 76
#define OBJECT_117_2 75
#define OBJECT_117_1 74
#define OBJECT_117_0 73
#define EXECUTE_CACHE_117_36 67
#define EXECUTE_CACHE_117_35 69
#define EXECUTE_CACHE_117_18 71
#define FREE_REFERENCES_LABEL_117_0 66
#define NUMBER_OF_LINKER_SECTIONS_117_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_117 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd21;
  machine_word Wrd58;
  machine_word Wrd56;
  machine_word Wrd55;
  machine_word Wrd44;
  machine_word Wrd36;
  machine_word Wrd121;
  machine_word Wrd128;
  machine_word Wrd124;
  machine_word Wrd116;
  machine_word Wrd118;
  machine_word Wrd120;
  machine_word Wrd119;
  machine_word Wrd112;
  machine_word Wrd114;
  machine_word Wrd115;
  machine_word Wrd104;
  machine_word Wrd111;
  machine_word Wrd107;
  machine_word Wrd101;
  machine_word Wrd102;
  machine_word Wrd103;
  machine_word Wrd93;
  machine_word Wrd100;
  machine_word Wrd96;
  machine_word Wrd88;
  machine_word Wrd90;
  machine_word Wrd92;
  machine_word Wrd91;
  machine_word Wrd84;
  machine_word Wrd86;
  machine_word Wrd87;
  machine_word Wrd76;
  machine_word Wrd83;
  machine_word Wrd79;
  machine_word Wrd73;
  machine_word Wrd74;
  machine_word Wrd75;
  machine_word Wrd65;
  machine_word Wrd72;
  machine_word Wrd68;
  machine_word Wrd60;
  machine_word Wrd62;
  machine_word Wrd64;
  machine_word Wrd34;
  machine_word Wrd129;
  machine_word Wrd16;
  machine_word Wrd12;
  machine_word Wrd7;
  machine_word Wrd54;
  machine_word Wrd61;
  machine_word Wrd57;
  machine_word Wrd51;
  machine_word Wrd50;
  machine_word Wrd53;
  machine_word Wrd52;
  machine_word Wrd41;
  machine_word Wrd48;
  machine_word Wrd28;
  machine_word Wrd63;
  machine_word Wrd17;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd10;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd23;
  machine_word Wrd42;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd22;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd35;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd11;
  machine_word Wrd13;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_117_4);
      goto append_mapB_50;

    case 1:
      current_block = (Rpc - LABEL_117_5);
      goto label_52;

    case 2:
      current_block = (Rpc - LABEL_117_6);
      goto label_53;

    case 3:
      current_block = (Rpc - LABEL_117_7);
      goto continuation_7;

    case 4:
      current_block = (Rpc - LABEL_117_8);
      goto map_1_12;

    case 5:
      current_block = (Rpc - LABEL_117_10);
      goto label_54;

    case 6:
      current_block = (Rpc - LABEL_117_11);
      goto continuation_19;

    case 7:
      current_block = (Rpc - LABEL_117_12);
      goto map_2_26;

    case 8:
      current_block = (Rpc - LABEL_117_14);
      goto label_55;

    case 9:
      current_block = (Rpc - LABEL_117_15);
      goto label_56;

    case 10:
      current_block = (Rpc - LABEL_117_16);
      goto map_n_47;

    case 11:
      current_block = (Rpc - LABEL_117_17);
      goto bad_end_49;

    case 12:
      current_block = (Rpc - LABEL_117_9);
      goto continuation_11;

    case 13:
      current_block = (Rpc - LABEL_117_20);
      goto label_57;

    case 14:
      current_block = (Rpc - LABEL_117_13);
      goto continuation_25;

    case 15:
      current_block = (Rpc - LABEL_117_22);
      goto label_58;

    case 16:
      current_block = (Rpc - LABEL_117_23);
      goto label_59;

    case 17:
      current_block = (Rpc - LABEL_117_24);
      goto continuation_37;

    case 18:
      current_block = (Rpc - LABEL_117_25);
      goto split_45;

    case 19:
      current_block = (Rpc - LABEL_117_26);
      goto label_60;

    case 20:
      current_block = (Rpc - LABEL_117_27);
      goto label_62;

    case 21:
      current_block = (Rpc - LABEL_117_28);
      goto label_63;

    case 22:
      current_block = (Rpc - LABEL_117_29);
      goto label_64;

    case 23:
      current_block = (Rpc - LABEL_117_30);
      goto label_65;

    case 24:
      current_block = (Rpc - LABEL_117_31);
      goto label_66;

    case 25:
      current_block = (Rpc - LABEL_117_32);
      goto label_61;

    case 26:
      current_block = (Rpc - LABEL_117_19);
      goto continuation_9;

    case 27:
      current_block = (Rpc - LABEL_117_21);
      goto continuation_22;

    case 28:
      current_block = (Rpc - LABEL_117_33);
      goto continuation_32;

    case 29:
      current_block = (Rpc - LABEL_117_34);
      goto continuation_31;

    case 30:
      current_block = (Rpc - LABEL_117_37);
      goto continuation_30;

    case 31:
      current_block = (Rpc - LABEL_117_38);
      goto continuation_29;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (append_mapB_68)
DEFLABEL (append_mapB_50)
  INTERRUPT_CHECK (26, LABEL_117_4);
  (Wrd5.Obj) = (Rsp [2]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_74;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rsp));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  Rdl = (& (Rsp [5]));
  goto map_1_12;

DEFLABEL (label_74)
  if (! ((Wrd6.uLng) == 1))
    goto label_79;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd11.Obj) = ((Wrd13.pObj) [1]);

DEFLABEL (label_78)
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd20.uLng) == 1))
    goto label_75;
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (59, Rsp));
  (* (--Rsp)) = (Wrd35.Obj);
  (Wrd39.Obj) = (Rsp [2]);
  (Wrd40.Obj) = (Rsp [3]);
  (* (Rhp++)) = (Wrd39.Obj);
  (* (Rhp++)) = (Wrd40.Obj);
  (Wrd37.pObj) = (& (Rhp [-2]));
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd37.pObj)));
  (* (--Rsp)) = (Wrd38.Obj);
  Rdl = (& (Rsp [5]));
  goto map_n_47;

DEFLABEL (label_75)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (59, Rsp));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd26.Obj) = (Rsp [3]);
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if (! ((Wrd27.uLng) == 1))
    goto label_77;
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd25.Obj) = ((Wrd24.pObj) [0]);
  (* (--Rsp)) = (Wrd25.Obj);

DEFLABEL (label_76)
  (Wrd32.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd32.Obj);
  Rdl = (& (Rsp [6]));
  goto map_2_26;

DEFLABEL (label_77)
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_117_6]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_117_1]), 1);

DEFLABEL (label_53)
  (* (--Rsp)) = Rvl;
  goto label_76;

DEFLABEL (label_79)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_117_5]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_117_0]), 1);

DEFLABEL (label_52)
  (Wrd11.Obj) = Rvl;
  goto label_78;

DEFLABEL (map_1_69)
DEFLABEL (map_1_12)
  DLINK_INTERRUPT_CHECK (25, LABEL_117_8);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_82;
  if (! ((Wrd5.Obj) == (current_block [OBJECT_117_2])))
    goto label_81;

DEFLABEL (label_80)
  Rvl = (current_block [OBJECT_117_2]);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_81)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_117_7]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd15.pObj)));
  (* (--Rsp)) = (Wrd17.Obj);
  goto bad_end_49;

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_117_7);
  (Wrd42.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd42.Obj));
  goto label_80;

DEFLABEL (label_82)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_117_9]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd24.Obj) = (Rsp [3]);
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd25.pObj)));
  (* (--Rsp)) = (Wrd27.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_86;
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd30.Obj) = ((Wrd29.pObj) [1]);
  (* (--Rsp)) = (Wrd30.Obj);

DEFLABEL (label_85)
  Rdl = (& (Rsp [2]));
  goto map_1_12;

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_117_9);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_117_19]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd15.Obj) = (Rsp [3]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 1))
    goto label_84;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_83)
  (Wrd25.Obj) = (Rsp [5]);
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd27.Obj) = ((Wrd26.pObj) [0]);
  (* (--Rsp)) = (Wrd27.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_117_19);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (* (--Rdl)) = (Rsp [1]);
  (* (--Rdl)) = (Rsp [0]);
  Rsp = Rdl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_117_36]));

DEFLABEL (label_84)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_117_20]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd15.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_117_1]), 1);

DEFLABEL (label_57)
  (Wrd17.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd17.Obj));
  (* (--Rsp)) = Rvl;
  goto label_83;

DEFLABEL (label_86)
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_117_10]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_117_0]), 1);

DEFLABEL (label_54)
  (Wrd33.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd33.Obj));
  (* (--Rsp)) = Rvl;
  goto label_85;

DEFLABEL (map_2_70)
DEFLABEL (map_2_26)
  DLINK_INTERRUPT_CHECK (25, LABEL_117_12);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_91;

DEFLABEL (label_90)
  (Wrd7.Obj) = (Rsp [0]);
  if ((Wrd7.Obj) == (current_block [OBJECT_117_2]))
    goto label_89;
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if ((Wrd10.uLng) == 1)
    goto label_89;

DEFLABEL (label_88)
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_117_11]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (Rsp [4]);
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd17.pObj)));
  (* (--Rsp)) = (Wrd19.Obj);
  goto bad_end_49;

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_117_11);
  (Wrd63.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd63.Obj));

DEFLABEL (label_87)
  Rvl = (current_block [OBJECT_117_2]);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_89)
  (Wrd20.Obj) = (Rsp [1]);
  if ((Wrd20.Obj) == (current_block [OBJECT_117_2]))
    goto label_87;
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if ((Wrd23.uLng) == 1)
    goto label_87;
  goto label_88;

DEFLABEL (label_91)
  (Wrd25.Obj) = (Rsp [1]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if (! ((Wrd26.uLng) == 1))
    goto label_90;
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_117_13]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (Wrd32.Obj) = (Rsp [4]);
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd33.pObj)));
  (* (--Rsp)) = (Wrd35.Obj);
  if (! ((Wrd26.uLng) == 1))
    goto label_99;
  (Wrd37.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd38.Obj) = ((Wrd37.pObj) [1]);
  (* (--Rsp)) = (Wrd38.Obj);

DEFLABEL (label_98)
  (Wrd52.Obj) = (Rsp [4]);
  (Wrd53.uLng) = (OBJECT_TYPE (Wrd52.Obj));
  if (! ((Wrd53.uLng) == 1))
    goto label_97;
  (Wrd50.pObj) = (OBJECT_ADDRESS (Wrd52.Obj));
  (Wrd51.Obj) = ((Wrd50.pObj) [1]);
  (* (--Rsp)) = (Wrd51.Obj);

DEFLABEL (label_96)
  Rdl = (& (Rsp [3]));
  goto map_2_26;

DEFLABEL (continuation_25)
  INTERRUPT_CHECK (27, LABEL_117_13);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_117_21]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd15.Obj) = (Rsp [4]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 1))
    goto label_95;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_94)
  (Wrd28.Obj) = (Rsp [4]);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if (! ((Wrd29.uLng) == 1))
    goto label_93;
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd28.Obj));
  (Wrd27.Obj) = ((Wrd26.pObj) [0]);
  (* (--Rsp)) = (Wrd27.Obj);

DEFLABEL (label_92)
  (Wrd38.Obj) = (Rsp [7]);
  (Wrd39.pObj) = (OBJECT_ADDRESS (Wrd38.Obj));
  (Wrd40.Obj) = ((Wrd39.pObj) [0]);
  (* (--Rsp)) = (Wrd40.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_22)
  INTERRUPT_CHECK (27, LABEL_117_21);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (* (--Rdl)) = (Rsp [1]);
  (* (--Rdl)) = (Rsp [0]);
  Rsp = Rdl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_117_36]));

DEFLABEL (label_93)
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_117_23]))));
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_117_1]), 1);

DEFLABEL (label_59)
  (Wrd30.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd30.Obj));
  (* (--Rsp)) = Rvl;
  goto label_92;

DEFLABEL (label_95)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_117_22]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd15.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_117_1]), 1);

DEFLABEL (label_58)
  (Wrd17.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd17.Obj));
  (* (--Rsp)) = Rvl;
  goto label_94;

DEFLABEL (label_97)
  (Wrd57.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd57.Obj);
  (Wrd61.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_117_15]))));
  (* (--Rsp)) = (Wrd61.Obj);
  (* (--Rsp)) = (Wrd52.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_117_0]), 1);

DEFLABEL (label_56)
  (Wrd54.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd54.Obj));
  (* (--Rsp)) = Rvl;
  goto label_96;

DEFLABEL (label_99)
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd48.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_117_14]))));
  (* (--Rsp)) = (Wrd48.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_117_0]), 1);

DEFLABEL (label_55)
  (Wrd41.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd41.Obj));
  (* (--Rsp)) = Rvl;
  goto label_98;

DEFLABEL (map_n_71)
DEFLABEL (map_n_47)
  DLINK_INTERRUPT_CHECK (25, LABEL_117_16);
  (Wrd5.Obj) = (current_block [OBJECT_117_2]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Rsp [2]) = (Wrd5.Obj);
  goto split_45;

DEFLABEL (bad_end_72)
DEFLABEL (bad_end_49)
  INTERRUPT_CHECK (26, LABEL_117_17);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [1]);
  (Wrd13.Obj) = ((Wrd9.pObj) [2]);
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd13.Obj);
  (Wrd6.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd6.pObj)));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_117_3]);
  (Rsp [1]) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_117_18]));

DEFLABEL (split_73)
DEFLABEL (split_45)
  DLINK_INTERRUPT_CHECK (25, LABEL_117_25);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_100;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_117_33]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [5]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd13.pObj)));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_117_34]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd21.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd21.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_117_35]));

DEFLABEL (continuation_31)
  INTERRUPT_CHECK (27, LABEL_117_34);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  Rdl = (& (Rsp [2]));
  goto map_n_47;

DEFLABEL (continuation_32)
  INTERRUPT_CHECK (27, LABEL_117_33);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_117_37]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_117_38]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_117_35]));

DEFLABEL (continuation_29)
  INTERRUPT_CHECK (27, LABEL_117_38);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (Rsp [7]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_117_4]), 2);

DEFLABEL (continuation_30)
  INTERRUPT_CHECK (27, LABEL_117_37);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (* (--Rdl)) = (Rsp [1]);
  (* (--Rdl)) = (Rsp [0]);
  Rsp = Rdl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_117_36]));

DEFLABEL (label_100)
  if (! ((Wrd6.uLng) == 1))
    goto label_117;
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd22.Obj) = ((Wrd24.pObj) [0]);

DEFLABEL (label_116)
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if ((Wrd35.uLng) == 1)
    goto label_105;
  (Wrd39.Obj) = (Rsp [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if (! ((Wrd40.uLng) == 1))
    goto label_104;
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd39.Obj));
  (Wrd36.Obj) = ((Wrd38.pObj) [0]);

DEFLABEL (label_103)
  if (! ((Wrd36.Obj) == (current_block [OBJECT_117_2])))
    goto label_102;

DEFLABEL (label_101)
  Rvl = (current_block [OBJECT_117_2]);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_102)
  (Wrd51.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd51.Obj);
  (Wrd54.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_117_24]))));
  (* (--Rsp)) = (Wrd54.Obj);
  (Wrd55.Obj) = (Rsp [5]);
  (Wrd56.pObj) = (OBJECT_ADDRESS (Wrd55.Obj));
  (Wrd58.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd56.pObj)));
  (* (--Rsp)) = (Wrd58.Obj);
  goto bad_end_49;

DEFLABEL (continuation_37)
  INTERRUPT_CHECK (27, LABEL_117_24);
  (Wrd129.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd129.Obj));
  goto label_101;

DEFLABEL (label_104)
  (Wrd44.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd44.Obj);
  (Wrd48.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_117_32]))));
  (* (--Rsp)) = (Wrd48.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_117_1]), 1);

DEFLABEL (label_61)
  (Wrd41.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd41.Obj));
  (Wrd36.Obj) = Rvl;
  goto label_103;

DEFLABEL (label_105)
  (Wrd63.Obj) = (Rsp [0]);
  (Wrd64.uLng) = (OBJECT_TYPE (Wrd63.Obj));
  if (! ((Wrd64.uLng) == 1))
    goto label_115;
  (Wrd62.pObj) = (OBJECT_ADDRESS (Wrd63.Obj));
  (Wrd60.Obj) = ((Wrd62.pObj) [0]);

DEFLABEL (label_114)
  (Wrd75.uLng) = (OBJECT_TYPE (Wrd60.Obj));
  if (! ((Wrd75.uLng) == 1))
    goto label_113;
  (Wrd74.pObj) = (OBJECT_ADDRESS (Wrd60.Obj));
  (Wrd73.Obj) = ((Wrd74.pObj) [0]);

DEFLABEL (label_112)
  (Wrd87.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd73.Obj);
  (* (Rhp++)) = (Wrd87.Obj);
  (Wrd86.pObj) = (& (Rhp [-2]));
  (Wrd84.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd86.pObj)));
  (Rsp [1]) = (Wrd84.Obj);
  (Wrd91.Obj) = (Rsp [0]);
  (Wrd92.uLng) = (OBJECT_TYPE (Wrd91.Obj));
  if (! ((Wrd92.uLng) == 1))
    goto label_111;
  (Wrd90.pObj) = (OBJECT_ADDRESS (Wrd91.Obj));
  (Wrd88.Obj) = ((Wrd90.pObj) [0]);

DEFLABEL (label_110)
  (Wrd103.uLng) = (OBJECT_TYPE (Wrd88.Obj));
  if (! ((Wrd103.uLng) == 1))
    goto label_109;
  (Wrd102.pObj) = (OBJECT_ADDRESS (Wrd88.Obj));
  (Wrd101.Obj) = ((Wrd102.pObj) [1]);

DEFLABEL (label_108)
  (Wrd115.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd101.Obj);
  (* (Rhp++)) = (Wrd115.Obj);
  (Wrd114.pObj) = (& (Rhp [-2]));
  (Wrd112.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd114.pObj)));
  (Rsp [2]) = (Wrd112.Obj);
  (Wrd119.Obj) = (Rsp [0]);
  (Wrd120.uLng) = (OBJECT_TYPE (Wrd119.Obj));
  if (! ((Wrd120.uLng) == 1))
    goto label_107;
  (Wrd118.pObj) = (OBJECT_ADDRESS (Wrd119.Obj));
  (Wrd116.Obj) = ((Wrd118.pObj) [1]);

DEFLABEL (label_106)
  (Rsp [0]) = (Wrd116.Obj);
  goto split_45;

DEFLABEL (label_107)
  (Wrd124.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd124.Obj);
  (Wrd128.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_117_31]))));
  (* (--Rsp)) = (Wrd128.Obj);
  (* (--Rsp)) = (Wrd119.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_117_0]), 1);

DEFLABEL (label_66)
  (Wrd121.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd121.Obj));
  (Wrd116.Obj) = Rvl;
  goto label_106;

DEFLABEL (label_109)
  (Wrd107.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd107.Obj);
  (Wrd111.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_117_30]))));
  (* (--Rsp)) = (Wrd111.Obj);
  (* (--Rsp)) = (Wrd88.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_117_0]), 1);

DEFLABEL (label_65)
  (Wrd104.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd104.Obj));
  (Wrd101.Obj) = Rvl;
  goto label_108;

DEFLABEL (label_111)
  (Wrd96.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd96.Obj);
  (Wrd100.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_117_29]))));
  (* (--Rsp)) = (Wrd100.Obj);
  (* (--Rsp)) = (Wrd91.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_117_1]), 1);

DEFLABEL (label_64)
  (Wrd93.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd93.Obj));
  (Wrd88.Obj) = Rvl;
  goto label_110;

DEFLABEL (label_113)
  (Wrd79.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd79.Obj);
  (Wrd83.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_117_28]))));
  (* (--Rsp)) = (Wrd83.Obj);
  (* (--Rsp)) = (Wrd60.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_117_1]), 1);

DEFLABEL (label_63)
  (Wrd76.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd76.Obj));
  (Wrd73.Obj) = Rvl;
  goto label_112;

DEFLABEL (label_115)
  (Wrd68.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd68.Obj);
  (Wrd72.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_117_27]))));
  (* (--Rsp)) = (Wrd72.Obj);
  (* (--Rsp)) = (Wrd63.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_117_1]), 1);

DEFLABEL (label_62)
  (Wrd65.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd65.Obj));
  (Wrd60.Obj) = Rvl;
  goto label_114;

DEFLABEL (label_117)
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_117_26]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_117_1]), 1);

DEFLABEL (label_60)
  (Wrd27.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd22.Obj) = Rvl;
  goto label_116;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_118_4 3
#define LABEL_118_5 5
#define LABEL_118_6 7
#define LABEL_118_7 9
#define LABEL_118_8 11
#define LABEL_118_10 13
#define LABEL_118_11 15
#define LABEL_118_12 17
#define LABEL_118_14 19
#define LABEL_118_15 21
#define LABEL_118_16 23
#define LABEL_118_17 25
#define LABEL_118_9 27
#define LABEL_118_20 29
#define LABEL_118_13 31
#define LABEL_118_22 33
#define LABEL_118_23 35
#define LABEL_118_24 37
#define LABEL_118_25 39
#define LABEL_118_26 41
#define LABEL_118_27 43
#define LABEL_118_28 45
#define LABEL_118_29 47
#define LABEL_118_30 49
#define LABEL_118_31 51
#define LABEL_118_32 53
#define LABEL_118_19 55
#define LABEL_118_21 57
#define LABEL_118_33 59
#define LABEL_118_34 61
#define LABEL_118_37 63
#define LABEL_118_38 65
#define ENVIRONMENT_LABEL_118_3 79
#define DEBUGGING_LABEL_118_2 78
#define OBJECT_118_4 77
#define OBJECT_118_3 76
#define OBJECT_118_2 75
#define OBJECT_118_1 74
#define OBJECT_118_0 73
#define EXECUTE_CACHE_118_36 67
#define EXECUTE_CACHE_118_35 69
#define EXECUTE_CACHE_118_18 71
#define FREE_REFERENCES_LABEL_118_0 66
#define NUMBER_OF_LINKER_SECTIONS_118_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_118 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd21;
  machine_word Wrd58;
  machine_word Wrd51;
  machine_word Wrd60;
  machine_word Wrd41;
  machine_word Wrd48;
  machine_word Wrd36;
  machine_word Wrd123;
  machine_word Wrd130;
  machine_word Wrd126;
  machine_word Wrd118;
  machine_word Wrd120;
  machine_word Wrd122;
  machine_word Wrd121;
  machine_word Wrd114;
  machine_word Wrd116;
  machine_word Wrd117;
  machine_word Wrd106;
  machine_word Wrd113;
  machine_word Wrd109;
  machine_word Wrd103;
  machine_word Wrd104;
  machine_word Wrd105;
  machine_word Wrd95;
  machine_word Wrd102;
  machine_word Wrd98;
  machine_word Wrd90;
  machine_word Wrd92;
  machine_word Wrd94;
  machine_word Wrd93;
  machine_word Wrd86;
  machine_word Wrd88;
  machine_word Wrd89;
  machine_word Wrd78;
  machine_word Wrd85;
  machine_word Wrd81;
  machine_word Wrd75;
  machine_word Wrd76;
  machine_word Wrd77;
  machine_word Wrd67;
  machine_word Wrd74;
  machine_word Wrd70;
  machine_word Wrd62;
  machine_word Wrd64;
  machine_word Wrd66;
  machine_word Wrd131;
  machine_word Wrd16;
  machine_word Wrd12;
  machine_word Wrd23;
  machine_word Wrd7;
  machine_word Wrd56;
  machine_word Wrd63;
  machine_word Wrd59;
  machine_word Wrd53;
  machine_word Wrd52;
  machine_word Wrd55;
  machine_word Wrd54;
  machine_word Wrd43;
  machine_word Wrd50;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd28;
  machine_word Wrd65;
  machine_word Wrd17;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd10;
  machine_word Wrd18;
  machine_word Wrd42;
  machine_word Wrd29;
  machine_word Wrd44;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd22;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd35;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd11;
  machine_word Wrd13;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_118_4);
      goto append_map_B_50;

    case 1:
      current_block = (Rpc - LABEL_118_5);
      goto label_52;

    case 2:
      current_block = (Rpc - LABEL_118_6);
      goto label_53;

    case 3:
      current_block = (Rpc - LABEL_118_7);
      goto continuation_7;

    case 4:
      current_block = (Rpc - LABEL_118_8);
      goto map_1_12;

    case 5:
      current_block = (Rpc - LABEL_118_10);
      goto label_54;

    case 6:
      current_block = (Rpc - LABEL_118_11);
      goto continuation_19;

    case 7:
      current_block = (Rpc - LABEL_118_12);
      goto map_2_26;

    case 8:
      current_block = (Rpc - LABEL_118_14);
      goto label_55;

    case 9:
      current_block = (Rpc - LABEL_118_15);
      goto label_56;

    case 10:
      current_block = (Rpc - LABEL_118_16);
      goto map_n_47;

    case 11:
      current_block = (Rpc - LABEL_118_17);
      goto bad_end_49;

    case 12:
      current_block = (Rpc - LABEL_118_9);
      goto continuation_11;

    case 13:
      current_block = (Rpc - LABEL_118_20);
      goto label_57;

    case 14:
      current_block = (Rpc - LABEL_118_13);
      goto continuation_25;

    case 15:
      current_block = (Rpc - LABEL_118_22);
      goto label_58;

    case 16:
      current_block = (Rpc - LABEL_118_23);
      goto label_59;

    case 17:
      current_block = (Rpc - LABEL_118_24);
      goto continuation_37;

    case 18:
      current_block = (Rpc - LABEL_118_25);
      goto split_45;

    case 19:
      current_block = (Rpc - LABEL_118_26);
      goto label_60;

    case 20:
      current_block = (Rpc - LABEL_118_27);
      goto label_62;

    case 21:
      current_block = (Rpc - LABEL_118_28);
      goto label_63;

    case 22:
      current_block = (Rpc - LABEL_118_29);
      goto label_64;

    case 23:
      current_block = (Rpc - LABEL_118_30);
      goto label_65;

    case 24:
      current_block = (Rpc - LABEL_118_31);
      goto label_66;

    case 25:
      current_block = (Rpc - LABEL_118_32);
      goto label_61;

    case 26:
      current_block = (Rpc - LABEL_118_19);
      goto continuation_9;

    case 27:
      current_block = (Rpc - LABEL_118_21);
      goto continuation_22;

    case 28:
      current_block = (Rpc - LABEL_118_33);
      goto continuation_32;

    case 29:
      current_block = (Rpc - LABEL_118_34);
      goto continuation_31;

    case 30:
      current_block = (Rpc - LABEL_118_37);
      goto continuation_30;

    case 31:
      current_block = (Rpc - LABEL_118_38);
      goto continuation_29;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (append_map_B_68)
DEFLABEL (append_map_B_50)
  INTERRUPT_CHECK (26, LABEL_118_4);
  (Wrd5.Obj) = (Rsp [3]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_74;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rsp));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  Rdl = (& (Rsp [6]));
  goto map_1_12;

DEFLABEL (label_74)
  if (! ((Wrd6.uLng) == 1))
    goto label_79;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd11.Obj) = ((Wrd13.pObj) [1]);

DEFLABEL (label_78)
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd20.uLng) == 1))
    goto label_75;
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (59, Rsp));
  (* (--Rsp)) = (Wrd35.Obj);
  (Wrd39.Obj) = (Rsp [3]);
  (Wrd40.Obj) = (Rsp [4]);
  (* (Rhp++)) = (Wrd39.Obj);
  (* (Rhp++)) = (Wrd40.Obj);
  (Wrd37.pObj) = (& (Rhp [-2]));
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd37.pObj)));
  (* (--Rsp)) = (Wrd38.Obj);
  Rdl = (& (Rsp [6]));
  goto map_n_47;

DEFLABEL (label_75)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (59, Rsp));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd26.Obj) = (Rsp [4]);
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if (! ((Wrd27.uLng) == 1))
    goto label_77;
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd25.Obj) = ((Wrd24.pObj) [0]);
  (* (--Rsp)) = (Wrd25.Obj);

DEFLABEL (label_76)
  (Wrd32.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd32.Obj);
  Rdl = (& (Rsp [7]));
  goto map_2_26;

DEFLABEL (label_77)
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_118_6]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_118_1]), 1);

DEFLABEL (label_53)
  (* (--Rsp)) = Rvl;
  goto label_76;

DEFLABEL (label_79)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_118_5]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_118_0]), 1);

DEFLABEL (label_52)
  (Wrd11.Obj) = Rvl;
  goto label_78;

DEFLABEL (map_1_69)
DEFLABEL (map_1_12)
  DLINK_INTERRUPT_CHECK (25, LABEL_118_8);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_82;
  if (! ((Wrd5.Obj) == (current_block [OBJECT_118_2])))
    goto label_81;

DEFLABEL (label_80)
  (Wrd18.Obj) = (Rsp [1]);
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  Rvl = ((Wrd19.pObj) [0]);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_81)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_118_7]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd15.pObj)));
  (* (--Rsp)) = (Wrd17.Obj);
  goto bad_end_49;

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_118_7);
  (Wrd44.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd44.Obj));
  goto label_80;

DEFLABEL (label_82)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_118_9]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd26.Obj) = (Rsp [3]);
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd27.pObj)));
  (* (--Rsp)) = (Wrd29.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_86;
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd32.Obj) = ((Wrd31.pObj) [1]);
  (* (--Rsp)) = (Wrd32.Obj);

DEFLABEL (label_85)
  Rdl = (& (Rsp [2]));
  goto map_1_12;

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_118_9);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_118_19]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd15.Obj) = (Rsp [3]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 1))
    goto label_84;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_83)
  (Wrd25.Obj) = (Rsp [5]);
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd27.Obj) = ((Wrd26.pObj) [1]);
  (* (--Rsp)) = (Wrd27.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_118_19);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (* (--Rdl)) = (Rsp [1]);
  (* (--Rdl)) = (Rsp [0]);
  Rsp = Rdl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_118_36]));

DEFLABEL (label_84)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_118_20]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd15.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_118_1]), 1);

DEFLABEL (label_57)
  (Wrd17.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd17.Obj));
  (* (--Rsp)) = Rvl;
  goto label_83;

DEFLABEL (label_86)
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_118_10]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_118_0]), 1);

DEFLABEL (label_54)
  (Wrd35.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd35.Obj));
  (* (--Rsp)) = Rvl;
  goto label_85;

DEFLABEL (map_2_70)
DEFLABEL (map_2_26)
  DLINK_INTERRUPT_CHECK (25, LABEL_118_12);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_91;

DEFLABEL (label_90)
  (Wrd7.Obj) = (Rsp [0]);
  if ((Wrd7.Obj) == (current_block [OBJECT_118_2]))
    goto label_89;
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if ((Wrd10.uLng) == 1)
    goto label_89;

DEFLABEL (label_88)
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_118_11]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (Rsp [4]);
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd17.pObj)));
  (* (--Rsp)) = (Wrd19.Obj);
  goto bad_end_49;

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_118_11);
  (Wrd65.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd65.Obj));

DEFLABEL (label_87)
  (Wrd24.Obj) = (Rsp [2]);
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  Rvl = ((Wrd25.pObj) [0]);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_89)
  (Wrd20.Obj) = (Rsp [1]);
  if ((Wrd20.Obj) == (current_block [OBJECT_118_2]))
    goto label_87;
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if ((Wrd23.uLng) == 1)
    goto label_87;
  goto label_88;

DEFLABEL (label_91)
  (Wrd27.Obj) = (Rsp [1]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if (! ((Wrd28.uLng) == 1))
    goto label_90;
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_118_13]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd34.Obj) = (Rsp [4]);
  (Wrd35.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd35.pObj)));
  (* (--Rsp)) = (Wrd37.Obj);
  if (! ((Wrd28.uLng) == 1))
    goto label_99;
  (Wrd39.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd40.Obj) = ((Wrd39.pObj) [1]);
  (* (--Rsp)) = (Wrd40.Obj);

DEFLABEL (label_98)
  (Wrd54.Obj) = (Rsp [4]);
  (Wrd55.uLng) = (OBJECT_TYPE (Wrd54.Obj));
  if (! ((Wrd55.uLng) == 1))
    goto label_97;
  (Wrd52.pObj) = (OBJECT_ADDRESS (Wrd54.Obj));
  (Wrd53.Obj) = ((Wrd52.pObj) [1]);
  (* (--Rsp)) = (Wrd53.Obj);

DEFLABEL (label_96)
  Rdl = (& (Rsp [3]));
  goto map_2_26;

DEFLABEL (continuation_25)
  INTERRUPT_CHECK (27, LABEL_118_13);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_118_21]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd15.Obj) = (Rsp [4]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 1))
    goto label_95;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_94)
  (Wrd28.Obj) = (Rsp [4]);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if (! ((Wrd29.uLng) == 1))
    goto label_93;
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd28.Obj));
  (Wrd27.Obj) = ((Wrd26.pObj) [0]);
  (* (--Rsp)) = (Wrd27.Obj);

DEFLABEL (label_92)
  (Wrd38.Obj) = (Rsp [7]);
  (Wrd39.pObj) = (OBJECT_ADDRESS (Wrd38.Obj));
  (Wrd40.Obj) = ((Wrd39.pObj) [1]);
  (* (--Rsp)) = (Wrd40.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_22)
  INTERRUPT_CHECK (27, LABEL_118_21);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (* (--Rdl)) = (Rsp [1]);
  (* (--Rdl)) = (Rsp [0]);
  Rsp = Rdl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_118_36]));

DEFLABEL (label_93)
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_118_23]))));
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_118_1]), 1);

DEFLABEL (label_59)
  (Wrd30.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd30.Obj));
  (* (--Rsp)) = Rvl;
  goto label_92;

DEFLABEL (label_95)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_118_22]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd15.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_118_1]), 1);

DEFLABEL (label_58)
  (Wrd17.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd17.Obj));
  (* (--Rsp)) = Rvl;
  goto label_94;

DEFLABEL (label_97)
  (Wrd59.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd59.Obj);
  (Wrd63.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_118_15]))));
  (* (--Rsp)) = (Wrd63.Obj);
  (* (--Rsp)) = (Wrd54.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_118_0]), 1);

DEFLABEL (label_56)
  (Wrd56.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd56.Obj));
  (* (--Rsp)) = Rvl;
  goto label_96;

DEFLABEL (label_99)
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_118_14]))));
  (* (--Rsp)) = (Wrd50.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_118_0]), 1);

DEFLABEL (label_55)
  (Wrd43.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd43.Obj));
  (* (--Rsp)) = Rvl;
  goto label_98;

DEFLABEL (map_n_71)
DEFLABEL (map_n_47)
  DLINK_INTERRUPT_CHECK (25, LABEL_118_16);
  (Wrd5.Obj) = (current_block [OBJECT_118_2]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Rsp [2]) = (Wrd5.Obj);
  goto split_45;

DEFLABEL (bad_end_72)
DEFLABEL (bad_end_49)
  INTERRUPT_CHECK (26, LABEL_118_17);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [2]);
  (Wrd13.Obj) = ((Wrd9.pObj) [3]);
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd13.Obj);
  (Wrd6.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd6.pObj)));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_118_3]);
  (Rsp [1]) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_118_18]));

DEFLABEL (split_73)
DEFLABEL (split_45)
  DLINK_INTERRUPT_CHECK (25, LABEL_118_25);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_100;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_118_33]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [5]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd13.pObj)));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_118_34]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd21.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd21.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_118_35]));

DEFLABEL (continuation_31)
  INTERRUPT_CHECK (27, LABEL_118_34);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  Rdl = (& (Rsp [2]));
  goto map_n_47;

DEFLABEL (continuation_32)
  INTERRUPT_CHECK (27, LABEL_118_33);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_118_37]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_118_38]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_118_35]));

DEFLABEL (continuation_29)
  INTERRUPT_CHECK (27, LABEL_118_38);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (Rsp [7]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [1]);
  (* (--Rsp)) = (Wrd9.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_118_4]), 2);

DEFLABEL (continuation_30)
  INTERRUPT_CHECK (27, LABEL_118_37);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (* (--Rdl)) = (Rsp [1]);
  (* (--Rdl)) = (Rsp [0]);
  Rsp = Rdl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_118_36]));

DEFLABEL (label_100)
  if (! ((Wrd6.uLng) == 1))
    goto label_117;
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd22.Obj) = ((Wrd24.pObj) [0]);

DEFLABEL (label_116)
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if ((Wrd35.uLng) == 1)
    goto label_105;
  (Wrd39.Obj) = (Rsp [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if (! ((Wrd40.uLng) == 1))
    goto label_104;
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd39.Obj));
  (Wrd36.Obj) = ((Wrd38.pObj) [0]);

DEFLABEL (label_103)
  if (! ((Wrd36.Obj) == (current_block [OBJECT_118_2])))
    goto label_102;

DEFLABEL (label_101)
  (Wrd59.Obj) = (Rsp [3]);
  (Wrd60.pObj) = (OBJECT_ADDRESS (Wrd59.Obj));
  Rvl = ((Wrd60.pObj) [0]);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_102)
  (Wrd51.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd51.Obj);
  (Wrd54.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_118_24]))));
  (* (--Rsp)) = (Wrd54.Obj);
  (Wrd55.Obj) = (Rsp [5]);
  (Wrd56.pObj) = (OBJECT_ADDRESS (Wrd55.Obj));
  (Wrd58.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd56.pObj)));
  (* (--Rsp)) = (Wrd58.Obj);
  goto bad_end_49;

DEFLABEL (continuation_37)
  INTERRUPT_CHECK (27, LABEL_118_24);
  (Wrd131.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd131.Obj));
  goto label_101;

DEFLABEL (label_104)
  (Wrd44.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd44.Obj);
  (Wrd48.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_118_32]))));
  (* (--Rsp)) = (Wrd48.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_118_1]), 1);

DEFLABEL (label_61)
  (Wrd41.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd41.Obj));
  (Wrd36.Obj) = Rvl;
  goto label_103;

DEFLABEL (label_105)
  (Wrd65.Obj) = (Rsp [0]);
  (Wrd66.uLng) = (OBJECT_TYPE (Wrd65.Obj));
  if (! ((Wrd66.uLng) == 1))
    goto label_115;
  (Wrd64.pObj) = (OBJECT_ADDRESS (Wrd65.Obj));
  (Wrd62.Obj) = ((Wrd64.pObj) [0]);

DEFLABEL (label_114)
  (Wrd77.uLng) = (OBJECT_TYPE (Wrd62.Obj));
  if (! ((Wrd77.uLng) == 1))
    goto label_113;
  (Wrd76.pObj) = (OBJECT_ADDRESS (Wrd62.Obj));
  (Wrd75.Obj) = ((Wrd76.pObj) [0]);

DEFLABEL (label_112)
  (Wrd89.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd75.Obj);
  (* (Rhp++)) = (Wrd89.Obj);
  (Wrd88.pObj) = (& (Rhp [-2]));
  (Wrd86.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd88.pObj)));
  (Rsp [1]) = (Wrd86.Obj);
  (Wrd93.Obj) = (Rsp [0]);
  (Wrd94.uLng) = (OBJECT_TYPE (Wrd93.Obj));
  if (! ((Wrd94.uLng) == 1))
    goto label_111;
  (Wrd92.pObj) = (OBJECT_ADDRESS (Wrd93.Obj));
  (Wrd90.Obj) = ((Wrd92.pObj) [0]);

DEFLABEL (label_110)
  (Wrd105.uLng) = (OBJECT_TYPE (Wrd90.Obj));
  if (! ((Wrd105.uLng) == 1))
    goto label_109;
  (Wrd104.pObj) = (OBJECT_ADDRESS (Wrd90.Obj));
  (Wrd103.Obj) = ((Wrd104.pObj) [1]);

DEFLABEL (label_108)
  (Wrd117.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd103.Obj);
  (* (Rhp++)) = (Wrd117.Obj);
  (Wrd116.pObj) = (& (Rhp [-2]));
  (Wrd114.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd116.pObj)));
  (Rsp [2]) = (Wrd114.Obj);
  (Wrd121.Obj) = (Rsp [0]);
  (Wrd122.uLng) = (OBJECT_TYPE (Wrd121.Obj));
  if (! ((Wrd122.uLng) == 1))
    goto label_107;
  (Wrd120.pObj) = (OBJECT_ADDRESS (Wrd121.Obj));
  (Wrd118.Obj) = ((Wrd120.pObj) [1]);

DEFLABEL (label_106)
  (Rsp [0]) = (Wrd118.Obj);
  goto split_45;

DEFLABEL (label_107)
  (Wrd126.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd126.Obj);
  (Wrd130.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_118_31]))));
  (* (--Rsp)) = (Wrd130.Obj);
  (* (--Rsp)) = (Wrd121.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_118_0]), 1);

DEFLABEL (label_66)
  (Wrd123.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd123.Obj));
  (Wrd118.Obj) = Rvl;
  goto label_106;

DEFLABEL (label_109)
  (Wrd109.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd109.Obj);
  (Wrd113.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_118_30]))));
  (* (--Rsp)) = (Wrd113.Obj);
  (* (--Rsp)) = (Wrd90.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_118_0]), 1);

DEFLABEL (label_65)
  (Wrd106.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd106.Obj));
  (Wrd103.Obj) = Rvl;
  goto label_108;

DEFLABEL (label_111)
  (Wrd98.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd98.Obj);
  (Wrd102.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_118_29]))));
  (* (--Rsp)) = (Wrd102.Obj);
  (* (--Rsp)) = (Wrd93.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_118_1]), 1);

DEFLABEL (label_64)
  (Wrd95.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd95.Obj));
  (Wrd90.Obj) = Rvl;
  goto label_110;

DEFLABEL (label_113)
  (Wrd81.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd81.Obj);
  (Wrd85.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_118_28]))));
  (* (--Rsp)) = (Wrd85.Obj);
  (* (--Rsp)) = (Wrd62.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_118_1]), 1);

DEFLABEL (label_63)
  (Wrd78.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd78.Obj));
  (Wrd75.Obj) = Rvl;
  goto label_112;

DEFLABEL (label_115)
  (Wrd70.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd70.Obj);
  (Wrd74.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_118_27]))));
  (* (--Rsp)) = (Wrd74.Obj);
  (* (--Rsp)) = (Wrd65.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_118_1]), 1);

DEFLABEL (label_62)
  (Wrd67.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd67.Obj));
  (Wrd62.Obj) = Rvl;
  goto label_114;

DEFLABEL (label_117)
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_118_26]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_118_1]), 1);

DEFLABEL (label_60)
  (Wrd27.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd22.Obj) = Rvl;
  goto label_116;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_119_5 3
#define LABEL_119_4 5
#define LABEL_119_6 7
#define LABEL_119_7 9
#define ENVIRONMENT_LABEL_119_3 20
#define DEBUGGING_LABEL_119_2 19
#define OBJECT_119_3 18
#define OBJECT_119_2 17
#define OBJECT_119_1 16
#define OBJECT_119_0 15
#define EXECUTE_CACHE_119_9 11
#define EXECUTE_CACHE_119_8 13
#define FREE_REFERENCES_LABEL_119_0 10
#define NUMBER_OF_LINKER_SECTIONS_119_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_119 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd26;
  machine_word Wrd28;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd25;
  machine_word Wrd17;
  machine_word Wrd19;
  machine_word Wrd16;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_119_5);
      goto continuation_2;

    case 1:
      current_block = (Rpc - LABEL_119_4);
      goto reduce_5;

    case 2:
      current_block = (Rpc - LABEL_119_6);
      goto label_7;

    case 3:
      current_block = (Rpc - LABEL_119_7);
      goto label_8;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (reduce_10)
DEFLABEL (reduce_5)
  INTERRUPT_CHECK (26, LABEL_119_4);
  (Wrd5.Obj) = (Rsp [2]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_13;
  if (! ((Wrd5.Obj) == (current_block [OBJECT_119_3])))
    goto label_12;

DEFLABEL (label_11)
  Rvl = (Rsp [1]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_12)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_119_5]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_119_2]);
  (* (--Rsp)) = (Wrd12.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_119_9]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_119_5);
  goto label_11;

DEFLABEL (label_13)
  (Wrd16.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd16.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_17;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd17.Obj) = ((Wrd19.pObj) [0]);

DEFLABEL (label_16)
  (Rsp [1]) = (Wrd17.Obj);
  (Wrd29.Obj) = (Rsp [3]);
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd29.Obj));
  if (! ((Wrd30.uLng) == 1))
    goto label_15;
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd29.Obj));
  (Wrd26.Obj) = ((Wrd28.pObj) [1]);

DEFLABEL (label_14)
  (Rsp [2]) = (Wrd26.Obj);
  (Wrd35.Obj) = (current_block [OBJECT_119_2]);
  (Rsp [3]) = (Wrd35.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_119_8]));

DEFLABEL (label_15)
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_119_7]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd29.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_119_1]), 1);

DEFLABEL (label_8)
  (Wrd26.Obj) = Rvl;
  goto label_14;

DEFLABEL (label_17)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_119_6]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_119_0]), 1);

DEFLABEL (label_7)
  (Wrd17.Obj) = Rvl;
  goto label_16;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_120_4 3
#define LABEL_120_5 5
#define TAG_120_6 1
#define ENVIRONMENT_LABEL_120_3 10
#define DEBUGGING_LABEL_120_2 9
#define EXECUTE_CACHE_120_7 7
#define FREE_REFERENCES_LABEL_120_0 6
#define NUMBER_OF_LINKER_SECTIONS_120_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_120 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_120_4);
      goto reduce_left_1;

    case 1:
      current_block = (Rpc - LABEL_120_5);
      goto lambda_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (reduce_left_4)
DEFLABEL (reduce_left_1)
  INTERRUPT_CHECK (26, LABEL_120_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_120_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_120_5])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  (Rsp [0]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_120_7]));

DEFLABEL (lambda_5)
  CLOSURE_HEADER (LABEL_120_5);

DEFLABEL (lambda_0)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd9.Obj);
  (Rsp [2]) = (Wrd8.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_121_5 3
#define LABEL_121_4 5
#define LABEL_121_6 7
#define LABEL_121_7 9
#define LABEL_121_9 11
#define LABEL_121_10 13
#define LABEL_121_12 15
#define LABEL_121_13 17
#define LABEL_121_11 19
#define ENVIRONMENT_LABEL_121_3 28
#define DEBUGGING_LABEL_121_2 27
#define OBJECT_121_3 26
#define OBJECT_121_2 25
#define OBJECT_121_1 24
#define OBJECT_121_0 23
#define EXECUTE_CACHE_121_8 21
#define FREE_REFERENCES_LABEL_121_0 20
#define NUMBER_OF_LINKER_SECTIONS_121_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_121 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd46;
  machine_word Wrd53;
  machine_word Wrd49;
  machine_word Wrd43;
  machine_word Wrd42;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd33;
  machine_word Wrd40;
  machine_word Wrd27;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd55;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd35;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd26;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd17;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_121_5);
      goto continuation_2;

    case 1:
      current_block = (Rpc - LABEL_121_4);
      goto reduce_right_14;

    case 2:
      current_block = (Rpc - LABEL_121_6);
      goto label_16;

    case 3:
      current_block = (Rpc - LABEL_121_7);
      goto label_17;

    case 4:
      current_block = (Rpc - LABEL_121_9);
      goto continuation_8;

    case 5:
      current_block = (Rpc - LABEL_121_10);
      goto loop_12;

    case 6:
      current_block = (Rpc - LABEL_121_12);
      goto label_18;

    case 7:
      current_block = (Rpc - LABEL_121_13);
      goto label_19;

    case 8:
      current_block = (Rpc - LABEL_121_11);
      goto continuation_11;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (reduce_right_21)
DEFLABEL (reduce_right_14)
  INTERRUPT_CHECK (26, LABEL_121_4);
  (Wrd5.Obj) = (Rsp [2]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_25;
  if (! ((Wrd5.Obj) == (current_block [OBJECT_121_2])))
    goto label_24;

DEFLABEL (label_23)
  Rvl = (Rsp [1]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_24)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_121_5]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_121_3]);
  (* (--Rsp)) = (Wrd12.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_121_8]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_121_5);
  goto label_23;

DEFLABEL (label_25)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (59, Rsp));
  (* (--Rsp)) = (Wrd17.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_29;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [1]);
  (* (--Rsp)) = (Wrd20.Obj);

DEFLABEL (label_28)
  (Wrd30.Obj) = (Rsp [4]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 1))
    goto label_27;
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd29.Obj) = ((Wrd28.pObj) [0]);
  (* (--Rsp)) = (Wrd29.Obj);

DEFLABEL (label_26)
  Rdl = (& (Rsp [6]));
  goto loop_12;

DEFLABEL (label_27)
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_121_7]))));
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_121_1]), 1);

DEFLABEL (label_17)
  (* (--Rsp)) = Rvl;
  goto label_26;

DEFLABEL (label_29)
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_121_6]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_121_0]), 1);

DEFLABEL (label_16)
  (* (--Rsp)) = Rvl;
  goto label_28;

DEFLABEL (loop_22)
DEFLABEL (loop_12)
  DLINK_INTERRUPT_CHECK (25, LABEL_121_10);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_32;
  if (! ((Wrd5.Obj) == (current_block [OBJECT_121_2])))
    goto label_31;

DEFLABEL (label_30)
  Rvl = (Rsp [0]);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_31)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_121_9]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_121_3]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [5]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [2]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_121_8]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_121_9);
  (Wrd55.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd55.Obj));
  goto label_30;

DEFLABEL (label_32)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_121_11]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd24.Obj) = (Rsp [4]);
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd25.pObj)));
  (* (--Rsp)) = (Wrd27.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_36;
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd30.Obj) = ((Wrd29.pObj) [1]);
  (* (--Rsp)) = (Wrd30.Obj);

DEFLABEL (label_35)
  (Wrd44.Obj) = (Rsp [5]);
  (Wrd45.uLng) = (OBJECT_TYPE (Wrd44.Obj));
  if (! ((Wrd45.uLng) == 1))
    goto label_34;
  (Wrd42.pObj) = (OBJECT_ADDRESS (Wrd44.Obj));
  (Wrd43.Obj) = ((Wrd42.pObj) [0]);
  (* (--Rsp)) = (Wrd43.Obj);

DEFLABEL (label_33)
  Rdl = (& (Rsp [3]));
  goto loop_12;

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_121_11);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [4]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [0]);
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rdl)) = (Rsp [2]);
  (* (--Rdl)) = (Rsp [1]);
  (* (--Rdl)) = (Rsp [0]);
  Rsp = Rdl;
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (label_34)
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd49.Obj);
  (Wrd53.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_121_13]))));
  (* (--Rsp)) = (Wrd53.Obj);
  (* (--Rsp)) = (Wrd44.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_121_1]), 1);

DEFLABEL (label_19)
  (Wrd46.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd46.Obj));
  (* (--Rsp)) = Rvl;
  goto label_33;

DEFLABEL (label_36)
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_121_12]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_121_0]), 1);

DEFLABEL (label_18)
  (Wrd33.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd33.Obj));
  (* (--Rsp)) = Rvl;
  goto label_35;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_122_4 3
#define LABEL_122_6 5
#define LABEL_122_7 7
#define LABEL_122_8 9
#define LABEL_122_9 11
#define LABEL_122_10 13
#define LABEL_122_11 15
#define LABEL_122_12 17
#define LABEL_122_13 19
#define LABEL_122_14 21
#define LABEL_122_15 23
#define LABEL_122_17 25
#define LABEL_122_19 27
#define LABEL_122_20 29
#define ENVIRONMENT_LABEL_122_3 43
#define DEBUGGING_LABEL_122_2 42
#define OBJECT_122_4 41
#define OBJECT_122_3 40
#define OBJECT_122_2 39
#define OBJECT_122_1 38
#define OBJECT_122_0 37
#define EXECUTE_CACHE_122_18 31
#define EXECUTE_CACHE_122_16 33
#define EXECUTE_CACHE_122_5 35
#define FREE_REFERENCES_LABEL_122_0 30
#define NUMBER_OF_LINKER_SECTIONS_122_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_122 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd14;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd9;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd29;
  machine_word Wrd21;
  machine_word Wrd23;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd90;
  machine_word Wrd82;
  machine_word Wrd84;
  machine_word Wrd86;
  machine_word Wrd85;
  machine_word Wrd78;
  machine_word Wrd80;
  machine_word Wrd81;
  machine_word Wrd77;
  machine_word Wrd71;
  machine_word Wrd72;
  machine_word Wrd73;
  machine_word Wrd70;
  machine_word Wrd62;
  machine_word Wrd64;
  machine_word Wrd66;
  machine_word Wrd65;
  machine_word Wrd58;
  machine_word Wrd60;
  machine_word Wrd61;
  machine_word Wrd57;
  machine_word Wrd51;
  machine_word Wrd52;
  machine_word Wrd53;
  machine_word Wrd50;
  machine_word Wrd42;
  machine_word Wrd44;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd13;
  machine_word Wrd7;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd12;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_122_4);
      goto fold_26;

    case 1:
      current_block = (Rpc - LABEL_122_6);
      goto loop_24;

    case 2:
      current_block = (Rpc - LABEL_122_7);
      goto continuation_14;

    case 3:
      current_block = (Rpc - LABEL_122_8);
      goto split_22;

    case 4:
      current_block = (Rpc - LABEL_122_9);
      goto label_28;

    case 5:
      current_block = (Rpc - LABEL_122_10);
      goto label_30;

    case 6:
      current_block = (Rpc - LABEL_122_11);
      goto label_31;

    case 7:
      current_block = (Rpc - LABEL_122_12);
      goto label_32;

    case 8:
      current_block = (Rpc - LABEL_122_13);
      goto label_33;

    case 9:
      current_block = (Rpc - LABEL_122_14);
      goto label_34;

    case 10:
      current_block = (Rpc - LABEL_122_15);
      goto label_29;

    case 11:
      current_block = (Rpc - LABEL_122_17);
      goto continuation_5;

    case 12:
      current_block = (Rpc - LABEL_122_19);
      goto continuation_8;

    case 13:
      current_block = (Rpc - LABEL_122_20);
      goto continuation_7;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (fold_36)
DEFLABEL (fold_26)
  INTERRUPT_CHECK (26, LABEL_122_4);
  (Wrd5.Obj) = (Rsp [3]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_39;
  (Wrd7.Obj) = (current_block [OBJECT_122_0]);
  (Rsp [3]) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_122_5]));

DEFLABEL (label_39)
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (Rhp++)) = (Wrd12.Obj);
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd10.pObj) = (& (Rhp [-2]));
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd10.pObj)));
  (* (--Rsp)) = (Wrd11.Obj);
  goto loop_24;

DEFLABEL (loop_37)
DEFLABEL (loop_24)
  INTERRUPT_CHECK (26, LABEL_122_6);
  (Wrd5.Obj) = (current_block [OBJECT_122_1]);
  (* (--Rsp)) = (Wrd5.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd7.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  goto split_22;

DEFLABEL (split_38)
DEFLABEL (split_22)
  INTERRUPT_CHECK (26, LABEL_122_8);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_40;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_122_17]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_122_18]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_122_17);
  (Rsp [3]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_122_19]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_122_20]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd15.Obj) = (Rsp [6]);
  (Wrd16.Obj) = (Rsp [3]);
  (* (Rhp++)) = (Wrd15.Obj);
  (* (Rhp++)) = (Wrd16.Obj);
  (Wrd13.pObj) = (& (Rhp [-2]));
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd13.pObj)));
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_122_18]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_122_20);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_122_4]), 2);

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_122_19);
  (Rsp [4]) = Rvl;
  Rsp = (& (Rsp [3]));
  goto loop_24;

DEFLABEL (label_40)
  if (! ((Wrd6.uLng) == 1))
    goto label_57;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd11.Obj) = ((Wrd13.pObj) [0]);

DEFLABEL (label_56)
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if ((Wrd20.uLng) == 1)
    goto label_45;
  (Wrd24.Obj) = (Rsp [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if (! ((Wrd25.uLng) == 1))
    goto label_44;
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd21.Obj) = ((Wrd23.pObj) [0]);

DEFLABEL (label_43)
  if (! ((Wrd21.Obj) == (current_block [OBJECT_122_1])))
    goto label_42;

DEFLABEL (label_41)
  Rvl = (Rsp [4]);
  Rsp = (& (Rsp [9]));
  goto pop_return;

DEFLABEL (label_42)
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_122_7]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd34.Obj) = (current_block [OBJECT_122_0]);
  (* (--Rsp)) = (Wrd34.Obj);
  (Wrd38.Obj) = (Rsp [9]);
  (Wrd39.Obj) = (Rsp [10]);
  (* (Rhp++)) = (Wrd38.Obj);
  (* (Rhp++)) = (Wrd39.Obj);
  (Wrd36.pObj) = (& (Rhp [-2]));
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd36.pObj)));
  (* (--Rsp)) = (Wrd37.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_122_16]));

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_122_7);
  goto label_41;

DEFLABEL (label_44)
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_122_15]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_122_2]), 1);

DEFLABEL (label_29)
  (Wrd21.Obj) = Rvl;
  goto label_43;

DEFLABEL (label_45)
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.uLng) = (OBJECT_TYPE (Wrd45.Obj));
  if (! ((Wrd46.uLng) == 1))
    goto label_55;
  (Wrd44.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd42.Obj) = ((Wrd44.pObj) [0]);

DEFLABEL (label_54)
  (Wrd53.uLng) = (OBJECT_TYPE (Wrd42.Obj));
  if (! ((Wrd53.uLng) == 1))
    goto label_53;
  (Wrd52.pObj) = (OBJECT_ADDRESS (Wrd42.Obj));
  (Wrd51.Obj) = ((Wrd52.pObj) [0]);

DEFLABEL (label_52)
  (Wrd61.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd51.Obj);
  (* (Rhp++)) = (Wrd61.Obj);
  (Wrd60.pObj) = (& (Rhp [-2]));
  (Wrd58.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd60.pObj)));
  (Rsp [1]) = (Wrd58.Obj);
  (Wrd65.Obj) = (Rsp [0]);
  (Wrd66.uLng) = (OBJECT_TYPE (Wrd65.Obj));
  if (! ((Wrd66.uLng) == 1))
    goto label_51;
  (Wrd64.pObj) = (OBJECT_ADDRESS (Wrd65.Obj));
  (Wrd62.Obj) = ((Wrd64.pObj) [0]);

DEFLABEL (label_50)
  (Wrd73.uLng) = (OBJECT_TYPE (Wrd62.Obj));
  if (! ((Wrd73.uLng) == 1))
    goto label_49;
  (Wrd72.pObj) = (OBJECT_ADDRESS (Wrd62.Obj));
  (Wrd71.Obj) = ((Wrd72.pObj) [1]);

DEFLABEL (label_48)
  (Wrd81.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd71.Obj);
  (* (Rhp++)) = (Wrd81.Obj);
  (Wrd80.pObj) = (& (Rhp [-2]));
  (Wrd78.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd80.pObj)));
  (Rsp [2]) = (Wrd78.Obj);
  (Wrd85.Obj) = (Rsp [0]);
  (Wrd86.uLng) = (OBJECT_TYPE (Wrd85.Obj));
  if (! ((Wrd86.uLng) == 1))
    goto label_47;
  (Wrd84.pObj) = (OBJECT_ADDRESS (Wrd85.Obj));
  (Wrd82.Obj) = ((Wrd84.pObj) [1]);

DEFLABEL (label_46)
  (Rsp [0]) = (Wrd82.Obj);
  goto split_22;

DEFLABEL (label_47)
  (Wrd90.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_122_14]))));
  (* (--Rsp)) = (Wrd90.Obj);
  (* (--Rsp)) = (Wrd85.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_122_3]), 1);

DEFLABEL (label_34)
  (Wrd82.Obj) = Rvl;
  goto label_46;

DEFLABEL (label_49)
  (Wrd77.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_122_13]))));
  (* (--Rsp)) = (Wrd77.Obj);
  (* (--Rsp)) = (Wrd62.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_122_3]), 1);

DEFLABEL (label_33)
  (Wrd71.Obj) = Rvl;
  goto label_48;

DEFLABEL (label_51)
  (Wrd70.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_122_12]))));
  (* (--Rsp)) = (Wrd70.Obj);
  (* (--Rsp)) = (Wrd65.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_122_2]), 1);

DEFLABEL (label_32)
  (Wrd62.Obj) = Rvl;
  goto label_50;

DEFLABEL (label_53)
  (Wrd57.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_122_11]))));
  (* (--Rsp)) = (Wrd57.Obj);
  (* (--Rsp)) = (Wrd42.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_122_2]), 1);

DEFLABEL (label_31)
  (Wrd51.Obj) = Rvl;
  goto label_52;

DEFLABEL (label_55)
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_122_10]))));
  (* (--Rsp)) = (Wrd50.Obj);
  (* (--Rsp)) = (Wrd45.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_122_2]), 1);

DEFLABEL (label_30)
  (Wrd42.Obj) = Rvl;
  goto label_54;

DEFLABEL (label_57)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_122_9]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_122_2]), 1);

DEFLABEL (label_28)
  (Wrd11.Obj) = Rvl;
  goto label_56;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_123_4 3
#define LABEL_123_5 5
#define LABEL_123_6 7
#define LABEL_123_8 9
#define LABEL_123_7 11
#define LABEL_123_10 13
#define ENVIRONMENT_LABEL_123_3 21
#define DEBUGGING_LABEL_123_2 20
#define OBJECT_123_2 19
#define OBJECT_123_1 18
#define OBJECT_123_0 17
#define EXECUTE_CACHE_123_9 15
#define FREE_REFERENCES_LABEL_123_0 14
#define NUMBER_OF_LINKER_SECTIONS_123_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_123 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd14;
  machine_word Wrd8;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_123_4);
      goto Z__fold_1_9;

    case 1:
      current_block = (Rpc - LABEL_123_5);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_123_6);
      goto loop_7;

    case 3:
      current_block = (Rpc - LABEL_123_8);
      goto label_11;

    case 4:
      current_block = (Rpc - LABEL_123_7);
      goto continuation_5;

    case 5:
      current_block = (Rpc - LABEL_123_10);
      goto label_12;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (Z__fold_1_14)
DEFLABEL (Z__fold_1_9)
  INTERRUPT_CHECK (26, LABEL_123_4);
  (Wrd5.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd6.Obj);
  goto loop_7;

DEFLABEL (loop_15)
DEFLABEL (loop_7)
  INTERRUPT_CHECK (26, LABEL_123_6);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_18;
  if (! ((Wrd5.Obj) == (current_block [OBJECT_123_1])))
    goto label_17;

DEFLABEL (label_16)
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [6]));
  goto pop_return;

DEFLABEL (label_17)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_123_5]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_123_9]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_123_5);
  goto label_16;

DEFLABEL (label_18)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_123_7]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd19.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd19.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_22;
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd22.Obj) = ((Wrd21.pObj) [0]);
  (* (--Rsp)) = (Wrd22.Obj);

DEFLABEL (label_21)
  (Wrd29.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd29.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_123_7);
  (Rsp [0]) = Rvl;
  (Wrd9.Obj) = (Rsp [1]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if (! ((Wrd10.uLng) == 1))
    goto label_20;
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [1]);

DEFLABEL (label_19)
  (Rsp [1]) = (Wrd6.Obj);
  goto loop_7;

DEFLABEL (label_20)
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_123_10]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_123_2]), 1);

DEFLABEL (label_12)
  (Wrd6.Obj) = Rvl;
  goto label_19;

DEFLABEL (label_22)
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_123_8]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_123_0]), 1);

DEFLABEL (label_11)
  (* (--Rsp)) = Rvl;
  goto label_21;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_124_4 3
#define LABEL_124_5 5
#define TAG_124_6 1
#define ENVIRONMENT_LABEL_124_3 11
#define DEBUGGING_LABEL_124_2 10
#define OBJECT_124_0 9
#define EXECUTE_CACHE_124_7 7
#define FREE_REFERENCES_LABEL_124_0 6
#define NUMBER_OF_LINKER_SECTIONS_124_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_124 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd5;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_124_4);
      goto fold_left_1;

    case 1:
      current_block = (Rpc - LABEL_124_5);
      goto lambda_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (fold_left_4)
DEFLABEL (fold_left_1)
  INTERRUPT_CHECK (26, LABEL_124_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd6.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_124_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_124_5])));
  Rhp += 1;
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd6.pObj)));
  Wrd7 = Wrd6;
  (Wrd8.Obj) = (Rsp [0]);
  ((Wrd7.pObj) [2]) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (Rsp [2]) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_124_0]);
  (Rsp [3]) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_124_7]));

DEFLABEL (lambda_5)
  CLOSURE_HEADER (LABEL_124_5);

DEFLABEL (lambda_0)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd9.Obj);
  (Rsp [2]) = (Wrd8.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_125_4 3
#define LABEL_125_5 5
#define LABEL_125_6 7
#define LABEL_125_8 9
#define LABEL_125_10 11
#define LABEL_125_7 13
#define LABEL_125_11 15
#define LABEL_125_12 17
#define LABEL_125_13 19
#define LABEL_125_14 21
#define LABEL_125_15 23
#define LABEL_125_16 25
#define LABEL_125_17 27
#define LABEL_125_18 29
#define LABEL_125_19 31
#define LABEL_125_20 33
#define LABEL_125_22 35
#define LABEL_125_23 37
#define LABEL_125_24 39
#define ENVIRONMENT_LABEL_125_3 53
#define DEBUGGING_LABEL_125_2 52
#define OBJECT_125_4 51
#define OBJECT_125_3 50
#define OBJECT_125_2 49
#define OBJECT_125_1 48
#define OBJECT_125_0 47
#define EXECUTE_CACHE_125_25 41
#define EXECUTE_CACHE_125_21 43
#define EXECUTE_CACHE_125_9 45
#define FREE_REFERENCES_LABEL_125_0 40
#define NUMBER_OF_LINKER_SECTIONS_125_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_125 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd7;
  machine_word Wrd63;
  machine_word Wrd62;
  machine_word Wrd69;
  machine_word Wrd66;
  machine_word Wrd65;
  machine_word Wrd64;
  machine_word Wrd60;
  machine_word Wrd59;
  machine_word Wrd56;
  machine_word Wrd71;
  machine_word Wrd70;
  machine_word Wrd46;
  machine_word Wrd53;
  machine_word Wrd49;
  machine_word Wrd41;
  machine_word Wrd43;
  machine_word Wrd45;
  machine_word Wrd134;
  machine_word Wrd141;
  machine_word Wrd137;
  machine_word Wrd129;
  machine_word Wrd131;
  machine_word Wrd133;
  machine_word Wrd132;
  machine_word Wrd125;
  machine_word Wrd127;
  machine_word Wrd128;
  machine_word Wrd117;
  machine_word Wrd124;
  machine_word Wrd120;
  machine_word Wrd114;
  machine_word Wrd115;
  machine_word Wrd116;
  machine_word Wrd106;
  machine_word Wrd113;
  machine_word Wrd109;
  machine_word Wrd101;
  machine_word Wrd103;
  machine_word Wrd105;
  machine_word Wrd104;
  machine_word Wrd97;
  machine_word Wrd99;
  machine_word Wrd100;
  machine_word Wrd89;
  machine_word Wrd96;
  machine_word Wrd92;
  machine_word Wrd86;
  machine_word Wrd87;
  machine_word Wrd88;
  machine_word Wrd78;
  machine_word Wrd85;
  machine_word Wrd81;
  machine_word Wrd73;
  machine_word Wrd75;
  machine_word Wrd77;
  machine_word Wrd76;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd142;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd11;
  machine_word Wrd17;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd35;
  machine_word Wrd42;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd29;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd44;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd16;
  machine_word Wrd12;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_125_4);
      goto fold_right_35;

    case 1:
      current_block = (Rpc - LABEL_125_5);
      goto continuation_4;

    case 2:
      current_block = (Rpc - LABEL_125_6);
      goto loop_8;

    case 3:
      current_block = (Rpc - LABEL_125_8);
      goto label_37;

    case 4:
      current_block = (Rpc - LABEL_125_10);
      goto loop_33;

    case 5:
      current_block = (Rpc - LABEL_125_7);
      goto continuation_7;

    case 6:
      current_block = (Rpc - LABEL_125_11);
      goto label_38;

    case 7:
      current_block = (Rpc - LABEL_125_12);
      goto continuation_23;

    case 8:
      current_block = (Rpc - LABEL_125_13);
      goto split_31;

    case 9:
      current_block = (Rpc - LABEL_125_14);
      goto label_39;

    case 10:
      current_block = (Rpc - LABEL_125_15);
      goto label_41;

    case 11:
      current_block = (Rpc - LABEL_125_16);
      goto label_42;

    case 12:
      current_block = (Rpc - LABEL_125_17);
      goto label_43;

    case 13:
      current_block = (Rpc - LABEL_125_18);
      goto label_44;

    case 14:
      current_block = (Rpc - LABEL_125_19);
      goto label_45;

    case 15:
      current_block = (Rpc - LABEL_125_20);
      goto label_40;

    case 16:
      current_block = (Rpc - LABEL_125_22);
      goto continuation_17;

    case 17:
      current_block = (Rpc - LABEL_125_23);
      goto continuation_15;

    case 18:
      current_block = (Rpc - LABEL_125_24);
      goto continuation_14;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (fold_right_47)
DEFLABEL (fold_right_35)
  INTERRUPT_CHECK (26, LABEL_125_4);
  (Wrd5.Obj) = (Rsp [3]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_51;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rsp));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  Rdl = (& (Rsp [6]));
  goto loop_8;

DEFLABEL (label_51)
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (59, Rsp));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd16.Obj) = (Rsp [3]);
  (* (Rhp++)) = (Wrd16.Obj);
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd14.pObj) = (& (Rhp [-2]));
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd14.pObj)));
  (* (--Rsp)) = (Wrd15.Obj);
  Rdl = (& (Rsp [6]));
  goto loop_33;

DEFLABEL (loop_48)
DEFLABEL (loop_8)
  DLINK_INTERRUPT_CHECK (25, LABEL_125_6);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_54;
  if (! ((Wrd5.Obj) == (current_block [OBJECT_125_1])))
    goto label_53;

DEFLABEL (label_52)
  (Wrd18.Obj) = (Rsp [1]);
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  Rvl = ((Wrd19.pObj) [1]);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_53)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_125_5]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_125_2]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [4]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [2]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_125_9]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_125_5);
  (Wrd44.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd44.Obj));
  goto label_52;

DEFLABEL (label_54)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_125_7]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd26.Obj) = (Rsp [3]);
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd27.pObj)));
  (* (--Rsp)) = (Wrd29.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_58;
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd32.Obj) = ((Wrd31.pObj) [1]);
  (* (--Rsp)) = (Wrd32.Obj);

DEFLABEL (label_57)
  Rdl = (& (Rsp [2]));
  goto loop_8;

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_125_7);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd10.Obj) = (Rsp [1]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_56;
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_55)
  (Wrd20.Obj) = (Rsp [3]);
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd22.Obj) = ((Wrd21.pObj) [0]);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rdl)) = (Rsp [2]);
  (* (--Rdl)) = (Rsp [1]);
  (* (--Rdl)) = (Rsp [0]);
  Rsp = Rdl;
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (label_56)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_125_11]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_125_3]), 1);

DEFLABEL (label_38)
  (Wrd12.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd12.Obj));
  (* (--Rsp)) = Rvl;
  goto label_55;

DEFLABEL (label_58)
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_125_8]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_125_0]), 1);

DEFLABEL (label_37)
  (Wrd35.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd35.Obj));
  (* (--Rsp)) = Rvl;
  goto label_57;

DEFLABEL (loop_49)
DEFLABEL (loop_33)
  DLINK_INTERRUPT_CHECK (25, LABEL_125_10);
  (Wrd5.Obj) = (current_block [OBJECT_125_1]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Rsp [2]) = (Wrd5.Obj);
  goto split_31;

DEFLABEL (split_50)
DEFLABEL (split_31)
  DLINK_INTERRUPT_CHECK (25, LABEL_125_13);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_59;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_125_22]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_125_23]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (Rsp [7]);
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd18.pObj)));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_125_24]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd26.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd26.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_125_25]));

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_125_24);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  Rdl = (& (Rsp [2]));
  goto loop_33;

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_125_23);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd11.Obj) = (Rsp [3]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_125_25]));

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_125_22);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (Rsp [4]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rdl)) = (Rsp [1]);
  (* (--Rdl)) = (Rsp [0]);
  Rsp = Rdl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_125_4]), 2);

DEFLABEL (label_59)
  if (! ((Wrd6.uLng) == 1))
    goto label_76;
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd27.Obj) = ((Wrd29.pObj) [0]);

DEFLABEL (label_75)
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if ((Wrd40.uLng) == 1)
    goto label_64;
  (Wrd44.Obj) = (Rsp [0]);
  (Wrd45.uLng) = (OBJECT_TYPE (Wrd44.Obj));
  if (! ((Wrd45.uLng) == 1))
    goto label_63;
  (Wrd43.pObj) = (OBJECT_ADDRESS (Wrd44.Obj));
  (Wrd41.Obj) = ((Wrd43.pObj) [0]);

DEFLABEL (label_62)
  if (! ((Wrd41.Obj) == (current_block [OBJECT_125_1])))
    goto label_61;

DEFLABEL (label_60)
  (Wrd70.Obj) = (Rsp [3]);
  (Wrd71.pObj) = (OBJECT_ADDRESS (Wrd70.Obj));
  Rvl = ((Wrd71.pObj) [1]);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_61)
  (Wrd56.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd56.Obj);
  (Wrd59.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_125_12]))));
  (* (--Rsp)) = (Wrd59.Obj);
  (Wrd60.Obj) = (current_block [OBJECT_125_2]);
  (* (--Rsp)) = (Wrd60.Obj);
  (Wrd64.Obj) = (Rsp [6]);
  (Wrd65.pObj) = (OBJECT_ADDRESS (Wrd64.Obj));
  (Wrd66.Obj) = ((Wrd65.pObj) [2]);
  (Wrd69.Obj) = ((Wrd65.pObj) [3]);
  (* (Rhp++)) = (Wrd66.Obj);
  (* (Rhp++)) = (Wrd69.Obj);
  (Wrd62.pObj) = (& (Rhp [-2]));
  (Wrd63.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd62.pObj)));
  (* (--Rsp)) = (Wrd63.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_125_21]));

DEFLABEL (continuation_23)
  INTERRUPT_CHECK (27, LABEL_125_12);
  (Wrd142.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd142.Obj));
  goto label_60;

DEFLABEL (label_63)
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd49.Obj);
  (Wrd53.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_125_20]))));
  (* (--Rsp)) = (Wrd53.Obj);
  (* (--Rsp)) = (Wrd44.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_125_3]), 1);

DEFLABEL (label_40)
  (Wrd46.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd46.Obj));
  (Wrd41.Obj) = Rvl;
  goto label_62;

DEFLABEL (label_64)
  (Wrd76.Obj) = (Rsp [0]);
  (Wrd77.uLng) = (OBJECT_TYPE (Wrd76.Obj));
  if (! ((Wrd77.uLng) == 1))
    goto label_74;
  (Wrd75.pObj) = (OBJECT_ADDRESS (Wrd76.Obj));
  (Wrd73.Obj) = ((Wrd75.pObj) [0]);

DEFLABEL (label_73)
  (Wrd88.uLng) = (OBJECT_TYPE (Wrd73.Obj));
  if (! ((Wrd88.uLng) == 1))
    goto label_72;
  (Wrd87.pObj) = (OBJECT_ADDRESS (Wrd73.Obj));
  (Wrd86.Obj) = ((Wrd87.pObj) [0]);

DEFLABEL (label_71)
  (Wrd100.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd86.Obj);
  (* (Rhp++)) = (Wrd100.Obj);
  (Wrd99.pObj) = (& (Rhp [-2]));
  (Wrd97.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd99.pObj)));
  (Rsp [1]) = (Wrd97.Obj);
  (Wrd104.Obj) = (Rsp [0]);
  (Wrd105.uLng) = (OBJECT_TYPE (Wrd104.Obj));
  if (! ((Wrd105.uLng) == 1))
    goto label_70;
  (Wrd103.pObj) = (OBJECT_ADDRESS (Wrd104.Obj));
  (Wrd101.Obj) = ((Wrd103.pObj) [0]);

DEFLABEL (label_69)
  (Wrd116.uLng) = (OBJECT_TYPE (Wrd101.Obj));
  if (! ((Wrd116.uLng) == 1))
    goto label_68;
  (Wrd115.pObj) = (OBJECT_ADDRESS (Wrd101.Obj));
  (Wrd114.Obj) = ((Wrd115.pObj) [1]);

DEFLABEL (label_67)
  (Wrd128.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd114.Obj);
  (* (Rhp++)) = (Wrd128.Obj);
  (Wrd127.pObj) = (& (Rhp [-2]));
  (Wrd125.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd127.pObj)));
  (Rsp [2]) = (Wrd125.Obj);
  (Wrd132.Obj) = (Rsp [0]);
  (Wrd133.uLng) = (OBJECT_TYPE (Wrd132.Obj));
  if (! ((Wrd133.uLng) == 1))
    goto label_66;
  (Wrd131.pObj) = (OBJECT_ADDRESS (Wrd132.Obj));
  (Wrd129.Obj) = ((Wrd131.pObj) [1]);

DEFLABEL (label_65)
  (Rsp [0]) = (Wrd129.Obj);
  goto split_31;

DEFLABEL (label_66)
  (Wrd137.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd137.Obj);
  (Wrd141.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_125_19]))));
  (* (--Rsp)) = (Wrd141.Obj);
  (* (--Rsp)) = (Wrd132.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_125_0]), 1);

DEFLABEL (label_45)
  (Wrd134.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd134.Obj));
  (Wrd129.Obj) = Rvl;
  goto label_65;

DEFLABEL (label_68)
  (Wrd120.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd120.Obj);
  (Wrd124.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_125_18]))));
  (* (--Rsp)) = (Wrd124.Obj);
  (* (--Rsp)) = (Wrd101.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_125_0]), 1);

DEFLABEL (label_44)
  (Wrd117.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd117.Obj));
  (Wrd114.Obj) = Rvl;
  goto label_67;

DEFLABEL (label_70)
  (Wrd109.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd109.Obj);
  (Wrd113.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_125_17]))));
  (* (--Rsp)) = (Wrd113.Obj);
  (* (--Rsp)) = (Wrd104.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_125_3]), 1);

DEFLABEL (label_43)
  (Wrd106.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd106.Obj));
  (Wrd101.Obj) = Rvl;
  goto label_69;

DEFLABEL (label_72)
  (Wrd92.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd92.Obj);
  (Wrd96.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_125_16]))));
  (* (--Rsp)) = (Wrd96.Obj);
  (* (--Rsp)) = (Wrd73.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_125_3]), 1);

DEFLABEL (label_42)
  (Wrd89.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd89.Obj));
  (Wrd86.Obj) = Rvl;
  goto label_71;

DEFLABEL (label_74)
  (Wrd81.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd81.Obj);
  (Wrd85.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_125_15]))));
  (* (--Rsp)) = (Wrd85.Obj);
  (* (--Rsp)) = (Wrd76.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_125_3]), 1);

DEFLABEL (label_41)
  (Wrd78.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd78.Obj));
  (Wrd73.Obj) = Rvl;
  goto label_73;

DEFLABEL (label_76)
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd35.Obj);
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_125_14]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_125_3]), 1);

DEFLABEL (label_39)
  (Wrd32.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd27.Obj) = Rvl;
  goto label_75;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_126_4 3
#define LABEL_126_5 5
#define LABEL_126_6 7
#define LABEL_126_8 9
#define LABEL_126_7 11
#define LABEL_126_10 13
#define ENVIRONMENT_LABEL_126_3 22
#define DEBUGGING_LABEL_126_2 21
#define OBJECT_126_3 20
#define OBJECT_126_2 19
#define OBJECT_126_1 18
#define OBJECT_126_0 17
#define EXECUTE_CACHE_126_9 15
#define FREE_REFERENCES_LABEL_126_0 14
#define NUMBER_OF_LINKER_SECTIONS_126_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_126 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd7;
  machine_word Wrd23;
  machine_word Wrd15;
  machine_word Wrd17;
  machine_word Wrd19;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_126_4);
      goto find_matching_item_9;

    case 1:
      current_block = (Rpc - LABEL_126_5);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_126_6);
      goto loop_7;

    case 3:
      current_block = (Rpc - LABEL_126_8);
      goto label_11;

    case 4:
      current_block = (Rpc - LABEL_126_7);
      goto continuation_5;

    case 5:
      current_block = (Rpc - LABEL_126_10);
      goto label_12;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (find_matching_item_14)
DEFLABEL (find_matching_item_9)
  INTERRUPT_CHECK (26, LABEL_126_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  goto loop_7;

DEFLABEL (loop_15)
DEFLABEL (loop_7)
  INTERRUPT_CHECK (26, LABEL_126_6);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_18;
  if (! ((Wrd5.Obj) == (current_block [OBJECT_126_1])))
    goto label_17;

DEFLABEL (label_16)
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_17)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_126_5]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_126_2]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_126_9]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_126_5);
  goto label_16;

DEFLABEL (label_18)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_126_7]))));
  (* (--Rsp)) = (Wrd18.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_24;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [0]);
  (* (--Rsp)) = (Wrd21.Obj);

DEFLABEL (label_23)
  (Wrd28.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd28.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_126_7);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_20;
  (Wrd7.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd7.Obj);
  Rsp = (& (Rsp [2]));
  (Wrd12.Obj) = (Rsp [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_19;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  Rvl = ((Wrd10.pObj) [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_19)
  INVOKE_PRIMITIVE ((current_block [OBJECT_126_0]), 1);

DEFLABEL (label_20)
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd19.uLng) == 1))
    goto label_22;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd15.Obj) = ((Wrd17.pObj) [1]);

DEFLABEL (label_21)
  (Rsp [0]) = (Wrd15.Obj);
  goto loop_7;

DEFLABEL (label_22)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_126_10]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_126_3]), 1);

DEFLABEL (label_12)
  (Wrd15.Obj) = Rvl;
  goto label_21;

DEFLABEL (label_24)
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_126_8]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_126_0]), 1);

DEFLABEL (label_11)
  (* (--Rsp)) = Rvl;
  goto label_23;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_127_4 3
#define LABEL_127_5 5
#define LABEL_127_6 7
#define LABEL_127_8 9
#define LABEL_127_7 11
#define LABEL_127_10 13
#define ENVIRONMENT_LABEL_127_3 22
#define DEBUGGING_LABEL_127_2 21
#define OBJECT_127_3 20
#define OBJECT_127_2 19
#define OBJECT_127_1 18
#define OBJECT_127_0 17
#define EXECUTE_CACHE_127_9 15
#define FREE_REFERENCES_LABEL_127_0 14
#define NUMBER_OF_LINKER_SECTIONS_127_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_127 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd15;
  machine_word Wrd7;
  machine_word Wrd9;
  machine_word Wrd10;
  machine_word Wrd19;
  machine_word Wrd22;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_127_4);
      goto find_non_matching_item_9;

    case 1:
      current_block = (Rpc - LABEL_127_5);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_127_6);
      goto loop_7;

    case 3:
      current_block = (Rpc - LABEL_127_8);
      goto label_11;

    case 4:
      current_block = (Rpc - LABEL_127_7);
      goto continuation_5;

    case 5:
      current_block = (Rpc - LABEL_127_10);
      goto label_12;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (find_non_matching_item_14)
DEFLABEL (find_non_matching_item_9)
  INTERRUPT_CHECK (26, LABEL_127_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  goto loop_7;

DEFLABEL (loop_15)
DEFLABEL (loop_7)
  INTERRUPT_CHECK (26, LABEL_127_6);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_18;
  if (! ((Wrd5.Obj) == (current_block [OBJECT_127_1])))
    goto label_17;

DEFLABEL (label_16)
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_17)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_127_5]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_127_2]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_127_9]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_127_5);
  goto label_16;

DEFLABEL (label_18)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_127_7]))));
  (* (--Rsp)) = (Wrd18.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_24;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [0]);
  (* (--Rsp)) = (Wrd21.Obj);

DEFLABEL (label_23)
  (Wrd28.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd28.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_127_7);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_21;
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_20;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_19)
  (Rsp [0]) = (Wrd7.Obj);
  goto loop_7;

DEFLABEL (label_20)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_127_10]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_127_3]), 1);

DEFLABEL (label_12)
  (Wrd7.Obj) = Rvl;
  goto label_19;

DEFLABEL (label_21)
  (Wrd16.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd16.Obj);
  Rsp = (& (Rsp [2]));
  (Wrd21.Obj) = (Rsp [0]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if (! ((Wrd22.uLng) == 1))
    goto label_22;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  Rvl = ((Wrd19.pObj) [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_22)
  INVOKE_PRIMITIVE ((current_block [OBJECT_127_0]), 1);

DEFLABEL (label_24)
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_127_8]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_127_0]), 1);

DEFLABEL (label_11)
  (* (--Rsp)) = Rvl;
  goto label_23;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_128_4 3
#define LABEL_128_5 5
#define LABEL_128_6 7
#define LABEL_128_8 9
#define LABEL_128_7 11
#define LABEL_128_10 13
#define LABEL_128_12 15
#define LABEL_128_11 17
#define ENVIRONMENT_LABEL_128_3 28
#define DEBUGGING_LABEL_128_2 27
#define OBJECT_128_3 26
#define OBJECT_128_2 25
#define OBJECT_128_1 24
#define OBJECT_128_0 23
#define EXECUTE_CACHE_128_13 19
#define EXECUTE_CACHE_128_9 21
#define FREE_REFERENCES_LABEL_128_0 18
#define NUMBER_OF_LINKER_SECTIONS_128_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_128 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd19;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd22;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_128_4);
      goto find_unique_matching_item_11;

    case 1:
      current_block = (Rpc - LABEL_128_5);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_128_6);
      goto loop_9;

    case 3:
      current_block = (Rpc - LABEL_128_8);
      goto label_13;

    case 4:
      current_block = (Rpc - LABEL_128_7);
      goto continuation_5;

    case 5:
      current_block = (Rpc - LABEL_128_10);
      goto label_15;

    case 6:
      current_block = (Rpc - LABEL_128_12);
      goto label_14;

    case 7:
      current_block = (Rpc - LABEL_128_11);
      goto continuation_8;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (find_unique_matching_item_17)
DEFLABEL (find_unique_matching_item_11)
  INTERRUPT_CHECK (26, LABEL_128_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  goto loop_9;

DEFLABEL (loop_18)
DEFLABEL (loop_9)
  INTERRUPT_CHECK (26, LABEL_128_6);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_21;
  if (! ((Wrd5.Obj) == (current_block [OBJECT_128_1])))
    goto label_20;

DEFLABEL (label_19)
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_20)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_128_5]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_128_2]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_128_9]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_128_5);
  goto label_19;

DEFLABEL (label_21)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_128_7]))));
  (* (--Rsp)) = (Wrd18.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_30;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [0]);
  (* (--Rsp)) = (Wrd21.Obj);

DEFLABEL (label_29)
  (Wrd28.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd28.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_128_7);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_26;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_128_11]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd14.Obj) = (Rsp [2]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 1))
    goto label_25;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [1]);
  (* (--Rsp)) = (Wrd13.Obj);

DEFLABEL (label_24)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_128_13]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_128_11);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_22;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_22)
  (Wrd9.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd9.Obj);
  Rsp = (& (Rsp [2]));
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 1))
    goto label_23;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  Rvl = ((Wrd12.pObj) [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_23)
  INVOKE_PRIMITIVE ((current_block [OBJECT_128_0]), 1);

DEFLABEL (label_25)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_128_12]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd14.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_128_3]), 1);

DEFLABEL (label_14)
  (* (--Rsp)) = Rvl;
  goto label_24;

DEFLABEL (label_26)
  (Wrd23.Obj) = (Rsp [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd24.uLng) == 1))
    goto label_28;
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd20.Obj) = ((Wrd22.pObj) [1]);

DEFLABEL (label_27)
  (Rsp [0]) = (Wrd20.Obj);
  goto loop_9;

DEFLABEL (label_28)
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_128_10]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_128_3]), 1);

DEFLABEL (label_15)
  (Wrd20.Obj) = Rvl;
  goto label_27;

DEFLABEL (label_30)
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_128_8]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_128_0]), 1);

DEFLABEL (label_13)
  (* (--Rsp)) = Rvl;
  goto label_29;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_129_4 3
#define LABEL_129_5 5
#define LABEL_129_6 7
#define LABEL_129_8 9
#define LABEL_129_7 11
#define LABEL_129_11 13
#define LABEL_129_13 15
#define LABEL_129_10 17
#define ENVIRONMENT_LABEL_129_3 28
#define DEBUGGING_LABEL_129_2 27
#define OBJECT_129_3 26
#define OBJECT_129_2 25
#define OBJECT_129_1 24
#define OBJECT_129_0 23
#define EXECUTE_CACHE_129_12 19
#define EXECUTE_CACHE_129_9 21
#define FREE_REFERENCES_LABEL_129_0 18
#define NUMBER_OF_LINKER_SECTIONS_129_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_129 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd15;
  machine_word Wrd7;
  machine_word Wrd9;
  machine_word Wrd10;
  machine_word Wrd22;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd19;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_129_4);
      goto find_unique_non_matching_item_11;

    case 1:
      current_block = (Rpc - LABEL_129_5);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_129_6);
      goto loop_9;

    case 3:
      current_block = (Rpc - LABEL_129_8);
      goto label_13;

    case 4:
      current_block = (Rpc - LABEL_129_7);
      goto continuation_5;

    case 5:
      current_block = (Rpc - LABEL_129_11);
      goto label_15;

    case 6:
      current_block = (Rpc - LABEL_129_13);
      goto label_14;

    case 7:
      current_block = (Rpc - LABEL_129_10);
      goto continuation_7;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (find_unique_non_matching_item_17)
DEFLABEL (find_unique_non_matching_item_11)
  INTERRUPT_CHECK (26, LABEL_129_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  goto loop_9;

DEFLABEL (loop_18)
DEFLABEL (loop_9)
  INTERRUPT_CHECK (26, LABEL_129_6);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_21;
  if (! ((Wrd5.Obj) == (current_block [OBJECT_129_1])))
    goto label_20;

DEFLABEL (label_19)
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_20)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_129_5]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_129_2]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_129_9]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_129_5);
  goto label_19;

DEFLABEL (label_21)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_129_7]))));
  (* (--Rsp)) = (Wrd18.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_30;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [0]);
  (* (--Rsp)) = (Wrd21.Obj);

DEFLABEL (label_29)
  (Wrd28.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd28.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_129_7);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_24;
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_23;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_22)
  (Rsp [0]) = (Wrd7.Obj);
  goto loop_9;

DEFLABEL (label_23)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_129_13]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_129_3]), 1);

DEFLABEL (label_14)
  (Wrd7.Obj) = Rvl;
  goto label_22;

DEFLABEL (label_24)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_129_10]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd19.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd23.Obj) = (Rsp [2]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd24.uLng) == 1))
    goto label_28;
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd22.Obj) = ((Wrd21.pObj) [1]);
  (* (--Rsp)) = (Wrd22.Obj);

DEFLABEL (label_27)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_129_12]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_129_10);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_25;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_25)
  (Wrd7.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd7.Obj);
  Rsp = (& (Rsp [2]));
  (Wrd12.Obj) = (Rsp [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_26;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  Rvl = ((Wrd10.pObj) [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_26)
  INVOKE_PRIMITIVE ((current_block [OBJECT_129_0]), 1);

DEFLABEL (label_28)
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_129_11]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_129_3]), 1);

DEFLABEL (label_15)
  (* (--Rsp)) = Rvl;
  goto label_27;

DEFLABEL (label_30)
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_129_8]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_129_0]), 1);

DEFLABEL (label_13)
  (* (--Rsp)) = Rvl;
  goto label_29;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_130_4 3
#define LABEL_130_5 5
#define LABEL_130_6 7
#define LABEL_130_8 9
#define LABEL_130_7 11
#define LABEL_130_10 13
#define ENVIRONMENT_LABEL_130_3 23
#define DEBUGGING_LABEL_130_2 22
#define OBJECT_130_4 21
#define OBJECT_130_3 20
#define OBJECT_130_2 19
#define OBJECT_130_1 18
#define OBJECT_130_0 17
#define EXECUTE_CACHE_130_9 15
#define FREE_REFERENCES_LABEL_130_0 14
#define NUMBER_OF_LINKER_SECTIONS_130_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_130 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd19;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_130_4);
      goto count_matching_items_10;

    case 1:
      current_block = (Rpc - LABEL_130_5);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_130_6);
      goto do_loop_8;

    case 3:
      current_block = (Rpc - LABEL_130_8);
      goto label_12;

    case 4:
      current_block = (Rpc - LABEL_130_7);
      goto continuation_6;

    case 5:
      current_block = (Rpc - LABEL_130_10);
      goto label_13;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (count_matching_items_15)
DEFLABEL (count_matching_items_10)
  INTERRUPT_CHECK (26, LABEL_130_4);
  (Wrd5.Obj) = (current_block [OBJECT_130_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd6.Obj);
  goto do_loop_8;

DEFLABEL (do_loop_16)
DEFLABEL (do_loop_8)
  INTERRUPT_CHECK (26, LABEL_130_6);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_19;
  if (! ((Wrd5.Obj) == (current_block [OBJECT_130_2])))
    goto label_18;

DEFLABEL (label_17)
  Rvl = (Rsp [1]);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_18)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_130_5]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_130_3]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_130_9]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_130_5);
  goto label_17;

DEFLABEL (label_19)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_130_7]))));
  (* (--Rsp)) = (Wrd18.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_26;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [0]);
  (* (--Rsp)) = (Wrd21.Obj);

DEFLABEL (label_25)
  (Wrd28.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd28.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_130_7);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_21;
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.Lng) = (FIXNUM_TO_LONG (Wrd8.Obj));
  (Wrd10.Lng) = ((Wrd9.Lng) + 1L);
  (Wrd7.Obj) = (LONG_TO_FIXNUM (Wrd10.Lng));
  goto label_20;

DEFLABEL (label_21)
  (Wrd7.Obj) = (Rsp [1]);

DEFLABEL (label_20)
DEFLABEL (label_24)
  (Rsp [1]) = (Wrd7.Obj);
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 1))
    goto label_23;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd11.Obj) = ((Wrd13.pObj) [1]);

DEFLABEL (label_22)
  (Rsp [0]) = (Wrd11.Obj);
  goto do_loop_8;

DEFLABEL (label_23)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_130_10]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd14.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_130_4]), 1);

DEFLABEL (label_13)
  (Wrd11.Obj) = Rvl;
  goto label_22;

DEFLABEL (label_26)
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_130_8]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_130_1]), 1);

DEFLABEL (label_12)
  (* (--Rsp)) = Rvl;
  goto label_25;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_131_4 3
#define LABEL_131_5 5
#define LABEL_131_6 7
#define LABEL_131_8 9
#define LABEL_131_7 11
#define LABEL_131_10 13
#define ENVIRONMENT_LABEL_131_3 23
#define DEBUGGING_LABEL_131_2 22
#define OBJECT_131_4 21
#define OBJECT_131_3 20
#define OBJECT_131_2 19
#define OBJECT_131_1 18
#define OBJECT_131_0 17
#define EXECUTE_CACHE_131_9 15
#define FREE_REFERENCES_LABEL_131_0 14
#define NUMBER_OF_LINKER_SECTIONS_131_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_131 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd8;
  machine_word Wrd10;
  machine_word Wrd7;
  machine_word Wrd19;
  machine_word Wrd17;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_131_4);
      goto count_non_matching_items_10;

    case 1:
      current_block = (Rpc - LABEL_131_5);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_131_6);
      goto do_loop_8;

    case 3:
      current_block = (Rpc - LABEL_131_8);
      goto label_12;

    case 4:
      current_block = (Rpc - LABEL_131_7);
      goto continuation_6;

    case 5:
      current_block = (Rpc - LABEL_131_10);
      goto label_13;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (count_non_matching_items_15)
DEFLABEL (count_non_matching_items_10)
  INTERRUPT_CHECK (26, LABEL_131_4);
  (Wrd5.Obj) = (current_block [OBJECT_131_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd6.Obj);
  goto do_loop_8;

DEFLABEL (do_loop_16)
DEFLABEL (do_loop_8)
  INTERRUPT_CHECK (26, LABEL_131_6);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_19;
  if (! ((Wrd5.Obj) == (current_block [OBJECT_131_2])))
    goto label_18;

DEFLABEL (label_17)
  Rvl = (Rsp [1]);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_18)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_131_5]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_131_3]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_131_9]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_131_5);
  goto label_17;

DEFLABEL (label_19)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_131_7]))));
  (* (--Rsp)) = (Wrd18.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_26;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [0]);
  (* (--Rsp)) = (Wrd21.Obj);

DEFLABEL (label_25)
  (Wrd28.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd28.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_131_7);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_21;
  (Wrd7.Obj) = (Rsp [1]);
  goto label_20;

DEFLABEL (label_21)
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  (Wrd19.Lng) = ((Wrd18.Lng) + 1L);
  (Wrd7.Obj) = (LONG_TO_FIXNUM (Wrd19.Lng));

DEFLABEL (label_20)
DEFLABEL (label_24)
  (Rsp [1]) = (Wrd7.Obj);
  (Wrd11.Obj) = (Rsp [0]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd12.uLng) == 1))
    goto label_23;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd8.Obj) = ((Wrd10.pObj) [1]);

DEFLABEL (label_22)
  (Rsp [0]) = (Wrd8.Obj);
  goto do_loop_8;

DEFLABEL (label_23)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_131_10]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_131_4]), 1);

DEFLABEL (label_13)
  (Wrd8.Obj) = Rvl;
  goto label_22;

DEFLABEL (label_26)
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_131_8]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_131_1]), 1);

DEFLABEL (label_12)
  (* (--Rsp)) = Rvl;
  goto label_25;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_132_4 3
#define LABEL_132_5 5
#define LABEL_132_7 7
#define LABEL_132_8 9
#define LABEL_132_10 11
#define LABEL_132_12 13
#define LABEL_132_6 15
#define LABEL_132_14 17
#define LABEL_132_13 19
#define LABEL_132_11 21
#define LABEL_132_15 23
#define LABEL_132_16 25
#define LABEL_132_17 27
#define LABEL_132_18 29
#define ENVIRONMENT_LABEL_132_3 39
#define DEBUGGING_LABEL_132_2 38
#define OBJECT_132_4 37
#define OBJECT_132_3 36
#define OBJECT_132_2 35
#define OBJECT_132_1 34
#define OBJECT_132_0 33
#define EXECUTE_CACHE_132_9 31
#define FREE_REFERENCES_LABEL_132_0 30
#define NUMBER_OF_LINKER_SECTIONS_132_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_132 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd49;
  machine_word Wrd43;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd15;
  machine_word Wrd17;
  machine_word Wrd9;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd23;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd31;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd10;
  machine_word Wrd39;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd29;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd26;
  machine_word Wrd22;
  machine_word Wrd14;
  machine_word Wrd16;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_132_4);
      goto keep_matching_items_24;

    case 1:
      current_block = (Rpc - LABEL_132_5);
      goto label_26;

    case 2:
      current_block = (Rpc - LABEL_132_7);
      goto label_27;

    case 3:
      current_block = (Rpc - LABEL_132_8);
      goto lambda_0;

    case 4:
      current_block = (Rpc - LABEL_132_10);
      goto loop_18;

    case 5:
      current_block = (Rpc - LABEL_132_12);
      goto label_29;

    case 6:
      current_block = (Rpc - LABEL_132_6);
      goto continuation_6;

    case 7:
      current_block = (Rpc - LABEL_132_14);
      goto label_28;

    case 8:
      current_block = (Rpc - LABEL_132_13);
      goto continuation_21;

    case 9:
      current_block = (Rpc - LABEL_132_11);
      goto continuation_11;

    case 10:
      current_block = (Rpc - LABEL_132_15);
      goto label_33;

    case 11:
      current_block = (Rpc - LABEL_132_16);
      goto label_30;

    case 12:
      current_block = (Rpc - LABEL_132_17);
      goto label_32;

    case 13:
      current_block = (Rpc - LABEL_132_18);
      goto label_31;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (keep_matching_items_35)
DEFLABEL (keep_matching_items_24)
  INTERRUPT_CHECK (26, LABEL_132_4);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_39;
  if ((Wrd5.Obj) == (current_block [OBJECT_132_1]))
    goto label_38;
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, Rsp));
  (* (--Rsp)) = (Wrd10.Obj);
  Rdl = (& (Rsp [3]));
  goto lambda_0;

DEFLABEL (label_38)
  Rvl = (Wrd5.Obj);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_39)
  if (! ((Wrd6.uLng) == 1))
    goto label_48;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd14.Obj) = ((Wrd16.pObj) [0]);

DEFLABEL (label_47)
  (Wrd26.Obj) = (current_block [OBJECT_132_1]);
  (* (Rhp++)) = (Wrd14.Obj);
  (* (Rhp++)) = (Wrd26.Obj);
  (Wrd24.pObj) = (& (Rhp [-2]));
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd24.pObj)));
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_132_6]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd34.Obj) = (Rsp [3]);
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if (! ((Wrd35.uLng) == 1))
    goto label_46;
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd33.Obj) = ((Wrd32.pObj) [1]);
  (* (--Rsp)) = (Wrd33.Obj);

DEFLABEL (label_45)
  goto loop_18;

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_132_6);

DEFLABEL (label_44)
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_132_13]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd12.uLng) == 1))
    goto label_43;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [0]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_42)
  (Wrd17.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd17.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_21)
  INTERRUPT_CHECK (27, LABEL_132_13);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_40;
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_40)
  (Wrd9.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd9.Obj);
  Rsp = (& (Rsp [2]));
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 1))
    goto label_41;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  Rvl = ((Wrd12.pObj) [1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_41)
  INVOKE_PRIMITIVE ((current_block [OBJECT_132_2]), 1);

DEFLABEL (label_43)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_132_14]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_132_0]), 1);

DEFLABEL (label_28)
  (* (--Rsp)) = Rvl;
  goto label_42;

DEFLABEL (label_46)
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_132_7]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_132_2]), 1);

DEFLABEL (label_27)
  (* (--Rsp)) = Rvl;
  goto label_45;

DEFLABEL (label_48)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_132_5]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_132_0]), 1);

DEFLABEL (label_26)
  (Wrd14.Obj) = Rvl;
  goto label_47;

DEFLABEL (lambda_36)
DEFLABEL (lambda_0)
  DLINK_INTERRUPT_CHECK (25, LABEL_132_8);
  (Wrd5.Obj) = (current_block [OBJECT_132_3]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd8.Obj) = ((Wrd7.pObj) [0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rdl)) = (Rsp [1]);
  (* (--Rdl)) = (Rsp [0]);
  Rsp = Rdl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_132_9]));

DEFLABEL (loop_37)
DEFLABEL (loop_18)
  INTERRUPT_CHECK (26, LABEL_132_10);
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 1)
    goto label_50;
  if ((Wrd18.Obj) == (current_block [OBJECT_132_1]))
    goto label_49;
  (Wrd23.pObj) = (& (Rsp [4]));
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd23.pObj)));
  (Rsp [1]) = (Wrd25.Obj);
  Rdl = (& (Rsp [2]));
  Rsp = (& (Rsp [1]));
  goto lambda_0;

DEFLABEL (label_49)
  Rsp = (& (Rsp [3]));
  goto label_44;

DEFLABEL (label_50)
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_132_11]))));
  (* (--Rsp)) = (Wrd31.Obj);
  if (! ((Wrd19.uLng) == 1))
    goto label_61;
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd34.Obj) = ((Wrd33.pObj) [0]);
  (* (--Rsp)) = (Wrd34.Obj);

DEFLABEL (label_60)
  (Wrd41.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd41.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_132_11);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_57;
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_56;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [0]);

DEFLABEL (label_55)
  (Wrd19.Obj) = (current_block [OBJECT_132_1]);
  (* (Rhp++)) = (Wrd7.Obj);
  (* (Rhp++)) = (Wrd19.Obj);
  (Wrd17.pObj) = (& (Rhp [-2]));
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd17.pObj)));
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd34.Obj) = (Rsp [2]);
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if (! ((Wrd35.uLng) == 1))
    goto label_54;
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  ((Wrd32.pObj) [1]) = (Wrd18.Obj);

DEFLABEL (label_53)
  (Wrd23.Obj) = (Rsp [1]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd24.uLng) == 1))
    goto label_52;
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd20.Obj) = ((Wrd22.pObj) [1]);

DEFLABEL (label_51)
  (Rsp [1]) = (Wrd20.Obj);
  (Wrd29.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd29.Obj);
  Rsp = (& (Rsp [1]));
  goto loop_18;

DEFLABEL (label_52)
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_132_18]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_132_2]), 1);

DEFLABEL (label_31)
  (Wrd20.Obj) = Rvl;
  goto label_51;

DEFLABEL (label_54)
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_132_17]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_132_4]), 2);

DEFLABEL (label_32)
  goto label_53;

DEFLABEL (label_56)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_132_16]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_132_0]), 1);

DEFLABEL (label_30)
  (Wrd7.Obj) = Rvl;
  goto label_55;

DEFLABEL (label_57)
  (Wrd44.Obj) = (Rsp [0]);
  (Wrd45.uLng) = (OBJECT_TYPE (Wrd44.Obj));
  if (! ((Wrd45.uLng) == 1))
    goto label_59;
  (Wrd43.pObj) = (OBJECT_ADDRESS (Wrd44.Obj));
  (Wrd41.Obj) = ((Wrd43.pObj) [1]);

DEFLABEL (label_58)
  (Rsp [0]) = (Wrd41.Obj);
  goto loop_18;

DEFLABEL (label_59)
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_132_15]))));
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd44.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_132_2]), 1);

DEFLABEL (label_33)
  (Wrd41.Obj) = Rvl;
  goto label_58;

DEFLABEL (label_61)
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_132_12]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_132_0]), 1);

DEFLABEL (label_29)
  (* (--Rsp)) = Rvl;
  goto label_60;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_133_4 3
#define LABEL_133_5 5
#define LABEL_133_7 7
#define LABEL_133_8 9
#define LABEL_133_10 11
#define LABEL_133_12 13
#define LABEL_133_6 15
#define LABEL_133_14 17
#define LABEL_133_13 19
#define LABEL_133_11 21
#define LABEL_133_15 23
#define LABEL_133_16 25
#define LABEL_133_17 27
#define LABEL_133_18 29
#define ENVIRONMENT_LABEL_133_3 39
#define DEBUGGING_LABEL_133_2 38
#define OBJECT_133_4 37
#define OBJECT_133_3 36
#define OBJECT_133_2 35
#define OBJECT_133_1 34
#define OBJECT_133_0 33
#define EXECUTE_CACHE_133_9 31
#define FREE_REFERENCES_LABEL_133_0 30
#define NUMBER_OF_LINKER_SECTIONS_133_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_133 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd15;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd49;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd27;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd13;
  machine_word Wrd17;
  machine_word Wrd9;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd23;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd31;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd10;
  machine_word Wrd39;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd29;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd26;
  machine_word Wrd22;
  machine_word Wrd14;
  machine_word Wrd16;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_133_4);
      goto delete_matching_items_24;

    case 1:
      current_block = (Rpc - LABEL_133_5);
      goto label_26;

    case 2:
      current_block = (Rpc - LABEL_133_7);
      goto label_27;

    case 3:
      current_block = (Rpc - LABEL_133_8);
      goto lambda_0;

    case 4:
      current_block = (Rpc - LABEL_133_10);
      goto loop_18;

    case 5:
      current_block = (Rpc - LABEL_133_12);
      goto label_29;

    case 6:
      current_block = (Rpc - LABEL_133_6);
      goto continuation_6;

    case 7:
      current_block = (Rpc - LABEL_133_14);
      goto label_28;

    case 8:
      current_block = (Rpc - LABEL_133_13);
      goto continuation_21;

    case 9:
      current_block = (Rpc - LABEL_133_11);
      goto continuation_11;

    case 10:
      current_block = (Rpc - LABEL_133_15);
      goto label_31;

    case 11:
      current_block = (Rpc - LABEL_133_16);
      goto label_33;

    case 12:
      current_block = (Rpc - LABEL_133_17);
      goto label_32;

    case 13:
      current_block = (Rpc - LABEL_133_18);
      goto label_30;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (delete_matching_items_35)
DEFLABEL (delete_matching_items_24)
  INTERRUPT_CHECK (26, LABEL_133_4);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_39;
  if ((Wrd5.Obj) == (current_block [OBJECT_133_1]))
    goto label_38;
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, Rsp));
  (* (--Rsp)) = (Wrd10.Obj);
  Rdl = (& (Rsp [3]));
  goto lambda_0;

DEFLABEL (label_38)
  Rvl = (Wrd5.Obj);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_39)
  if (! ((Wrd6.uLng) == 1))
    goto label_48;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd14.Obj) = ((Wrd16.pObj) [0]);

DEFLABEL (label_47)
  (Wrd26.Obj) = (current_block [OBJECT_133_1]);
  (* (Rhp++)) = (Wrd14.Obj);
  (* (Rhp++)) = (Wrd26.Obj);
  (Wrd24.pObj) = (& (Rhp [-2]));
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd24.pObj)));
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_133_6]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd34.Obj) = (Rsp [3]);
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if (! ((Wrd35.uLng) == 1))
    goto label_46;
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd33.Obj) = ((Wrd32.pObj) [1]);
  (* (--Rsp)) = (Wrd33.Obj);

DEFLABEL (label_45)
  goto loop_18;

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_133_6);

DEFLABEL (label_44)
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_133_13]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd12.uLng) == 1))
    goto label_43;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [0]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_42)
  (Wrd17.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd17.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_21)
  INTERRUPT_CHECK (27, LABEL_133_13);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_40;
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_40)
  (Wrd7.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd7.Obj);
  Rsp = (& (Rsp [2]));
  (Wrd12.Obj) = (Rsp [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_41;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  Rvl = ((Wrd10.pObj) [1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_41)
  INVOKE_PRIMITIVE ((current_block [OBJECT_133_2]), 1);

DEFLABEL (label_43)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_133_14]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_133_0]), 1);

DEFLABEL (label_28)
  (* (--Rsp)) = Rvl;
  goto label_42;

DEFLABEL (label_46)
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_133_7]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_133_2]), 1);

DEFLABEL (label_27)
  (* (--Rsp)) = Rvl;
  goto label_45;

DEFLABEL (label_48)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_133_5]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_133_0]), 1);

DEFLABEL (label_26)
  (Wrd14.Obj) = Rvl;
  goto label_47;

DEFLABEL (lambda_36)
DEFLABEL (lambda_0)
  DLINK_INTERRUPT_CHECK (25, LABEL_133_8);
  (Wrd5.Obj) = (current_block [OBJECT_133_3]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd8.Obj) = ((Wrd7.pObj) [0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rdl)) = (Rsp [1]);
  (* (--Rdl)) = (Rsp [0]);
  Rsp = Rdl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_133_9]));

DEFLABEL (loop_37)
DEFLABEL (loop_18)
  INTERRUPT_CHECK (26, LABEL_133_10);
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 1)
    goto label_50;
  if ((Wrd18.Obj) == (current_block [OBJECT_133_1]))
    goto label_49;
  (Wrd23.pObj) = (& (Rsp [4]));
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd23.pObj)));
  (Rsp [1]) = (Wrd25.Obj);
  Rdl = (& (Rsp [2]));
  Rsp = (& (Rsp [1]));
  goto lambda_0;

DEFLABEL (label_49)
  Rsp = (& (Rsp [3]));
  goto label_44;

DEFLABEL (label_50)
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_133_11]))));
  (* (--Rsp)) = (Wrd31.Obj);
  if (! ((Wrd19.uLng) == 1))
    goto label_61;
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd34.Obj) = ((Wrd33.pObj) [0]);
  (* (--Rsp)) = (Wrd34.Obj);

DEFLABEL (label_60)
  (Wrd41.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd41.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_133_11);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_53;
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_52;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_51)
  (Rsp [0]) = (Wrd7.Obj);
  goto loop_18;

DEFLABEL (label_52)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_133_18]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_133_2]), 1);

DEFLABEL (label_30)
  (Wrd7.Obj) = Rvl;
  goto label_51;

DEFLABEL (label_53)
  (Wrd19.Obj) = (Rsp [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 1))
    goto label_59;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd16.Obj) = ((Wrd18.pObj) [0]);

DEFLABEL (label_58)
  (Wrd28.Obj) = (current_block [OBJECT_133_1]);
  (* (Rhp++)) = (Wrd16.Obj);
  (* (Rhp++)) = (Wrd28.Obj);
  (Wrd26.pObj) = (& (Rhp [-2]));
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd26.pObj)));
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd43.Obj) = (Rsp [2]);
  (Wrd44.uLng) = (OBJECT_TYPE (Wrd43.Obj));
  if (! ((Wrd44.uLng) == 1))
    goto label_57;
  (Wrd41.pObj) = (OBJECT_ADDRESS (Wrd43.Obj));
  ((Wrd41.pObj) [1]) = (Wrd27.Obj);

DEFLABEL (label_56)
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd33.uLng) == 1))
    goto label_55;
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd29.Obj) = ((Wrd31.pObj) [1]);

DEFLABEL (label_54)
  (Rsp [1]) = (Wrd29.Obj);
  (Wrd38.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd38.Obj);
  Rsp = (& (Rsp [1]));
  goto loop_18;

DEFLABEL (label_55)
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_133_17]))));
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_133_2]), 1);

DEFLABEL (label_32)
  (Wrd29.Obj) = Rvl;
  goto label_54;

DEFLABEL (label_57)
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_133_16]))));
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd43.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_133_4]), 2);

DEFLABEL (label_33)
  goto label_56;

DEFLABEL (label_59)
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_133_15]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_133_0]), 1);

DEFLABEL (label_31)
  (Wrd16.Obj) = Rvl;
  goto label_58;

DEFLABEL (label_61)
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_133_12]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_133_0]), 1);

DEFLABEL (label_29)
  (* (--Rsp)) = Rvl;
  goto label_60;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_134_4 3
#define LABEL_134_5 5
#define LABEL_134_6 7
#define LABEL_134_8 9
#define LABEL_134_9 11
#define LABEL_134_7 13
#define LABEL_134_12 15
#define LABEL_134_13 17
#define LABEL_134_14 19
#define LABEL_134_15 21
#define LABEL_134_17 23
#define LABEL_134_11 25
#define LABEL_134_16 27
#define LABEL_134_18 29
#define LABEL_134_19 31
#define ENVIRONMENT_LABEL_134_3 41
#define DEBUGGING_LABEL_134_2 40
#define OBJECT_134_4 39
#define OBJECT_134_3 38
#define OBJECT_134_2 37
#define OBJECT_134_1 36
#define OBJECT_134_0 35
#define EXECUTE_CACHE_134_10 33
#define FREE_REFERENCES_LABEL_134_0 32
#define NUMBER_OF_LINKER_SECTIONS_134_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_134 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd22;
  machine_word Wrd18;
  machine_word Wrd27;
  machine_word Wrd24;
  machine_word Wrd16;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd41;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd21;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd12;
  machine_word Wrd32;
  machine_word Wrd28;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd8;
  machine_word Wrd17;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd29;
  machine_word Wrd36;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd5;
  machine_word Wrd40;
  machine_word Wrd7;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_134_4);
      goto delete_matching_itemsB_19;

    case 1:
      current_block = (Rpc - LABEL_134_5);
      goto continuation_2;

    case 2:
      current_block = (Rpc - LABEL_134_6);
      goto lambda_8;

    case 3:
      current_block = (Rpc - LABEL_134_8);
      goto label_21;

    case 4:
      current_block = (Rpc - LABEL_134_9);
      goto lambda_17;

    case 5:
      current_block = (Rpc - LABEL_134_7);
      goto continuation_4;

    case 6:
      current_block = (Rpc - LABEL_134_12);
      goto label_23;

    case 7:
      current_block = (Rpc - LABEL_134_13);
      goto label_22;

    case 8:
      current_block = (Rpc - LABEL_134_14);
      goto continuation_15;

    case 9:
      current_block = (Rpc - LABEL_134_15);
      goto lambda_16;

    case 10:
      current_block = (Rpc - LABEL_134_17);
      goto label_24;

    case 11:
      current_block = (Rpc - LABEL_134_11);
      goto continuation_6;

    case 12:
      current_block = (Rpc - LABEL_134_16);
      goto continuation_12;

    case 13:
      current_block = (Rpc - LABEL_134_18);
      goto label_26;

    case 14:
      current_block = (Rpc - LABEL_134_19);
      goto label_25;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (delete_matching_itemsB_28)
DEFLABEL (delete_matching_itemsB_19)
  INTERRUPT_CHECK (26, LABEL_134_4);
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (59, Rsp));
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd7.Obj);
  Rdl = (& (Rsp [4]));
  goto lambda_8;

DEFLABEL (lambda_29)
DEFLABEL (lambda_8)
  DLINK_INTERRUPT_CHECK (25, LABEL_134_6);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_34;
  if (! ((Wrd5.Obj) == (current_block [OBJECT_134_1])))
    goto label_33;

DEFLABEL (label_32)
  Rvl = (current_block [OBJECT_134_1]);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_33)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_134_5]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd15.pObj)));
  (* (--Rsp)) = (Wrd17.Obj);
  goto lambda_17;

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_134_5);
  (Wrd40.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd40.Obj));
  goto label_32;

DEFLABEL (label_34)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_134_7]))));
  (* (--Rsp)) = (Wrd23.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_42;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (* (--Rsp)) = (Wrd26.Obj);

DEFLABEL (label_41)
  (Wrd37.Obj) = (Rsp [4]);
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd37.Obj));
  (Wrd39.Obj) = ((Wrd38.pObj) [1]);
  (* (--Rsp)) = (Wrd39.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_134_7);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_37;
  (Wrd12.Obj) = (Rsp [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_36;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd9.Obj) = ((Wrd11.pObj) [1]);

DEFLABEL (label_35)
  (Rsp [0]) = (Wrd9.Obj);
  goto lambda_8;

DEFLABEL (label_36)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_134_13]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_134_3]), 1);

DEFLABEL (label_22)
  (Wrd14.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd9.Obj) = Rvl;
  goto label_35;

DEFLABEL (label_37)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_134_11]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd30.Obj) = (Rsp [2]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 1))
    goto label_40;
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd29.Obj) = ((Wrd28.pObj) [1]);
  (* (--Rsp)) = (Wrd29.Obj);

DEFLABEL (label_39)
  (Wrd40.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd40.Obj);
  goto lambda_16;

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_134_11);

DEFLABEL (label_38)
  (Wrd37.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd37.Obj));
  Rvl = (Rsp [0]);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_40)
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_134_12]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_134_3]), 1);

DEFLABEL (label_23)
  (Wrd32.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd32.Obj));
  (* (--Rsp)) = Rvl;
  goto label_39;

DEFLABEL (label_42)
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_134_8]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_134_0]), 1);

DEFLABEL (label_21)
  (Wrd29.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd29.Obj));
  (* (--Rsp)) = Rvl;
  goto label_41;

DEFLABEL (lambda_30)
DEFLABEL (lambda_17)
  INTERRUPT_CHECK (26, LABEL_134_9);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [0]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_134_2]);
  (Rsp [1]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_134_10]));

DEFLABEL (lambda_31)
DEFLABEL (lambda_16)
  INTERRUPT_CHECK (26, LABEL_134_15);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if ((Wrd9.uLng) == 1)
    goto label_44;
  if ((Wrd8.Obj) == (current_block [OBJECT_134_1]))
    goto label_43;
  (Wrd13.Obj) = (Rsp [5]);
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd14.pObj)));
  (Rsp [1]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  goto lambda_17;

DEFLABEL (label_43)
  Rsp = (& (Rsp [3]));
  goto label_38;

DEFLABEL (label_44)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_134_16]))));
  (* (--Rsp)) = (Wrd23.Obj);
  if (! ((Wrd9.uLng) == 1))
    goto label_52;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (* (--Rsp)) = (Wrd26.Obj);

DEFLABEL (label_51)
  (Wrd33.Obj) = (Rsp [7]);
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd35.Obj) = ((Wrd34.pObj) [1]);
  (* (--Rsp)) = (Wrd35.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_134_16);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_48;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_134_14]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [6]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd11.pObj)));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd17.Obj) = (Rsp [3]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_47;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [1]);
  (* (--Rsp)) = (Wrd16.Obj);

DEFLABEL (label_46)
  Rdl = (& (Rsp [2]));
  goto lambda_8;

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_134_14);
  (Rsp [1]) = Rvl;
  (Wrd43.Obj) = (Rsp [0]);
  (Wrd44.uLng) = (OBJECT_TYPE (Wrd43.Obj));
  if ((Wrd44.uLng) == 1)
    goto label_45;
  INVOKE_PRIMITIVE ((current_block [OBJECT_134_4]), 2);

DEFLABEL (label_45)
  (Wrd41.pObj) = (OBJECT_ADDRESS (Wrd43.Obj));
  ((Wrd41.pObj) [1]) = Rvl;
  goto label_43;

DEFLABEL (label_47)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_134_19]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_134_3]), 1);

DEFLABEL (label_25)
  (* (--Rsp)) = Rvl;
  goto label_46;

DEFLABEL (label_48)
  (Wrd24.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd24.Obj);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if (! ((Wrd29.uLng) == 1))
    goto label_50;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd25.Obj) = ((Wrd27.pObj) [1]);

DEFLABEL (label_49)
  (Rsp [1]) = (Wrd25.Obj);
  goto lambda_16;

DEFLABEL (label_50)
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_134_18]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_134_3]), 1);

DEFLABEL (label_26)
  (Wrd25.Obj) = Rvl;
  goto label_49;

DEFLABEL (label_52)
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_134_17]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_134_0]), 1);

DEFLABEL (label_24)
  (* (--Rsp)) = Rvl;
  goto label_51;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_135_4 3
#define LABEL_135_5 5
#define LABEL_135_6 7
#define LABEL_135_8 9
#define LABEL_135_9 11
#define LABEL_135_7 13
#define LABEL_135_11 15
#define LABEL_135_13 17
#define LABEL_135_14 19
#define LABEL_135_15 21
#define LABEL_135_17 23
#define LABEL_135_12 25
#define LABEL_135_16 27
#define LABEL_135_18 29
#define LABEL_135_19 31
#define ENVIRONMENT_LABEL_135_3 41
#define DEBUGGING_LABEL_135_2 40
#define OBJECT_135_4 39
#define OBJECT_135_3 38
#define OBJECT_135_2 37
#define OBJECT_135_1 36
#define OBJECT_135_0 35
#define EXECUTE_CACHE_135_10 33
#define FREE_REFERENCES_LABEL_135_0 32
#define NUMBER_OF_LINKER_SECTIONS_135_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_135 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd12;
  machine_word Wrd21;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd9;
  machine_word Wrd41;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd27;
  machine_word Wrd19;
  machine_word Wrd16;
  machine_word Wrd18;
  machine_word Wrd33;
  machine_word Wrd28;
  machine_word Wrd30;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd8;
  machine_word Wrd17;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd29;
  machine_word Wrd36;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd5;
  machine_word Wrd40;
  machine_word Wrd7;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_135_4);
      goto keep_matching_itemsB_19;

    case 1:
      current_block = (Rpc - LABEL_135_5);
      goto continuation_2;

    case 2:
      current_block = (Rpc - LABEL_135_6);
      goto lambda_8;

    case 3:
      current_block = (Rpc - LABEL_135_8);
      goto label_21;

    case 4:
      current_block = (Rpc - LABEL_135_9);
      goto lambda_17;

    case 5:
      current_block = (Rpc - LABEL_135_7);
      goto continuation_4;

    case 6:
      current_block = (Rpc - LABEL_135_11);
      goto label_23;

    case 7:
      current_block = (Rpc - LABEL_135_13);
      goto label_22;

    case 8:
      current_block = (Rpc - LABEL_135_14);
      goto continuation_14;

    case 9:
      current_block = (Rpc - LABEL_135_15);
      goto lambda_16;

    case 10:
      current_block = (Rpc - LABEL_135_17);
      goto label_24;

    case 11:
      current_block = (Rpc - LABEL_135_12);
      goto continuation_7;

    case 12:
      current_block = (Rpc - LABEL_135_16);
      goto continuation_12;

    case 13:
      current_block = (Rpc - LABEL_135_18);
      goto label_26;

    case 14:
      current_block = (Rpc - LABEL_135_19);
      goto label_25;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (keep_matching_itemsB_28)
DEFLABEL (keep_matching_itemsB_19)
  INTERRUPT_CHECK (26, LABEL_135_4);
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (59, Rsp));
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd7.Obj);
  Rdl = (& (Rsp [4]));
  goto lambda_8;

DEFLABEL (lambda_29)
DEFLABEL (lambda_8)
  DLINK_INTERRUPT_CHECK (25, LABEL_135_6);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_34;
  if (! ((Wrd5.Obj) == (current_block [OBJECT_135_1])))
    goto label_33;

DEFLABEL (label_32)
  Rvl = (current_block [OBJECT_135_1]);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_33)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_135_5]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd15.pObj)));
  (* (--Rsp)) = (Wrd17.Obj);
  goto lambda_17;

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_135_5);
  (Wrd40.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd40.Obj));
  goto label_32;

DEFLABEL (label_34)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_135_7]))));
  (* (--Rsp)) = (Wrd23.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_42;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (* (--Rsp)) = (Wrd26.Obj);

DEFLABEL (label_41)
  (Wrd37.Obj) = (Rsp [4]);
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd37.Obj));
  (Wrd39.Obj) = ((Wrd38.pObj) [1]);
  (* (--Rsp)) = (Wrd39.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_135_7);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_38;
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_135_12]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd17.Obj) = (Rsp [2]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_37;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [1]);
  (* (--Rsp)) = (Wrd16.Obj);

DEFLABEL (label_36)
  (Wrd27.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd27.Obj);
  goto lambda_16;

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_135_12);

DEFLABEL (label_35)
  (Wrd37.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd37.Obj));
  Rvl = (Rsp [0]);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_37)
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_135_13]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_135_3]), 1);

DEFLABEL (label_22)
  (Wrd19.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd19.Obj));
  (* (--Rsp)) = Rvl;
  goto label_36;

DEFLABEL (label_38)
  (Wrd31.Obj) = (Rsp [0]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if (! ((Wrd32.uLng) == 1))
    goto label_40;
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd31.Obj));
  (Wrd28.Obj) = ((Wrd30.pObj) [1]);

DEFLABEL (label_39)
  (Rsp [0]) = (Wrd28.Obj);
  goto lambda_8;

DEFLABEL (label_40)
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd36.Obj);
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_135_11]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd31.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_135_3]), 1);

DEFLABEL (label_23)
  (Wrd33.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd28.Obj) = Rvl;
  goto label_39;

DEFLABEL (label_42)
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_135_8]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_135_0]), 1);

DEFLABEL (label_21)
  (Wrd29.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd29.Obj));
  (* (--Rsp)) = Rvl;
  goto label_41;

DEFLABEL (lambda_30)
DEFLABEL (lambda_17)
  INTERRUPT_CHECK (26, LABEL_135_9);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [0]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_135_2]);
  (Rsp [1]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_135_10]));

DEFLABEL (lambda_31)
DEFLABEL (lambda_16)
  INTERRUPT_CHECK (26, LABEL_135_15);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if ((Wrd9.uLng) == 1)
    goto label_44;
  if ((Wrd8.Obj) == (current_block [OBJECT_135_1]))
    goto label_43;
  (Wrd13.Obj) = (Rsp [5]);
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd14.pObj)));
  (Rsp [1]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  goto lambda_17;

DEFLABEL (label_43)
  Rsp = (& (Rsp [3]));
  goto label_35;

DEFLABEL (label_44)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_135_16]))));
  (* (--Rsp)) = (Wrd23.Obj);
  if (! ((Wrd9.uLng) == 1))
    goto label_52;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (* (--Rsp)) = (Wrd26.Obj);

DEFLABEL (label_51)
  (Wrd33.Obj) = (Rsp [7]);
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd35.Obj) = ((Wrd34.pObj) [1]);
  (* (--Rsp)) = (Wrd35.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_135_16);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_47;
  (Wrd7.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd7.Obj);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd12.uLng) == 1))
    goto label_46;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd8.Obj) = ((Wrd10.pObj) [1]);

DEFLABEL (label_45)
  (Rsp [1]) = (Wrd8.Obj);
  goto lambda_16;

DEFLABEL (label_46)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_135_19]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_135_3]), 1);

DEFLABEL (label_25)
  (Wrd8.Obj) = Rvl;
  goto label_45;

DEFLABEL (label_47)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_135_14]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd20.Obj) = (Rsp [6]);
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd21.pObj)));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd27.Obj) = (Rsp [3]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if (! ((Wrd28.uLng) == 1))
    goto label_50;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [1]);
  (* (--Rsp)) = (Wrd26.Obj);

DEFLABEL (label_49)
  Rdl = (& (Rsp [2]));
  goto lambda_8;

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_135_14);
  (Rsp [1]) = Rvl;
  (Wrd43.Obj) = (Rsp [0]);
  (Wrd44.uLng) = (OBJECT_TYPE (Wrd43.Obj));
  if ((Wrd44.uLng) == 1)
    goto label_48;
  INVOKE_PRIMITIVE ((current_block [OBJECT_135_4]), 2);

DEFLABEL (label_48)
  (Wrd41.pObj) = (OBJECT_ADDRESS (Wrd43.Obj));
  ((Wrd41.pObj) [1]) = Rvl;
  goto label_43;

DEFLABEL (label_50)
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_135_18]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_135_3]), 1);

DEFLABEL (label_26)
  (* (--Rsp)) = Rvl;
  goto label_49;

DEFLABEL (label_52)
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_135_17]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_135_0]), 1);

DEFLABEL (label_24)
  (* (--Rsp)) = Rvl;
  goto label_51;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_136_4 3
#define LABEL_136_5 5
#define TAG_136_6 1
#define ENVIRONMENT_LABEL_136_3 10
#define DEBUGGING_LABEL_136_2 9
#define EXECUTE_CACHE_136_7 7
#define FREE_REFERENCES_LABEL_136_0 6
#define NUMBER_OF_LINKER_SECTIONS_136_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_136 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_136_4);
      goto list_deletor_1;

    case 1:
      current_block = (Rpc - LABEL_136_5);
      goto lambda_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (list_deletor_4)
DEFLABEL (list_deletor_1)
  INTERRUPT_CHECK (26, LABEL_136_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_136_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_136_5])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  Rvl = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (lambda_5)
  CLOSURE_HEADER (LABEL_136_5);

DEFLABEL (lambda_0)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Wrd8.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd8.Obj);
  (Rsp [1]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_136_7]));

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_137_4 3
#define LABEL_137_5 5
#define TAG_137_6 1
#define ENVIRONMENT_LABEL_137_3 10
#define DEBUGGING_LABEL_137_2 9
#define EXECUTE_CACHE_137_7 7
#define FREE_REFERENCES_LABEL_137_0 6
#define NUMBER_OF_LINKER_SECTIONS_137_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_137 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_137_4);
      goto list_deletorB_1;

    case 1:
      current_block = (Rpc - LABEL_137_5);
      goto lambda_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (list_deletorB_4)
DEFLABEL (list_deletorB_1)
  INTERRUPT_CHECK (26, LABEL_137_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_137_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_137_5])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  Rvl = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (lambda_5)
  CLOSURE_HEADER (LABEL_137_5);

DEFLABEL (lambda_0)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Wrd8.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd8.Obj);
  (Rsp [1]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_137_7]));

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_138_4 3
#define LABEL_138_5 5
#define LABEL_138_6 7
#define LABEL_138_7 9
#define LABEL_138_8 11
#define ENVIRONMENT_LABEL_138_3 20
#define DEBUGGING_LABEL_138_2 19
#define OBJECT_138_3 18
#define OBJECT_138_2 17
#define OBJECT_138_1 16
#define OBJECT_138_0 15
#define EXECUTE_CACHE_138_9 13
#define FREE_REFERENCES_LABEL_138_0 12
#define NUMBER_OF_LINKER_SECTIONS_138_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_138 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd34;
  machine_word Wrd26;
  machine_word Wrd28;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd16;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_138_4);
      goto memq_11;

    case 1:
      current_block = (Rpc - LABEL_138_5);
      goto continuation_4;

    case 2:
      current_block = (Rpc - LABEL_138_6);
      goto loop_8;

    case 3:
      current_block = (Rpc - LABEL_138_7);
      goto label_13;

    case 4:
      current_block = (Rpc - LABEL_138_8);
      goto label_14;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (memq_16)
DEFLABEL (memq_11)
  INTERRUPT_CHECK (26, LABEL_138_4);
  (Wrd5.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd5.Obj);
  goto loop_8;

DEFLABEL (loop_17)
DEFLABEL (loop_8)
  INTERRUPT_CHECK (26, LABEL_138_6);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_20;
  if ((Wrd5.Obj) == (current_block [OBJECT_138_2]))
    goto label_18;
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_138_5]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_138_3]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_138_9]));

DEFLABEL (label_18)
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_19)
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_20)
  if (! ((Wrd6.uLng) == 1))
    goto label_25;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd16.Obj) = ((Wrd18.pObj) [0]);

DEFLABEL (label_24)
  (Wrd25.Obj) = (Rsp [1]);
  if ((Wrd16.Obj) == (Wrd25.Obj))
    goto label_23;
  (Wrd29.Obj) = (Rsp [0]);
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd29.Obj));
  if (! ((Wrd30.uLng) == 1))
    goto label_22;
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd29.Obj));
  (Wrd26.Obj) = ((Wrd28.pObj) [1]);

DEFLABEL (label_21)
  (Rsp [0]) = (Wrd26.Obj);
  goto loop_8;

DEFLABEL (label_22)
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_138_8]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd29.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_138_1]), 1);

DEFLABEL (label_14)
  (Wrd26.Obj) = Rvl;
  goto label_21;

DEFLABEL (label_23)
  Rvl = (Rsp [0]);
  goto label_19;

DEFLABEL (label_25)
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_138_7]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_138_0]), 1);

DEFLABEL (label_13)
  (Wrd16.Obj) = Rvl;
  goto label_24;

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_138_5);
  goto label_18;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_139_4 3
#define LABEL_139_5 5
#define LABEL_139_6 7
#define LABEL_139_8 9
#define LABEL_139_7 11
#define LABEL_139_11 13
#define ENVIRONMENT_LABEL_139_3 24
#define DEBUGGING_LABEL_139_2 23
#define OBJECT_139_3 22
#define OBJECT_139_2 21
#define OBJECT_139_1 20
#define OBJECT_139_0 19
#define EXECUTE_CACHE_139_10 15
#define EXECUTE_CACHE_139_9 17
#define FREE_REFERENCES_LABEL_139_0 14
#define NUMBER_OF_LINKER_SECTIONS_139_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_139 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd17;
  machine_word Wrd9;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd28;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_139_4);
      goto memv_11;

    case 1:
      current_block = (Rpc - LABEL_139_5);
      goto continuation_4;

    case 2:
      current_block = (Rpc - LABEL_139_6);
      goto loop_8;

    case 3:
      current_block = (Rpc - LABEL_139_8);
      goto label_13;

    case 4:
      current_block = (Rpc - LABEL_139_7);
      goto continuation_6;

    case 5:
      current_block = (Rpc - LABEL_139_11);
      goto label_14;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (memv_16)
DEFLABEL (memv_11)
  INTERRUPT_CHECK (26, LABEL_139_4);
  (Wrd5.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd5.Obj);
  goto loop_8;

DEFLABEL (loop_17)
DEFLABEL (loop_8)
  INTERRUPT_CHECK (26, LABEL_139_6);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_20;
  if (! ((Wrd5.Obj) == (current_block [OBJECT_139_1])))
    goto label_19;

DEFLABEL (label_18)
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_19)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_139_5]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_139_2]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_139_10]));

DEFLABEL (label_20)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_139_7]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd19.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd19.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_25;
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd22.Obj) = ((Wrd21.pObj) [0]);
  (* (--Rsp)) = (Wrd22.Obj);

DEFLABEL (label_24)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_139_9]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_139_7);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_21;
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_21)
  (Wrd12.Obj) = (Rsp [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_23;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd9.Obj) = ((Wrd11.pObj) [1]);

DEFLABEL (label_22)
  (Rsp [0]) = (Wrd9.Obj);
  goto loop_8;

DEFLABEL (label_23)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_139_11]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_139_3]), 1);

DEFLABEL (label_14)
  (Wrd9.Obj) = Rvl;
  goto label_22;

DEFLABEL (label_25)
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_139_8]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_139_0]), 1);

DEFLABEL (label_13)
  (* (--Rsp)) = Rvl;
  goto label_24;

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_139_5);
  goto label_18;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_140_4 3
#define LABEL_140_5 5
#define LABEL_140_6 7
#define LABEL_140_7 9
#define LABEL_140_9 11
#define LABEL_140_8 13
#define LABEL_140_11 15
#define ENVIRONMENT_LABEL_140_3 27
#define DEBUGGING_LABEL_140_2 26
#define OBJECT_140_4 25
#define OBJECT_140_3 24
#define OBJECT_140_2 23
#define OBJECT_140_1 22
#define OBJECT_140_0 21
#define EXECUTE_CACHE_140_10 17
#define FREE_REFERENCE_140_0 20
#define FREE_REFERENCES_LABEL_140_0 16
#define NUMBER_OF_LINKER_SECTIONS_140_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_140 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd17;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd8;
  machine_word Wrd9;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_140_4);
      goto member_14;

    case 1:
      current_block = (Rpc - LABEL_140_5);
      goto label_16;

    case 2:
      current_block = (Rpc - LABEL_140_6);
      goto continuation_6;

    case 3:
      current_block = (Rpc - LABEL_140_7);
      goto loop_10;

    case 4:
      current_block = (Rpc - LABEL_140_9);
      goto label_17;

    case 5:
      current_block = (Rpc - LABEL_140_8);
      goto continuation_8;

    case 6:
      current_block = (Rpc - LABEL_140_11);
      goto label_18;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (member_20)
DEFLABEL (member_14)
  INTERRUPT_CHECK (26, LABEL_140_4);
  (Wrd5.Obj) = (Rsp [2]);
  if ((Wrd5.Obj) == (current_block [OBJECT_140_0]))
    goto label_23;
  (* (--Rsp)) = (Wrd5.Obj);

DEFLABEL (label_22)
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  goto loop_10;

DEFLABEL (label_23)
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_140_0]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_25;
  Wrd9 = Wrd13;

DEFLABEL (label_24)
  (* (--Rsp)) = (Wrd9.Obj);
  goto label_22;

DEFLABEL (label_25)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_140_5])), (Wrd10.pObj));

DEFLABEL (label_16)
  (Wrd9.Obj) = Rvl;
  goto label_24;

DEFLABEL (loop_21)
DEFLABEL (loop_10)
  INTERRUPT_CHECK (26, LABEL_140_7);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_28;
  if (! ((Wrd5.Obj) == (current_block [OBJECT_140_2])))
    goto label_27;

DEFLABEL (label_26)
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [5]));
  goto pop_return;

DEFLABEL (label_27)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_140_6]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_140_3]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_140_10]));

DEFLABEL (label_28)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_140_8]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd19.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd19.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_33;
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd22.Obj) = ((Wrd21.pObj) [0]);
  (* (--Rsp)) = (Wrd22.Obj);

DEFLABEL (label_32)
  (Wrd29.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd29.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_140_8);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_29;
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [5]));
  goto pop_return;

DEFLABEL (label_29)
  (Wrd12.Obj) = (Rsp [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_31;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd9.Obj) = ((Wrd11.pObj) [1]);

DEFLABEL (label_30)
  (Rsp [0]) = (Wrd9.Obj);
  goto loop_10;

DEFLABEL (label_31)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_140_11]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_140_4]), 1);

DEFLABEL (label_18)
  (Wrd9.Obj) = Rvl;
  goto label_30;

DEFLABEL (label_33)
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_140_9]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_140_1]), 1);

DEFLABEL (label_17)
  (* (--Rsp)) = Rvl;
  goto label_32;

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_140_6);
  goto label_26;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_141_4 3
#define LABEL_141_5 5
#define TAG_141_6 1
#define LABEL_141_7 7
#define LABEL_141_8 9
#define LABEL_141_10 11
#define LABEL_141_9 13
#define LABEL_141_12 15
#define ENVIRONMENT_LABEL_141_3 23
#define DEBUGGING_LABEL_141_2 22
#define OBJECT_141_2 21
#define OBJECT_141_1 20
#define OBJECT_141_0 19
#define EXECUTE_CACHE_141_11 17
#define FREE_REFERENCES_LABEL_141_0 16
#define NUMBER_OF_LINKER_SECTIONS_141_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_141 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd17;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_141_4);
      goto member_procedure_12;

    case 1:
      current_block = (Rpc - LABEL_141_5);
      goto lambda_18;

    case 2:
      current_block = (Rpc - LABEL_141_7);
      goto continuation_4;

    case 3:
      current_block = (Rpc - LABEL_141_8);
      goto loop_8;

    case 4:
      current_block = (Rpc - LABEL_141_10);
      goto label_14;

    case 5:
      current_block = (Rpc - LABEL_141_9);
      goto continuation_6;

    case 6:
      current_block = (Rpc - LABEL_141_12);
      goto label_15;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (member_procedure_17)
DEFLABEL (member_procedure_12)
  INTERRUPT_CHECK (26, LABEL_141_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_141_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_141_5])));
  Rhp += 2;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd10 = Wrd7;
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd10.pObj) [2]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd10.pObj) [3]) = (Wrd9.Obj);
  Rvl = (Wrd6.Obj);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (lambda_18)
  CLOSURE_HEADER (LABEL_141_5);

DEFLABEL (lambda_11)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd5.Obj);
  goto loop_8;

DEFLABEL (loop_19)
DEFLABEL (loop_8)
  INTERRUPT_CHECK (26, LABEL_141_8);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_22;
  if (! ((Wrd5.Obj) == (current_block [OBJECT_141_1])))
    goto label_21;

DEFLABEL (label_20)
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_21)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_141_7]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [2]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [2]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_141_11]));

DEFLABEL (label_22)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_141_9]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd21.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd21.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_27;
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd24.Obj) = ((Wrd23.pObj) [0]);
  (* (--Rsp)) = (Wrd24.Obj);

DEFLABEL (label_26)
  (Wrd31.Obj) = (Rsp [4]);
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd31.Obj));
  (Wrd33.Obj) = ((Wrd32.pObj) [3]);
  (* (--Rsp)) = (Wrd33.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_141_9);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_23;
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_23)
  (Wrd12.Obj) = (Rsp [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_25;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd9.Obj) = ((Wrd11.pObj) [1]);

DEFLABEL (label_24)
  (Rsp [0]) = (Wrd9.Obj);
  goto loop_8;

DEFLABEL (label_25)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_141_12]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_141_2]), 1);

DEFLABEL (label_15)
  (Wrd9.Obj) = Rvl;
  goto label_24;

DEFLABEL (label_27)
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_141_10]))));
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_141_0]), 1);

DEFLABEL (label_14)
  (* (--Rsp)) = Rvl;
  goto label_26;

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_141_7);
  goto label_20;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_142_4 3
#define LABEL_142_5 5
#define TAG_142_6 1
#define LABEL_142_7 7
#define LABEL_142_8 9
#define LABEL_142_9 11
#define LABEL_142_10 13
#define LABEL_142_11 15
#define ENVIRONMENT_LABEL_142_3 23
#define DEBUGGING_LABEL_142_2 22
#define OBJECT_142_2 21
#define OBJECT_142_1 20
#define OBJECT_142_0 19
#define EXECUTE_CACHE_142_12 17
#define FREE_REFERENCES_LABEL_142_0 16
#define NUMBER_OF_LINKER_SECTIONS_142_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_142 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd19;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd42;
  machine_word Wrd54;
  machine_word Wrd46;
  machine_word Wrd48;
  machine_word Wrd50;
  machine_word Wrd49;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_142_4);
      goto add_member_procedure_13;

    case 1:
      current_block = (Rpc - LABEL_142_5);
      goto lambda_19;

    case 2:
      current_block = (Rpc - LABEL_142_7);
      goto continuation_7;

    case 3:
      current_block = (Rpc - LABEL_142_8);
      goto label_16;

    case 4:
      current_block = (Rpc - LABEL_142_9);
      goto continuation_5;

    case 5:
      current_block = (Rpc - LABEL_142_10);
      goto loop_9;

    case 6:
      current_block = (Rpc - LABEL_142_11);
      goto label_15;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (add_member_procedure_18)
DEFLABEL (add_member_procedure_13)
  INTERRUPT_CHECK (26, LABEL_142_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_142_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_142_5])));
  Rhp += 2;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd10 = Wrd7;
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd10.pObj) [2]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd10.pObj) [3]) = (Wrd9.Obj);
  Rvl = (Wrd6.Obj);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (lambda_19)
  CLOSURE_HEADER (LABEL_142_5);

DEFLABEL (lambda_12)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd5.Obj);
  goto loop_9;

DEFLABEL (loop_20)
DEFLABEL (loop_9)
  INTERRUPT_CHECK (26, LABEL_142_10);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_24;
  if ((Wrd5.Obj) == (current_block [OBJECT_142_2]))
    goto label_21;
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_142_9]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [2]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [2]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_142_12]));

DEFLABEL (label_21)
  Rsp = (& (Rsp [1]));

DEFLABEL (label_23)
  (Wrd21.Obj) = (Rsp [1]);
  (Wrd22.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd21.Obj);
  (* (Rhp++)) = (Wrd22.Obj);
  (Wrd19.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd19.pObj)));

DEFLABEL (label_22)
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_24)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_142_7]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd26.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd26.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_29;
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd29.Obj) = ((Wrd28.pObj) [0]);
  (* (--Rsp)) = (Wrd29.Obj);

DEFLABEL (label_28)
  (Wrd36.Obj) = (Rsp [4]);
  (Wrd37.pObj) = (OBJECT_ADDRESS (Wrd36.Obj));
  (Wrd38.Obj) = ((Wrd37.pObj) [3]);
  (* (--Rsp)) = (Wrd38.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_142_7);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_25;
  (Wrd42.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [1]));
  if ((Wrd42.Obj) == ((SCHEME_OBJECT) 0))
    goto label_23;
  Rvl = (Rsp [2]);
  goto label_22;

DEFLABEL (label_25)
  (Wrd49.Obj) = (Rsp [0]);
  (Wrd50.uLng) = (OBJECT_TYPE (Wrd49.Obj));
  if (! ((Wrd50.uLng) == 1))
    goto label_27;
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd49.Obj));
  (Wrd46.Obj) = ((Wrd48.pObj) [1]);

DEFLABEL (label_26)
  (Rsp [0]) = (Wrd46.Obj);
  goto loop_9;

DEFLABEL (label_27)
  (Wrd54.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_142_8]))));
  (* (--Rsp)) = (Wrd54.Obj);
  (* (--Rsp)) = (Wrd49.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_142_0]), 1);

DEFLABEL (label_16)
  (Wrd46.Obj) = Rvl;
  goto label_26;

DEFLABEL (label_29)
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_142_11]))));
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_142_1]), 1);

DEFLABEL (label_15)
  (* (--Rsp)) = Rvl;
  goto label_28;

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_142_9);
  goto label_21;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_143_4 3
#define LABEL_143_5 5
#define LABEL_143_6 7
#define LABEL_143_8 9
#define LABEL_143_7 11
#define LABEL_143_10 13
#define ENVIRONMENT_LABEL_143_3 21
#define DEBUGGING_LABEL_143_2 20
#define OBJECT_143_2 19
#define OBJECT_143_1 18
#define OBJECT_143_0 17
#define EXECUTE_CACHE_143_9 15
#define FREE_REFERENCES_LABEL_143_0 14
#define NUMBER_OF_LINKER_SECTIONS_143_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_143 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd17;
  machine_word Wrd9;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_143_4);
      goto Z__member_11;

    case 1:
      current_block = (Rpc - LABEL_143_5);
      goto continuation_4;

    case 2:
      current_block = (Rpc - LABEL_143_6);
      goto loop_8;

    case 3:
      current_block = (Rpc - LABEL_143_8);
      goto label_13;

    case 4:
      current_block = (Rpc - LABEL_143_7);
      goto continuation_6;

    case 5:
      current_block = (Rpc - LABEL_143_10);
      goto label_14;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (Z__member_16)
DEFLABEL (Z__member_11)
  INTERRUPT_CHECK (26, LABEL_143_4);
  (Wrd5.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd5.Obj);
  goto loop_8;

DEFLABEL (loop_17)
DEFLABEL (loop_8)
  INTERRUPT_CHECK (26, LABEL_143_6);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_20;
  if (! ((Wrd5.Obj) == (current_block [OBJECT_143_1])))
    goto label_19;

DEFLABEL (label_18)
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [5]));
  goto pop_return;

DEFLABEL (label_19)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_5]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_9]));

DEFLABEL (label_20)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_7]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd19.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd19.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_25;
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd22.Obj) = ((Wrd21.pObj) [0]);
  (* (--Rsp)) = (Wrd22.Obj);

DEFLABEL (label_24)
  (Wrd29.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd29.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_143_7);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_21;
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [5]));
  goto pop_return;

DEFLABEL (label_21)
  (Wrd12.Obj) = (Rsp [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_23;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd9.Obj) = ((Wrd11.pObj) [1]);

DEFLABEL (label_22)
  (Rsp [0]) = (Wrd9.Obj);
  goto loop_8;

DEFLABEL (label_23)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_10]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_143_2]), 1);

DEFLABEL (label_14)
  (Wrd9.Obj) = Rvl;
  goto label_22;

DEFLABEL (label_25)
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_8]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_143_0]), 1);

DEFLABEL (label_13)
  (* (--Rsp)) = Rvl;
  goto label_24;

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_143_5);
  goto label_18;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_144_4 3
#define LABEL_144_5 5
#define TAG_144_6 1
#define LABEL_144_7 7
#define LABEL_144_8 9
#define TAG_144_9 3
#define ENVIRONMENT_LABEL_144_3 11
#define DEBUGGING_LABEL_144_2 10
#define FREE_REFERENCES_LABEL_144_0 10
#define NUMBER_OF_LINKER_SECTIONS_144_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_144 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd8;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_144_4);
      goto delete_member_procedure_3;

    case 1:
      current_block = (Rpc - LABEL_144_5);
      goto lambda_7;

    case 2:
      current_block = (Rpc - LABEL_144_7);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_144_8);
      goto lambda_8;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (delete_member_procedure_6)
DEFLABEL (delete_member_procedure_3)
  INTERRUPT_CHECK (26, LABEL_144_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_144_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_144_5])));
  Rhp += 2;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd10 = Wrd7;
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd10.pObj) [2]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd10.pObj) [3]) = (Wrd9.Obj);
  Rvl = (Wrd6.Obj);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (lambda_7)
  CLOSURE_HEADER (LABEL_144_5);

DEFLABEL (lambda_2)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_144_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd9.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_144_9);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_144_8])));
  Rhp += 2;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd9.pObj)));
  Wrd12 = Wrd9;
  (Wrd13.Obj) = (Rsp [1]);
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [2]);
  ((Wrd12.pObj) [2]) = (Wrd15.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  ((Wrd12.pObj) [3]) = (Wrd11.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd18.Obj) = ((Wrd14.pObj) [3]);
  (* (--Rsp)) = (Wrd18.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_144_7);
  (Rsp [1]) = Rvl;
  Rsp = (& (Rsp [1]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (lambda_8)
  CLOSURE_HEADER (LABEL_144_8);

DEFLABEL (lambda_0)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = ((Wrd6.pObj) [3]);
  (Wrd11.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd11.Obj);
  (Rsp [2]) = (Wrd8.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_145_5 3
#define LABEL_145_4 5
#define LABEL_145_6 7
#define LABEL_145_8 9
#define LABEL_145_9 11
#define LABEL_145_11 13
#define LABEL_145_12 15
#define LABEL_145_13 17
#define LABEL_145_14 19
#define LABEL_145_15 21
#define LABEL_145_16 23
#define LABEL_145_7 25
#define LABEL_145_17 27
#define ENVIRONMENT_LABEL_145_3 37
#define DEBUGGING_LABEL_145_2 36
#define OBJECT_145_4 35
#define OBJECT_145_3 34
#define OBJECT_145_2 33
#define OBJECT_145_1 32
#define OBJECT_145_0 31
#define EXECUTE_CACHE_145_10 29
#define FREE_REFERENCES_LABEL_145_0 28
#define NUMBER_OF_LINKER_SECTIONS_145_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_145 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd20;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd13;
  machine_word Wrd9;
  machine_word Wrd30;
  machine_word Wrd67;
  machine_word Wrd66;
  machine_word Wrd58;
  machine_word Wrd60;
  machine_word Wrd62;
  machine_word Wrd61;
  machine_word Wrd78;
  machine_word Wrd70;
  machine_word Wrd73;
  machine_word Wrd72;
  machine_word Wrd56;
  machine_word Wrd55;
  machine_word Wrd57;
  machine_word Wrd53;
  machine_word Wrd45;
  machine_word Wrd47;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd87;
  machine_word Wrd79;
  machine_word Wrd81;
  machine_word Wrd83;
  machine_word Wrd82;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd26;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd14;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd42;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd32;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd29;
  machine_word Wrd25;
  machine_word Wrd17;
  machine_word Wrd19;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_145_5);
      goto continuation_3;

    case 1:
      current_block = (Rpc - LABEL_145_4);
      goto delq_25;

    case 2:
      current_block = (Rpc - LABEL_145_6);
      goto label_27;

    case 3:
      current_block = (Rpc - LABEL_145_8);
      goto label_28;

    case 4:
      current_block = (Rpc - LABEL_145_9);
      goto lambda_0;

    case 5:
      current_block = (Rpc - LABEL_145_11);
      goto loop_19;

    case 6:
      current_block = (Rpc - LABEL_145_12);
      goto label_30;

    case 7:
      current_block = (Rpc - LABEL_145_13);
      goto label_34;

    case 8:
      current_block = (Rpc - LABEL_145_14);
      goto label_31;

    case 9:
      current_block = (Rpc - LABEL_145_15);
      goto label_33;

    case 10:
      current_block = (Rpc - LABEL_145_16);
      goto label_32;

    case 11:
      current_block = (Rpc - LABEL_145_7);
      goto continuation_7;

    case 12:
      current_block = (Rpc - LABEL_145_17);
      goto label_29;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (delq_36)
DEFLABEL (delq_25)
  INTERRUPT_CHECK (26, LABEL_145_4);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_41;
  if (! ((Wrd5.Obj) == (current_block [OBJECT_145_1])))
    goto label_40;

DEFLABEL (label_39)
  Rvl = (Rsp [1]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_40)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_145_5]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.pObj) = (& (Rsp [1]));
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd12.pObj)));
  (* (--Rsp)) = (Wrd14.Obj);
  goto lambda_0;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_145_5);
  goto label_39;

DEFLABEL (label_41)
  if (! ((Wrd6.uLng) == 1))
    goto label_50;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd17.Obj) = ((Wrd19.pObj) [0]);

DEFLABEL (label_49)
  (Wrd29.Obj) = (current_block [OBJECT_145_1]);
  (* (Rhp++)) = (Wrd17.Obj);
  (* (Rhp++)) = (Wrd29.Obj);
  (Wrd27.pObj) = (& (Rhp [-2]));
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd27.pObj)));
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_145_7]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd37.Obj) = (Rsp [4]);
  (Wrd38.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if (! ((Wrd38.uLng) == 1))
    goto label_48;
  (Wrd35.pObj) = (OBJECT_ADDRESS (Wrd37.Obj));
  (Wrd36.Obj) = ((Wrd35.pObj) [1]);
  (* (--Rsp)) = (Wrd36.Obj);

DEFLABEL (label_47)
  goto loop_19;

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_145_7);

DEFLABEL (label_46)
  (Wrd8.Obj) = (Rsp [2]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_45;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [0]);

DEFLABEL (label_44)
  (Wrd14.Obj) = (Rsp [1]);
  if ((Wrd5.Obj) == (Wrd14.Obj))
    goto label_42;
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_42)
  (Wrd17.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd17.Obj);
  Rsp = (& (Rsp [2]));
  (Wrd22.Obj) = (Rsp [0]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if (! ((Wrd23.uLng) == 1))
    goto label_43;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
  Rvl = ((Wrd20.pObj) [1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_43)
  INVOKE_PRIMITIVE ((current_block [OBJECT_145_2]), 1);

DEFLABEL (label_45)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_145_17]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_145_0]), 1);

DEFLABEL (label_29)
  (Wrd5.Obj) = Rvl;
  goto label_44;

DEFLABEL (label_48)
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_145_8]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_145_2]), 1);

DEFLABEL (label_28)
  (* (--Rsp)) = Rvl;
  goto label_47;

DEFLABEL (label_50)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_145_6]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_145_0]), 1);

DEFLABEL (label_27)
  (Wrd17.Obj) = Rvl;
  goto label_49;

DEFLABEL (lambda_37)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_145_9);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [1]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_145_3]);
  (Rsp [1]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_145_10]));

DEFLABEL (loop_38)
DEFLABEL (loop_19)
  INTERRUPT_CHECK (26, LABEL_145_11);
  (Wrd25.Obj) = (Rsp [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 1)
    goto label_52;
  if ((Wrd25.Obj) == (current_block [OBJECT_145_1]))
    goto label_51;
  (Wrd30.pObj) = (& (Rsp [4]));
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd30.pObj)));
  (Rsp [1]) = (Wrd32.Obj);
  Rsp = (& (Rsp [1]));
  goto lambda_0;

DEFLABEL (label_51)
  Rsp = (& (Rsp [3]));
  goto label_46;

DEFLABEL (label_52)
  if (! ((Wrd26.uLng) == 1))
    goto label_63;
  (Wrd37.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd35.Obj) = ((Wrd37.pObj) [0]);

DEFLABEL (label_62)
  (Wrd44.Obj) = (Rsp [4]);
  if ((Wrd35.Obj) == (Wrd44.Obj))
    goto label_59;
  (Wrd48.Obj) = (Rsp [0]);
  (Wrd49.uLng) = (OBJECT_TYPE (Wrd48.Obj));
  if (! ((Wrd49.uLng) == 1))
    goto label_58;
  (Wrd47.pObj) = (OBJECT_ADDRESS (Wrd48.Obj));
  (Wrd45.Obj) = ((Wrd47.pObj) [0]);

DEFLABEL (label_57)
  (Wrd57.Obj) = (current_block [OBJECT_145_1]);
  (* (Rhp++)) = (Wrd45.Obj);
  (* (Rhp++)) = (Wrd57.Obj);
  (Wrd55.pObj) = (& (Rhp [-2]));
  (Wrd56.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd55.pObj)));
  (* (--Rsp)) = (Wrd56.Obj);
  (Wrd72.Obj) = (Rsp [2]);
  (Wrd73.uLng) = (OBJECT_TYPE (Wrd72.Obj));
  if (! ((Wrd73.uLng) == 1))
    goto label_56;
  (Wrd70.pObj) = (OBJECT_ADDRESS (Wrd72.Obj));
  ((Wrd70.pObj) [1]) = (Wrd56.Obj);

DEFLABEL (label_55)
  (Wrd61.Obj) = (Rsp [1]);
  (Wrd62.uLng) = (OBJECT_TYPE (Wrd61.Obj));
  if (! ((Wrd62.uLng) == 1))
    goto label_54;
  (Wrd60.pObj) = (OBJECT_ADDRESS (Wrd61.Obj));
  (Wrd58.Obj) = ((Wrd60.pObj) [1]);

DEFLABEL (label_53)
  (Rsp [1]) = (Wrd58.Obj);
  (Wrd67.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd67.Obj);
  Rsp = (& (Rsp [1]));
  goto loop_19;

DEFLABEL (label_54)
  (Wrd66.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_145_16]))));
  (* (--Rsp)) = (Wrd66.Obj);
  (* (--Rsp)) = (Wrd61.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_145_2]), 1);

DEFLABEL (label_32)
  (Wrd58.Obj) = Rvl;
  goto label_53;

DEFLABEL (label_56)
  (Wrd78.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_145_15]))));
  (* (--Rsp)) = (Wrd78.Obj);
  (* (--Rsp)) = (Wrd56.Obj);
  (* (--Rsp)) = (Wrd72.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_145_4]), 2);

DEFLABEL (label_33)
  goto label_55;

DEFLABEL (label_58)
  (Wrd53.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_145_14]))));
  (* (--Rsp)) = (Wrd53.Obj);
  (* (--Rsp)) = (Wrd48.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_145_0]), 1);

DEFLABEL (label_31)
  (Wrd45.Obj) = Rvl;
  goto label_57;

DEFLABEL (label_59)
  (Wrd82.Obj) = (Rsp [0]);
  (Wrd83.uLng) = (OBJECT_TYPE (Wrd82.Obj));
  if (! ((Wrd83.uLng) == 1))
    goto label_61;
  (Wrd81.pObj) = (OBJECT_ADDRESS (Wrd82.Obj));
  (Wrd79.Obj) = ((Wrd81.pObj) [1]);

DEFLABEL (label_60)
  (Rsp [0]) = (Wrd79.Obj);
  goto loop_19;

DEFLABEL (label_61)
  (Wrd87.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_145_13]))));
  (* (--Rsp)) = (Wrd87.Obj);
  (* (--Rsp)) = (Wrd82.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_145_2]), 1);

DEFLABEL (label_34)
  (Wrd79.Obj) = Rvl;
  goto label_60;

DEFLABEL (label_63)
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_145_12]))));
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_145_0]), 1);

DEFLABEL (label_30)
  (Wrd35.Obj) = Rvl;
  goto label_62;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_146_5 3
#define LABEL_146_4 5
#define LABEL_146_6 7
#define LABEL_146_8 9
#define LABEL_146_9 11
#define LABEL_146_11 13
#define LABEL_146_13 15
#define LABEL_146_7 17
#define LABEL_146_15 19
#define LABEL_146_14 21
#define LABEL_146_12 23
#define LABEL_146_17 25
#define LABEL_146_18 27
#define LABEL_146_19 29
#define LABEL_146_20 31
#define ENVIRONMENT_LABEL_146_3 43
#define DEBUGGING_LABEL_146_2 42
#define OBJECT_146_4 41
#define OBJECT_146_3 40
#define OBJECT_146_2 39
#define OBJECT_146_1 38
#define OBJECT_146_0 37
#define EXECUTE_CACHE_146_16 33
#define EXECUTE_CACHE_146_10 35
#define FREE_REFERENCES_LABEL_146_0 32
#define NUMBER_OF_LINKER_SECTIONS_146_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_146 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd15;
  machine_word Wrd9;
  machine_word Wrd49;
  machine_word Wrd41;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd26;
  machine_word Wrd24;
  machine_word Wrd16;
  machine_word Wrd20;
  machine_word Wrd10;
  machine_word Wrd13;
  machine_word Wrd23;
  machine_word Wrd40;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd18;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd14;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd42;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd32;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd29;
  machine_word Wrd25;
  machine_word Wrd17;
  machine_word Wrd19;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_146_5);
      goto continuation_3;

    case 1:
      current_block = (Rpc - LABEL_146_4);
      goto delv_25;

    case 2:
      current_block = (Rpc - LABEL_146_6);
      goto label_27;

    case 3:
      current_block = (Rpc - LABEL_146_8);
      goto label_28;

    case 4:
      current_block = (Rpc - LABEL_146_9);
      goto lambda_0;

    case 5:
      current_block = (Rpc - LABEL_146_11);
      goto loop_19;

    case 6:
      current_block = (Rpc - LABEL_146_13);
      goto label_30;

    case 7:
      current_block = (Rpc - LABEL_146_7);
      goto continuation_7;

    case 8:
      current_block = (Rpc - LABEL_146_15);
      goto label_29;

    case 9:
      current_block = (Rpc - LABEL_146_14);
      goto continuation_22;

    case 10:
      current_block = (Rpc - LABEL_146_12);
      goto continuation_12;

    case 11:
      current_block = (Rpc - LABEL_146_17);
      goto label_32;

    case 12:
      current_block = (Rpc - LABEL_146_18);
      goto label_34;

    case 13:
      current_block = (Rpc - LABEL_146_19);
      goto label_33;

    case 14:
      current_block = (Rpc - LABEL_146_20);
      goto label_31;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (delv_36)
DEFLABEL (delv_25)
  INTERRUPT_CHECK (26, LABEL_146_4);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_41;
  if (! ((Wrd5.Obj) == (current_block [OBJECT_146_1])))
    goto label_40;

DEFLABEL (label_39)
  Rvl = (Rsp [1]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_40)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_146_5]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.pObj) = (& (Rsp [1]));
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd12.pObj)));
  (* (--Rsp)) = (Wrd14.Obj);
  goto lambda_0;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_146_5);
  goto label_39;

DEFLABEL (label_41)
  if (! ((Wrd6.uLng) == 1))
    goto label_49;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd17.Obj) = ((Wrd19.pObj) [0]);

DEFLABEL (label_48)
  (Wrd29.Obj) = (current_block [OBJECT_146_1]);
  (* (Rhp++)) = (Wrd17.Obj);
  (* (Rhp++)) = (Wrd29.Obj);
  (Wrd27.pObj) = (& (Rhp [-2]));
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd27.pObj)));
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_146_7]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd37.Obj) = (Rsp [4]);
  (Wrd38.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if (! ((Wrd38.uLng) == 1))
    goto label_47;
  (Wrd35.pObj) = (OBJECT_ADDRESS (Wrd37.Obj));
  (Wrd36.Obj) = ((Wrd35.pObj) [1]);
  (* (--Rsp)) = (Wrd36.Obj);

DEFLABEL (label_46)
  goto loop_19;

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_146_7);

DEFLABEL (label_45)
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_146_14]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd12.Obj) = (Rsp [4]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_43;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [0]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_42)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_146_16]));

DEFLABEL (label_43)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_146_15]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_146_0]), 1);

DEFLABEL (label_29)
DEFLABEL (label_44)
  (* (--Rsp)) = Rvl;
  goto label_42;

DEFLABEL (label_47)
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_146_8]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_146_2]), 1);

DEFLABEL (label_28)
  (* (--Rsp)) = Rvl;
  goto label_46;

DEFLABEL (label_49)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_146_6]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_146_0]), 1);

DEFLABEL (label_27)
  (Wrd17.Obj) = Rvl;
  goto label_48;

DEFLABEL (continuation_22)
  INTERRUPT_CHECK (27, LABEL_146_14);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_50;
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_50)
  (Wrd7.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd7.Obj);
  Rsp = (& (Rsp [2]));
  (Wrd12.Obj) = (Rsp [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_51;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  Rvl = ((Wrd10.pObj) [1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_51)
  INVOKE_PRIMITIVE ((current_block [OBJECT_146_2]), 1);

DEFLABEL (lambda_37)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_146_9);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [1]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_146_3]);
  (Rsp [1]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_146_10]));

DEFLABEL (loop_38)
DEFLABEL (loop_19)
  INTERRUPT_CHECK (26, LABEL_146_11);
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 1)
    goto label_53;
  if ((Wrd18.Obj) == (current_block [OBJECT_146_1]))
    goto label_52;
  (Wrd23.pObj) = (& (Rsp [4]));
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd23.pObj)));
  (Rsp [1]) = (Wrd25.Obj);
  Rsp = (& (Rsp [1]));
  goto lambda_0;

DEFLABEL (label_52)
  Rsp = (& (Rsp [3]));
  goto label_45;

DEFLABEL (label_53)
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_146_12]))));
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd31.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd31.Obj);
  if (! ((Wrd19.uLng) == 1))
    goto label_54;
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd34.Obj) = ((Wrd33.pObj) [0]);
  (* (--Rsp)) = (Wrd34.Obj);
  goto label_42;

DEFLABEL (label_54)
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_146_13]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_146_0]), 1);

DEFLABEL (label_30)
  goto label_44;

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_146_12);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_57;
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_56;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_55)
  (Rsp [0]) = (Wrd7.Obj);
  goto loop_19;

DEFLABEL (label_56)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_146_20]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_146_2]), 1);

DEFLABEL (label_31)
  (Wrd7.Obj) = Rvl;
  goto label_55;

DEFLABEL (label_57)
  (Wrd19.Obj) = (Rsp [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 1))
    goto label_63;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd16.Obj) = ((Wrd18.pObj) [0]);

DEFLABEL (label_62)
  (Wrd28.Obj) = (current_block [OBJECT_146_1]);
  (* (Rhp++)) = (Wrd16.Obj);
  (* (Rhp++)) = (Wrd28.Obj);
  (Wrd26.pObj) = (& (Rhp [-2]));
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd26.pObj)));
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd43.Obj) = (Rsp [2]);
  (Wrd44.uLng) = (OBJECT_TYPE (Wrd43.Obj));
  if (! ((Wrd44.uLng) == 1))
    goto label_61;
  (Wrd41.pObj) = (OBJECT_ADDRESS (Wrd43.Obj));
  ((Wrd41.pObj) [1]) = (Wrd27.Obj);

DEFLABEL (label_60)
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd33.uLng) == 1))
    goto label_59;
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd29.Obj) = ((Wrd31.pObj) [1]);

DEFLABEL (label_58)
  (Rsp [1]) = (Wrd29.Obj);
  (Wrd38.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd38.Obj);
  Rsp = (& (Rsp [1]));
  goto loop_19;

DEFLABEL (label_59)
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_146_19]))));
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_146_2]), 1);

DEFLABEL (label_33)
  (Wrd29.Obj) = Rvl;
  goto label_58;

DEFLABEL (label_61)
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_146_18]))));
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd43.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_146_4]), 2);

DEFLABEL (label_34)
  goto label_60;

DEFLABEL (label_63)
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_146_17]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_146_0]), 1);

DEFLABEL (label_32)
  (Wrd16.Obj) = Rvl;
  goto label_62;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_147_5 3
#define LABEL_147_4 5
#define LABEL_147_6 7
#define LABEL_147_7 9
#define LABEL_147_9 11
#define LABEL_147_10 13
#define LABEL_147_12 15
#define LABEL_147_14 17
#define LABEL_147_8 19
#define LABEL_147_16 21
#define LABEL_147_15 23
#define LABEL_147_13 25
#define LABEL_147_17 27
#define LABEL_147_18 29
#define LABEL_147_19 31
#define LABEL_147_20 33
#define ENVIRONMENT_LABEL_147_3 46
#define DEBUGGING_LABEL_147_2 45
#define OBJECT_147_5 44
#define OBJECT_147_4 43
#define OBJECT_147_3 42
#define OBJECT_147_2 41
#define OBJECT_147_1 40
#define OBJECT_147_0 39
#define EXECUTE_CACHE_147_11 35
#define FREE_REFERENCE_147_0 38
#define FREE_REFERENCES_LABEL_147_0 34
#define NUMBER_OF_LINKER_SECTIONS_147_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_147 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd37;
  machine_word Wrd29;
  machine_word Wrd33;
  machine_word Wrd49;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd27;
  machine_word Wrd16;
  machine_word Wrd18;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd26;
  machine_word Wrd24;
  machine_word Wrd42;
  machine_word Wrd34;
  machine_word Wrd19;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd17;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd45;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd35;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd32;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd22;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd46;
  machine_word Wrd51;
  machine_word Wrd50;
  machine_word Wrd47;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_147_5);
      goto continuation_5;

    case 1:
      current_block = (Rpc - LABEL_147_4);
      goto delete_28;

    case 2:
      current_block = (Rpc - LABEL_147_6);
      goto label_32;

    case 3:
      current_block = (Rpc - LABEL_147_7);
      goto label_30;

    case 4:
      current_block = (Rpc - LABEL_147_9);
      goto label_31;

    case 5:
      current_block = (Rpc - LABEL_147_10);
      goto lambda_2;

    case 6:
      current_block = (Rpc - LABEL_147_12);
      goto loop_21;

    case 7:
      current_block = (Rpc - LABEL_147_14);
      goto label_34;

    case 8:
      current_block = (Rpc - LABEL_147_8);
      goto continuation_9;

    case 9:
      current_block = (Rpc - LABEL_147_16);
      goto label_33;

    case 10:
      current_block = (Rpc - LABEL_147_15);
      goto continuation_24;

    case 11:
      current_block = (Rpc - LABEL_147_13);
      goto continuation_14;

    case 12:
      current_block = (Rpc - LABEL_147_17);
      goto label_36;

    case 13:
      current_block = (Rpc - LABEL_147_18);
      goto label_38;

    case 14:
      current_block = (Rpc - LABEL_147_19);
      goto label_37;

    case 15:
      current_block = (Rpc - LABEL_147_20);
      goto label_35;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (delete_40)
DEFLABEL (delete_28)
  INTERRUPT_CHECK (26, LABEL_147_4);
  (Wrd5.Obj) = (Rsp [2]);
  if ((Wrd5.Obj) == (current_block [OBJECT_147_0]))
    goto label_56;
  (* (--Rsp)) = (Wrd5.Obj);

DEFLABEL (label_55)
  (Wrd8.Obj) = (Rsp [2]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if ((Wrd9.uLng) == 1)
    goto label_45;
  if (! ((Wrd8.Obj) == (current_block [OBJECT_147_2])))
    goto label_44;

DEFLABEL (label_43)
  Rvl = (Rsp [2]);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_44)
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_147_5]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.pObj) = (& (Rsp [2]));
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd15.pObj)));
  (* (--Rsp)) = (Wrd17.Obj);
  goto lambda_2;

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_147_5);
  goto label_43;

DEFLABEL (label_45)
  if (! ((Wrd9.uLng) == 1))
    goto label_54;
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd20.Obj) = ((Wrd22.pObj) [0]);

DEFLABEL (label_53)
  (Wrd32.Obj) = (current_block [OBJECT_147_2]);
  (* (Rhp++)) = (Wrd20.Obj);
  (* (Rhp++)) = (Wrd32.Obj);
  (Wrd30.pObj) = (& (Rhp [-2]));
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd30.pObj)));
  (* (--Rsp)) = (Wrd31.Obj);
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_147_8]))));
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd31.Obj);
  (Wrd40.Obj) = (Rsp [5]);
  (Wrd41.uLng) = (OBJECT_TYPE (Wrd40.Obj));
  if (! ((Wrd41.uLng) == 1))
    goto label_52;
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd40.Obj));
  (Wrd39.Obj) = ((Wrd38.pObj) [1]);
  (* (--Rsp)) = (Wrd39.Obj);

DEFLABEL (label_51)
  goto loop_21;

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_147_8);

DEFLABEL (label_50)
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_147_15]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd12.Obj) = (Rsp [5]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_49;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [0]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_48)
  (Wrd18.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd18.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_24)
  INTERRUPT_CHECK (27, LABEL_147_15);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_46;
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [5]));
  goto pop_return;

DEFLABEL (label_46)
  (Wrd7.Obj) = (Rsp [0]);
  (Rsp [4]) = (Wrd7.Obj);
  Rsp = (& (Rsp [4]));
  (Wrd12.Obj) = (Rsp [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_47;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  Rvl = ((Wrd10.pObj) [1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_47)
  INVOKE_PRIMITIVE ((current_block [OBJECT_147_3]), 1);

DEFLABEL (label_49)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_147_16]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_147_1]), 1);

DEFLABEL (label_33)
  (* (--Rsp)) = Rvl;
  goto label_48;

DEFLABEL (label_52)
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_147_9]))));
  (* (--Rsp)) = (Wrd45.Obj);
  (* (--Rsp)) = (Wrd40.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_147_3]), 1);

DEFLABEL (label_31)
  (* (--Rsp)) = Rvl;
  goto label_51;

DEFLABEL (label_54)
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_147_7]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_147_1]), 1);

DEFLABEL (label_30)
  (Wrd20.Obj) = Rvl;
  goto label_53;

DEFLABEL (label_56)
  (Wrd47.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_147_0]));
  (Wrd50.Obj) = ((Wrd47.pObj) [0]);
  (Wrd51.uLng) = (OBJECT_TYPE (Wrd50.Obj));
  if ((Wrd51.uLng) == 50)
    goto label_58;
  Wrd46 = Wrd50;

DEFLABEL (label_57)
  (* (--Rsp)) = (Wrd46.Obj);
  goto label_55;

DEFLABEL (label_58)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_147_6])), (Wrd47.pObj));

DEFLABEL (label_32)
  (Wrd46.Obj) = Rvl;
  goto label_57;

DEFLABEL (lambda_41)
DEFLABEL (lambda_2)
  INTERRUPT_CHECK (26, LABEL_147_10);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [1]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_147_4]);
  (Rsp [1]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_147_11]));

DEFLABEL (loop_42)
DEFLABEL (loop_21)
  INTERRUPT_CHECK (26, LABEL_147_12);
  (Wrd19.Obj) = (Rsp [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if ((Wrd20.uLng) == 1)
    goto label_60;
  if ((Wrd19.Obj) == (current_block [OBJECT_147_2]))
    goto label_59;
  (Wrd24.pObj) = (& (Rsp [5]));
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd24.pObj)));
  (Rsp [1]) = (Wrd26.Obj);
  Rsp = (& (Rsp [1]));
  goto lambda_2;

DEFLABEL (label_59)
  Rsp = (& (Rsp [3]));
  goto label_50;

DEFLABEL (label_60)
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_147_13]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (Wrd32.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd32.Obj);
  if (! ((Wrd20.uLng) == 1))
    goto label_71;
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd35.Obj) = ((Wrd34.pObj) [0]);
  (* (--Rsp)) = (Wrd35.Obj);

DEFLABEL (label_70)
  (Wrd42.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd42.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_147_13);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_63;
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_62;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_61)
  (Rsp [0]) = (Wrd7.Obj);
  goto loop_21;

DEFLABEL (label_62)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_147_20]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_147_3]), 1);

DEFLABEL (label_35)
  (Wrd7.Obj) = Rvl;
  goto label_61;

DEFLABEL (label_63)
  (Wrd19.Obj) = (Rsp [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 1))
    goto label_69;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd16.Obj) = ((Wrd18.pObj) [0]);

DEFLABEL (label_68)
  (Wrd28.Obj) = (current_block [OBJECT_147_2]);
  (* (Rhp++)) = (Wrd16.Obj);
  (* (Rhp++)) = (Wrd28.Obj);
  (Wrd26.pObj) = (& (Rhp [-2]));
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd26.pObj)));
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd43.Obj) = (Rsp [2]);
  (Wrd44.uLng) = (OBJECT_TYPE (Wrd43.Obj));
  if (! ((Wrd44.uLng) == 1))
    goto label_67;
  (Wrd41.pObj) = (OBJECT_ADDRESS (Wrd43.Obj));
  ((Wrd41.pObj) [1]) = (Wrd27.Obj);

DEFLABEL (label_66)
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd33.uLng) == 1))
    goto label_65;
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd29.Obj) = ((Wrd31.pObj) [1]);

DEFLABEL (label_64)
  (Rsp [1]) = (Wrd29.Obj);
  (Wrd38.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd38.Obj);
  Rsp = (& (Rsp [1]));
  goto loop_21;

DEFLABEL (label_65)
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_147_19]))));
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_147_3]), 1);

DEFLABEL (label_37)
  (Wrd29.Obj) = Rvl;
  goto label_64;

DEFLABEL (label_67)
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_147_18]))));
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd43.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_147_5]), 2);

DEFLABEL (label_38)
  goto label_66;

DEFLABEL (label_69)
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_147_17]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_147_1]), 1);

DEFLABEL (label_36)
  (Wrd16.Obj) = Rvl;
  goto label_68;

DEFLABEL (label_71)
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_147_14]))));
  (* (--Rsp)) = (Wrd41.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_147_1]), 1);

DEFLABEL (label_34)
  (* (--Rsp)) = Rvl;
  goto label_70;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_148_5 3
#define LABEL_148_4 5
#define LABEL_148_6 7
#define LABEL_148_8 9
#define LABEL_148_9 11
#define LABEL_148_11 13
#define LABEL_148_13 15
#define LABEL_148_7 17
#define LABEL_148_15 19
#define LABEL_148_14 21
#define LABEL_148_12 23
#define LABEL_148_16 25
#define LABEL_148_17 27
#define LABEL_148_18 29
#define LABEL_148_19 31
#define ENVIRONMENT_LABEL_148_3 40
#define DEBUGGING_LABEL_148_2 39
#define OBJECT_148_3 38
#define OBJECT_148_2 37
#define OBJECT_148_1 36
#define OBJECT_148_0 35
#define EXECUTE_CACHE_148_10 33
#define FREE_REFERENCES_LABEL_148_0 32
#define NUMBER_OF_LINKER_SECTIONS_148_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_148 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd15;
  machine_word Wrd9;
  machine_word Wrd33;
  machine_word Wrd49;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd16;
  machine_word Wrd18;
  machine_word Wrd10;
  machine_word Wrd13;
  machine_word Wrd26;
  machine_word Wrd24;
  machine_word Wrd41;
  machine_word Wrd34;
  machine_word Wrd31;
  machine_word Wrd20;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd14;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd42;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd32;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd29;
  machine_word Wrd25;
  machine_word Wrd17;
  machine_word Wrd19;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_148_5);
      goto continuation_3;

    case 1:
      current_block = (Rpc - LABEL_148_4);
      goto Z__delete_25;

    case 2:
      current_block = (Rpc - LABEL_148_6);
      goto label_27;

    case 3:
      current_block = (Rpc - LABEL_148_8);
      goto label_28;

    case 4:
      current_block = (Rpc - LABEL_148_9);
      goto lambda_0;

    case 5:
      current_block = (Rpc - LABEL_148_11);
      goto loop_19;

    case 6:
      current_block = (Rpc - LABEL_148_13);
      goto label_30;

    case 7:
      current_block = (Rpc - LABEL_148_7);
      goto continuation_7;

    case 8:
      current_block = (Rpc - LABEL_148_15);
      goto label_29;

    case 9:
      current_block = (Rpc - LABEL_148_14);
      goto continuation_22;

    case 10:
      current_block = (Rpc - LABEL_148_12);
      goto continuation_12;

    case 11:
      current_block = (Rpc - LABEL_148_16);
      goto label_32;

    case 12:
      current_block = (Rpc - LABEL_148_17);
      goto label_34;

    case 13:
      current_block = (Rpc - LABEL_148_18);
      goto label_33;

    case 14:
      current_block = (Rpc - LABEL_148_19);
      goto label_31;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (Z__delete_36)
DEFLABEL (Z__delete_25)
  INTERRUPT_CHECK (26, LABEL_148_4);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_41;
  if (! ((Wrd5.Obj) == (current_block [OBJECT_148_1])))
    goto label_40;

DEFLABEL (label_39)
  Rvl = (Rsp [1]);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_40)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_148_5]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.pObj) = (& (Rsp [1]));
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd12.pObj)));
  (* (--Rsp)) = (Wrd14.Obj);
  goto lambda_0;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_148_5);
  goto label_39;

DEFLABEL (label_41)
  if (! ((Wrd6.uLng) == 1))
    goto label_50;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd17.Obj) = ((Wrd19.pObj) [0]);

DEFLABEL (label_49)
  (Wrd29.Obj) = (current_block [OBJECT_148_1]);
  (* (Rhp++)) = (Wrd17.Obj);
  (* (Rhp++)) = (Wrd29.Obj);
  (Wrd27.pObj) = (& (Rhp [-2]));
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd27.pObj)));
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_148_7]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd37.Obj) = (Rsp [4]);
  (Wrd38.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if (! ((Wrd38.uLng) == 1))
    goto label_48;
  (Wrd35.pObj) = (OBJECT_ADDRESS (Wrd37.Obj));
  (Wrd36.Obj) = ((Wrd35.pObj) [1]);
  (* (--Rsp)) = (Wrd36.Obj);

DEFLABEL (label_47)
  goto loop_19;

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_148_7);

DEFLABEL (label_46)
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_148_14]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd12.Obj) = (Rsp [4]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_45;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [0]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_44)
  (Wrd18.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd18.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_22)
  INTERRUPT_CHECK (27, LABEL_148_14);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_42;
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [5]));
  goto pop_return;

DEFLABEL (label_42)
  (Wrd7.Obj) = (Rsp [0]);
  (Rsp [4]) = (Wrd7.Obj);
  Rsp = (& (Rsp [4]));
  (Wrd12.Obj) = (Rsp [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_43;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  Rvl = ((Wrd10.pObj) [1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_43)
  INVOKE_PRIMITIVE ((current_block [OBJECT_148_2]), 1);

DEFLABEL (label_45)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_148_15]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_148_0]), 1);

DEFLABEL (label_29)
  (* (--Rsp)) = Rvl;
  goto label_44;

DEFLABEL (label_48)
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_148_8]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_148_2]), 1);

DEFLABEL (label_28)
  (* (--Rsp)) = Rvl;
  goto label_47;

DEFLABEL (label_50)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_148_6]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_148_0]), 1);

DEFLABEL (label_27)
  (Wrd17.Obj) = Rvl;
  goto label_49;

DEFLABEL (lambda_37)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_148_9);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [1]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = ((Wrd6.pObj) [3]);
  (Rsp [1]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_148_10]));

DEFLABEL (loop_38)
DEFLABEL (loop_19)
  INTERRUPT_CHECK (26, LABEL_148_11);
  (Wrd19.Obj) = (Rsp [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if ((Wrd20.uLng) == 1)
    goto label_52;
  if ((Wrd19.Obj) == (current_block [OBJECT_148_1]))
    goto label_51;
  (Wrd24.pObj) = (& (Rsp [4]));
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd24.pObj)));
  (Rsp [1]) = (Wrd26.Obj);
  Rsp = (& (Rsp [1]));
  goto lambda_0;

DEFLABEL (label_51)
  Rsp = (& (Rsp [3]));
  goto label_46;

DEFLABEL (label_52)
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_148_12]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (Wrd32.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd32.Obj);
  if (! ((Wrd20.uLng) == 1))
    goto label_63;
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd35.Obj) = ((Wrd34.pObj) [0]);
  (* (--Rsp)) = (Wrd35.Obj);

DEFLABEL (label_62)
  (Wrd42.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd42.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_148_12);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_55;
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_54;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_53)
  (Rsp [0]) = (Wrd7.Obj);
  goto loop_19;

DEFLABEL (label_54)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_148_19]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_148_2]), 1);

DEFLABEL (label_31)
  (Wrd7.Obj) = Rvl;
  goto label_53;

DEFLABEL (label_55)
  (Wrd19.Obj) = (Rsp [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 1))
    goto label_61;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd16.Obj) = ((Wrd18.pObj) [0]);

DEFLABEL (label_60)
  (Wrd28.Obj) = (current_block [OBJECT_148_1]);
  (* (Rhp++)) = (Wrd16.Obj);
  (* (Rhp++)) = (Wrd28.Obj);
  (Wrd26.pObj) = (& (Rhp [-2]));
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd26.pObj)));
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd43.Obj) = (Rsp [2]);
  (Wrd44.uLng) = (OBJECT_TYPE (Wrd43.Obj));
  if (! ((Wrd44.uLng) == 1))
    goto label_59;
  (Wrd41.pObj) = (OBJECT_ADDRESS (Wrd43.Obj));
  ((Wrd41.pObj) [1]) = (Wrd27.Obj);

DEFLABEL (label_58)
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd33.uLng) == 1))
    goto label_57;
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd29.Obj) = ((Wrd31.pObj) [1]);

DEFLABEL (label_56)
  (Rsp [1]) = (Wrd29.Obj);
  (Wrd38.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd38.Obj);
  Rsp = (& (Rsp [1]));
  goto loop_19;

DEFLABEL (label_57)
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_148_18]))));
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_148_2]), 1);

DEFLABEL (label_33)
  (Wrd29.Obj) = Rvl;
  goto label_56;

DEFLABEL (label_59)
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_148_17]))));
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd43.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_148_3]), 2);

DEFLABEL (label_34)
  goto label_58;

DEFLABEL (label_61)
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_148_16]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_148_0]), 1);

DEFLABEL (label_32)
  (Wrd16.Obj) = Rvl;
  goto label_60;

DEFLABEL (label_63)
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_148_13]))));
  (* (--Rsp)) = (Wrd41.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_148_0]), 1);

DEFLABEL (label_30)
  (* (--Rsp)) = Rvl;
  goto label_62;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_149_4 3
#define LABEL_149_5 5
#define LABEL_149_6 7
#define LABEL_149_7 9
#define LABEL_149_8 11
#define LABEL_149_10 13
#define LABEL_149_12 15
#define LABEL_149_13 17
#define LABEL_149_14 19
#define LABEL_149_15 21
#define LABEL_149_16 23
#define LABEL_149_9 25
#define ENVIRONMENT_LABEL_149_3 35
#define DEBUGGING_LABEL_149_2 34
#define OBJECT_149_4 33
#define OBJECT_149_3 32
#define OBJECT_149_2 31
#define OBJECT_149_1 30
#define OBJECT_149_0 29
#define EXECUTE_CACHE_149_11 27
#define FREE_REFERENCES_LABEL_149_0 26
#define NUMBER_OF_LINKER_SECTIONS_149_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_149 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd12;
  machine_word Wrd40;
  machine_word Wrd50;
  machine_word Wrd49;
  machine_word Wrd51;
  machine_word Wrd47;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd63;
  machine_word Wrd65;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd53;
  machine_word Wrd45;
  machine_word Wrd52;
  machine_word Wrd42;
  machine_word Wrd41;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd39;
  machine_word Wrd36;
  machine_word Wrd59;
  machine_word Wrd66;
  machine_word Wrd62;
  machine_word Wrd54;
  machine_word Wrd56;
  machine_word Wrd58;
  machine_word Wrd57;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd24;
  machine_word Wrd31;
  machine_word Wrd27;
  machine_word Wrd19;
  machine_word Wrd21;
  machine_word Wrd5;
  machine_word Wrd67;
  machine_word Wrd7;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_149_4);
      goto delqB_19;

    case 1:
      current_block = (Rpc - LABEL_149_5);
      goto continuation_2;

    case 2:
      current_block = (Rpc - LABEL_149_6);
      goto lambda_8;

    case 3:
      current_block = (Rpc - LABEL_149_7);
      goto label_21;

    case 4:
      current_block = (Rpc - LABEL_149_8);
      goto label_23;

    case 5:
      current_block = (Rpc - LABEL_149_10);
      goto label_22;

    case 6:
      current_block = (Rpc - LABEL_149_12);
      goto continuation_15;

    case 7:
      current_block = (Rpc - LABEL_149_13);
      goto lambda_16;

    case 8:
      current_block = (Rpc - LABEL_149_14);
      goto label_24;

    case 9:
      current_block = (Rpc - LABEL_149_15);
      goto label_26;

    case 10:
      current_block = (Rpc - LABEL_149_16);
      goto label_25;

    case 11:
      current_block = (Rpc - LABEL_149_9);
      goto continuation_6;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (delqB_28)
DEFLABEL (delqB_19)
  INTERRUPT_CHECK (26, LABEL_149_4);
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (59, Rsp));
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  Rdl = (& (Rsp [4]));
  goto lambda_8;

DEFLABEL (lambda_29)
DEFLABEL (lambda_8)
  DLINK_INTERRUPT_CHECK (25, LABEL_149_6);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_33;
  if (! ((Wrd5.Obj) == (current_block [OBJECT_149_2])))
    goto label_32;

DEFLABEL (label_31)
  Rvl = (current_block [OBJECT_149_2]);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_32)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_149_5]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_149_3]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [4]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [1]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_149_11]));

DEFLABEL (label_33)
  if (! ((Wrd6.uLng) == 1))
    goto label_41;
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd19.Obj) = ((Wrd21.pObj) [0]);

DEFLABEL (label_40)
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd34.Obj) = ((Wrd33.pObj) [0]);
  if ((Wrd34.Obj) == (Wrd19.Obj))
    goto label_37;
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd36.Obj);
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_149_9]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (Wrd43.Obj) = (Rsp [2]);
  (Wrd44.uLng) = (OBJECT_TYPE (Wrd43.Obj));
  if (! ((Wrd44.uLng) == 1))
    goto label_36;
  (Wrd41.pObj) = (OBJECT_ADDRESS (Wrd43.Obj));
  (Wrd42.Obj) = ((Wrd41.pObj) [1]);
  (* (--Rsp)) = (Wrd42.Obj);

DEFLABEL (label_35)
  (Wrd53.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd53.Obj);
  goto lambda_16;

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_149_9);

DEFLABEL (label_34)
  (Wrd59.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd59.Obj));
  Rvl = (Rsp [0]);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_36)
  (* (--Rsp)) = (Wrd36.Obj);
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_149_10]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (* (--Rsp)) = (Wrd43.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_149_1]), 1);

DEFLABEL (label_22)
  (Wrd45.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd45.Obj));
  (* (--Rsp)) = Rvl;
  goto label_35;

DEFLABEL (label_37)
  (Wrd57.Obj) = (Rsp [0]);
  (Wrd58.uLng) = (OBJECT_TYPE (Wrd57.Obj));
  if (! ((Wrd58.uLng) == 1))
    goto label_39;
  (Wrd56.pObj) = (OBJECT_ADDRESS (Wrd57.Obj));
  (Wrd54.Obj) = ((Wrd56.pObj) [1]);

DEFLABEL (label_38)
  (Rsp [0]) = (Wrd54.Obj);
  goto lambda_8;

DEFLABEL (label_39)
  (Wrd62.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd62.Obj);
  (Wrd66.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_149_8]))));
  (* (--Rsp)) = (Wrd66.Obj);
  (* (--Rsp)) = (Wrd57.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_149_1]), 1);

DEFLABEL (label_23)
  (Wrd59.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd59.Obj));
  (Wrd54.Obj) = Rvl;
  goto label_38;

DEFLABEL (label_41)
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_149_7]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_149_0]), 1);

DEFLABEL (label_21)
  (Wrd24.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd19.Obj) = Rvl;
  goto label_40;

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_149_5);
  (Wrd67.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd67.Obj));
  goto label_31;

DEFLABEL (lambda_30)
DEFLABEL (lambda_16)
  INTERRUPT_CHECK (26, LABEL_149_13);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if ((Wrd9.uLng) == 1)
    goto label_43;
  if ((Wrd8.Obj) == (current_block [OBJECT_149_2]))
    goto label_42;
  (Wrd13.Obj) = (Rsp [5]);
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd12.Obj) = ((Wrd14.pObj) [1]);
  (Rsp [0]) = (Wrd12.Obj);
  (Wrd15.Obj) = (current_block [OBJECT_149_3]);
  (Rsp [1]) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_149_11]));

DEFLABEL (label_42)
  Rsp = (& (Rsp [3]));
  goto label_34;

DEFLABEL (label_43)
  if (! ((Wrd9.uLng) == 1))
    goto label_51;
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd19.Obj) = ((Wrd21.pObj) [0]);

DEFLABEL (label_50)
  (Wrd28.Obj) = (Rsp [5]);
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd28.Obj));
  (Wrd30.Obj) = ((Wrd29.pObj) [0]);
  if ((Wrd30.Obj) == (Wrd19.Obj))
    goto label_46;
  (Wrd31.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd31.Obj);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if (! ((Wrd36.uLng) == 1))
    goto label_45;
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd31.Obj));
  (Wrd32.Obj) = ((Wrd34.pObj) [1]);

DEFLABEL (label_44)
  (Rsp [1]) = (Wrd32.Obj);
  goto lambda_16;

DEFLABEL (label_45)
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_149_16]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd31.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_149_1]), 1);

DEFLABEL (label_25)
  (Wrd32.Obj) = Rvl;
  goto label_44;

DEFLABEL (label_46)
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_149_12]))));
  (* (--Rsp)) = (Wrd43.Obj);
  (Wrd47.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd29.pObj)));
  (* (--Rsp)) = (Wrd47.Obj);
  (Wrd51.Obj) = (Rsp [3]);
  (Wrd52.uLng) = (OBJECT_TYPE (Wrd51.Obj));
  if (! ((Wrd52.uLng) == 1))
    goto label_49;
  (Wrd49.pObj) = (OBJECT_ADDRESS (Wrd51.Obj));
  (Wrd50.Obj) = ((Wrd49.pObj) [1]);
  (* (--Rsp)) = (Wrd50.Obj);

DEFLABEL (label_48)
  Rdl = (& (Rsp [2]));
  goto lambda_8;

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_149_12);
  (Rsp [1]) = Rvl;
  (Wrd65.Obj) = (Rsp [0]);
  (Wrd66.uLng) = (OBJECT_TYPE (Wrd65.Obj));
  if ((Wrd66.uLng) == 1)
    goto label_47;
  INVOKE_PRIMITIVE ((current_block [OBJECT_149_4]), 2);

DEFLABEL (label_47)
  (Wrd63.pObj) = (OBJECT_ADDRESS (Wrd65.Obj));
  ((Wrd63.pObj) [1]) = Rvl;
  goto label_42;

DEFLABEL (label_49)
  (Wrd56.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_149_15]))));
  (* (--Rsp)) = (Wrd56.Obj);
  (* (--Rsp)) = (Wrd51.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_149_1]), 1);

DEFLABEL (label_26)
  (* (--Rsp)) = Rvl;
  goto label_48;

DEFLABEL (label_51)
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_149_14]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_149_0]), 1);

DEFLABEL (label_24)
  (Wrd19.Obj) = Rvl;
  goto label_50;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_150_4 3
#define LABEL_150_5 5
#define LABEL_150_6 7
#define LABEL_150_8 9
#define LABEL_150_7 11
#define LABEL_150_12 13
#define LABEL_150_13 15
#define LABEL_150_14 17
#define LABEL_150_15 19
#define LABEL_150_17 21
#define LABEL_150_11 23
#define LABEL_150_16 25
#define LABEL_150_18 27
#define LABEL_150_19 29
#define ENVIRONMENT_LABEL_150_3 41
#define DEBUGGING_LABEL_150_2 40
#define OBJECT_150_4 39
#define OBJECT_150_3 38
#define OBJECT_150_2 37
#define OBJECT_150_1 36
#define OBJECT_150_0 35
#define EXECUTE_CACHE_150_10 31
#define EXECUTE_CACHE_150_9 33
#define FREE_REFERENCES_LABEL_150_0 30
#define NUMBER_OF_LINKER_SECTIONS_150_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_150 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd22;
  machine_word Wrd18;
  machine_word Wrd27;
  machine_word Wrd35;
  machine_word Wrd33;
  machine_word Wrd24;
  machine_word Wrd8;
  machine_word Wrd42;
  machine_word Wrd41;
  machine_word Wrd21;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd12;
  machine_word Wrd32;
  machine_word Wrd28;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd29;
  machine_word Wrd36;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd5;
  machine_word Wrd40;
  machine_word Wrd7;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_150_4);
      goto delvB_19;

    case 1:
      current_block = (Rpc - LABEL_150_5);
      goto continuation_2;

    case 2:
      current_block = (Rpc - LABEL_150_6);
      goto lambda_8;

    case 3:
      current_block = (Rpc - LABEL_150_8);
      goto label_21;

    case 4:
      current_block = (Rpc - LABEL_150_7);
      goto continuation_4;

    case 5:
      current_block = (Rpc - LABEL_150_12);
      goto label_23;

    case 6:
      current_block = (Rpc - LABEL_150_13);
      goto label_22;

    case 7:
      current_block = (Rpc - LABEL_150_14);
      goto continuation_15;

    case 8:
      current_block = (Rpc - LABEL_150_15);
      goto lambda_16;

    case 9:
      current_block = (Rpc - LABEL_150_17);
      goto label_24;

    case 10:
      current_block = (Rpc - LABEL_150_11);
      goto continuation_6;

    case 11:
      current_block = (Rpc - LABEL_150_16);
      goto continuation_12;

    case 12:
      current_block = (Rpc - LABEL_150_18);
      goto label_26;

    case 13:
      current_block = (Rpc - LABEL_150_19);
      goto label_25;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (delvB_28)
DEFLABEL (delvB_19)
  INTERRUPT_CHECK (26, LABEL_150_4);
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (59, Rsp));
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  Rdl = (& (Rsp [4]));
  goto lambda_8;

DEFLABEL (lambda_29)
DEFLABEL (lambda_8)
  DLINK_INTERRUPT_CHECK (25, LABEL_150_6);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_33;
  if (! ((Wrd5.Obj) == (current_block [OBJECT_150_1])))
    goto label_32;

DEFLABEL (label_31)
  Rvl = (current_block [OBJECT_150_1]);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_32)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_150_5]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_150_2]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [4]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [1]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_150_10]));

DEFLABEL (label_33)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_150_7]))));
  (* (--Rsp)) = (Wrd23.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_41;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (* (--Rsp)) = (Wrd26.Obj);

DEFLABEL (label_40)
  (Wrd37.Obj) = (Rsp [4]);
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd37.Obj));
  (Wrd39.Obj) = ((Wrd38.pObj) [0]);
  (* (--Rsp)) = (Wrd39.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_150_9]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_150_7);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_36;
  (Wrd12.Obj) = (Rsp [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_35;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd9.Obj) = ((Wrd11.pObj) [1]);

DEFLABEL (label_34)
  (Rsp [0]) = (Wrd9.Obj);
  goto lambda_8;

DEFLABEL (label_35)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_150_13]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_150_3]), 1);

DEFLABEL (label_22)
  (Wrd14.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd9.Obj) = Rvl;
  goto label_34;

DEFLABEL (label_36)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_150_11]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd30.Obj) = (Rsp [2]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 1))
    goto label_39;
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd29.Obj) = ((Wrd28.pObj) [1]);
  (* (--Rsp)) = (Wrd29.Obj);

DEFLABEL (label_38)
  (Wrd40.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd40.Obj);
  goto lambda_16;

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_150_11);

DEFLABEL (label_37)
  (Wrd35.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd35.Obj));
  Rvl = (Rsp [0]);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_39)
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_150_12]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_150_3]), 1);

DEFLABEL (label_23)
  (Wrd32.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd32.Obj));
  (* (--Rsp)) = Rvl;
  goto label_38;

DEFLABEL (label_41)
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_150_8]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_150_0]), 1);

DEFLABEL (label_21)
  (Wrd29.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd29.Obj));
  (* (--Rsp)) = Rvl;
  goto label_40;

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_150_5);
  (Wrd40.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd40.Obj));
  goto label_31;

DEFLABEL (lambda_30)
DEFLABEL (lambda_16)
  INTERRUPT_CHECK (26, LABEL_150_15);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if ((Wrd9.uLng) == 1)
    goto label_43;
  if ((Wrd8.Obj) == (current_block [OBJECT_150_1]))
    goto label_42;
  (Wrd13.Obj) = (Rsp [5]);
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd12.Obj) = ((Wrd14.pObj) [1]);
  (Rsp [0]) = (Wrd12.Obj);
  (Wrd15.Obj) = (current_block [OBJECT_150_2]);
  (Rsp [1]) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_150_10]));

DEFLABEL (label_42)
  Rsp = (& (Rsp [3]));
  goto label_37;

DEFLABEL (label_43)
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_150_16]))));
  (* (--Rsp)) = (Wrd21.Obj);
  if (! ((Wrd9.uLng) == 1))
    goto label_51;
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd24.Obj) = ((Wrd23.pObj) [0]);
  (* (--Rsp)) = (Wrd24.Obj);

DEFLABEL (label_50)
  (Wrd31.Obj) = (Rsp [7]);
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd31.Obj));
  (Wrd33.Obj) = ((Wrd32.pObj) [0]);
  (* (--Rsp)) = (Wrd33.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_150_9]));

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_150_16);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_47;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_150_14]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [6]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd11.pObj)));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd17.Obj) = (Rsp [3]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_46;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [1]);
  (* (--Rsp)) = (Wrd16.Obj);

DEFLABEL (label_45)
  Rdl = (& (Rsp [2]));
  goto lambda_8;

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_150_14);
  (Rsp [1]) = Rvl;
  (Wrd41.Obj) = (Rsp [0]);
  (Wrd42.uLng) = (OBJECT_TYPE (Wrd41.Obj));
  if ((Wrd42.uLng) == 1)
    goto label_44;
  INVOKE_PRIMITIVE ((current_block [OBJECT_150_4]), 2);

DEFLABEL (label_44)
  (Wrd39.pObj) = (OBJECT_ADDRESS (Wrd41.Obj));
  ((Wrd39.pObj) [1]) = Rvl;
  goto label_42;

DEFLABEL (label_46)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_150_19]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_150_3]), 1);

DEFLABEL (label_25)
  (* (--Rsp)) = Rvl;
  goto label_45;

DEFLABEL (label_47)
  (Wrd24.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd24.Obj);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if (! ((Wrd29.uLng) == 1))
    goto label_49;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd25.Obj) = ((Wrd27.pObj) [1]);

DEFLABEL (label_48)
  (Rsp [1]) = (Wrd25.Obj);
  goto lambda_16;

DEFLABEL (label_49)
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_150_18]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_150_3]), 1);

DEFLABEL (label_26)
  (Wrd25.Obj) = Rvl;
  goto label_48;

DEFLABEL (label_51)
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_150_17]))));
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_150_0]), 1);

DEFLABEL (label_24)
  (* (--Rsp)) = Rvl;
  goto label_50;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_151_4 3
#define LABEL_151_5 5
#define LABEL_151_6 7
#define LABEL_151_7 9
#define LABEL_151_9 11
#define LABEL_151_8 13
#define LABEL_151_12 15
#define LABEL_151_13 17
#define LABEL_151_14 19
#define LABEL_151_15 21
#define LABEL_151_17 23
#define LABEL_151_11 25
#define LABEL_151_16 27
#define LABEL_151_18 29
#define LABEL_151_19 31
#define ENVIRONMENT_LABEL_151_3 44
#define DEBUGGING_LABEL_151_2 43
#define OBJECT_151_5 42
#define OBJECT_151_4 41
#define OBJECT_151_3 40
#define OBJECT_151_2 39
#define OBJECT_151_1 38
#define OBJECT_151_0 37
#define EXECUTE_CACHE_151_10 33
#define FREE_REFERENCE_151_0 36
#define FREE_REFERENCES_LABEL_151_0 32
#define NUMBER_OF_LINKER_SECTIONS_151_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_151 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd22;
  machine_word Wrd18;
  machine_word Wrd27;
  machine_word Wrd33;
  machine_word Wrd24;
  machine_word Wrd8;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd21;
  machine_word Wrd11;
  machine_word Wrd40;
  machine_word Wrd32;
  machine_word Wrd28;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd42;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd29;
  machine_word Wrd36;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd6;
  machine_word Wrd43;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd12;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_151_4);
      goto deleteB_22;

    case 1:
      current_block = (Rpc - LABEL_151_5);
      goto label_24;

    case 2:
      current_block = (Rpc - LABEL_151_6);
      goto continuation_4;

    case 3:
      current_block = (Rpc - LABEL_151_7);
      goto lambda_10;

    case 4:
      current_block = (Rpc - LABEL_151_9);
      goto label_25;

    case 5:
      current_block = (Rpc - LABEL_151_8);
      goto continuation_6;

    case 6:
      current_block = (Rpc - LABEL_151_12);
      goto label_27;

    case 7:
      current_block = (Rpc - LABEL_151_13);
      goto label_26;

    case 8:
      current_block = (Rpc - LABEL_151_14);
      goto continuation_17;

    case 9:
      current_block = (Rpc - LABEL_151_15);
      goto lambda_18;

    case 10:
      current_block = (Rpc - LABEL_151_17);
      goto label_28;

    case 11:
      current_block = (Rpc - LABEL_151_11);
      goto continuation_8;

    case 12:
      current_block = (Rpc - LABEL_151_16);
      goto continuation_14;

    case 13:
      current_block = (Rpc - LABEL_151_18);
      goto label_30;

    case 14:
      current_block = (Rpc - LABEL_151_19);
      goto label_29;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (deleteB_32)
DEFLABEL (deleteB_22)
  INTERRUPT_CHECK (26, LABEL_151_4);
  (Wrd5.Obj) = (Rsp [2]);
  if ((Wrd5.Obj) == (current_block [OBJECT_151_0]))
    goto label_36;
  (* (--Rsp)) = (Wrd5.Obj);

DEFLABEL (label_35)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (59, Rsp));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  Rdl = (& (Rsp [6]));
  goto lambda_10;

DEFLABEL (label_36)
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_151_0]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_38;
  Wrd12 = Wrd16;

DEFLABEL (label_37)
  (* (--Rsp)) = (Wrd12.Obj);
  goto label_35;

DEFLABEL (label_38)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_151_5])), (Wrd13.pObj));

DEFLABEL (label_24)
  (Wrd12.Obj) = Rvl;
  goto label_37;

DEFLABEL (lambda_33)
DEFLABEL (lambda_10)
  DLINK_INTERRUPT_CHECK (25, LABEL_151_7);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_41;
  if (! ((Wrd5.Obj) == (current_block [OBJECT_151_2])))
    goto label_40;

DEFLABEL (label_39)
  Rvl = (current_block [OBJECT_151_2]);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_40)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_151_6]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_151_3]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [4]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [2]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_151_10]));

DEFLABEL (label_41)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_151_8]))));
  (* (--Rsp)) = (Wrd23.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_49;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (* (--Rsp)) = (Wrd26.Obj);

DEFLABEL (label_48)
  (Wrd37.Obj) = (Rsp [4]);
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd37.Obj));
  (Wrd39.Obj) = ((Wrd38.pObj) [1]);
  (* (--Rsp)) = (Wrd39.Obj);
  (Wrd42.Obj) = ((Wrd38.pObj) [0]);
  (* (--Rsp)) = (Wrd42.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_151_8);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_44;
  (Wrd12.Obj) = (Rsp [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_43;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd9.Obj) = ((Wrd11.pObj) [1]);

DEFLABEL (label_42)
  (Rsp [0]) = (Wrd9.Obj);
  goto lambda_10;

DEFLABEL (label_43)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_151_13]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_151_4]), 1);

DEFLABEL (label_26)
  (Wrd14.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd9.Obj) = Rvl;
  goto label_42;

DEFLABEL (label_44)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_151_11]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd30.Obj) = (Rsp [2]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 1))
    goto label_47;
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd29.Obj) = ((Wrd28.pObj) [1]);
  (* (--Rsp)) = (Wrd29.Obj);

DEFLABEL (label_46)
  (Wrd40.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd40.Obj);
  goto lambda_18;

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_151_11);

DEFLABEL (label_45)
  (Wrd38.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd38.Obj));
  Rvl = (Rsp [0]);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_47)
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_151_12]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_151_4]), 1);

DEFLABEL (label_27)
  (Wrd32.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd32.Obj));
  (* (--Rsp)) = Rvl;
  goto label_46;

DEFLABEL (label_49)
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_151_9]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_151_1]), 1);

DEFLABEL (label_25)
  (Wrd29.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd29.Obj));
  (* (--Rsp)) = Rvl;
  goto label_48;

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_151_6);
  (Wrd43.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd43.Obj));
  goto label_39;

DEFLABEL (lambda_34)
DEFLABEL (lambda_18)
  INTERRUPT_CHECK (26, LABEL_151_15);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if ((Wrd9.uLng) == 1)
    goto label_51;
  if ((Wrd8.Obj) == (current_block [OBJECT_151_2]))
    goto label_50;
  (Wrd13.Obj) = (Rsp [5]);
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd12.Obj) = ((Wrd14.pObj) [2]);
  (Rsp [0]) = (Wrd12.Obj);
  (Wrd15.Obj) = (current_block [OBJECT_151_3]);
  (Rsp [1]) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_151_10]));

DEFLABEL (label_50)
  Rsp = (& (Rsp [3]));
  goto label_45;

DEFLABEL (label_51)
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_151_16]))));
  (* (--Rsp)) = (Wrd21.Obj);
  if (! ((Wrd9.uLng) == 1))
    goto label_59;
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd24.Obj) = ((Wrd23.pObj) [0]);
  (* (--Rsp)) = (Wrd24.Obj);

DEFLABEL (label_58)
  (Wrd31.Obj) = (Rsp [7]);
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd31.Obj));
  (Wrd33.Obj) = ((Wrd32.pObj) [1]);
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd36.Obj) = ((Wrd32.pObj) [0]);
  (* (--Rsp)) = (Wrd36.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_151_16);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_55;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_151_14]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [6]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd11.pObj)));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd17.Obj) = (Rsp [3]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_54;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [1]);
  (* (--Rsp)) = (Wrd16.Obj);

DEFLABEL (label_53)
  Rdl = (& (Rsp [2]));
  goto lambda_10;

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_151_14);
  (Rsp [1]) = Rvl;
  (Wrd44.Obj) = (Rsp [0]);
  (Wrd45.uLng) = (OBJECT_TYPE (Wrd44.Obj));
  if ((Wrd45.uLng) == 1)
    goto label_52;
  INVOKE_PRIMITIVE ((current_block [OBJECT_151_5]), 2);

DEFLABEL (label_52)
  (Wrd42.pObj) = (OBJECT_ADDRESS (Wrd44.Obj));
  ((Wrd42.pObj) [1]) = Rvl;
  goto label_50;

DEFLABEL (label_54)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_151_19]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_151_4]), 1);

DEFLABEL (label_29)
  (* (--Rsp)) = Rvl;
  goto label_53;

DEFLABEL (label_55)
  (Wrd24.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd24.Obj);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if (! ((Wrd29.uLng) == 1))
    goto label_57;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd25.Obj) = ((Wrd27.pObj) [1]);

DEFLABEL (label_56)
  (Rsp [1]) = (Wrd25.Obj);
  goto lambda_18;

DEFLABEL (label_57)
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_151_18]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_151_4]), 1);

DEFLABEL (label_30)
  (Wrd25.Obj) = Rvl;
  goto label_56;

DEFLABEL (label_59)
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_151_17]))));
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_151_1]), 1);

DEFLABEL (label_28)
  (* (--Rsp)) = Rvl;
  goto label_58;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_152_4 3
#define LABEL_152_5 5
#define LABEL_152_6 7
#define LABEL_152_8 9
#define LABEL_152_7 11
#define LABEL_152_11 13
#define LABEL_152_12 15
#define LABEL_152_13 17
#define LABEL_152_14 19
#define LABEL_152_16 21
#define LABEL_152_10 23
#define LABEL_152_15 25
#define LABEL_152_17 27
#define LABEL_152_18 29
#define ENVIRONMENT_LABEL_152_3 38
#define DEBUGGING_LABEL_152_2 37
#define OBJECT_152_3 36
#define OBJECT_152_2 35
#define OBJECT_152_1 34
#define OBJECT_152_0 33
#define EXECUTE_CACHE_152_9 31
#define FREE_REFERENCES_LABEL_152_0 30
#define NUMBER_OF_LINKER_SECTIONS_152_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_152 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd18;
  machine_word Wrd24;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd8;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd21;
  machine_word Wrd17;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd12;
  machine_word Wrd32;
  machine_word Wrd29;
  machine_word Wrd30;
  machine_word Wrd26;
  machine_word Wrd23;
  machine_word Wrd19;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd44;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd31;
  machine_word Wrd38;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd5;
  machine_word Wrd45;
  machine_word Wrd7;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_152_4);
      goto Z__deleteB_19;

    case 1:
      current_block = (Rpc - LABEL_152_5);
      goto continuation_2;

    case 2:
      current_block = (Rpc - LABEL_152_6);
      goto lambda_8;

    case 3:
      current_block = (Rpc - LABEL_152_8);
      goto label_21;

    case 4:
      current_block = (Rpc - LABEL_152_7);
      goto continuation_4;

    case 5:
      current_block = (Rpc - LABEL_152_11);
      goto label_23;

    case 6:
      current_block = (Rpc - LABEL_152_12);
      goto label_22;

    case 7:
      current_block = (Rpc - LABEL_152_13);
      goto continuation_15;

    case 8:
      current_block = (Rpc - LABEL_152_14);
      goto lambda_16;

    case 9:
      current_block = (Rpc - LABEL_152_16);
      goto label_24;

    case 10:
      current_block = (Rpc - LABEL_152_10);
      goto continuation_6;

    case 11:
      current_block = (Rpc - LABEL_152_15);
      goto continuation_12;

    case 12:
      current_block = (Rpc - LABEL_152_17);
      goto label_26;

    case 13:
      current_block = (Rpc - LABEL_152_18);
      goto label_25;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (Z__deleteB_28)
DEFLABEL (Z__deleteB_19)
  INTERRUPT_CHECK (26, LABEL_152_4);
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (59, Rsp));
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  Rdl = (& (Rsp [6]));
  goto lambda_8;

DEFLABEL (lambda_29)
DEFLABEL (lambda_8)
  DLINK_INTERRUPT_CHECK (25, LABEL_152_6);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_33;
  if (! ((Wrd5.Obj) == (current_block [OBJECT_152_1])))
    goto label_32;

DEFLABEL (label_31)
  Rvl = (current_block [OBJECT_152_1]);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_32)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_152_5]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [3]);
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd19.Obj) = ((Wrd15.pObj) [1]);
  (* (--Rsp)) = (Wrd19.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_152_9]));

DEFLABEL (label_33)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_152_7]))));
  (* (--Rsp)) = (Wrd25.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_41;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [0]);
  (* (--Rsp)) = (Wrd28.Obj);

DEFLABEL (label_40)
  (Wrd39.Obj) = (Rsp [4]);
  (Wrd40.pObj) = (OBJECT_ADDRESS (Wrd39.Obj));
  (Wrd41.Obj) = ((Wrd40.pObj) [0]);
  (* (--Rsp)) = (Wrd41.Obj);
  (Wrd44.Obj) = ((Wrd40.pObj) [2]);
  (* (--Rsp)) = (Wrd44.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_152_7);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_36;
  (Wrd12.Obj) = (Rsp [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_35;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd9.Obj) = ((Wrd11.pObj) [1]);

DEFLABEL (label_34)
  (Rsp [0]) = (Wrd9.Obj);
  goto lambda_8;

DEFLABEL (label_35)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_152_12]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_152_2]), 1);

DEFLABEL (label_22)
  (Wrd14.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd9.Obj) = Rvl;
  goto label_34;

DEFLABEL (label_36)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_152_10]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd30.Obj) = (Rsp [2]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 1))
    goto label_39;
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd29.Obj) = ((Wrd28.pObj) [1]);
  (* (--Rsp)) = (Wrd29.Obj);

DEFLABEL (label_38)
  (Wrd40.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd40.Obj);
  goto lambda_16;

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_152_10);

DEFLABEL (label_37)
  (Wrd40.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd40.Obj));
  Rvl = (Rsp [0]);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_39)
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_152_11]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_152_2]), 1);

DEFLABEL (label_23)
  (Wrd32.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd32.Obj));
  (* (--Rsp)) = Rvl;
  goto label_38;

DEFLABEL (label_41)
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_152_8]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_152_0]), 1);

DEFLABEL (label_21)
  (Wrd31.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd31.Obj));
  (* (--Rsp)) = Rvl;
  goto label_40;

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_152_5);
  (Wrd45.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd45.Obj));
  goto label_31;

DEFLABEL (lambda_30)
DEFLABEL (lambda_16)
  INTERRUPT_CHECK (26, LABEL_152_14);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if ((Wrd9.uLng) == 1)
    goto label_43;
  if ((Wrd8.Obj) == (current_block [OBJECT_152_1]))
    goto label_42;
  (Wrd13.Obj) = (Rsp [5]);
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd12.Obj) = ((Wrd14.pObj) [1]);
  (Rsp [0]) = (Wrd12.Obj);
  (Wrd15.Obj) = ((Wrd14.pObj) [3]);
  (Rsp [1]) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_152_9]));

DEFLABEL (label_42)
  Rsp = (& (Rsp [3]));
  goto label_37;

DEFLABEL (label_43)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_152_15]))));
  (* (--Rsp)) = (Wrd23.Obj);
  if (! ((Wrd9.uLng) == 1))
    goto label_51;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [0]);
  (* (--Rsp)) = (Wrd26.Obj);

DEFLABEL (label_50)
  (Wrd33.Obj) = (Rsp [7]);
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd35.Obj) = ((Wrd34.pObj) [0]);
  (* (--Rsp)) = (Wrd35.Obj);
  (Wrd38.Obj) = ((Wrd34.pObj) [2]);
  (* (--Rsp)) = (Wrd38.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_152_15);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_47;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_152_13]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [6]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd11.pObj)));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd17.Obj) = (Rsp [3]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_46;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [1]);
  (* (--Rsp)) = (Wrd16.Obj);

DEFLABEL (label_45)
  Rdl = (& (Rsp [2]));
  goto lambda_8;

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_152_13);
  (Rsp [1]) = Rvl;
  (Wrd46.Obj) = (Rsp [0]);
  (Wrd47.uLng) = (OBJECT_TYPE (Wrd46.Obj));
  if ((Wrd47.uLng) == 1)
    goto label_44;
  INVOKE_PRIMITIVE ((current_block [OBJECT_152_3]), 2);

DEFLABEL (label_44)
  (Wrd44.pObj) = (OBJECT_ADDRESS (Wrd46.Obj));
  ((Wrd44.pObj) [1]) = Rvl;
  goto label_42;

DEFLABEL (label_46)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_152_18]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_152_2]), 1);

DEFLABEL (label_25)
  (* (--Rsp)) = Rvl;
  goto label_45;

DEFLABEL (label_47)
  (Wrd24.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd24.Obj);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if (! ((Wrd29.uLng) == 1))
    goto label_49;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd25.Obj) = ((Wrd27.pObj) [1]);

DEFLABEL (label_48)
  (Rsp [1]) = (Wrd25.Obj);
  goto lambda_16;

DEFLABEL (label_49)
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_152_17]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_152_2]), 1);

DEFLABEL (label_26)
  (Wrd25.Obj) = Rvl;
  goto label_48;

DEFLABEL (label_51)
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_152_16]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_152_0]), 1);

DEFLABEL (label_24)
  (* (--Rsp)) = Rvl;
  goto label_50;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_153_4 3
#define LABEL_153_5 5
#define ENVIRONMENT_LABEL_153_3 12
#define DEBUGGING_LABEL_153_2 11
#define EXECUTE_CACHE_153_6 7
#define FREE_REFERENCE_153_0 10
#define FREE_REFERENCES_LABEL_153_0 6
#define NUMBER_OF_LINKER_SECTIONS_153_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_153 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd7;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_153_4);
      goto alistP_0;

    case 1:
      current_block = (Rpc - LABEL_153_5);
      goto label_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (alistP_4)
DEFLABEL (alistP_0)
  INTERRUPT_CHECK (26, LABEL_153_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_153_0]));
  (Wrd11.Obj) = ((Wrd8.pObj) [0]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if ((Wrd12.uLng) == 50)
    goto label_6;
  Wrd7 = Wrd11;

DEFLABEL (label_5)
  (Rsp [1]) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_153_6]));

DEFLABEL (label_6)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_153_5])), (Wrd8.pObj));

DEFLABEL (label_2)
  (Wrd7.Obj) = Rvl;
  goto label_5;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_154_4 3
#define LABEL_154_5 5
#define ENVIRONMENT_LABEL_154_3 13
#define DEBUGGING_LABEL_154_2 12
#define OBJECT_154_0 11
#define EXECUTE_CACHE_154_7 7
#define EXECUTE_CACHE_154_6 9
#define FREE_REFERENCES_LABEL_154_0 6
#define NUMBER_OF_LINKER_SECTIONS_154_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_154 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_154_4);
      goto guarantee_alist_1;

    case 1:
      current_block = (Rpc - LABEL_154_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (guarantee_alist_4)
DEFLABEL (guarantee_alist_1)
  INTERRUPT_CHECK (26, LABEL_154_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_154_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_154_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_154_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_5;
  Rvl = (current_block [OBJECT_154_0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_5)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_154_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_155_4 3
#define ENVIRONMENT_LABEL_155_3 11
#define DEBUGGING_LABEL_155_2 10
#define OBJECT_155_2 9
#define OBJECT_155_1 8
#define OBJECT_155_0 7
#define EXECUTE_CACHE_155_5 5
#define FREE_REFERENCES_LABEL_155_0 4
#define NUMBER_OF_LINKER_SECTIONS_155_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_155 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_155_4);
      goto error_not_alist_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (error_not_alist_5)
DEFLABEL (error_not_alist_2)
  INTERRUPT_CHECK (26, LABEL_155_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_155_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [2]);
  if ((Wrd7.Obj) == (current_block [OBJECT_155_1]))
    goto label_7;
  Wrd9 = Wrd7;
  goto label_6;

DEFLABEL (label_7)
  (Wrd9.Obj) = (current_block [OBJECT_155_2]);

DEFLABEL (label_6)
DEFLABEL (label_8)
  (Rsp [2]) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_155_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_156_4 3
#define ENVIRONMENT_LABEL_156_3 5
#define DEBUGGING_LABEL_156_2 4
#define FREE_REFERENCES_LABEL_156_0 4
#define NUMBER_OF_LINKER_SECTIONS_156_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_156 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd12;
  machine_word Wrd14;
  machine_word Wrd5;
  machine_word Wrd7;
  machine_word Wrd9;
  machine_word Wrd8;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_156_4);
      goto alist_cons_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (alist_cons_4)
DEFLABEL (alist_cons_1)
  INTERRUPT_CHECK (26, LABEL_156_4);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd8.Obj);
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (Wrd14.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd5.Obj);
  (* (Rhp++)) = (Wrd14.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  Rsp = (& (Rsp [3]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_157_4 3
#define LABEL_157_5 5
#define LABEL_157_6 7
#define LABEL_157_8 9
#define LABEL_157_9 11
#define LABEL_157_11 13
#define LABEL_157_12 15
#define LABEL_157_13 17
#define LABEL_157_14 19
#define LABEL_157_15 21
#define LABEL_157_16 23
#define LABEL_157_17 25
#define LABEL_157_18 27
#define LABEL_157_7 29
#define ENVIRONMENT_LABEL_157_3 39
#define DEBUGGING_LABEL_157_2 38
#define OBJECT_157_4 37
#define OBJECT_157_3 36
#define OBJECT_157_2 35
#define OBJECT_157_1 34
#define OBJECT_157_0 33
#define EXECUTE_CACHE_157_10 31
#define FREE_REFERENCES_LABEL_157_0 30
#define NUMBER_OF_LINKER_SECTIONS_157_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_157 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd83;
  machine_word Wrd82;
  machine_word Wrd74;
  machine_word Wrd76;
  machine_word Wrd78;
  machine_word Wrd77;
  machine_word Wrd94;
  machine_word Wrd86;
  machine_word Wrd89;
  machine_word Wrd88;
  machine_word Wrd72;
  machine_word Wrd71;
  machine_word Wrd73;
  machine_word Wrd67;
  machine_word Wrd69;
  machine_word Wrd66;
  machine_word Wrd65;
  machine_word Wrd59;
  machine_word Wrd60;
  machine_word Wrd61;
  machine_word Wrd58;
  machine_word Wrd50;
  machine_word Wrd54;
  machine_word Wrd53;
  machine_word Wrd49;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd34;
  machine_word Wrd36;
  machine_word Wrd26;
  machine_word Wrd18;
  machine_word Wrd20;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd25;
  machine_word Wrd52;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd42;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd39;
  machine_word Wrd35;
  machine_word Wrd27;
  machine_word Wrd29;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd14;
  machine_word Wrd16;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_157_4);
      goto alist_copy_27;

    case 1:
      current_block = (Rpc - LABEL_157_5);
      goto label_29;

    case 2:
      current_block = (Rpc - LABEL_157_6);
      goto label_30;

    case 3:
      current_block = (Rpc - LABEL_157_8);
      goto label_31;

    case 4:
      current_block = (Rpc - LABEL_157_9);
      goto lambda_0;

    case 5:
      current_block = (Rpc - LABEL_157_11);
      goto loop_23;

    case 6:
      current_block = (Rpc - LABEL_157_12);
      goto label_32;

    case 7:
      current_block = (Rpc - LABEL_157_13);
      goto label_33;

    case 8:
      current_block = (Rpc - LABEL_157_14);
      goto label_34;

    case 9:
      current_block = (Rpc - LABEL_157_15);
      goto label_35;

    case 10:
      current_block = (Rpc - LABEL_157_16);
      goto label_36;

    case 11:
      current_block = (Rpc - LABEL_157_17);
      goto label_38;

    case 12:
      current_block = (Rpc - LABEL_157_18);
      goto label_37;

    case 13:
      current_block = (Rpc - LABEL_157_7);
      goto continuation_8;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (alist_copy_40)
DEFLABEL (alist_copy_27)
  INTERRUPT_CHECK (26, LABEL_157_4);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_45;
  if ((Wrd5.Obj) == (current_block [OBJECT_157_1]))
    goto label_44;

DEFLABEL (label_43)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (59, Rsp));
  (* (--Rsp)) = (Wrd25.Obj);
  Rdl = (& (Rsp [2]));
  goto lambda_0;

DEFLABEL (label_44)
  Rvl = (Wrd5.Obj);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_45)
  if (! ((Wrd6.uLng) == 1))
    goto label_52;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd14.Obj) = ((Wrd16.pObj) [0]);

DEFLABEL (label_51)
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd23.uLng) == 1))
    goto label_43;
  (Wrd30.Obj) = (Rsp [0]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 1))
    goto label_50;
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd27.Obj) = ((Wrd29.pObj) [0]);

DEFLABEL (label_49)
  (Wrd39.Obj) = (current_block [OBJECT_157_1]);
  (* (Rhp++)) = (Wrd27.Obj);
  (* (Rhp++)) = (Wrd39.Obj);
  (Wrd37.pObj) = (& (Rhp [-2]));
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd37.pObj)));
  (* (--Rsp)) = (Wrd38.Obj);
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_157_7]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  (Wrd47.Obj) = (Rsp [3]);
  (Wrd48.uLng) = (OBJECT_TYPE (Wrd47.Obj));
  if (! ((Wrd48.uLng) == 1))
    goto label_48;
  (Wrd45.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  (Wrd46.Obj) = ((Wrd45.pObj) [1]);
  (* (--Rsp)) = (Wrd46.Obj);

DEFLABEL (label_47)
  goto loop_23;

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_157_7);

DEFLABEL (label_46)
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_48)
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_157_8]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (* (--Rsp)) = (Wrd47.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_157_2]), 1);

DEFLABEL (label_31)
  (* (--Rsp)) = Rvl;
  goto label_47;

DEFLABEL (label_50)
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_157_6]))));
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_157_0]), 1);

DEFLABEL (label_30)
  (Wrd27.Obj) = Rvl;
  goto label_49;

DEFLABEL (label_52)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_157_5]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_157_0]), 1);

DEFLABEL (label_29)
  (Wrd14.Obj) = Rvl;
  goto label_51;

DEFLABEL (lambda_41)
DEFLABEL (lambda_0)
  DLINK_INTERRUPT_CHECK (25, LABEL_157_9);
  (Wrd5.Obj) = (current_block [OBJECT_157_3]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd8.Obj) = ((Wrd7.pObj) [0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rdl)) = (Rsp [1]);
  (* (--Rdl)) = (Rsp [0]);
  Rsp = Rdl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_157_10]));

DEFLABEL (loop_42)
DEFLABEL (loop_23)
  INTERRUPT_CHECK (26, LABEL_157_11);
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if ((Wrd8.uLng) == 1)
    goto label_55;
  if ((Wrd7.Obj) == (current_block [OBJECT_157_1]))
    goto label_54;

DEFLABEL (label_53)
  (Wrd29.pObj) = (& (Rsp [4]));
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd29.pObj)));
  (Rsp [1]) = (Wrd31.Obj);
  Rdl = (& (Rsp [2]));
  Rsp = (& (Rsp [1]));
  goto lambda_0;

DEFLABEL (label_54)
  Rsp = (& (Rsp [3]));
  goto label_46;

DEFLABEL (label_55)
  if (! ((Wrd8.uLng) == 1))
    goto label_69;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd18.Obj) = ((Wrd20.pObj) [0]);

DEFLABEL (label_68)
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd27.uLng) == 1))
    goto label_53;
  (Wrd37.Obj) = (Rsp [0]);
  (Wrd38.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if (! ((Wrd38.uLng) == 1))
    goto label_67;
  (Wrd36.pObj) = (OBJECT_ADDRESS (Wrd37.Obj));
  (Wrd34.Obj) = ((Wrd36.pObj) [0]);

DEFLABEL (label_66)
  (Wrd45.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if (! ((Wrd45.uLng) == 1))
    goto label_65;
  (Wrd43.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd44.Obj) = ((Wrd43.pObj) [1]);
  (* (--Rsp)) = (Wrd44.Obj);

DEFLABEL (label_64)
  (Wrd53.Obj) = (Rsp [1]);
  (Wrd54.uLng) = (OBJECT_TYPE (Wrd53.Obj));
  if (! ((Wrd54.uLng) == 1))
    goto label_63;
  (Wrd52.pObj) = (OBJECT_ADDRESS (Wrd53.Obj));
  (Wrd50.Obj) = ((Wrd52.pObj) [0]);

DEFLABEL (label_62)
  (Wrd61.uLng) = (OBJECT_TYPE (Wrd50.Obj));
  if (! ((Wrd61.uLng) == 1))
    goto label_61;
  (Wrd60.pObj) = (OBJECT_ADDRESS (Wrd50.Obj));
  (Wrd59.Obj) = ((Wrd60.pObj) [0]);

DEFLABEL (label_60)
  (Wrd66.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd59.Obj);
  (* (Rhp++)) = (Wrd66.Obj);
  (Wrd69.pObj) = (& (Rhp [-2]));
  (Wrd67.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd69.pObj)));
  (Wrd73.Obj) = (current_block [OBJECT_157_1]);
  (* (Rhp++)) = (Wrd67.Obj);
  (* (Rhp++)) = (Wrd73.Obj);
  (Wrd71.pObj) = (& (Rhp [-2]));
  (Wrd72.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd71.pObj)));
  (* (--Rsp)) = (Wrd72.Obj);
  (Wrd88.Obj) = (Rsp [2]);
  (Wrd89.uLng) = (OBJECT_TYPE (Wrd88.Obj));
  if (! ((Wrd89.uLng) == 1))
    goto label_59;
  (Wrd86.pObj) = (OBJECT_ADDRESS (Wrd88.Obj));
  ((Wrd86.pObj) [1]) = (Wrd72.Obj);

DEFLABEL (label_58)
  (Wrd77.Obj) = (Rsp [1]);
  (Wrd78.uLng) = (OBJECT_TYPE (Wrd77.Obj));
  if (! ((Wrd78.uLng) == 1))
    goto label_57;
  (Wrd76.pObj) = (OBJECT_ADDRESS (Wrd77.Obj));
  (Wrd74.Obj) = ((Wrd76.pObj) [1]);

DEFLABEL (label_56)
  (Rsp [1]) = (Wrd74.Obj);
  (Wrd83.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd83.Obj);
  Rsp = (& (Rsp [1]));
  goto loop_23;

DEFLABEL (label_57)
  (Wrd82.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_157_18]))));
  (* (--Rsp)) = (Wrd82.Obj);
  (* (--Rsp)) = (Wrd77.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_157_2]), 1);

DEFLABEL (label_37)
  (Wrd74.Obj) = Rvl;
  goto label_56;

DEFLABEL (label_59)
  (Wrd94.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_157_17]))));
  (* (--Rsp)) = (Wrd94.Obj);
  (* (--Rsp)) = (Wrd72.Obj);
  (* (--Rsp)) = (Wrd88.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_157_4]), 2);

DEFLABEL (label_38)
  goto label_58;

DEFLABEL (label_61)
  (Wrd65.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_157_16]))));
  (* (--Rsp)) = (Wrd65.Obj);
  (* (--Rsp)) = (Wrd50.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_157_0]), 1);

DEFLABEL (label_36)
  (Wrd59.Obj) = Rvl;
  goto label_60;

DEFLABEL (label_63)
  (Wrd58.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_157_15]))));
  (* (--Rsp)) = (Wrd58.Obj);
  (* (--Rsp)) = (Wrd53.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_157_0]), 1);

DEFLABEL (label_35)
  (Wrd50.Obj) = Rvl;
  goto label_62;

DEFLABEL (label_65)
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_157_14]))));
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_157_2]), 1);

DEFLABEL (label_34)
  (* (--Rsp)) = Rvl;
  goto label_64;

DEFLABEL (label_67)
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_157_13]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_157_0]), 1);

DEFLABEL (label_33)
  (Wrd34.Obj) = Rvl;
  goto label_66;

DEFLABEL (label_69)
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_157_12]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_157_0]), 1);

DEFLABEL (label_32)
  (Wrd18.Obj) = Rvl;
  goto label_68;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_158_4 3
#define LABEL_158_5 5
#define TAG_158_6 1
#define LABEL_158_7 7
#define LABEL_158_8 9
#define LABEL_158_11 11
#define LABEL_158_9 13
#define LABEL_158_13 15
#define LABEL_158_10 17
#define ENVIRONMENT_LABEL_158_3 25
#define DEBUGGING_LABEL_158_2 24
#define OBJECT_158_2 23
#define OBJECT_158_1 22
#define OBJECT_158_0 21
#define EXECUTE_CACHE_158_12 19
#define FREE_REFERENCES_LABEL_158_0 18
#define NUMBER_OF_LINKER_SECTIONS_158_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_158 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd23;
  machine_word Wrd17;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd24;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_158_4);
      goto association_procedure_13;

    case 1:
      current_block = (Rpc - LABEL_158_5);
      goto lambda_19;

    case 2:
      current_block = (Rpc - LABEL_158_7);
      goto continuation_4;

    case 3:
      current_block = (Rpc - LABEL_158_8);
      goto loop_9;

    case 4:
      current_block = (Rpc - LABEL_158_11);
      goto label_15;

    case 5:
      current_block = (Rpc - LABEL_158_9);
      goto continuation_7;

    case 6:
      current_block = (Rpc - LABEL_158_13);
      goto label_16;

    case 7:
      current_block = (Rpc - LABEL_158_10);
      goto continuation_6;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (association_procedure_18)
DEFLABEL (association_procedure_13)
  INTERRUPT_CHECK (26, LABEL_158_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_158_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_158_5])));
  Rhp += 3;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd12 = Wrd7;
  (Wrd13.Obj) = (Rsp [2]);
  ((Wrd12.pObj) [2]) = (Wrd13.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd12.pObj) [3]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd12.pObj) [4]) = (Wrd9.Obj);
  Rvl = (Wrd6.Obj);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (lambda_19)
  CLOSURE_HEADER (LABEL_158_5);

DEFLABEL (lambda_12)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd5.Obj);
  goto loop_9;

DEFLABEL (loop_20)
DEFLABEL (loop_9)
  INTERRUPT_CHECK (26, LABEL_158_8);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_23;
  if (! ((Wrd5.Obj) == (current_block [OBJECT_158_1])))
    goto label_22;

DEFLABEL (label_21)
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_22)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_158_7]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [2]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [2]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_158_12]));

DEFLABEL (label_23)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_158_9]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd21.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_158_10]))));
  (* (--Rsp)) = (Wrd24.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_29;
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd27.Obj) = ((Wrd26.pObj) [0]);
  (* (--Rsp)) = (Wrd27.Obj);

DEFLABEL (label_28)
  (Wrd34.Obj) = (Rsp [5]);
  (Wrd35.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd36.Obj) = ((Wrd35.pObj) [3]);
  (* (--Rsp)) = (Wrd36.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_158_10);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [4]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [4]);
  (* (--Rsp)) = (Wrd7.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_158_9);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_25;
  (Wrd7.Obj) = (Rsp [0]);
  (Rsp [3]) = (Wrd7.Obj);
  Rsp = (& (Rsp [3]));
  (Wrd12.Obj) = (Rsp [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_24;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  Rvl = ((Wrd10.pObj) [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_24)
  INVOKE_PRIMITIVE ((current_block [OBJECT_158_0]), 1);

DEFLABEL (label_25)
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd19.uLng) == 1))
    goto label_27;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd15.Obj) = ((Wrd17.pObj) [1]);

DEFLABEL (label_26)
  (Rsp [0]) = (Wrd15.Obj);
  goto loop_9;

DEFLABEL (label_27)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_158_13]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_158_2]), 1);

DEFLABEL (label_16)
  (Wrd15.Obj) = Rvl;
  goto label_26;

DEFLABEL (label_29)
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_158_11]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_158_0]), 1);

DEFLABEL (label_15)
  (* (--Rsp)) = Rvl;
  goto label_28;

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_158_7);
  goto label_21;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_159_4 3
#define LABEL_159_5 5
#define TAG_159_6 1
#define LABEL_159_7 7
#define LABEL_159_8 9
#define TAG_159_9 3
#define LABEL_159_10 11
#define ENVIRONMENT_LABEL_159_3 13
#define DEBUGGING_LABEL_159_2 12
#define FREE_REFERENCES_LABEL_159_0 12
#define NUMBER_OF_LINKER_SECTIONS_159_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_159 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd14;
  machine_word Wrd10;
  machine_word Wrd5;
  machine_word Wrd22;
  machine_word Wrd15;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd8;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_159_4);
      goto delete_association_procedure_4;

    case 1:
      current_block = (Rpc - LABEL_159_5);
      goto lambda_8;

    case 2:
      current_block = (Rpc - LABEL_159_7);
      goto continuation_2;

    case 3:
      current_block = (Rpc - LABEL_159_8);
      goto lambda_9;

    case 4:
      current_block = (Rpc - LABEL_159_10);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (delete_association_procedure_7)
DEFLABEL (delete_association_procedure_4)
  INTERRUPT_CHECK (26, LABEL_159_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_159_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_159_5])));
  Rhp += 3;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd12 = Wrd7;
  (Wrd13.Obj) = (Rsp [2]);
  ((Wrd12.pObj) [2]) = (Wrd13.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd12.pObj) [3]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd12.pObj) [4]) = (Wrd9.Obj);
  Rvl = (Wrd6.Obj);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (lambda_8)
  CLOSURE_HEADER (LABEL_159_5);

DEFLABEL (lambda_3)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_159_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd9.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_159_9);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_159_8])));
  Rhp += 3;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd9.pObj)));
  Wrd16 = Wrd9;
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd19.Obj) = ((Wrd18.pObj) [2]);
  ((Wrd16.pObj) [2]) = (Wrd19.Obj);
  (Wrd15.Obj) = ((Wrd18.pObj) [3]);
  ((Wrd16.pObj) [3]) = (Wrd15.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  ((Wrd16.pObj) [4]) = (Wrd11.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd22.Obj) = ((Wrd18.pObj) [4]);
  (* (--Rsp)) = (Wrd22.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_159_7);
  (Rsp [1]) = Rvl;
  Rsp = (& (Rsp [1]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (lambda_9)
  CLOSURE_HEADER (LABEL_159_8);

DEFLABEL (lambda_1)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = ((Wrd6.pObj) [4]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_159_10]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd17.Obj) = ((Wrd6.pObj) [2]);
  (* (--Rsp)) = (Wrd17.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_159_10);
  (Rsp [2]) = Rvl;
  (Wrd6.Obj) = (* (Rsp++));
  (Rsp [2]) = (Wrd6.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_160_4 3
#define LABEL_160_5 5
#define LABEL_160_6 7
#define LABEL_160_7 9
#define LABEL_160_8 11
#define ENVIRONMENT_LABEL_160_3 18
#define DEBUGGING_LABEL_160_2 17
#define OBJECT_160_1 16
#define OBJECT_160_0 15
#define EXECUTE_CACHE_160_9 13
#define FREE_REFERENCES_LABEL_160_0 12
#define NUMBER_OF_LINKER_SECTIONS_160_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_160 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd26;
  machine_word Wrd24;
  machine_word Wrd11;
  machine_word Wrd23;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd30;
  machine_word Wrd31;
  machine_word Wrd27;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd19;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_160_4);
      goto assq_15;

    case 1:
      current_block = (Rpc - LABEL_160_5);
      goto continuation_7;

    case 2:
      current_block = (Rpc - LABEL_160_6);
      goto continuation_4;

    case 3:
      current_block = (Rpc - LABEL_160_7);
      goto loop_12;

    case 4:
      current_block = (Rpc - LABEL_160_8);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (assq_18)
DEFLABEL (assq_15)
  INTERRUPT_CHECK (26, LABEL_160_4);
  (Wrd5.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd5.Obj);
  goto loop_12;

DEFLABEL (loop_19)
DEFLABEL (loop_12)
  INTERRUPT_CHECK (26, LABEL_160_7);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_24;
  if ((Wrd5.Obj) == (current_block [OBJECT_160_0]))
    goto label_22;
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_160_6]))));
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_21)
  (Wrd24.pObj) = (& (Rsp [2]));
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd24.pObj)));
  (* (--Rsp)) = (Wrd26.Obj);
  goto lambda_0;

DEFLABEL (label_22)
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_23)
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_24)
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd17.Obj) = ((Wrd19.pObj) [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if ((Wrd20.uLng) == 1)
    goto label_25;
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_160_5]))));
  (* (--Rsp)) = (Wrd23.Obj);
  goto label_21;

DEFLABEL (label_25)
  (Wrd28.Obj) = (Rsp [0]);
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd28.Obj));
  (Wrd27.Obj) = ((Wrd29.pObj) [0]);
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd30.Obj) = ((Wrd31.pObj) [0]);
  (Wrd32.Obj) = (Rsp [1]);
  if ((Wrd30.Obj) == (Wrd32.Obj))
    goto label_26;
  (Wrd33.Obj) = ((Wrd29.pObj) [1]);
  (Rsp [0]) = (Wrd33.Obj);
  goto loop_12;

DEFLABEL (label_26)
  Rvl = (Wrd27.Obj);
  goto label_23;

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_160_6);
  goto label_22;

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_160_5);
  goto label_25;

DEFLABEL (lambda_20)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_160_8);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [1]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_160_1]);
  (Rsp [1]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_160_9]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_161_4 3
#define LABEL_161_5 5
#define LABEL_161_6 7
#define LABEL_161_7 9
#define LABEL_161_10 11
#define LABEL_161_8 13
#define ENVIRONMENT_LABEL_161_3 22
#define DEBUGGING_LABEL_161_2 21
#define OBJECT_161_1 20
#define OBJECT_161_0 19
#define EXECUTE_CACHE_161_11 15
#define EXECUTE_CACHE_161_9 17
#define FREE_REFERENCES_LABEL_161_0 14
#define NUMBER_OF_LINKER_SECTIONS_161_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_161 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd26;
  machine_word Wrd24;
  machine_word Wrd11;
  machine_word Wrd23;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd31;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd19;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_161_4);
      goto assv_15;

    case 1:
      current_block = (Rpc - LABEL_161_5);
      goto continuation_7;

    case 2:
      current_block = (Rpc - LABEL_161_6);
      goto continuation_4;

    case 3:
      current_block = (Rpc - LABEL_161_7);
      goto loop_12;

    case 4:
      current_block = (Rpc - LABEL_161_10);
      goto lambda_0;

    case 5:
      current_block = (Rpc - LABEL_161_8);
      goto continuation_10;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (assv_18)
DEFLABEL (assv_15)
  INTERRUPT_CHECK (26, LABEL_161_4);
  (Wrd5.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd5.Obj);
  goto loop_12;

DEFLABEL (loop_19)
DEFLABEL (loop_12)
  INTERRUPT_CHECK (26, LABEL_161_7);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_24;
  if (! ((Wrd5.Obj) == (current_block [OBJECT_161_0])))
    goto label_22;

DEFLABEL (label_21)
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_22)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_161_6]))));
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_23)
  (Wrd24.pObj) = (& (Rsp [2]));
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd24.pObj)));
  (* (--Rsp)) = (Wrd26.Obj);
  goto lambda_0;

DEFLABEL (label_24)
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd17.Obj) = ((Wrd19.pObj) [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd20.uLng) == 1))
    goto label_27;

DEFLABEL (label_26)
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_161_8]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd30.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd32.Obj) = (Rsp [2]);
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd31.Obj) = ((Wrd33.pObj) [0]);
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd31.Obj));
  (Wrd35.Obj) = ((Wrd34.pObj) [0]);
  (* (--Rsp)) = (Wrd35.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_161_9]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_161_8);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_25;
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  Rvl = ((Wrd9.pObj) [0]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_25)
  (Wrd12.Obj) = (Rsp [0]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd11.Obj) = ((Wrd13.pObj) [1]);
  (Rsp [0]) = (Wrd11.Obj);
  goto loop_12;

DEFLABEL (label_27)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_161_5]))));
  (* (--Rsp)) = (Wrd23.Obj);
  goto label_23;

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_161_6);
  goto label_21;

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_161_5);
  goto label_26;

DEFLABEL (lambda_20)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_161_10);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [1]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_161_1]);
  (Rsp [1]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_161_11]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_162_4 3
#define LABEL_162_5 5
#define LABEL_162_6 7
#define LABEL_162_7 9
#define LABEL_162_8 11
#define LABEL_162_10 13
#define LABEL_162_9 15
#define ENVIRONMENT_LABEL_162_3 25
#define DEBUGGING_LABEL_162_2 24
#define OBJECT_162_2 23
#define OBJECT_162_1 22
#define OBJECT_162_0 21
#define EXECUTE_CACHE_162_11 17
#define FREE_REFERENCE_162_0 20
#define FREE_REFERENCES_LABEL_162_0 16
#define NUMBER_OF_LINKER_SECTIONS_162_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_162 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd12;
  machine_word Wrd7;
  machine_word Wrd26;
  machine_word Wrd24;
  machine_word Wrd11;
  machine_word Wrd23;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd31;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd19;
  machine_word Wrd6;
  machine_word Wrd8;
  machine_word Wrd9;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_162_4);
      goto assoc_18;

    case 1:
      current_block = (Rpc - LABEL_162_5);
      goto label_20;

    case 2:
      current_block = (Rpc - LABEL_162_6);
      goto continuation_9;

    case 3:
      current_block = (Rpc - LABEL_162_7);
      goto continuation_6;

    case 4:
      current_block = (Rpc - LABEL_162_8);
      goto loop_14;

    case 5:
      current_block = (Rpc - LABEL_162_10);
      goto lambda_2;

    case 6:
      current_block = (Rpc - LABEL_162_9);
      goto continuation_12;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (assoc_22)
DEFLABEL (assoc_18)
  INTERRUPT_CHECK (26, LABEL_162_4);
  (Wrd5.Obj) = (Rsp [2]);
  if ((Wrd5.Obj) == (current_block [OBJECT_162_0]))
    goto label_26;
  (* (--Rsp)) = (Wrd5.Obj);

DEFLABEL (label_25)
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  goto loop_14;

DEFLABEL (label_26)
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_162_0]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_28;
  Wrd9 = Wrd13;

DEFLABEL (label_27)
  (* (--Rsp)) = (Wrd9.Obj);
  goto label_25;

DEFLABEL (label_28)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_162_5])), (Wrd10.pObj));

DEFLABEL (label_20)
  (Wrd9.Obj) = Rvl;
  goto label_27;

DEFLABEL (loop_23)
DEFLABEL (loop_14)
  INTERRUPT_CHECK (26, LABEL_162_8);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_32;
  if (! ((Wrd5.Obj) == (current_block [OBJECT_162_1])))
    goto label_30;

DEFLABEL (label_29)
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [5]));
  goto pop_return;

DEFLABEL (label_30)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_162_7]))));
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_31)
  (Wrd24.pObj) = (& (Rsp [3]));
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd24.pObj)));
  (* (--Rsp)) = (Wrd26.Obj);
  goto lambda_2;

DEFLABEL (label_32)
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd17.Obj) = ((Wrd19.pObj) [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd20.uLng) == 1))
    goto label_35;

DEFLABEL (label_34)
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_162_9]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd30.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd32.Obj) = (Rsp [2]);
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd31.Obj) = ((Wrd33.pObj) [0]);
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd31.Obj));
  (Wrd35.Obj) = ((Wrd34.pObj) [0]);
  (* (--Rsp)) = (Wrd35.Obj);
  (Wrd36.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd36.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_162_9);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_33;
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  Rvl = ((Wrd9.pObj) [0]);
  Rsp = (& (Rsp [5]));
  goto pop_return;

DEFLABEL (label_33)
  (Wrd12.Obj) = (Rsp [0]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd11.Obj) = ((Wrd13.pObj) [1]);
  (Rsp [0]) = (Wrd11.Obj);
  goto loop_14;

DEFLABEL (label_35)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_162_6]))));
  (* (--Rsp)) = (Wrd23.Obj);
  goto label_31;

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_162_7);
  goto label_29;

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_162_6);
  goto label_34;

DEFLABEL (lambda_24)
DEFLABEL (lambda_2)
  INTERRUPT_CHECK (26, LABEL_162_10);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [1]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_162_2]);
  (Rsp [1]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_162_11]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_163_4 3
#define LABEL_163_5 5
#define LABEL_163_6 7
#define LABEL_163_7 9
#define LABEL_163_9 11
#define LABEL_163_8 13
#define ENVIRONMENT_LABEL_163_3 19
#define DEBUGGING_LABEL_163_2 18
#define OBJECT_163_0 17
#define EXECUTE_CACHE_163_10 15
#define FREE_REFERENCES_LABEL_163_0 14
#define NUMBER_OF_LINKER_SECTIONS_163_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_163 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd26;
  machine_word Wrd24;
  machine_word Wrd11;
  machine_word Wrd23;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd31;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd19;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_163_4);
      goto Z__assoc_15;

    case 1:
      current_block = (Rpc - LABEL_163_5);
      goto continuation_7;

    case 2:
      current_block = (Rpc - LABEL_163_6);
      goto continuation_4;

    case 3:
      current_block = (Rpc - LABEL_163_7);
      goto loop_12;

    case 4:
      current_block = (Rpc - LABEL_163_9);
      goto lambda_0;

    case 5:
      current_block = (Rpc - LABEL_163_8);
      goto continuation_10;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (Z__assoc_18)
DEFLABEL (Z__assoc_15)
  INTERRUPT_CHECK (26, LABEL_163_4);
  (Wrd5.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd5.Obj);
  goto loop_12;

DEFLABEL (loop_19)
DEFLABEL (loop_12)
  INTERRUPT_CHECK (26, LABEL_163_7);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_24;
  if (! ((Wrd5.Obj) == (current_block [OBJECT_163_0])))
    goto label_22;

DEFLABEL (label_21)
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [5]));
  goto pop_return;

DEFLABEL (label_22)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_163_6]))));
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_23)
  (Wrd24.pObj) = (& (Rsp [2]));
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd24.pObj)));
  (* (--Rsp)) = (Wrd26.Obj);
  goto lambda_0;

DEFLABEL (label_24)
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd17.Obj) = ((Wrd19.pObj) [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd20.uLng) == 1))
    goto label_27;

DEFLABEL (label_26)
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_163_8]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd30.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd32.Obj) = (Rsp [2]);
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd31.Obj) = ((Wrd33.pObj) [0]);
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd31.Obj));
  (Wrd35.Obj) = ((Wrd34.pObj) [0]);
  (* (--Rsp)) = (Wrd35.Obj);
  (Wrd36.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd36.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_163_8);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_25;
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  Rvl = ((Wrd9.pObj) [0]);
  Rsp = (& (Rsp [5]));
  goto pop_return;

DEFLABEL (label_25)
  (Wrd12.Obj) = (Rsp [0]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd11.Obj) = ((Wrd13.pObj) [1]);
  (Rsp [0]) = (Wrd11.Obj);
  goto loop_12;

DEFLABEL (label_27)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_163_5]))));
  (* (--Rsp)) = (Wrd23.Obj);
  goto label_23;

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_163_6);
  goto label_21;

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_163_5);
  goto label_26;

DEFLABEL (lambda_20)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_163_9);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [1]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = ((Wrd6.pObj) [3]);
  (Rsp [1]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_163_10]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_164_5 3
#define LABEL_164_6 5
#define LABEL_164_4 7
#define LABEL_164_7 9
#define LABEL_164_8 11
#define LABEL_164_10 13
#define LABEL_164_11 15
#define LABEL_164_13 17
#define LABEL_164_14 19
#define LABEL_164_15 21
#define LABEL_164_16 23
#define LABEL_164_17 25
#define LABEL_164_18 27
#define LABEL_164_19 29
#define LABEL_164_20 31
#define LABEL_164_21 33
#define LABEL_164_9 35
#define LABEL_164_22 37
#define LABEL_164_23 39
#define ENVIRONMENT_LABEL_164_3 49
#define DEBUGGING_LABEL_164_2 48
#define OBJECT_164_4 47
#define OBJECT_164_3 46
#define OBJECT_164_2 45
#define OBJECT_164_1 44
#define OBJECT_164_0 43
#define EXECUTE_CACHE_164_12 41
#define FREE_REFERENCES_LABEL_164_0 40
#define NUMBER_OF_LINKER_SECTIONS_164_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_164 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd27;
  machine_word Wrd24;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd14;
  machine_word Wrd15;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd9;
  machine_word Wrd39;
  machine_word Wrd57;
  machine_word Wrd55;
  machine_word Wrd97;
  machine_word Wrd96;
  machine_word Wrd88;
  machine_word Wrd90;
  machine_word Wrd92;
  machine_word Wrd91;
  machine_word Wrd108;
  machine_word Wrd100;
  machine_word Wrd103;
  machine_word Wrd102;
  machine_word Wrd86;
  machine_word Wrd85;
  machine_word Wrd87;
  machine_word Wrd83;
  machine_word Wrd75;
  machine_word Wrd77;
  machine_word Wrd79;
  machine_word Wrd78;
  machine_word Wrd117;
  machine_word Wrd109;
  machine_word Wrd111;
  machine_word Wrd113;
  machine_word Wrd112;
  machine_word Wrd74;
  machine_word Wrd73;
  machine_word Wrd67;
  machine_word Wrd68;
  machine_word Wrd69;
  machine_word Wrd66;
  machine_word Wrd60;
  machine_word Wrd62;
  machine_word Wrd61;
  machine_word Wrd50;
  machine_word Wrd42;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd32;
  machine_word Wrd30;
  machine_word Wrd11;
  machine_word Wrd29;
  machine_word Wrd58;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd54;
  machine_word Wrd53;
  machine_word Wrd48;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd45;
  machine_word Wrd41;
  machine_word Wrd33;
  machine_word Wrd35;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd17;
  machine_word Wrd19;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_164_5);
      goto continuation_6;

    case 1:
      current_block = (Rpc - LABEL_164_6);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_164_4);
      goto del_assq_33;

    case 3:
      current_block = (Rpc - LABEL_164_7);
      goto label_35;

    case 4:
      current_block = (Rpc - LABEL_164_8);
      goto label_36;

    case 5:
      current_block = (Rpc - LABEL_164_10);
      goto label_37;

    case 6:
      current_block = (Rpc - LABEL_164_11);
      goto lambda_0;

    case 7:
      current_block = (Rpc - LABEL_164_13);
      goto continuation_16;

    case 8:
      current_block = (Rpc - LABEL_164_14);
      goto loop_26;

    case 9:
      current_block = (Rpc - LABEL_164_15);
      goto label_40;

    case 10:
      current_block = (Rpc - LABEL_164_16);
      goto label_41;

    case 11:
      current_block = (Rpc - LABEL_164_17);
      goto label_42;

    case 12:
      current_block = (Rpc - LABEL_164_18);
      goto label_46;

    case 13:
      current_block = (Rpc - LABEL_164_19);
      goto label_43;

    case 14:
      current_block = (Rpc - LABEL_164_20);
      goto label_45;

    case 15:
      current_block = (Rpc - LABEL_164_21);
      goto label_44;

    case 16:
      current_block = (Rpc - LABEL_164_9);
      goto continuation_10;

    case 17:
      current_block = (Rpc - LABEL_164_22);
      goto label_38;

    case 18:
      current_block = (Rpc - LABEL_164_23);
      goto label_39;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (del_assq_48)
DEFLABEL (del_assq_33)
  INTERRUPT_CHECK (26, LABEL_164_4);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_54;
  if (! ((Wrd5.Obj) == (current_block [OBJECT_164_1])))
    goto label_52;

DEFLABEL (label_51)
  Rvl = (Rsp [1]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_52)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_164_6]))));
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_53)
  (Wrd30.pObj) = (& (Rsp [1]));
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd30.pObj)));
  (* (--Rsp)) = (Wrd32.Obj);
  goto lambda_0;

DEFLABEL (label_54)
  if (! ((Wrd6.uLng) == 1))
    goto label_68;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd17.Obj) = ((Wrd19.pObj) [0]);

DEFLABEL (label_67)
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if ((Wrd26.uLng) == 1)
    goto label_55;
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_164_5]))));
  (* (--Rsp)) = (Wrd29.Obj);
  goto label_53;

DEFLABEL (label_55)
  (Wrd36.Obj) = (Rsp [1]);
  (Wrd37.uLng) = (OBJECT_TYPE (Wrd36.Obj));
  if (! ((Wrd37.uLng) == 1))
    goto label_66;
  (Wrd35.pObj) = (OBJECT_ADDRESS (Wrd36.Obj));
  (Wrd33.Obj) = ((Wrd35.pObj) [0]);

DEFLABEL (label_65)
  (Wrd45.Obj) = (current_block [OBJECT_164_1]);
  (* (Rhp++)) = (Wrd33.Obj);
  (* (Rhp++)) = (Wrd45.Obj);
  (Wrd43.pObj) = (& (Rhp [-2]));
  (Wrd44.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd43.pObj)));
  (* (--Rsp)) = (Wrd44.Obj);
  (Wrd48.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_164_9]))));
  (* (--Rsp)) = (Wrd48.Obj);
  (* (--Rsp)) = (Wrd44.Obj);
  (Wrd53.Obj) = (Rsp [4]);
  (Wrd54.uLng) = (OBJECT_TYPE (Wrd53.Obj));
  if (! ((Wrd54.uLng) == 1))
    goto label_64;
  (Wrd51.pObj) = (OBJECT_ADDRESS (Wrd53.Obj));
  (Wrd52.Obj) = ((Wrd51.pObj) [1]);
  (* (--Rsp)) = (Wrd52.Obj);

DEFLABEL (label_63)
  goto loop_26;

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_164_9);

DEFLABEL (label_62)
  (Wrd8.Obj) = (Rsp [2]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_61;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [0]);

DEFLABEL (label_60)
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd16.uLng) == 1))
    goto label_59;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd14.Obj) = ((Wrd15.pObj) [0]);

DEFLABEL (label_58)
  (Wrd21.Obj) = (Rsp [1]);
  if ((Wrd14.Obj) == (Wrd21.Obj))
    goto label_56;
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_56)
  (Wrd24.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd24.Obj);
  Rsp = (& (Rsp [2]));
  (Wrd29.Obj) = (Rsp [0]);
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd29.Obj));
  if (! ((Wrd30.uLng) == 1))
    goto label_57;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd29.Obj));
  Rvl = ((Wrd27.pObj) [1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_57)
  INVOKE_PRIMITIVE ((current_block [OBJECT_164_2]), 1);

DEFLABEL (label_59)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_164_23]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_164_0]), 1);

DEFLABEL (label_39)
  (Wrd14.Obj) = Rvl;
  goto label_58;

DEFLABEL (label_61)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_164_22]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_164_0]), 1);

DEFLABEL (label_38)
  (Wrd5.Obj) = Rvl;
  goto label_60;

DEFLABEL (label_64)
  (Wrd58.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_164_10]))));
  (* (--Rsp)) = (Wrd58.Obj);
  (* (--Rsp)) = (Wrd53.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_164_2]), 1);

DEFLABEL (label_37)
  (* (--Rsp)) = Rvl;
  goto label_63;

DEFLABEL (label_66)
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_164_8]))));
  (* (--Rsp)) = (Wrd41.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_164_0]), 1);

DEFLABEL (label_36)
  (Wrd33.Obj) = Rvl;
  goto label_65;

DEFLABEL (label_68)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_164_7]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_164_0]), 1);

DEFLABEL (label_35)
  (Wrd17.Obj) = Rvl;
  goto label_67;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_164_6);
  goto label_51;

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_164_5);
  goto label_55;

DEFLABEL (lambda_49)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_164_11);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [1]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_164_3]);
  (Rsp [1]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_164_12]));

DEFLABEL (loop_50)
DEFLABEL (loop_26)
  INTERRUPT_CHECK (26, LABEL_164_14);
  (Wrd32.Obj) = (Rsp [0]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if ((Wrd33.uLng) == 1)
    goto label_70;
  if ((Wrd32.Obj) == (current_block [OBJECT_164_1]))
    goto label_69;
  (Wrd37.pObj) = (& (Rsp [4]));
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd37.pObj)));
  (Rsp [1]) = (Wrd39.Obj);
  Rsp = (& (Rsp [1]));
  goto lambda_0;

DEFLABEL (label_69)
  Rsp = (& (Rsp [3]));
  goto label_62;

DEFLABEL (label_70)
  if (! ((Wrd33.uLng) == 1))
    goto label_86;
  (Wrd44.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd42.Obj) = ((Wrd44.pObj) [0]);

DEFLABEL (label_85)
  (Wrd51.uLng) = (OBJECT_TYPE (Wrd42.Obj));
  if ((Wrd51.uLng) == 1)
    goto label_84;
  (Wrd54.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_164_13]))));
  (* (--Rsp)) = (Wrd54.Obj);
  (Wrd55.pObj) = (& (Rsp [5]));
  (Wrd57.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd55.pObj)));
  (* (--Rsp)) = (Wrd57.Obj);
  goto lambda_0;

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_164_13);

DEFLABEL (label_84)
  (Wrd61.Obj) = (Rsp [0]);
  (Wrd62.uLng) = (OBJECT_TYPE (Wrd61.Obj));
  if (! ((Wrd62.uLng) == 1))
    goto label_83;
  (Wrd60.pObj) = (OBJECT_ADDRESS (Wrd61.Obj));
  (Wrd58.Obj) = ((Wrd60.pObj) [0]);

DEFLABEL (label_82)
  (Wrd69.uLng) = (OBJECT_TYPE (Wrd58.Obj));
  if (! ((Wrd69.uLng) == 1))
    goto label_81;
  (Wrd68.pObj) = (OBJECT_ADDRESS (Wrd58.Obj));
  (Wrd67.Obj) = ((Wrd68.pObj) [0]);

DEFLABEL (label_80)
  (Wrd74.Obj) = (Rsp [4]);
  if ((Wrd67.Obj) == (Wrd74.Obj))
    goto label_77;
  (Wrd78.Obj) = (Rsp [0]);
  (Wrd79.uLng) = (OBJECT_TYPE (Wrd78.Obj));
  if (! ((Wrd79.uLng) == 1))
    goto label_76;
  (Wrd77.pObj) = (OBJECT_ADDRESS (Wrd78.Obj));
  (Wrd75.Obj) = ((Wrd77.pObj) [0]);

DEFLABEL (label_75)
  (Wrd87.Obj) = (current_block [OBJECT_164_1]);
  (* (Rhp++)) = (Wrd75.Obj);
  (* (Rhp++)) = (Wrd87.Obj);
  (Wrd85.pObj) = (& (Rhp [-2]));
  (Wrd86.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd85.pObj)));
  (* (--Rsp)) = (Wrd86.Obj);
  (Wrd102.Obj) = (Rsp [2]);
  (Wrd103.uLng) = (OBJECT_TYPE (Wrd102.Obj));
  if (! ((Wrd103.uLng) == 1))
    goto label_74;
  (Wrd100.pObj) = (OBJECT_ADDRESS (Wrd102.Obj));
  ((Wrd100.pObj) [1]) = (Wrd86.Obj);

DEFLABEL (label_73)
  (Wrd91.Obj) = (Rsp [1]);
  (Wrd92.uLng) = (OBJECT_TYPE (Wrd91.Obj));
  if (! ((Wrd92.uLng) == 1))
    goto label_72;
  (Wrd90.pObj) = (OBJECT_ADDRESS (Wrd91.Obj));
  (Wrd88.Obj) = ((Wrd90.pObj) [1]);

DEFLABEL (label_71)
  (Rsp [1]) = (Wrd88.Obj);
  (Wrd97.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd97.Obj);
  Rsp = (& (Rsp [1]));
  goto loop_26;

DEFLABEL (label_72)
  (Wrd96.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_164_21]))));
  (* (--Rsp)) = (Wrd96.Obj);
  (* (--Rsp)) = (Wrd91.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_164_2]), 1);

DEFLABEL (label_44)
  (Wrd88.Obj) = Rvl;
  goto label_71;

DEFLABEL (label_74)
  (Wrd108.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_164_20]))));
  (* (--Rsp)) = (Wrd108.Obj);
  (* (--Rsp)) = (Wrd86.Obj);
  (* (--Rsp)) = (Wrd102.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_164_4]), 2);

DEFLABEL (label_45)
  goto label_73;

DEFLABEL (label_76)
  (Wrd83.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_164_19]))));
  (* (--Rsp)) = (Wrd83.Obj);
  (* (--Rsp)) = (Wrd78.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_164_0]), 1);

DEFLABEL (label_43)
  (Wrd75.Obj) = Rvl;
  goto label_75;

DEFLABEL (label_77)
  (Wrd112.Obj) = (Rsp [0]);
  (Wrd113.uLng) = (OBJECT_TYPE (Wrd112.Obj));
  if (! ((Wrd113.uLng) == 1))
    goto label_79;
  (Wrd111.pObj) = (OBJECT_ADDRESS (Wrd112.Obj));
  (Wrd109.Obj) = ((Wrd111.pObj) [1]);

DEFLABEL (label_78)
  (Rsp [0]) = (Wrd109.Obj);
  goto loop_26;

DEFLABEL (label_79)
  (Wrd117.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_164_18]))));
  (* (--Rsp)) = (Wrd117.Obj);
  (* (--Rsp)) = (Wrd112.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_164_2]), 1);

DEFLABEL (label_46)
  (Wrd109.Obj) = Rvl;
  goto label_78;

DEFLABEL (label_81)
  (Wrd73.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_164_17]))));
  (* (--Rsp)) = (Wrd73.Obj);
  (* (--Rsp)) = (Wrd58.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_164_0]), 1);

DEFLABEL (label_42)
  (Wrd67.Obj) = Rvl;
  goto label_80;

DEFLABEL (label_83)
  (Wrd66.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_164_16]))));
  (* (--Rsp)) = (Wrd66.Obj);
  (* (--Rsp)) = (Wrd61.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_164_0]), 1);

DEFLABEL (label_41)
  (Wrd58.Obj) = Rvl;
  goto label_82;

DEFLABEL (label_86)
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_164_15]))));
  (* (--Rsp)) = (Wrd50.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_164_0]), 1);

DEFLABEL (label_40)
  (Wrd42.Obj) = Rvl;
  goto label_85;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_165_5 3
#define LABEL_165_6 5
#define LABEL_165_4 7
#define LABEL_165_7 9
#define LABEL_165_8 11
#define LABEL_165_10 13
#define LABEL_165_11 15
#define LABEL_165_13 17
#define LABEL_165_14 19
#define LABEL_165_15 21
#define LABEL_165_17 23
#define LABEL_165_18 25
#define LABEL_165_9 27
#define LABEL_165_20 29
#define LABEL_165_21 31
#define LABEL_165_19 33
#define LABEL_165_16 35
#define LABEL_165_23 37
#define LABEL_165_24 39
#define LABEL_165_25 41
#define LABEL_165_26 43
#define ENVIRONMENT_LABEL_165_3 55
#define DEBUGGING_LABEL_165_2 54
#define OBJECT_165_4 53
#define OBJECT_165_3 52
#define OBJECT_165_2 51
#define OBJECT_165_1 50
#define OBJECT_165_0 49
#define EXECUTE_CACHE_165_22 45
#define EXECUTE_CACHE_165_12 47
#define FREE_REFERENCES_LABEL_165_0 44
#define NUMBER_OF_LINKER_SECTIONS_165_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_165 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd15;
  machine_word Wrd38;
  machine_word Wrd31;
  machine_word Wrd49;
  machine_word Wrd27;
  machine_word Wrd28;
  machine_word Wrd16;
  machine_word Wrd10;
  machine_word Wrd24;
  machine_word Wrd18;
  machine_word Wrd20;
  machine_word Wrd9;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd50;
  machine_word Wrd47;
  machine_word Wrd70;
  machine_word Wrd65;
  machine_word Wrd64;
  machine_word Wrd66;
  machine_word Wrd63;
  machine_word Wrd55;
  machine_word Wrd57;
  machine_word Wrd59;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd32;
  machine_word Wrd30;
  machine_word Wrd11;
  machine_word Wrd29;
  machine_word Wrd58;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd54;
  machine_word Wrd53;
  machine_word Wrd48;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd45;
  machine_word Wrd41;
  machine_word Wrd33;
  machine_word Wrd35;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd17;
  machine_word Wrd19;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_165_5);
      goto continuation_6;

    case 1:
      current_block = (Rpc - LABEL_165_6);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_165_4);
      goto del_assv_33;

    case 3:
      current_block = (Rpc - LABEL_165_7);
      goto label_35;

    case 4:
      current_block = (Rpc - LABEL_165_8);
      goto label_36;

    case 5:
      current_block = (Rpc - LABEL_165_10);
      goto label_37;

    case 6:
      current_block = (Rpc - LABEL_165_11);
      goto lambda_0;

    case 7:
      current_block = (Rpc - LABEL_165_13);
      goto continuation_16;

    case 8:
      current_block = (Rpc - LABEL_165_14);
      goto loop_26;

    case 9:
      current_block = (Rpc - LABEL_165_15);
      goto label_40;

    case 10:
      current_block = (Rpc - LABEL_165_17);
      goto label_41;

    case 11:
      current_block = (Rpc - LABEL_165_18);
      goto label_42;

    case 12:
      current_block = (Rpc - LABEL_165_9);
      goto continuation_10;

    case 13:
      current_block = (Rpc - LABEL_165_20);
      goto label_38;

    case 14:
      current_block = (Rpc - LABEL_165_21);
      goto label_39;

    case 15:
      current_block = (Rpc - LABEL_165_19);
      goto continuation_30;

    case 16:
      current_block = (Rpc - LABEL_165_16);
      goto continuation_19;

    case 17:
      current_block = (Rpc - LABEL_165_23);
      goto label_44;

    case 18:
      current_block = (Rpc - LABEL_165_24);
      goto label_46;

    case 19:
      current_block = (Rpc - LABEL_165_25);
      goto label_45;

    case 20:
      current_block = (Rpc - LABEL_165_26);
      goto label_43;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (del_assv_48)
DEFLABEL (del_assv_33)
  INTERRUPT_CHECK (26, LABEL_165_4);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_54;
  if (! ((Wrd5.Obj) == (current_block [OBJECT_165_1])))
    goto label_52;

DEFLABEL (label_51)
  Rvl = (Rsp [1]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_52)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_165_6]))));
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_53)
  (Wrd30.pObj) = (& (Rsp [1]));
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd30.pObj)));
  (* (--Rsp)) = (Wrd32.Obj);
  goto lambda_0;

DEFLABEL (label_54)
  if (! ((Wrd6.uLng) == 1))
    goto label_67;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd17.Obj) = ((Wrd19.pObj) [0]);

DEFLABEL (label_66)
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if ((Wrd26.uLng) == 1)
    goto label_55;
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_165_5]))));
  (* (--Rsp)) = (Wrd29.Obj);
  goto label_53;

DEFLABEL (label_55)
  (Wrd36.Obj) = (Rsp [1]);
  (Wrd37.uLng) = (OBJECT_TYPE (Wrd36.Obj));
  if (! ((Wrd37.uLng) == 1))
    goto label_65;
  (Wrd35.pObj) = (OBJECT_ADDRESS (Wrd36.Obj));
  (Wrd33.Obj) = ((Wrd35.pObj) [0]);

DEFLABEL (label_64)
  (Wrd45.Obj) = (current_block [OBJECT_165_1]);
  (* (Rhp++)) = (Wrd33.Obj);
  (* (Rhp++)) = (Wrd45.Obj);
  (Wrd43.pObj) = (& (Rhp [-2]));
  (Wrd44.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd43.pObj)));
  (* (--Rsp)) = (Wrd44.Obj);
  (Wrd48.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_165_9]))));
  (* (--Rsp)) = (Wrd48.Obj);
  (* (--Rsp)) = (Wrd44.Obj);
  (Wrd53.Obj) = (Rsp [4]);
  (Wrd54.uLng) = (OBJECT_TYPE (Wrd53.Obj));
  if (! ((Wrd54.uLng) == 1))
    goto label_63;
  (Wrd51.pObj) = (OBJECT_ADDRESS (Wrd53.Obj));
  (Wrd52.Obj) = ((Wrd51.pObj) [1]);
  (* (--Rsp)) = (Wrd52.Obj);

DEFLABEL (label_62)
  goto loop_26;

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_165_9);

DEFLABEL (label_61)
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_165_19]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd12.Obj) = (Rsp [4]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_60;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd9.Obj) = ((Wrd11.pObj) [0]);

DEFLABEL (label_59)
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if (! ((Wrd20.uLng) == 1))
    goto label_57;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd19.Obj) = ((Wrd18.pObj) [0]);
  (* (--Rsp)) = (Wrd19.Obj);

DEFLABEL (label_56)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_165_22]));

DEFLABEL (label_57)
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_165_21]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_165_0]), 1);

DEFLABEL (label_39)
DEFLABEL (label_58)
  (* (--Rsp)) = Rvl;
  goto label_56;

DEFLABEL (label_60)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_165_20]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_165_0]), 1);

DEFLABEL (label_38)
  (Wrd9.Obj) = Rvl;
  goto label_59;

DEFLABEL (label_63)
  (Wrd58.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_165_10]))));
  (* (--Rsp)) = (Wrd58.Obj);
  (* (--Rsp)) = (Wrd53.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_165_2]), 1);

DEFLABEL (label_37)
  (* (--Rsp)) = Rvl;
  goto label_62;

DEFLABEL (label_65)
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_165_8]))));
  (* (--Rsp)) = (Wrd41.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_165_0]), 1);

DEFLABEL (label_36)
  (Wrd33.Obj) = Rvl;
  goto label_64;

DEFLABEL (label_67)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_165_7]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_165_0]), 1);

DEFLABEL (label_35)
  (Wrd17.Obj) = Rvl;
  goto label_66;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_165_6);
  goto label_51;

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_165_5);
  goto label_55;

DEFLABEL (continuation_30)
  INTERRUPT_CHECK (27, LABEL_165_19);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_68;
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_68)
  (Wrd7.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd7.Obj);
  Rsp = (& (Rsp [2]));
  (Wrd12.Obj) = (Rsp [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_69;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  Rvl = ((Wrd10.pObj) [1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_69)
  INVOKE_PRIMITIVE ((current_block [OBJECT_165_2]), 1);

DEFLABEL (lambda_49)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_165_11);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [1]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_165_3]);
  (Rsp [1]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_165_12]));

DEFLABEL (loop_50)
DEFLABEL (loop_26)
  INTERRUPT_CHECK (26, LABEL_165_14);
  (Wrd25.Obj) = (Rsp [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 1)
    goto label_71;
  if ((Wrd25.Obj) == (current_block [OBJECT_165_1]))
    goto label_70;
  (Wrd30.pObj) = (& (Rsp [4]));
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd30.pObj)));
  (Rsp [1]) = (Wrd32.Obj);
  Rsp = (& (Rsp [1]));
  goto lambda_0;

DEFLABEL (label_70)
  Rsp = (& (Rsp [3]));
  goto label_61;

DEFLABEL (label_71)
  if (! ((Wrd26.uLng) == 1))
    goto label_77;
  (Wrd37.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd35.Obj) = ((Wrd37.pObj) [0]);

DEFLABEL (label_76)
  (Wrd44.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if ((Wrd44.uLng) == 1)
    goto label_75;
  (Wrd47.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_165_13]))));
  (* (--Rsp)) = (Wrd47.Obj);
  (Wrd48.pObj) = (& (Rsp [5]));
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd48.pObj)));
  (* (--Rsp)) = (Wrd50.Obj);
  goto lambda_0;

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_165_13);

DEFLABEL (label_75)
  (Wrd53.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_165_16]))));
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd54.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd54.Obj);
  (Wrd58.Obj) = (Rsp [2]);
  (Wrd59.uLng) = (OBJECT_TYPE (Wrd58.Obj));
  if (! ((Wrd59.uLng) == 1))
    goto label_74;
  (Wrd57.pObj) = (OBJECT_ADDRESS (Wrd58.Obj));
  (Wrd55.Obj) = ((Wrd57.pObj) [0]);

DEFLABEL (label_73)
  (Wrd66.uLng) = (OBJECT_TYPE (Wrd55.Obj));
  if (! ((Wrd66.uLng) == 1))
    goto label_72;
  (Wrd64.pObj) = (OBJECT_ADDRESS (Wrd55.Obj));
  (Wrd65.Obj) = ((Wrd64.pObj) [0]);
  (* (--Rsp)) = (Wrd65.Obj);
  goto label_56;

DEFLABEL (label_72)
  (Wrd70.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_165_18]))));
  (* (--Rsp)) = (Wrd70.Obj);
  (* (--Rsp)) = (Wrd55.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_165_0]), 1);

DEFLABEL (label_42)
  goto label_58;

DEFLABEL (label_74)
  (Wrd63.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_165_17]))));
  (* (--Rsp)) = (Wrd63.Obj);
  (* (--Rsp)) = (Wrd58.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_165_0]), 1);

DEFLABEL (label_41)
  (Wrd55.Obj) = Rvl;
  goto label_73;

DEFLABEL (label_77)
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_165_15]))));
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_165_0]), 1);

DEFLABEL (label_40)
  (Wrd35.Obj) = Rvl;
  goto label_76;

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_165_16);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_80;
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_79;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_78)
  (Rsp [0]) = (Wrd7.Obj);
  goto loop_26;

DEFLABEL (label_79)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_165_26]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_165_2]), 1);

DEFLABEL (label_43)
  (Wrd7.Obj) = Rvl;
  goto label_78;

DEFLABEL (label_80)
  (Wrd19.Obj) = (Rsp [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 1))
    goto label_86;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd16.Obj) = ((Wrd18.pObj) [0]);

DEFLABEL (label_85)
  (Wrd28.Obj) = (current_block [OBJECT_165_1]);
  (* (Rhp++)) = (Wrd16.Obj);
  (* (Rhp++)) = (Wrd28.Obj);
  (Wrd26.pObj) = (& (Rhp [-2]));
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd26.pObj)));
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd43.Obj) = (Rsp [2]);
  (Wrd44.uLng) = (OBJECT_TYPE (Wrd43.Obj));
  if (! ((Wrd44.uLng) == 1))
    goto label_84;
  (Wrd41.pObj) = (OBJECT_ADDRESS (Wrd43.Obj));
  ((Wrd41.pObj) [1]) = (Wrd27.Obj);

DEFLABEL (label_83)
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd33.uLng) == 1))
    goto label_82;
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd29.Obj) = ((Wrd31.pObj) [1]);

DEFLABEL (label_81)
  (Rsp [1]) = (Wrd29.Obj);
  (Wrd38.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd38.Obj);
  Rsp = (& (Rsp [1]));
  goto loop_26;

DEFLABEL (label_82)
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_165_25]))));
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_165_2]), 1);

DEFLABEL (label_45)
  (Wrd29.Obj) = Rvl;
  goto label_81;

DEFLABEL (label_84)
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_165_24]))));
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd43.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_165_4]), 2);

DEFLABEL (label_46)
  goto label_83;

DEFLABEL (label_86)
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_165_23]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_165_0]), 1);

DEFLABEL (label_44)
  (Wrd16.Obj) = Rvl;
  goto label_85;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_166_5 3
#define LABEL_166_6 5
#define LABEL_166_4 7
#define LABEL_166_7 9
#define LABEL_166_8 11
#define LABEL_166_10 13
#define LABEL_166_11 15
#define LABEL_166_13 17
#define LABEL_166_14 19
#define LABEL_166_15 21
#define LABEL_166_17 23
#define LABEL_166_18 25
#define LABEL_166_9 27
#define LABEL_166_20 29
#define LABEL_166_21 31
#define LABEL_166_19 33
#define LABEL_166_16 35
#define LABEL_166_23 37
#define LABEL_166_24 39
#define LABEL_166_25 41
#define LABEL_166_26 43
#define ENVIRONMENT_LABEL_166_3 55
#define DEBUGGING_LABEL_166_2 54
#define OBJECT_166_4 53
#define OBJECT_166_3 52
#define OBJECT_166_2 51
#define OBJECT_166_1 50
#define OBJECT_166_0 49
#define EXECUTE_CACHE_166_22 45
#define EXECUTE_CACHE_166_12 47
#define FREE_REFERENCES_LABEL_166_0 44
#define NUMBER_OF_LINKER_SECTIONS_166_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_166 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd15;
  machine_word Wrd38;
  machine_word Wrd31;
  machine_word Wrd49;
  machine_word Wrd27;
  machine_word Wrd28;
  machine_word Wrd16;
  machine_word Wrd10;
  machine_word Wrd24;
  machine_word Wrd18;
  machine_word Wrd20;
  machine_word Wrd9;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd50;
  machine_word Wrd47;
  machine_word Wrd70;
  machine_word Wrd65;
  machine_word Wrd64;
  machine_word Wrd66;
  machine_word Wrd63;
  machine_word Wrd55;
  machine_word Wrd57;
  machine_word Wrd59;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd32;
  machine_word Wrd30;
  machine_word Wrd11;
  machine_word Wrd29;
  machine_word Wrd58;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd54;
  machine_word Wrd53;
  machine_word Wrd48;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd45;
  machine_word Wrd41;
  machine_word Wrd33;
  machine_word Wrd35;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd17;
  machine_word Wrd19;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_166_5);
      goto continuation_6;

    case 1:
      current_block = (Rpc - LABEL_166_6);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_166_4);
      goto del_assoc_33;

    case 3:
      current_block = (Rpc - LABEL_166_7);
      goto label_35;

    case 4:
      current_block = (Rpc - LABEL_166_8);
      goto label_36;

    case 5:
      current_block = (Rpc - LABEL_166_10);
      goto label_37;

    case 6:
      current_block = (Rpc - LABEL_166_11);
      goto lambda_0;

    case 7:
      current_block = (Rpc - LABEL_166_13);
      goto continuation_16;

    case 8:
      current_block = (Rpc - LABEL_166_14);
      goto loop_26;

    case 9:
      current_block = (Rpc - LABEL_166_15);
      goto label_40;

    case 10:
      current_block = (Rpc - LABEL_166_17);
      goto label_41;

    case 11:
      current_block = (Rpc - LABEL_166_18);
      goto label_42;

    case 12:
      current_block = (Rpc - LABEL_166_9);
      goto continuation_10;

    case 13:
      current_block = (Rpc - LABEL_166_20);
      goto label_38;

    case 14:
      current_block = (Rpc - LABEL_166_21);
      goto label_39;

    case 15:
      current_block = (Rpc - LABEL_166_19);
      goto continuation_30;

    case 16:
      current_block = (Rpc - LABEL_166_16);
      goto continuation_19;

    case 17:
      current_block = (Rpc - LABEL_166_23);
      goto label_44;

    case 18:
      current_block = (Rpc - LABEL_166_24);
      goto label_46;

    case 19:
      current_block = (Rpc - LABEL_166_25);
      goto label_45;

    case 20:
      current_block = (Rpc - LABEL_166_26);
      goto label_43;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (del_assoc_48)
DEFLABEL (del_assoc_33)
  INTERRUPT_CHECK (26, LABEL_166_4);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_54;
  if (! ((Wrd5.Obj) == (current_block [OBJECT_166_1])))
    goto label_52;

DEFLABEL (label_51)
  Rvl = (Rsp [1]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_52)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_166_6]))));
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_53)
  (Wrd30.pObj) = (& (Rsp [1]));
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd30.pObj)));
  (* (--Rsp)) = (Wrd32.Obj);
  goto lambda_0;

DEFLABEL (label_54)
  if (! ((Wrd6.uLng) == 1))
    goto label_67;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd17.Obj) = ((Wrd19.pObj) [0]);

DEFLABEL (label_66)
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if ((Wrd26.uLng) == 1)
    goto label_55;
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_166_5]))));
  (* (--Rsp)) = (Wrd29.Obj);
  goto label_53;

DEFLABEL (label_55)
  (Wrd36.Obj) = (Rsp [1]);
  (Wrd37.uLng) = (OBJECT_TYPE (Wrd36.Obj));
  if (! ((Wrd37.uLng) == 1))
    goto label_65;
  (Wrd35.pObj) = (OBJECT_ADDRESS (Wrd36.Obj));
  (Wrd33.Obj) = ((Wrd35.pObj) [0]);

DEFLABEL (label_64)
  (Wrd45.Obj) = (current_block [OBJECT_166_1]);
  (* (Rhp++)) = (Wrd33.Obj);
  (* (Rhp++)) = (Wrd45.Obj);
  (Wrd43.pObj) = (& (Rhp [-2]));
  (Wrd44.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd43.pObj)));
  (* (--Rsp)) = (Wrd44.Obj);
  (Wrd48.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_166_9]))));
  (* (--Rsp)) = (Wrd48.Obj);
  (* (--Rsp)) = (Wrd44.Obj);
  (Wrd53.Obj) = (Rsp [4]);
  (Wrd54.uLng) = (OBJECT_TYPE (Wrd53.Obj));
  if (! ((Wrd54.uLng) == 1))
    goto label_63;
  (Wrd51.pObj) = (OBJECT_ADDRESS (Wrd53.Obj));
  (Wrd52.Obj) = ((Wrd51.pObj) [1]);
  (* (--Rsp)) = (Wrd52.Obj);

DEFLABEL (label_62)
  goto loop_26;

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_166_9);

DEFLABEL (label_61)
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_166_19]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd12.Obj) = (Rsp [4]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_60;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd9.Obj) = ((Wrd11.pObj) [0]);

DEFLABEL (label_59)
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if (! ((Wrd20.uLng) == 1))
    goto label_57;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd19.Obj) = ((Wrd18.pObj) [0]);
  (* (--Rsp)) = (Wrd19.Obj);

DEFLABEL (label_56)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_166_22]));

DEFLABEL (label_57)
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_166_21]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_166_0]), 1);

DEFLABEL (label_39)
DEFLABEL (label_58)
  (* (--Rsp)) = Rvl;
  goto label_56;

DEFLABEL (label_60)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_166_20]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_166_0]), 1);

DEFLABEL (label_38)
  (Wrd9.Obj) = Rvl;
  goto label_59;

DEFLABEL (label_63)
  (Wrd58.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_166_10]))));
  (* (--Rsp)) = (Wrd58.Obj);
  (* (--Rsp)) = (Wrd53.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_166_2]), 1);

DEFLABEL (label_37)
  (* (--Rsp)) = Rvl;
  goto label_62;

DEFLABEL (label_65)
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_166_8]))));
  (* (--Rsp)) = (Wrd41.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_166_0]), 1);

DEFLABEL (label_36)
  (Wrd33.Obj) = Rvl;
  goto label_64;

DEFLABEL (label_67)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_166_7]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_166_0]), 1);

DEFLABEL (label_35)
  (Wrd17.Obj) = Rvl;
  goto label_66;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_166_6);
  goto label_51;

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_166_5);
  goto label_55;

DEFLABEL (continuation_30)
  INTERRUPT_CHECK (27, LABEL_166_19);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_68;
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_68)
  (Wrd7.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd7.Obj);
  Rsp = (& (Rsp [2]));
  (Wrd12.Obj) = (Rsp [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_69;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  Rvl = ((Wrd10.pObj) [1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_69)
  INVOKE_PRIMITIVE ((current_block [OBJECT_166_2]), 1);

DEFLABEL (lambda_49)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_166_11);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [1]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_166_3]);
  (Rsp [1]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_166_12]));

DEFLABEL (loop_50)
DEFLABEL (loop_26)
  INTERRUPT_CHECK (26, LABEL_166_14);
  (Wrd25.Obj) = (Rsp [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 1)
    goto label_71;
  if ((Wrd25.Obj) == (current_block [OBJECT_166_1]))
    goto label_70;
  (Wrd30.pObj) = (& (Rsp [4]));
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd30.pObj)));
  (Rsp [1]) = (Wrd32.Obj);
  Rsp = (& (Rsp [1]));
  goto lambda_0;

DEFLABEL (label_70)
  Rsp = (& (Rsp [3]));
  goto label_61;

DEFLABEL (label_71)
  if (! ((Wrd26.uLng) == 1))
    goto label_77;
  (Wrd37.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd35.Obj) = ((Wrd37.pObj) [0]);

DEFLABEL (label_76)
  (Wrd44.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if ((Wrd44.uLng) == 1)
    goto label_75;
  (Wrd47.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_166_13]))));
  (* (--Rsp)) = (Wrd47.Obj);
  (Wrd48.pObj) = (& (Rsp [5]));
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd48.pObj)));
  (* (--Rsp)) = (Wrd50.Obj);
  goto lambda_0;

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_166_13);

DEFLABEL (label_75)
  (Wrd53.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_166_16]))));
  (* (--Rsp)) = (Wrd53.Obj);
  (Wrd54.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd54.Obj);
  (Wrd58.Obj) = (Rsp [2]);
  (Wrd59.uLng) = (OBJECT_TYPE (Wrd58.Obj));
  if (! ((Wrd59.uLng) == 1))
    goto label_74;
  (Wrd57.pObj) = (OBJECT_ADDRESS (Wrd58.Obj));
  (Wrd55.Obj) = ((Wrd57.pObj) [0]);

DEFLABEL (label_73)
  (Wrd66.uLng) = (OBJECT_TYPE (Wrd55.Obj));
  if (! ((Wrd66.uLng) == 1))
    goto label_72;
  (Wrd64.pObj) = (OBJECT_ADDRESS (Wrd55.Obj));
  (Wrd65.Obj) = ((Wrd64.pObj) [0]);
  (* (--Rsp)) = (Wrd65.Obj);
  goto label_56;

DEFLABEL (label_72)
  (Wrd70.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_166_18]))));
  (* (--Rsp)) = (Wrd70.Obj);
  (* (--Rsp)) = (Wrd55.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_166_0]), 1);

DEFLABEL (label_42)
  goto label_58;

DEFLABEL (label_74)
  (Wrd63.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_166_17]))));
  (* (--Rsp)) = (Wrd63.Obj);
  (* (--Rsp)) = (Wrd58.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_166_0]), 1);

DEFLABEL (label_41)
  (Wrd55.Obj) = Rvl;
  goto label_73;

DEFLABEL (label_77)
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_166_15]))));
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_166_0]), 1);

DEFLABEL (label_40)
  (Wrd35.Obj) = Rvl;
  goto label_76;

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_166_16);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_80;
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_79;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_78)
  (Rsp [0]) = (Wrd7.Obj);
  goto loop_26;

DEFLABEL (label_79)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_166_26]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_166_2]), 1);

DEFLABEL (label_43)
  (Wrd7.Obj) = Rvl;
  goto label_78;

DEFLABEL (label_80)
  (Wrd19.Obj) = (Rsp [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 1))
    goto label_86;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd16.Obj) = ((Wrd18.pObj) [0]);

DEFLABEL (label_85)
  (Wrd28.Obj) = (current_block [OBJECT_166_1]);
  (* (Rhp++)) = (Wrd16.Obj);
  (* (Rhp++)) = (Wrd28.Obj);
  (Wrd26.pObj) = (& (Rhp [-2]));
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd26.pObj)));
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd43.Obj) = (Rsp [2]);
  (Wrd44.uLng) = (OBJECT_TYPE (Wrd43.Obj));
  if (! ((Wrd44.uLng) == 1))
    goto label_84;
  (Wrd41.pObj) = (OBJECT_ADDRESS (Wrd43.Obj));
  ((Wrd41.pObj) [1]) = (Wrd27.Obj);

DEFLABEL (label_83)
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd33.uLng) == 1))
    goto label_82;
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd29.Obj) = ((Wrd31.pObj) [1]);

DEFLABEL (label_81)
  (Rsp [1]) = (Wrd29.Obj);
  (Wrd38.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd38.Obj);
  Rsp = (& (Rsp [1]));
  goto loop_26;

DEFLABEL (label_82)
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_166_25]))));
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_166_2]), 1);

DEFLABEL (label_45)
  (Wrd29.Obj) = Rvl;
  goto label_81;

DEFLABEL (label_84)
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_166_24]))));
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd43.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_166_4]), 2);

DEFLABEL (label_46)
  goto label_83;

DEFLABEL (label_86)
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_166_23]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_166_0]), 1);

DEFLABEL (label_44)
  (Wrd16.Obj) = Rvl;
  goto label_85;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_167_5 3
#define LABEL_167_6 5
#define LABEL_167_4 7
#define LABEL_167_7 9
#define LABEL_167_8 11
#define LABEL_167_9 13
#define LABEL_167_11 15
#define LABEL_167_12 17
#define LABEL_167_14 19
#define LABEL_167_15 21
#define LABEL_167_16 23
#define LABEL_167_18 25
#define LABEL_167_19 27
#define LABEL_167_10 29
#define LABEL_167_21 31
#define LABEL_167_22 33
#define LABEL_167_20 35
#define LABEL_167_17 37
#define LABEL_167_23 39
#define LABEL_167_24 41
#define LABEL_167_25 43
#define LABEL_167_26 45
#define ENVIRONMENT_LABEL_167_3 58
#define DEBUGGING_LABEL_167_2 57
#define OBJECT_167_5 56
#define OBJECT_167_4 55
#define OBJECT_167_3 54
#define OBJECT_167_2 53
#define OBJECT_167_1 52
#define OBJECT_167_0 51
#define EXECUTE_CACHE_167_13 47
#define FREE_REFERENCE_167_0 50
#define FREE_REFERENCES_LABEL_167_0 46
#define NUMBER_OF_LINKER_SECTIONS_167_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_167 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd15;
  machine_word Wrd37;
  machine_word Wrd41;
  machine_word Wrd43;
  machine_word Wrd16;
  machine_word Wrd10;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd11;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd31;
  machine_word Wrd49;
  machine_word Wrd72;
  machine_word Wrd71;
  machine_word Wrd65;
  machine_word Wrd64;
  machine_word Wrd58;
  machine_word Wrd60;
  machine_word Wrd59;
  machine_word Wrd45;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd35;
  machine_word Wrd33;
  machine_word Wrd14;
  machine_word Wrd32;
  machine_word Wrd61;
  machine_word Wrd55;
  machine_word Wrd54;
  machine_word Wrd57;
  machine_word Wrd56;
  machine_word Wrd51;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd48;
  machine_word Wrd44;
  machine_word Wrd36;
  machine_word Wrd38;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd22;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd62;
  machine_word Wrd67;
  machine_word Wrd66;
  machine_word Wrd63;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_167_5);
      goto continuation_8;

    case 1:
      current_block = (Rpc - LABEL_167_6);
      goto continuation_5;

    case 2:
      current_block = (Rpc - LABEL_167_4);
      goto alist_delete_36;

    case 3:
      current_block = (Rpc - LABEL_167_7);
      goto label_41;

    case 4:
      current_block = (Rpc - LABEL_167_8);
      goto label_38;

    case 5:
      current_block = (Rpc - LABEL_167_9);
      goto label_39;

    case 6:
      current_block = (Rpc - LABEL_167_11);
      goto label_40;

    case 7:
      current_block = (Rpc - LABEL_167_12);
      goto lambda_2;

    case 8:
      current_block = (Rpc - LABEL_167_14);
      goto continuation_18;

    case 9:
      current_block = (Rpc - LABEL_167_15);
      goto loop_28;

    case 10:
      current_block = (Rpc - LABEL_167_16);
      goto label_44;

    case 11:
      current_block = (Rpc - LABEL_167_18);
      goto label_45;

    case 12:
      current_block = (Rpc - LABEL_167_19);
      goto label_46;

    case 13:
      current_block = (Rpc - LABEL_167_10);
      goto continuation_12;

    case 14:
      current_block = (Rpc - LABEL_167_21);
      goto label_42;

    case 15:
      current_block = (Rpc - LABEL_167_22);
      goto label_43;

    case 16:
      current_block = (Rpc - LABEL_167_20);
      goto continuation_32;

    case 17:
      current_block = (Rpc - LABEL_167_17);
      goto continuation_21;

    case 18:
      current_block = (Rpc - LABEL_167_23);
      goto label_48;

    case 19:
      current_block = (Rpc - LABEL_167_24);
      goto label_50;

    case 20:
      current_block = (Rpc - LABEL_167_25);
      goto label_49;

    case 21:
      current_block = (Rpc - LABEL_167_26);
      goto label_47;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (alist_delete_52)
DEFLABEL (alist_delete_36)
  INTERRUPT_CHECK (26, LABEL_167_4);
  (Wrd5.Obj) = (Rsp [2]);
  if ((Wrd5.Obj) == (current_block [OBJECT_167_0]))
    goto label_74;
  (* (--Rsp)) = (Wrd5.Obj);

DEFLABEL (label_73)
  (Wrd8.Obj) = (Rsp [2]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if ((Wrd9.uLng) == 1)
    goto label_58;
  if (! ((Wrd8.Obj) == (current_block [OBJECT_167_2])))
    goto label_56;

DEFLABEL (label_55)
  Rvl = (Rsp [2]);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_56)
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_167_6]))));
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_57)
  (Wrd33.pObj) = (& (Rsp [2]));
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd33.pObj)));
  (* (--Rsp)) = (Wrd35.Obj);
  goto lambda_2;

DEFLABEL (label_58)
  if (! ((Wrd9.uLng) == 1))
    goto label_72;
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd20.Obj) = ((Wrd22.pObj) [0]);

DEFLABEL (label_71)
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if ((Wrd29.uLng) == 1)
    goto label_59;
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_167_5]))));
  (* (--Rsp)) = (Wrd32.Obj);
  goto label_57;

DEFLABEL (label_59)
  (Wrd39.Obj) = (Rsp [2]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if (! ((Wrd40.uLng) == 1))
    goto label_70;
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd39.Obj));
  (Wrd36.Obj) = ((Wrd38.pObj) [0]);

DEFLABEL (label_69)
  (Wrd48.Obj) = (current_block [OBJECT_167_2]);
  (* (Rhp++)) = (Wrd36.Obj);
  (* (Rhp++)) = (Wrd48.Obj);
  (Wrd46.pObj) = (& (Rhp [-2]));
  (Wrd47.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd46.pObj)));
  (* (--Rsp)) = (Wrd47.Obj);
  (Wrd51.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_167_10]))));
  (* (--Rsp)) = (Wrd51.Obj);
  (* (--Rsp)) = (Wrd47.Obj);
  (Wrd56.Obj) = (Rsp [5]);
  (Wrd57.uLng) = (OBJECT_TYPE (Wrd56.Obj));
  if (! ((Wrd57.uLng) == 1))
    goto label_68;
  (Wrd54.pObj) = (OBJECT_ADDRESS (Wrd56.Obj));
  (Wrd55.Obj) = ((Wrd54.pObj) [1]);
  (* (--Rsp)) = (Wrd55.Obj);

DEFLABEL (label_67)
  goto loop_28;

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_167_10);

DEFLABEL (label_66)
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_167_20]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd12.Obj) = (Rsp [5]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_65;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd9.Obj) = ((Wrd11.pObj) [0]);

DEFLABEL (label_64)
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if (! ((Wrd20.uLng) == 1))
    goto label_63;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd19.Obj) = ((Wrd18.pObj) [0]);
  (* (--Rsp)) = (Wrd19.Obj);

DEFLABEL (label_62)
  (Wrd25.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd25.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_32)
  INTERRUPT_CHECK (27, LABEL_167_20);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_60;
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [5]));
  goto pop_return;

DEFLABEL (label_60)
  (Wrd7.Obj) = (Rsp [0]);
  (Rsp [4]) = (Wrd7.Obj);
  Rsp = (& (Rsp [4]));
  (Wrd12.Obj) = (Rsp [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_61;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  Rvl = ((Wrd10.pObj) [1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_61)
  INVOKE_PRIMITIVE ((current_block [OBJECT_167_3]), 1);

DEFLABEL (label_63)
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_167_22]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_167_1]), 1);

DEFLABEL (label_43)
  (* (--Rsp)) = Rvl;
  goto label_62;

DEFLABEL (label_65)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_167_21]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_167_1]), 1);

DEFLABEL (label_42)
  (Wrd9.Obj) = Rvl;
  goto label_64;

DEFLABEL (label_68)
  (Wrd61.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_167_11]))));
  (* (--Rsp)) = (Wrd61.Obj);
  (* (--Rsp)) = (Wrd56.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_167_3]), 1);

DEFLABEL (label_40)
  (* (--Rsp)) = Rvl;
  goto label_67;

DEFLABEL (label_70)
  (Wrd44.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_167_9]))));
  (* (--Rsp)) = (Wrd44.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_167_1]), 1);

DEFLABEL (label_39)
  (Wrd36.Obj) = Rvl;
  goto label_69;

DEFLABEL (label_72)
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_167_8]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_167_1]), 1);

DEFLABEL (label_38)
  (Wrd20.Obj) = Rvl;
  goto label_71;

DEFLABEL (label_74)
  (Wrd63.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_167_0]));
  (Wrd66.Obj) = ((Wrd63.pObj) [0]);
  (Wrd67.uLng) = (OBJECT_TYPE (Wrd66.Obj));
  if ((Wrd67.uLng) == 50)
    goto label_76;
  Wrd62 = Wrd66;

DEFLABEL (label_75)
  (* (--Rsp)) = (Wrd62.Obj);
  goto label_73;

DEFLABEL (label_76)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_167_7])), (Wrd63.pObj));

DEFLABEL (label_41)
  (Wrd62.Obj) = Rvl;
  goto label_75;

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_167_6);
  goto label_55;

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_167_5);
  goto label_59;

DEFLABEL (lambda_53)
DEFLABEL (lambda_2)
  INTERRUPT_CHECK (26, LABEL_167_12);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [1]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_167_4]);
  (Rsp [1]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_167_13]));

DEFLABEL (loop_54)
DEFLABEL (loop_28)
  INTERRUPT_CHECK (26, LABEL_167_15);
  (Wrd26.Obj) = (Rsp [0]);
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if ((Wrd27.uLng) == 1)
    goto label_78;
  if ((Wrd26.Obj) == (current_block [OBJECT_167_2]))
    goto label_77;
  (Wrd31.pObj) = (& (Rsp [5]));
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd31.pObj)));
  (Rsp [1]) = (Wrd33.Obj);
  Rsp = (& (Rsp [1]));
  goto lambda_2;

DEFLABEL (label_77)
  Rsp = (& (Rsp [3]));
  goto label_66;

DEFLABEL (label_78)
  if (! ((Wrd27.uLng) == 1))
    goto label_94;
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd36.Obj) = ((Wrd38.pObj) [0]);

DEFLABEL (label_93)
  (Wrd45.uLng) = (OBJECT_TYPE (Wrd36.Obj));
  if ((Wrd45.uLng) == 1)
    goto label_92;
  (Wrd48.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_167_14]))));
  (* (--Rsp)) = (Wrd48.Obj);
  (Wrd49.pObj) = (& (Rsp [6]));
  (Wrd51.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd49.pObj)));
  (* (--Rsp)) = (Wrd51.Obj);
  goto lambda_2;

DEFLABEL (continuation_18)
  INTERRUPT_CHECK (27, LABEL_167_14);

DEFLABEL (label_92)
  (Wrd54.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_167_17]))));
  (* (--Rsp)) = (Wrd54.Obj);
  (Wrd55.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd55.Obj);
  (Wrd59.Obj) = (Rsp [2]);
  (Wrd60.uLng) = (OBJECT_TYPE (Wrd59.Obj));
  if (! ((Wrd60.uLng) == 1))
    goto label_91;
  (Wrd58.pObj) = (OBJECT_ADDRESS (Wrd59.Obj));
  (Wrd56.Obj) = ((Wrd58.pObj) [0]);

DEFLABEL (label_90)
  (Wrd67.uLng) = (OBJECT_TYPE (Wrd56.Obj));
  if (! ((Wrd67.uLng) == 1))
    goto label_89;
  (Wrd65.pObj) = (OBJECT_ADDRESS (Wrd56.Obj));
  (Wrd66.Obj) = ((Wrd65.pObj) [0]);
  (* (--Rsp)) = (Wrd66.Obj);

DEFLABEL (label_88)
  (Wrd72.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd72.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_21)
  INTERRUPT_CHECK (27, LABEL_167_17);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_81;
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_80;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_79)
  (Rsp [0]) = (Wrd7.Obj);
  goto loop_28;

DEFLABEL (label_80)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_167_26]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_167_3]), 1);

DEFLABEL (label_47)
  (Wrd7.Obj) = Rvl;
  goto label_79;

DEFLABEL (label_81)
  (Wrd19.Obj) = (Rsp [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 1))
    goto label_87;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd16.Obj) = ((Wrd18.pObj) [0]);

DEFLABEL (label_86)
  (Wrd28.Obj) = (current_block [OBJECT_167_2]);
  (* (Rhp++)) = (Wrd16.Obj);
  (* (Rhp++)) = (Wrd28.Obj);
  (Wrd26.pObj) = (& (Rhp [-2]));
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd26.pObj)));
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd43.Obj) = (Rsp [2]);
  (Wrd44.uLng) = (OBJECT_TYPE (Wrd43.Obj));
  if (! ((Wrd44.uLng) == 1))
    goto label_85;
  (Wrd41.pObj) = (OBJECT_ADDRESS (Wrd43.Obj));
  ((Wrd41.pObj) [1]) = (Wrd27.Obj);

DEFLABEL (label_84)
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd33.uLng) == 1))
    goto label_83;
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd29.Obj) = ((Wrd31.pObj) [1]);

DEFLABEL (label_82)
  (Rsp [1]) = (Wrd29.Obj);
  (Wrd38.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd38.Obj);
  Rsp = (& (Rsp [1]));
  goto loop_28;

DEFLABEL (label_83)
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_167_25]))));
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_167_3]), 1);

DEFLABEL (label_49)
  (Wrd29.Obj) = Rvl;
  goto label_82;

DEFLABEL (label_85)
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_167_24]))));
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd43.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_167_5]), 2);

DEFLABEL (label_50)
  goto label_84;

DEFLABEL (label_87)
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_167_23]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_167_1]), 1);

DEFLABEL (label_48)
  (Wrd16.Obj) = Rvl;
  goto label_86;

DEFLABEL (label_89)
  (Wrd71.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_167_19]))));
  (* (--Rsp)) = (Wrd71.Obj);
  (* (--Rsp)) = (Wrd56.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_167_1]), 1);

DEFLABEL (label_46)
  (* (--Rsp)) = Rvl;
  goto label_88;

DEFLABEL (label_91)
  (Wrd64.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_167_18]))));
  (* (--Rsp)) = (Wrd64.Obj);
  (* (--Rsp)) = (Wrd59.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_167_1]), 1);

DEFLABEL (label_45)
  (Wrd56.Obj) = Rvl;
  goto label_90;

DEFLABEL (label_94)
  (Wrd44.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_167_16]))));
  (* (--Rsp)) = (Wrd44.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_167_1]), 1);

DEFLABEL (label_44)
  (Wrd36.Obj) = Rvl;
  goto label_93;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_168_5 3
#define LABEL_168_6 5
#define LABEL_168_4 7
#define LABEL_168_7 9
#define LABEL_168_8 11
#define LABEL_168_10 13
#define LABEL_168_11 15
#define LABEL_168_13 17
#define LABEL_168_14 19
#define LABEL_168_15 21
#define LABEL_168_17 23
#define LABEL_168_18 25
#define LABEL_168_9 27
#define LABEL_168_20 29
#define LABEL_168_21 31
#define LABEL_168_19 33
#define LABEL_168_16 35
#define LABEL_168_22 37
#define LABEL_168_23 39
#define LABEL_168_24 41
#define LABEL_168_25 43
#define ENVIRONMENT_LABEL_168_3 52
#define DEBUGGING_LABEL_168_2 51
#define OBJECT_168_3 50
#define OBJECT_168_2 49
#define OBJECT_168_1 48
#define OBJECT_168_0 47
#define EXECUTE_CACHE_168_12 45
#define FREE_REFERENCES_LABEL_168_0 44
#define NUMBER_OF_LINKER_SECTIONS_168_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_168 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd15;
  machine_word Wrd28;
  machine_word Wrd16;
  machine_word Wrd10;
  machine_word Wrd24;
  machine_word Wrd18;
  machine_word Wrd20;
  machine_word Wrd9;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd31;
  machine_word Wrd49;
  machine_word Wrd72;
  machine_word Wrd71;
  machine_word Wrd66;
  machine_word Wrd65;
  machine_word Wrd67;
  machine_word Wrd64;
  machine_word Wrd56;
  machine_word Wrd60;
  machine_word Wrd59;
  machine_word Wrd55;
  machine_word Wrd38;
  machine_word Wrd27;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd32;
  machine_word Wrd30;
  machine_word Wrd11;
  machine_word Wrd29;
  machine_word Wrd58;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd54;
  machine_word Wrd53;
  machine_word Wrd48;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd45;
  machine_word Wrd41;
  machine_word Wrd33;
  machine_word Wrd35;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd17;
  machine_word Wrd19;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_168_5);
      goto continuation_6;

    case 1:
      current_block = (Rpc - LABEL_168_6);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_168_4);
      goto Z__alist_delete_33;

    case 3:
      current_block = (Rpc - LABEL_168_7);
      goto label_35;

    case 4:
      current_block = (Rpc - LABEL_168_8);
      goto label_36;

    case 5:
      current_block = (Rpc - LABEL_168_10);
      goto label_37;

    case 6:
      current_block = (Rpc - LABEL_168_11);
      goto lambda_0;

    case 7:
      current_block = (Rpc - LABEL_168_13);
      goto continuation_16;

    case 8:
      current_block = (Rpc - LABEL_168_14);
      goto loop_26;

    case 9:
      current_block = (Rpc - LABEL_168_15);
      goto label_40;

    case 10:
      current_block = (Rpc - LABEL_168_17);
      goto label_41;

    case 11:
      current_block = (Rpc - LABEL_168_18);
      goto label_42;

    case 12:
      current_block = (Rpc - LABEL_168_9);
      goto continuation_10;

    case 13:
      current_block = (Rpc - LABEL_168_20);
      goto label_38;

    case 14:
      current_block = (Rpc - LABEL_168_21);
      goto label_39;

    case 15:
      current_block = (Rpc - LABEL_168_19);
      goto continuation_30;

    case 16:
      current_block = (Rpc - LABEL_168_16);
      goto continuation_19;

    case 17:
      current_block = (Rpc - LABEL_168_22);
      goto label_44;

    case 18:
      current_block = (Rpc - LABEL_168_23);
      goto label_46;

    case 19:
      current_block = (Rpc - LABEL_168_24);
      goto label_45;

    case 20:
      current_block = (Rpc - LABEL_168_25);
      goto label_43;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (Z__alist_delete_48)
DEFLABEL (Z__alist_delete_33)
  INTERRUPT_CHECK (26, LABEL_168_4);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_54;
  if (! ((Wrd5.Obj) == (current_block [OBJECT_168_1])))
    goto label_52;

DEFLABEL (label_51)
  Rvl = (Rsp [1]);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_52)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_168_6]))));
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_53)
  (Wrd30.pObj) = (& (Rsp [1]));
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd30.pObj)));
  (* (--Rsp)) = (Wrd32.Obj);
  goto lambda_0;

DEFLABEL (label_54)
  if (! ((Wrd6.uLng) == 1))
    goto label_68;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd17.Obj) = ((Wrd19.pObj) [0]);

DEFLABEL (label_67)
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if ((Wrd26.uLng) == 1)
    goto label_55;
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_168_5]))));
  (* (--Rsp)) = (Wrd29.Obj);
  goto label_53;

DEFLABEL (label_55)
  (Wrd36.Obj) = (Rsp [1]);
  (Wrd37.uLng) = (OBJECT_TYPE (Wrd36.Obj));
  if (! ((Wrd37.uLng) == 1))
    goto label_66;
  (Wrd35.pObj) = (OBJECT_ADDRESS (Wrd36.Obj));
  (Wrd33.Obj) = ((Wrd35.pObj) [0]);

DEFLABEL (label_65)
  (Wrd45.Obj) = (current_block [OBJECT_168_1]);
  (* (Rhp++)) = (Wrd33.Obj);
  (* (Rhp++)) = (Wrd45.Obj);
  (Wrd43.pObj) = (& (Rhp [-2]));
  (Wrd44.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd43.pObj)));
  (* (--Rsp)) = (Wrd44.Obj);
  (Wrd48.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_168_9]))));
  (* (--Rsp)) = (Wrd48.Obj);
  (* (--Rsp)) = (Wrd44.Obj);
  (Wrd53.Obj) = (Rsp [4]);
  (Wrd54.uLng) = (OBJECT_TYPE (Wrd53.Obj));
  if (! ((Wrd54.uLng) == 1))
    goto label_64;
  (Wrd51.pObj) = (OBJECT_ADDRESS (Wrd53.Obj));
  (Wrd52.Obj) = ((Wrd51.pObj) [1]);
  (* (--Rsp)) = (Wrd52.Obj);

DEFLABEL (label_63)
  goto loop_26;

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_168_9);

DEFLABEL (label_62)
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_168_19]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd12.Obj) = (Rsp [4]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_61;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd9.Obj) = ((Wrd11.pObj) [0]);

DEFLABEL (label_60)
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if (! ((Wrd20.uLng) == 1))
    goto label_59;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd19.Obj) = ((Wrd18.pObj) [0]);
  (* (--Rsp)) = (Wrd19.Obj);

DEFLABEL (label_58)
  (Wrd25.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd25.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_30)
  INTERRUPT_CHECK (27, LABEL_168_19);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_56;
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [5]));
  goto pop_return;

DEFLABEL (label_56)
  (Wrd7.Obj) = (Rsp [0]);
  (Rsp [4]) = (Wrd7.Obj);
  Rsp = (& (Rsp [4]));
  (Wrd12.Obj) = (Rsp [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_57;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  Rvl = ((Wrd10.pObj) [1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_57)
  INVOKE_PRIMITIVE ((current_block [OBJECT_168_2]), 1);

DEFLABEL (label_59)
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_168_21]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_168_0]), 1);

DEFLABEL (label_39)
  (* (--Rsp)) = Rvl;
  goto label_58;

DEFLABEL (label_61)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_168_20]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_168_0]), 1);

DEFLABEL (label_38)
  (Wrd9.Obj) = Rvl;
  goto label_60;

DEFLABEL (label_64)
  (Wrd58.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_168_10]))));
  (* (--Rsp)) = (Wrd58.Obj);
  (* (--Rsp)) = (Wrd53.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_168_2]), 1);

DEFLABEL (label_37)
  (* (--Rsp)) = Rvl;
  goto label_63;

DEFLABEL (label_66)
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_168_8]))));
  (* (--Rsp)) = (Wrd41.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_168_0]), 1);

DEFLABEL (label_36)
  (Wrd33.Obj) = Rvl;
  goto label_65;

DEFLABEL (label_68)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_168_7]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_168_0]), 1);

DEFLABEL (label_35)
  (Wrd17.Obj) = Rvl;
  goto label_67;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_168_6);
  goto label_51;

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_168_5);
  goto label_55;

DEFLABEL (lambda_49)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_168_11);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [1]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = ((Wrd6.pObj) [3]);
  (Rsp [1]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_168_12]));

DEFLABEL (loop_50)
DEFLABEL (loop_26)
  INTERRUPT_CHECK (26, LABEL_168_14);
  (Wrd26.Obj) = (Rsp [0]);
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if ((Wrd27.uLng) == 1)
    goto label_70;
  if ((Wrd26.Obj) == (current_block [OBJECT_168_1]))
    goto label_69;
  (Wrd31.pObj) = (& (Rsp [4]));
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd31.pObj)));
  (Rsp [1]) = (Wrd33.Obj);
  Rsp = (& (Rsp [1]));
  goto lambda_0;

DEFLABEL (label_69)
  Rsp = (& (Rsp [3]));
  goto label_62;

DEFLABEL (label_70)
  if (! ((Wrd27.uLng) == 1))
    goto label_86;
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd36.Obj) = ((Wrd38.pObj) [0]);

DEFLABEL (label_85)
  (Wrd45.uLng) = (OBJECT_TYPE (Wrd36.Obj));
  if ((Wrd45.uLng) == 1)
    goto label_84;
  (Wrd48.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_168_13]))));
  (* (--Rsp)) = (Wrd48.Obj);
  (Wrd49.pObj) = (& (Rsp [5]));
  (Wrd51.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd49.pObj)));
  (* (--Rsp)) = (Wrd51.Obj);
  goto lambda_0;

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_168_13);

DEFLABEL (label_84)
  (Wrd54.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_168_16]))));
  (* (--Rsp)) = (Wrd54.Obj);
  (Wrd55.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd55.Obj);
  (Wrd59.Obj) = (Rsp [2]);
  (Wrd60.uLng) = (OBJECT_TYPE (Wrd59.Obj));
  if (! ((Wrd60.uLng) == 1))
    goto label_83;
  (Wrd58.pObj) = (OBJECT_ADDRESS (Wrd59.Obj));
  (Wrd56.Obj) = ((Wrd58.pObj) [0]);

DEFLABEL (label_82)
  (Wrd67.uLng) = (OBJECT_TYPE (Wrd56.Obj));
  if (! ((Wrd67.uLng) == 1))
    goto label_81;
  (Wrd65.pObj) = (OBJECT_ADDRESS (Wrd56.Obj));
  (Wrd66.Obj) = ((Wrd65.pObj) [0]);
  (* (--Rsp)) = (Wrd66.Obj);

DEFLABEL (label_80)
  (Wrd72.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd72.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_168_16);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_73;
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_72;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_71)
  (Rsp [0]) = (Wrd7.Obj);
  goto loop_26;

DEFLABEL (label_72)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_168_25]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_168_2]), 1);

DEFLABEL (label_43)
  (Wrd7.Obj) = Rvl;
  goto label_71;

DEFLABEL (label_73)
  (Wrd19.Obj) = (Rsp [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 1))
    goto label_79;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd16.Obj) = ((Wrd18.pObj) [0]);

DEFLABEL (label_78)
  (Wrd28.Obj) = (current_block [OBJECT_168_1]);
  (* (Rhp++)) = (Wrd16.Obj);
  (* (Rhp++)) = (Wrd28.Obj);
  (Wrd26.pObj) = (& (Rhp [-2]));
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd26.pObj)));
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd43.Obj) = (Rsp [2]);
  (Wrd44.uLng) = (OBJECT_TYPE (Wrd43.Obj));
  if (! ((Wrd44.uLng) == 1))
    goto label_77;
  (Wrd41.pObj) = (OBJECT_ADDRESS (Wrd43.Obj));
  ((Wrd41.pObj) [1]) = (Wrd27.Obj);

DEFLABEL (label_76)
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd33.uLng) == 1))
    goto label_75;
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd29.Obj) = ((Wrd31.pObj) [1]);

DEFLABEL (label_74)
  (Rsp [1]) = (Wrd29.Obj);
  (Wrd38.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd38.Obj);
  Rsp = (& (Rsp [1]));
  goto loop_26;

DEFLABEL (label_75)
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_168_24]))));
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_168_2]), 1);

DEFLABEL (label_45)
  (Wrd29.Obj) = Rvl;
  goto label_74;

DEFLABEL (label_77)
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_168_23]))));
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd43.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_168_3]), 2);

DEFLABEL (label_46)
  goto label_76;

DEFLABEL (label_79)
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_168_22]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_168_0]), 1);

DEFLABEL (label_44)
  (Wrd16.Obj) = Rvl;
  goto label_78;

DEFLABEL (label_81)
  (Wrd71.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_168_18]))));
  (* (--Rsp)) = (Wrd71.Obj);
  (* (--Rsp)) = (Wrd56.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_168_0]), 1);

DEFLABEL (label_42)
  (* (--Rsp)) = Rvl;
  goto label_80;

DEFLABEL (label_83)
  (Wrd64.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_168_17]))));
  (* (--Rsp)) = (Wrd64.Obj);
  (* (--Rsp)) = (Wrd59.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_168_0]), 1);

DEFLABEL (label_41)
  (Wrd56.Obj) = Rvl;
  goto label_82;

DEFLABEL (label_86)
  (Wrd44.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_168_15]))));
  (* (--Rsp)) = (Wrd44.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_168_0]), 1);

DEFLABEL (label_40)
  (Wrd36.Obj) = Rvl;
  goto label_85;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_169_4 3
#define LABEL_169_5 5
#define LABEL_169_6 7
#define LABEL_169_7 9
#define LABEL_169_8 11
#define LABEL_169_9 13
#define LABEL_169_10 15
#define LABEL_169_11 17
#define LABEL_169_13 19
#define LABEL_169_14 21
#define LABEL_169_16 23
#define LABEL_169_17 25
#define LABEL_169_18 27
#define LABEL_169_19 29
#define LABEL_169_20 31
#define LABEL_169_21 33
#define LABEL_169_22 35
#define LABEL_169_23 37
#define LABEL_169_12 39
#define ENVIRONMENT_LABEL_169_3 49
#define DEBUGGING_LABEL_169_2 48
#define OBJECT_169_4 47
#define OBJECT_169_3 46
#define OBJECT_169_2 45
#define OBJECT_169_1 44
#define OBJECT_169_0 43
#define EXECUTE_CACHE_169_15 41
#define FREE_REFERENCES_LABEL_169_0 40
#define NUMBER_OF_LINKER_SECTIONS_169_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_169 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd85;
  machine_word Wrd16;
  machine_word Wrd35;
  machine_word Wrd33;
  machine_word Wrd60;
  machine_word Wrd62;
  machine_word Wrd82;
  machine_word Wrd69;
  machine_word Wrd53;
  machine_word Wrd48;
  machine_word Wrd49;
  machine_word Wrd40;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd23;
  machine_word Wrd9;
  machine_word Wrd89;
  machine_word Wrd8;
  machine_word Wrd17;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd41;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd34;
  machine_word Wrd87;
  machine_word Wrd79;
  machine_word Wrd86;
  machine_word Wrd76;
  machine_word Wrd75;
  machine_word Wrd78;
  machine_word Wrd77;
  machine_word Wrd73;
  machine_word Wrd70;
  machine_word Wrd93;
  machine_word Wrd100;
  machine_word Wrd96;
  machine_word Wrd88;
  machine_word Wrd90;
  machine_word Wrd92;
  machine_word Wrd91;
  machine_word Wrd68;
  machine_word Wrd67;
  machine_word Wrd66;
  machine_word Wrd58;
  machine_word Wrd65;
  machine_word Wrd61;
  machine_word Wrd55;
  machine_word Wrd56;
  machine_word Wrd57;
  machine_word Wrd47;
  machine_word Wrd54;
  machine_word Wrd50;
  machine_word Wrd42;
  machine_word Wrd44;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd32;
  machine_word Wrd24;
  machine_word Wrd31;
  machine_word Wrd27;
  machine_word Wrd19;
  machine_word Wrd21;
  machine_word Wrd5;
  machine_word Wrd101;
  machine_word Wrd103;
  machine_word Wrd7;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_169_4);
      goto del_assqB_27;

    case 1:
      current_block = (Rpc - LABEL_169_5);
      goto continuation_5;

    case 2:
      current_block = (Rpc - LABEL_169_6);
      goto continuation_2;

    case 3:
      current_block = (Rpc - LABEL_169_7);
      goto lambda_12;

    case 4:
      current_block = (Rpc - LABEL_169_8);
      goto label_29;

    case 5:
      current_block = (Rpc - LABEL_169_9);
      goto label_30;

    case 6:
      current_block = (Rpc - LABEL_169_10);
      goto label_31;

    case 7:
      current_block = (Rpc - LABEL_169_11);
      goto label_33;

    case 8:
      current_block = (Rpc - LABEL_169_13);
      goto label_32;

    case 9:
      current_block = (Rpc - LABEL_169_14);
      goto lambda_25;

    case 10:
      current_block = (Rpc - LABEL_169_16);
      goto continuation_23;

    case 11:
      current_block = (Rpc - LABEL_169_17);
      goto continuation_17;

    case 12:
      current_block = (Rpc - LABEL_169_18);
      goto lambda_24;

    case 13:
      current_block = (Rpc - LABEL_169_19);
      goto label_34;

    case 14:
      current_block = (Rpc - LABEL_169_20);
      goto label_35;

    case 15:
      current_block = (Rpc - LABEL_169_21);
      goto label_36;

    case 16:
      current_block = (Rpc - LABEL_169_22);
      goto label_38;

    case 17:
      current_block = (Rpc - LABEL_169_23);
      goto label_37;

    case 18:
      current_block = (Rpc - LABEL_169_12);
      goto continuation_10;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (del_assqB_40)
DEFLABEL (del_assqB_27)
  INTERRUPT_CHECK (26, LABEL_169_4);
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (59, Rsp));
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  Rdl = (& (Rsp [4]));
  goto lambda_12;

DEFLABEL (lambda_41)
DEFLABEL (lambda_12)
  DLINK_INTERRUPT_CHECK (25, LABEL_169_7);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_46;
  if (! ((Wrd5.Obj) == (current_block [OBJECT_169_2])))
    goto label_45;

DEFLABEL (label_44)
  Rvl = (current_block [OBJECT_169_2]);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_45)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_169_6]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd15.pObj)));
  (* (--Rsp)) = (Wrd17.Obj);
  goto lambda_25;

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_169_6);
  (Wrd101.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd101.Obj));
  goto label_44;

DEFLABEL (label_46)
  if (! ((Wrd6.uLng) == 1))
    goto label_59;
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd19.Obj) = ((Wrd21.pObj) [0]);

DEFLABEL (label_58)
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if ((Wrd32.uLng) == 1)
    goto label_57;
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd34.Obj);
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_169_5]))));
  (* (--Rsp)) = (Wrd37.Obj);
  (Wrd38.Obj) = (Rsp [3]);
  (Wrd39.pObj) = (OBJECT_ADDRESS (Wrd38.Obj));
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd39.pObj)));
  (* (--Rsp)) = (Wrd41.Obj);
  goto lambda_25;

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_169_5);
  (Wrd103.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd103.Obj));

DEFLABEL (label_57)
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.uLng) = (OBJECT_TYPE (Wrd45.Obj));
  if (! ((Wrd46.uLng) == 1))
    goto label_56;
  (Wrd44.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd42.Obj) = ((Wrd44.pObj) [0]);

DEFLABEL (label_55)
  (Wrd57.uLng) = (OBJECT_TYPE (Wrd42.Obj));
  if (! ((Wrd57.uLng) == 1))
    goto label_54;
  (Wrd56.pObj) = (OBJECT_ADDRESS (Wrd42.Obj));
  (Wrd55.Obj) = ((Wrd56.pObj) [0]);

DEFLABEL (label_53)
  (Wrd66.Obj) = (Rsp [1]);
  (Wrd67.pObj) = (OBJECT_ADDRESS (Wrd66.Obj));
  (Wrd68.Obj) = ((Wrd67.pObj) [0]);
  if ((Wrd55.Obj) == (Wrd68.Obj))
    goto label_50;
  (Wrd70.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd70.Obj);
  (Wrd73.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_169_12]))));
  (* (--Rsp)) = (Wrd73.Obj);
  (Wrd77.Obj) = (Rsp [2]);
  (Wrd78.uLng) = (OBJECT_TYPE (Wrd77.Obj));
  if (! ((Wrd78.uLng) == 1))
    goto label_49;
  (Wrd75.pObj) = (OBJECT_ADDRESS (Wrd77.Obj));
  (Wrd76.Obj) = ((Wrd75.pObj) [1]);
  (* (--Rsp)) = (Wrd76.Obj);

DEFLABEL (label_48)
  (Wrd87.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd87.Obj);
  goto lambda_24;

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_169_12);

DEFLABEL (label_47)
  (Wrd85.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd85.Obj));
  Rvl = (Rsp [0]);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_49)
  (* (--Rsp)) = (Wrd70.Obj);
  (Wrd86.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_169_13]))));
  (* (--Rsp)) = (Wrd86.Obj);
  (* (--Rsp)) = (Wrd77.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_169_1]), 1);

DEFLABEL (label_32)
  (Wrd79.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd79.Obj));
  (* (--Rsp)) = Rvl;
  goto label_48;

DEFLABEL (label_50)
  (Wrd91.Obj) = (Rsp [0]);
  (Wrd92.uLng) = (OBJECT_TYPE (Wrd91.Obj));
  if (! ((Wrd92.uLng) == 1))
    goto label_52;
  (Wrd90.pObj) = (OBJECT_ADDRESS (Wrd91.Obj));
  (Wrd88.Obj) = ((Wrd90.pObj) [1]);

DEFLABEL (label_51)
  (Rsp [0]) = (Wrd88.Obj);
  goto lambda_12;

DEFLABEL (label_52)
  (Wrd96.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd96.Obj);
  (Wrd100.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_169_11]))));
  (* (--Rsp)) = (Wrd100.Obj);
  (* (--Rsp)) = (Wrd91.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_169_1]), 1);

DEFLABEL (label_33)
  (Wrd93.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd93.Obj));
  (Wrd88.Obj) = Rvl;
  goto label_51;

DEFLABEL (label_54)
  (Wrd61.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd61.Obj);
  (Wrd65.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_169_10]))));
  (* (--Rsp)) = (Wrd65.Obj);
  (* (--Rsp)) = (Wrd42.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_169_0]), 1);

DEFLABEL (label_31)
  (Wrd58.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd58.Obj));
  (Wrd55.Obj) = Rvl;
  goto label_53;

DEFLABEL (label_56)
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd50.Obj);
  (Wrd54.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_169_9]))));
  (* (--Rsp)) = (Wrd54.Obj);
  (* (--Rsp)) = (Wrd45.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_169_0]), 1);

DEFLABEL (label_30)
  (Wrd47.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd47.Obj));
  (Wrd42.Obj) = Rvl;
  goto label_55;

DEFLABEL (label_59)
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_169_8]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_169_0]), 1);

DEFLABEL (label_29)
  (Wrd24.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd19.Obj) = Rvl;
  goto label_58;

DEFLABEL (lambda_42)
DEFLABEL (lambda_25)
  INTERRUPT_CHECK (26, LABEL_169_14);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [1]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_169_3]);
  (Rsp [1]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_169_15]));

DEFLABEL (lambda_43)
DEFLABEL (lambda_24)
  INTERRUPT_CHECK (26, LABEL_169_18);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if ((Wrd9.uLng) == 1)
    goto label_61;
  if ((Wrd8.Obj) == (current_block [OBJECT_169_2]))
    goto label_60;
  (Wrd13.Obj) = (Rsp [5]);
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd14.pObj)));
  (Rsp [1]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  goto lambda_25;

DEFLABEL (label_60)
  Rsp = (& (Rsp [3]));
  goto label_47;

DEFLABEL (label_61)
  if (! ((Wrd9.uLng) == 1))
    goto label_74;
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd21.Obj) = ((Wrd23.pObj) [0]);

DEFLABEL (label_73)
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if ((Wrd30.uLng) == 1)
    goto label_72;
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_169_17]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd34.Obj) = (Rsp [6]);
  (Wrd35.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd35.pObj)));
  (* (--Rsp)) = (Wrd37.Obj);
  goto lambda_25;

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_169_17);

DEFLABEL (label_72)
  (Wrd41.Obj) = (Rsp [1]);
  (Wrd42.uLng) = (OBJECT_TYPE (Wrd41.Obj));
  if (! ((Wrd42.uLng) == 1))
    goto label_71;
  (Wrd40.pObj) = (OBJECT_ADDRESS (Wrd41.Obj));
  (Wrd38.Obj) = ((Wrd40.pObj) [0]);

DEFLABEL (label_70)
  (Wrd49.uLng) = (OBJECT_TYPE (Wrd38.Obj));
  if (! ((Wrd49.uLng) == 1))
    goto label_69;
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd38.Obj));
  (Wrd47.Obj) = ((Wrd48.pObj) [0]);

DEFLABEL (label_68)
  (Wrd54.Obj) = (Rsp [5]);
  (Wrd55.pObj) = (OBJECT_ADDRESS (Wrd54.Obj));
  (Wrd56.Obj) = ((Wrd55.pObj) [0]);
  if ((Wrd47.Obj) == (Wrd56.Obj))
    goto label_64;
  (Wrd57.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd57.Obj);
  (Wrd62.uLng) = (OBJECT_TYPE (Wrd57.Obj));
  if (! ((Wrd62.uLng) == 1))
    goto label_63;
  (Wrd60.pObj) = (OBJECT_ADDRESS (Wrd57.Obj));
  (Wrd58.Obj) = ((Wrd60.pObj) [1]);

DEFLABEL (label_62)
  (Rsp [1]) = (Wrd58.Obj);
  goto lambda_24;

DEFLABEL (label_63)
  (Wrd66.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_169_23]))));
  (* (--Rsp)) = (Wrd66.Obj);
  (* (--Rsp)) = (Wrd57.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_169_1]), 1);

DEFLABEL (label_37)
  (Wrd58.Obj) = Rvl;
  goto label_62;

DEFLABEL (label_64)
  (Wrd69.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_169_16]))));
  (* (--Rsp)) = (Wrd69.Obj);
  (Wrd73.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd55.pObj)));
  (* (--Rsp)) = (Wrd73.Obj);
  (Wrd77.Obj) = (Rsp [3]);
  (Wrd78.uLng) = (OBJECT_TYPE (Wrd77.Obj));
  if (! ((Wrd78.uLng) == 1))
    goto label_67;
  (Wrd75.pObj) = (OBJECT_ADDRESS (Wrd77.Obj));
  (Wrd76.Obj) = ((Wrd75.pObj) [1]);
  (* (--Rsp)) = (Wrd76.Obj);

DEFLABEL (label_66)
  Rdl = (& (Rsp [2]));
  goto lambda_12;

DEFLABEL (continuation_23)
  INTERRUPT_CHECK (27, LABEL_169_16);
  (Rsp [1]) = Rvl;
  (Wrd91.Obj) = (Rsp [0]);
  (Wrd92.uLng) = (OBJECT_TYPE (Wrd91.Obj));
  if ((Wrd92.uLng) == 1)
    goto label_65;
  INVOKE_PRIMITIVE ((current_block [OBJECT_169_4]), 2);

DEFLABEL (label_65)
  (Wrd89.pObj) = (OBJECT_ADDRESS (Wrd91.Obj));
  ((Wrd89.pObj) [1]) = Rvl;
  goto label_60;

DEFLABEL (label_67)
  (Wrd82.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_169_22]))));
  (* (--Rsp)) = (Wrd82.Obj);
  (* (--Rsp)) = (Wrd77.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_169_1]), 1);

DEFLABEL (label_38)
  (* (--Rsp)) = Rvl;
  goto label_66;

DEFLABEL (label_69)
  (Wrd53.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_169_21]))));
  (* (--Rsp)) = (Wrd53.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_169_0]), 1);

DEFLABEL (label_36)
  (Wrd47.Obj) = Rvl;
  goto label_68;

DEFLABEL (label_71)
  (Wrd46.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_169_20]))));
  (* (--Rsp)) = (Wrd46.Obj);
  (* (--Rsp)) = (Wrd41.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_169_0]), 1);

DEFLABEL (label_35)
  (Wrd38.Obj) = Rvl;
  goto label_70;

DEFLABEL (label_74)
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_169_19]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_169_0]), 1);

DEFLABEL (label_34)
  (Wrd21.Obj) = Rvl;
  goto label_73;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_170_4 3
#define LABEL_170_5 5
#define LABEL_170_6 7
#define LABEL_170_7 9
#define LABEL_170_8 11
#define LABEL_170_10 13
#define LABEL_170_11 15
#define LABEL_170_13 17
#define LABEL_170_9 19
#define LABEL_170_16 21
#define LABEL_170_17 23
#define LABEL_170_18 25
#define LABEL_170_19 27
#define LABEL_170_20 29
#define LABEL_170_21 31
#define LABEL_170_23 33
#define LABEL_170_24 35
#define LABEL_170_15 37
#define LABEL_170_22 39
#define LABEL_170_25 41
#define LABEL_170_26 43
#define ENVIRONMENT_LABEL_170_3 55
#define DEBUGGING_LABEL_170_2 54
#define OBJECT_170_4 53
#define OBJECT_170_3 52
#define OBJECT_170_2 51
#define OBJECT_170_1 50
#define OBJECT_170_0 49
#define EXECUTE_CACHE_170_14 45
#define EXECUTE_CACHE_170_12 47
#define FREE_REFERENCES_LABEL_170_0 44
#define NUMBER_OF_LINKER_SECTIONS_170_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_170 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd22;
  machine_word Wrd18;
  machine_word Wrd25;
  machine_word Wrd61;
  machine_word Wrd16;
  machine_word Wrd35;
  machine_word Wrd33;
  machine_word Wrd59;
  machine_word Wrd44;
  machine_word Wrd42;
  machine_word Wrd68;
  machine_word Wrd67;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd12;
  machine_word Wrd40;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd30;
  machine_word Wrd26;
  machine_word Wrd23;
  machine_word Wrd8;
  machine_word Wrd17;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd41;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd34;
  machine_word Wrd66;
  machine_word Wrd73;
  machine_word Wrd69;
  machine_word Wrd64;
  machine_word Wrd63;
  machine_word Wrd65;
  machine_word Wrd55;
  machine_word Wrd62;
  machine_word Wrd50;
  machine_word Wrd52;
  machine_word Wrd54;
  machine_word Wrd53;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd43;
  machine_word Wrd32;
  machine_word Wrd24;
  machine_word Wrd31;
  machine_word Wrd27;
  machine_word Wrd19;
  machine_word Wrd21;
  machine_word Wrd5;
  machine_word Wrd74;
  machine_word Wrd76;
  machine_word Wrd7;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_170_4);
      goto del_assvB_27;

    case 1:
      current_block = (Rpc - LABEL_170_5);
      goto continuation_5;

    case 2:
      current_block = (Rpc - LABEL_170_6);
      goto continuation_2;

    case 3:
      current_block = (Rpc - LABEL_170_7);
      goto lambda_12;

    case 4:
      current_block = (Rpc - LABEL_170_8);
      goto label_29;

    case 5:
      current_block = (Rpc - LABEL_170_10);
      goto label_30;

    case 6:
      current_block = (Rpc - LABEL_170_11);
      goto label_31;

    case 7:
      current_block = (Rpc - LABEL_170_13);
      goto lambda_25;

    case 8:
      current_block = (Rpc - LABEL_170_9);
      goto continuation_8;

    case 9:
      current_block = (Rpc - LABEL_170_16);
      goto label_33;

    case 10:
      current_block = (Rpc - LABEL_170_17);
      goto label_32;

    case 11:
      current_block = (Rpc - LABEL_170_18);
      goto continuation_23;

    case 12:
      current_block = (Rpc - LABEL_170_19);
      goto continuation_17;

    case 13:
      current_block = (Rpc - LABEL_170_20);
      goto lambda_24;

    case 14:
      current_block = (Rpc - LABEL_170_21);
      goto label_34;

    case 15:
      current_block = (Rpc - LABEL_170_23);
      goto label_35;

    case 16:
      current_block = (Rpc - LABEL_170_24);
      goto label_36;

    case 17:
      current_block = (Rpc - LABEL_170_15);
      goto continuation_10;

    case 18:
      current_block = (Rpc - LABEL_170_22);
      goto continuation_20;

    case 19:
      current_block = (Rpc - LABEL_170_25);
      goto label_38;

    case 20:
      current_block = (Rpc - LABEL_170_26);
      goto label_37;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (del_assvB_40)
DEFLABEL (del_assvB_27)
  INTERRUPT_CHECK (26, LABEL_170_4);
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (59, Rsp));
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  Rdl = (& (Rsp [4]));
  goto lambda_12;

DEFLABEL (lambda_41)
DEFLABEL (lambda_12)
  DLINK_INTERRUPT_CHECK (25, LABEL_170_7);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_46;
  if (! ((Wrd5.Obj) == (current_block [OBJECT_170_1])))
    goto label_45;

DEFLABEL (label_44)
  Rvl = (current_block [OBJECT_170_1]);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_45)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_170_6]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd15.pObj)));
  (* (--Rsp)) = (Wrd17.Obj);
  goto lambda_25;

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_170_6);
  (Wrd74.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd74.Obj));
  goto label_44;

DEFLABEL (label_46)
  if (! ((Wrd6.uLng) == 1))
    goto label_59;
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd19.Obj) = ((Wrd21.pObj) [0]);

DEFLABEL (label_58)
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if ((Wrd32.uLng) == 1)
    goto label_57;
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd34.Obj);
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_170_5]))));
  (* (--Rsp)) = (Wrd37.Obj);
  (Wrd38.Obj) = (Rsp [3]);
  (Wrd39.pObj) = (OBJECT_ADDRESS (Wrd38.Obj));
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd39.pObj)));
  (* (--Rsp)) = (Wrd41.Obj);
  goto lambda_25;

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_170_5);
  (Wrd76.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd76.Obj));

DEFLABEL (label_57)
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd43.Obj);
  (Wrd46.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_170_9]))));
  (* (--Rsp)) = (Wrd46.Obj);
  (Wrd47.Obj) = (Rsp [3]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  (Wrd49.Obj) = ((Wrd48.pObj) [0]);
  (* (--Rsp)) = (Wrd49.Obj);
  (Wrd53.Obj) = (Rsp [3]);
  (Wrd54.uLng) = (OBJECT_TYPE (Wrd53.Obj));
  if (! ((Wrd54.uLng) == 1))
    goto label_56;
  (Wrd52.pObj) = (OBJECT_ADDRESS (Wrd53.Obj));
  (Wrd50.Obj) = ((Wrd52.pObj) [0]);

DEFLABEL (label_55)
  (Wrd65.uLng) = (OBJECT_TYPE (Wrd50.Obj));
  if (! ((Wrd65.uLng) == 1))
    goto label_54;
  (Wrd63.pObj) = (OBJECT_ADDRESS (Wrd50.Obj));
  (Wrd64.Obj) = ((Wrd63.pObj) [0]);
  (* (--Rsp)) = (Wrd64.Obj);

DEFLABEL (label_53)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_170_12]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_170_9);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_49;
  (Wrd12.Obj) = (Rsp [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_48;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd9.Obj) = ((Wrd11.pObj) [1]);

DEFLABEL (label_47)
  (Rsp [0]) = (Wrd9.Obj);
  goto lambda_12;

DEFLABEL (label_48)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_170_17]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_170_3]), 1);

DEFLABEL (label_32)
  (Wrd14.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd9.Obj) = Rvl;
  goto label_47;

DEFLABEL (label_49)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_170_15]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd30.Obj) = (Rsp [2]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 1))
    goto label_52;
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd29.Obj) = ((Wrd28.pObj) [1]);
  (* (--Rsp)) = (Wrd29.Obj);

DEFLABEL (label_51)
  (Wrd40.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd40.Obj);
  goto lambda_24;

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_170_15);

DEFLABEL (label_50)
  (Wrd61.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd61.Obj));
  Rvl = (Rsp [0]);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_52)
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_170_16]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_170_3]), 1);

DEFLABEL (label_33)
  (Wrd32.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd32.Obj));
  (* (--Rsp)) = Rvl;
  goto label_51;

DEFLABEL (label_54)
  (Wrd69.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd69.Obj);
  (Wrd73.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_170_11]))));
  (* (--Rsp)) = (Wrd73.Obj);
  (* (--Rsp)) = (Wrd50.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_170_0]), 1);

DEFLABEL (label_31)
  (Wrd66.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd66.Obj));
  (* (--Rsp)) = Rvl;
  goto label_53;

DEFLABEL (label_56)
  (* (--Rsp)) = (Wrd43.Obj);
  (Wrd62.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_170_10]))));
  (* (--Rsp)) = (Wrd62.Obj);
  (* (--Rsp)) = (Wrd53.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_170_0]), 1);

DEFLABEL (label_30)
  (Wrd55.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd55.Obj));
  (Wrd50.Obj) = Rvl;
  goto label_55;

DEFLABEL (label_59)
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_170_8]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_170_0]), 1);

DEFLABEL (label_29)
  (Wrd24.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd19.Obj) = Rvl;
  goto label_58;

DEFLABEL (lambda_42)
DEFLABEL (lambda_25)
  INTERRUPT_CHECK (26, LABEL_170_13);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [1]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_170_2]);
  (Rsp [1]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_170_14]));

DEFLABEL (lambda_43)
DEFLABEL (lambda_24)
  INTERRUPT_CHECK (26, LABEL_170_20);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if ((Wrd9.uLng) == 1)
    goto label_61;
  if ((Wrd8.Obj) == (current_block [OBJECT_170_1]))
    goto label_60;
  (Wrd13.Obj) = (Rsp [5]);
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd14.pObj)));
  (Rsp [1]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  goto lambda_25;

DEFLABEL (label_60)
  Rsp = (& (Rsp [3]));
  goto label_50;

DEFLABEL (label_61)
  if (! ((Wrd9.uLng) == 1))
    goto label_74;
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd21.Obj) = ((Wrd23.pObj) [0]);

DEFLABEL (label_73)
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if ((Wrd30.uLng) == 1)
    goto label_72;
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_170_19]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd34.Obj) = (Rsp [6]);
  (Wrd35.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd35.pObj)));
  (* (--Rsp)) = (Wrd37.Obj);
  goto lambda_25;

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_170_19);

DEFLABEL (label_72)
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_170_22]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (Wrd41.Obj) = (Rsp [6]);
  (Wrd42.pObj) = (OBJECT_ADDRESS (Wrd41.Obj));
  (Wrd43.Obj) = ((Wrd42.pObj) [0]);
  (* (--Rsp)) = (Wrd43.Obj);
  (Wrd47.Obj) = (Rsp [3]);
  (Wrd48.uLng) = (OBJECT_TYPE (Wrd47.Obj));
  if (! ((Wrd48.uLng) == 1))
    goto label_71;
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  (Wrd44.Obj) = ((Wrd46.pObj) [0]);

DEFLABEL (label_70)
  (Wrd55.uLng) = (OBJECT_TYPE (Wrd44.Obj));
  if (! ((Wrd55.uLng) == 1))
    goto label_69;
  (Wrd53.pObj) = (OBJECT_ADDRESS (Wrd44.Obj));
  (Wrd54.Obj) = ((Wrd53.pObj) [0]);
  (* (--Rsp)) = (Wrd54.Obj);

DEFLABEL (label_68)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_170_12]));

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_170_22);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_65;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_170_18]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [6]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd11.pObj)));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd17.Obj) = (Rsp [3]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_64;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [1]);
  (* (--Rsp)) = (Wrd16.Obj);

DEFLABEL (label_63)
  Rdl = (& (Rsp [2]));
  goto lambda_12;

DEFLABEL (continuation_23)
  INTERRUPT_CHECK (27, LABEL_170_18);
  (Rsp [1]) = Rvl;
  (Wrd67.Obj) = (Rsp [0]);
  (Wrd68.uLng) = (OBJECT_TYPE (Wrd67.Obj));
  if ((Wrd68.uLng) == 1)
    goto label_62;
  INVOKE_PRIMITIVE ((current_block [OBJECT_170_4]), 2);

DEFLABEL (label_62)
  (Wrd65.pObj) = (OBJECT_ADDRESS (Wrd67.Obj));
  ((Wrd65.pObj) [1]) = Rvl;
  goto label_60;

DEFLABEL (label_64)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_170_26]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_170_3]), 1);

DEFLABEL (label_37)
  (* (--Rsp)) = Rvl;
  goto label_63;

DEFLABEL (label_65)
  (Wrd24.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd24.Obj);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if (! ((Wrd29.uLng) == 1))
    goto label_67;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd25.Obj) = ((Wrd27.pObj) [1]);

DEFLABEL (label_66)
  (Rsp [1]) = (Wrd25.Obj);
  goto lambda_24;

DEFLABEL (label_67)
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_170_25]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_170_3]), 1);

DEFLABEL (label_38)
  (Wrd25.Obj) = Rvl;
  goto label_66;

DEFLABEL (label_69)
  (Wrd59.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_170_24]))));
  (* (--Rsp)) = (Wrd59.Obj);
  (* (--Rsp)) = (Wrd44.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_170_0]), 1);

DEFLABEL (label_36)
  (* (--Rsp)) = Rvl;
  goto label_68;

DEFLABEL (label_71)
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_170_23]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (* (--Rsp)) = (Wrd47.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_170_0]), 1);

DEFLABEL (label_35)
  (Wrd44.Obj) = Rvl;
  goto label_70;

DEFLABEL (label_74)
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_170_21]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_170_0]), 1);

DEFLABEL (label_34)
  (Wrd21.Obj) = Rvl;
  goto label_73;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_171_4 3
#define LABEL_171_5 5
#define LABEL_171_6 7
#define LABEL_171_7 9
#define LABEL_171_8 11
#define LABEL_171_10 13
#define LABEL_171_11 15
#define LABEL_171_13 17
#define LABEL_171_9 19
#define LABEL_171_16 21
#define LABEL_171_17 23
#define LABEL_171_18 25
#define LABEL_171_19 27
#define LABEL_171_20 29
#define LABEL_171_21 31
#define LABEL_171_23 33
#define LABEL_171_24 35
#define LABEL_171_15 37
#define LABEL_171_22 39
#define LABEL_171_25 41
#define LABEL_171_26 43
#define ENVIRONMENT_LABEL_171_3 55
#define DEBUGGING_LABEL_171_2 54
#define OBJECT_171_4 53
#define OBJECT_171_3 52
#define OBJECT_171_2 51
#define OBJECT_171_1 50
#define OBJECT_171_0 49
#define EXECUTE_CACHE_171_14 45
#define EXECUTE_CACHE_171_12 47
#define FREE_REFERENCES_LABEL_171_0 44
#define NUMBER_OF_LINKER_SECTIONS_171_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_171 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd22;
  machine_word Wrd18;
  machine_word Wrd25;
  machine_word Wrd61;
  machine_word Wrd16;
  machine_word Wrd35;
  machine_word Wrd33;
  machine_word Wrd59;
  machine_word Wrd44;
  machine_word Wrd42;
  machine_word Wrd68;
  machine_word Wrd67;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd12;
  machine_word Wrd40;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd30;
  machine_word Wrd26;
  machine_word Wrd23;
  machine_word Wrd8;
  machine_word Wrd17;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd41;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd34;
  machine_word Wrd66;
  machine_word Wrd73;
  machine_word Wrd69;
  machine_word Wrd64;
  machine_word Wrd63;
  machine_word Wrd65;
  machine_word Wrd55;
  machine_word Wrd62;
  machine_word Wrd50;
  machine_word Wrd52;
  machine_word Wrd54;
  machine_word Wrd53;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd43;
  machine_word Wrd32;
  machine_word Wrd24;
  machine_word Wrd31;
  machine_word Wrd27;
  machine_word Wrd19;
  machine_word Wrd21;
  machine_word Wrd5;
  machine_word Wrd74;
  machine_word Wrd76;
  machine_word Wrd7;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_171_4);
      goto del_assocB_27;

    case 1:
      current_block = (Rpc - LABEL_171_5);
      goto continuation_5;

    case 2:
      current_block = (Rpc - LABEL_171_6);
      goto continuation_2;

    case 3:
      current_block = (Rpc - LABEL_171_7);
      goto lambda_12;

    case 4:
      current_block = (Rpc - LABEL_171_8);
      goto label_29;

    case 5:
      current_block = (Rpc - LABEL_171_10);
      goto label_30;

    case 6:
      current_block = (Rpc - LABEL_171_11);
      goto label_31;

    case 7:
      current_block = (Rpc - LABEL_171_13);
      goto lambda_25;

    case 8:
      current_block = (Rpc - LABEL_171_9);
      goto continuation_8;

    case 9:
      current_block = (Rpc - LABEL_171_16);
      goto label_33;

    case 10:
      current_block = (Rpc - LABEL_171_17);
      goto label_32;

    case 11:
      current_block = (Rpc - LABEL_171_18);
      goto continuation_23;

    case 12:
      current_block = (Rpc - LABEL_171_19);
      goto continuation_17;

    case 13:
      current_block = (Rpc - LABEL_171_20);
      goto lambda_24;

    case 14:
      current_block = (Rpc - LABEL_171_21);
      goto label_34;

    case 15:
      current_block = (Rpc - LABEL_171_23);
      goto label_35;

    case 16:
      current_block = (Rpc - LABEL_171_24);
      goto label_36;

    case 17:
      current_block = (Rpc - LABEL_171_15);
      goto continuation_10;

    case 18:
      current_block = (Rpc - LABEL_171_22);
      goto continuation_20;

    case 19:
      current_block = (Rpc - LABEL_171_25);
      goto label_38;

    case 20:
      current_block = (Rpc - LABEL_171_26);
      goto label_37;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (del_assocB_40)
DEFLABEL (del_assocB_27)
  INTERRUPT_CHECK (26, LABEL_171_4);
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (59, Rsp));
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  Rdl = (& (Rsp [4]));
  goto lambda_12;

DEFLABEL (lambda_41)
DEFLABEL (lambda_12)
  DLINK_INTERRUPT_CHECK (25, LABEL_171_7);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_46;
  if (! ((Wrd5.Obj) == (current_block [OBJECT_171_1])))
    goto label_45;

DEFLABEL (label_44)
  Rvl = (current_block [OBJECT_171_1]);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_45)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_171_6]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd15.pObj)));
  (* (--Rsp)) = (Wrd17.Obj);
  goto lambda_25;

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_171_6);
  (Wrd74.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd74.Obj));
  goto label_44;

DEFLABEL (label_46)
  if (! ((Wrd6.uLng) == 1))
    goto label_59;
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd19.Obj) = ((Wrd21.pObj) [0]);

DEFLABEL (label_58)
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if ((Wrd32.uLng) == 1)
    goto label_57;
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd34.Obj);
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_171_5]))));
  (* (--Rsp)) = (Wrd37.Obj);
  (Wrd38.Obj) = (Rsp [3]);
  (Wrd39.pObj) = (OBJECT_ADDRESS (Wrd38.Obj));
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd39.pObj)));
  (* (--Rsp)) = (Wrd41.Obj);
  goto lambda_25;

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_171_5);
  (Wrd76.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd76.Obj));

DEFLABEL (label_57)
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd43.Obj);
  (Wrd46.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_171_9]))));
  (* (--Rsp)) = (Wrd46.Obj);
  (Wrd47.Obj) = (Rsp [3]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  (Wrd49.Obj) = ((Wrd48.pObj) [0]);
  (* (--Rsp)) = (Wrd49.Obj);
  (Wrd53.Obj) = (Rsp [3]);
  (Wrd54.uLng) = (OBJECT_TYPE (Wrd53.Obj));
  if (! ((Wrd54.uLng) == 1))
    goto label_56;
  (Wrd52.pObj) = (OBJECT_ADDRESS (Wrd53.Obj));
  (Wrd50.Obj) = ((Wrd52.pObj) [0]);

DEFLABEL (label_55)
  (Wrd65.uLng) = (OBJECT_TYPE (Wrd50.Obj));
  if (! ((Wrd65.uLng) == 1))
    goto label_54;
  (Wrd63.pObj) = (OBJECT_ADDRESS (Wrd50.Obj));
  (Wrd64.Obj) = ((Wrd63.pObj) [0]);
  (* (--Rsp)) = (Wrd64.Obj);

DEFLABEL (label_53)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_171_12]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_171_9);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_49;
  (Wrd12.Obj) = (Rsp [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_48;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd9.Obj) = ((Wrd11.pObj) [1]);

DEFLABEL (label_47)
  (Rsp [0]) = (Wrd9.Obj);
  goto lambda_12;

DEFLABEL (label_48)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_171_17]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_171_3]), 1);

DEFLABEL (label_32)
  (Wrd14.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd9.Obj) = Rvl;
  goto label_47;

DEFLABEL (label_49)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_171_15]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd30.Obj) = (Rsp [2]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 1))
    goto label_52;
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd29.Obj) = ((Wrd28.pObj) [1]);
  (* (--Rsp)) = (Wrd29.Obj);

DEFLABEL (label_51)
  (Wrd40.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd40.Obj);
  goto lambda_24;

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_171_15);

DEFLABEL (label_50)
  (Wrd61.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd61.Obj));
  Rvl = (Rsp [0]);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_52)
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_171_16]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_171_3]), 1);

DEFLABEL (label_33)
  (Wrd32.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd32.Obj));
  (* (--Rsp)) = Rvl;
  goto label_51;

DEFLABEL (label_54)
  (Wrd69.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd69.Obj);
  (Wrd73.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_171_11]))));
  (* (--Rsp)) = (Wrd73.Obj);
  (* (--Rsp)) = (Wrd50.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_171_0]), 1);

DEFLABEL (label_31)
  (Wrd66.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd66.Obj));
  (* (--Rsp)) = Rvl;
  goto label_53;

DEFLABEL (label_56)
  (* (--Rsp)) = (Wrd43.Obj);
  (Wrd62.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_171_10]))));
  (* (--Rsp)) = (Wrd62.Obj);
  (* (--Rsp)) = (Wrd53.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_171_0]), 1);

DEFLABEL (label_30)
  (Wrd55.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd55.Obj));
  (Wrd50.Obj) = Rvl;
  goto label_55;

DEFLABEL (label_59)
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_171_8]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_171_0]), 1);

DEFLABEL (label_29)
  (Wrd24.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd19.Obj) = Rvl;
  goto label_58;

DEFLABEL (lambda_42)
DEFLABEL (lambda_25)
  INTERRUPT_CHECK (26, LABEL_171_13);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [1]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_171_2]);
  (Rsp [1]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_171_14]));

DEFLABEL (lambda_43)
DEFLABEL (lambda_24)
  INTERRUPT_CHECK (26, LABEL_171_20);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if ((Wrd9.uLng) == 1)
    goto label_61;
  if ((Wrd8.Obj) == (current_block [OBJECT_171_1]))
    goto label_60;
  (Wrd13.Obj) = (Rsp [5]);
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd14.pObj)));
  (Rsp [1]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  goto lambda_25;

DEFLABEL (label_60)
  Rsp = (& (Rsp [3]));
  goto label_50;

DEFLABEL (label_61)
  if (! ((Wrd9.uLng) == 1))
    goto label_74;
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd21.Obj) = ((Wrd23.pObj) [0]);

DEFLABEL (label_73)
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if ((Wrd30.uLng) == 1)
    goto label_72;
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_171_19]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd34.Obj) = (Rsp [6]);
  (Wrd35.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd35.pObj)));
  (* (--Rsp)) = (Wrd37.Obj);
  goto lambda_25;

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_171_19);

DEFLABEL (label_72)
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_171_22]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (Wrd41.Obj) = (Rsp [6]);
  (Wrd42.pObj) = (OBJECT_ADDRESS (Wrd41.Obj));
  (Wrd43.Obj) = ((Wrd42.pObj) [0]);
  (* (--Rsp)) = (Wrd43.Obj);
  (Wrd47.Obj) = (Rsp [3]);
  (Wrd48.uLng) = (OBJECT_TYPE (Wrd47.Obj));
  if (! ((Wrd48.uLng) == 1))
    goto label_71;
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  (Wrd44.Obj) = ((Wrd46.pObj) [0]);

DEFLABEL (label_70)
  (Wrd55.uLng) = (OBJECT_TYPE (Wrd44.Obj));
  if (! ((Wrd55.uLng) == 1))
    goto label_69;
  (Wrd53.pObj) = (OBJECT_ADDRESS (Wrd44.Obj));
  (Wrd54.Obj) = ((Wrd53.pObj) [0]);
  (* (--Rsp)) = (Wrd54.Obj);

DEFLABEL (label_68)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_171_12]));

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_171_22);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_65;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_171_18]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [6]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd11.pObj)));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd17.Obj) = (Rsp [3]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_64;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [1]);
  (* (--Rsp)) = (Wrd16.Obj);

DEFLABEL (label_63)
  Rdl = (& (Rsp [2]));
  goto lambda_12;

DEFLABEL (continuation_23)
  INTERRUPT_CHECK (27, LABEL_171_18);
  (Rsp [1]) = Rvl;
  (Wrd67.Obj) = (Rsp [0]);
  (Wrd68.uLng) = (OBJECT_TYPE (Wrd67.Obj));
  if ((Wrd68.uLng) == 1)
    goto label_62;
  INVOKE_PRIMITIVE ((current_block [OBJECT_171_4]), 2);

DEFLABEL (label_62)
  (Wrd65.pObj) = (OBJECT_ADDRESS (Wrd67.Obj));
  ((Wrd65.pObj) [1]) = Rvl;
  goto label_60;

DEFLABEL (label_64)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_171_26]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_171_3]), 1);

DEFLABEL (label_37)
  (* (--Rsp)) = Rvl;
  goto label_63;

DEFLABEL (label_65)
  (Wrd24.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd24.Obj);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if (! ((Wrd29.uLng) == 1))
    goto label_67;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd25.Obj) = ((Wrd27.pObj) [1]);

DEFLABEL (label_66)
  (Rsp [1]) = (Wrd25.Obj);
  goto lambda_24;

DEFLABEL (label_67)
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_171_25]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_171_3]), 1);

DEFLABEL (label_38)
  (Wrd25.Obj) = Rvl;
  goto label_66;

DEFLABEL (label_69)
  (Wrd59.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_171_24]))));
  (* (--Rsp)) = (Wrd59.Obj);
  (* (--Rsp)) = (Wrd44.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_171_0]), 1);

DEFLABEL (label_36)
  (* (--Rsp)) = Rvl;
  goto label_68;

DEFLABEL (label_71)
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_171_23]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (* (--Rsp)) = (Wrd47.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_171_0]), 1);

DEFLABEL (label_35)
  (Wrd44.Obj) = Rvl;
  goto label_70;

DEFLABEL (label_74)
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_171_21]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_171_0]), 1);

DEFLABEL (label_34)
  (Wrd21.Obj) = Rvl;
  goto label_73;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_172_4 3
#define LABEL_172_5 5
#define LABEL_172_6 7
#define LABEL_172_7 9
#define LABEL_172_8 11
#define LABEL_172_9 13
#define LABEL_172_11 15
#define LABEL_172_12 17
#define LABEL_172_13 19
#define LABEL_172_10 21
#define LABEL_172_16 23
#define LABEL_172_17 25
#define LABEL_172_18 27
#define LABEL_172_19 29
#define LABEL_172_20 31
#define LABEL_172_21 33
#define LABEL_172_23 35
#define LABEL_172_24 37
#define LABEL_172_15 39
#define LABEL_172_22 41
#define LABEL_172_25 43
#define LABEL_172_26 45
#define ENVIRONMENT_LABEL_172_3 58
#define DEBUGGING_LABEL_172_2 57
#define OBJECT_172_5 56
#define OBJECT_172_4 55
#define OBJECT_172_3 54
#define OBJECT_172_2 53
#define OBJECT_172_1 52
#define OBJECT_172_0 51
#define EXECUTE_CACHE_172_14 47
#define FREE_REFERENCE_172_0 50
#define FREE_REFERENCES_LABEL_172_0 46
#define NUMBER_OF_LINKER_SECTIONS_172_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_172 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd27;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd34;
  machine_word Wrd63;
  machine_word Wrd62;
  machine_word Wrd61;
  machine_word Wrd46;
  machine_word Wrd44;
  machine_word Wrd42;
  machine_word Wrd24;
  machine_word Wrd70;
  machine_word Wrd73;
  machine_word Wrd72;
  machine_word Wrd21;
  machine_word Wrd11;
  machine_word Wrd29;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd26;
  machine_word Wrd23;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd43;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd35;
  machine_word Wrd78;
  machine_word Wrd77;
  machine_word Wrd76;
  machine_word Wrd68;
  machine_word Wrd75;
  machine_word Wrd71;
  machine_word Wrd66;
  machine_word Wrd65;
  machine_word Wrd67;
  machine_word Wrd57;
  machine_word Wrd64;
  machine_word Wrd52;
  machine_word Wrd54;
  machine_word Wrd56;
  machine_word Wrd55;
  machine_word Wrd51;
  machine_word Wrd50;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd45;
  machine_word Wrd33;
  machine_word Wrd25;
  machine_word Wrd32;
  machine_word Wrd28;
  machine_word Wrd20;
  machine_word Wrd22;
  machine_word Wrd6;
  machine_word Wrd79;
  machine_word Wrd81;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd12;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_172_4);
      goto alist_deleteB_30;

    case 1:
      current_block = (Rpc - LABEL_172_5);
      goto label_32;

    case 2:
      current_block = (Rpc - LABEL_172_6);
      goto continuation_7;

    case 3:
      current_block = (Rpc - LABEL_172_7);
      goto continuation_4;

    case 4:
      current_block = (Rpc - LABEL_172_8);
      goto lambda_14;

    case 5:
      current_block = (Rpc - LABEL_172_9);
      goto label_33;

    case 6:
      current_block = (Rpc - LABEL_172_11);
      goto label_34;

    case 7:
      current_block = (Rpc - LABEL_172_12);
      goto label_35;

    case 8:
      current_block = (Rpc - LABEL_172_13);
      goto lambda_27;

    case 9:
      current_block = (Rpc - LABEL_172_10);
      goto continuation_10;

    case 10:
      current_block = (Rpc - LABEL_172_16);
      goto label_37;

    case 11:
      current_block = (Rpc - LABEL_172_17);
      goto label_36;

    case 12:
      current_block = (Rpc - LABEL_172_18);
      goto continuation_25;

    case 13:
      current_block = (Rpc - LABEL_172_19);
      goto continuation_19;

    case 14:
      current_block = (Rpc - LABEL_172_20);
      goto lambda_26;

    case 15:
      current_block = (Rpc - LABEL_172_21);
      goto label_38;

    case 16:
      current_block = (Rpc - LABEL_172_23);
      goto label_39;

    case 17:
      current_block = (Rpc - LABEL_172_24);
      goto label_40;

    case 18:
      current_block = (Rpc - LABEL_172_15);
      goto continuation_12;

    case 19:
      current_block = (Rpc - LABEL_172_22);
      goto continuation_22;

    case 20:
      current_block = (Rpc - LABEL_172_25);
      goto label_42;

    case 21:
      current_block = (Rpc - LABEL_172_26);
      goto label_41;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (alist_deleteB_44)
DEFLABEL (alist_deleteB_30)
  INTERRUPT_CHECK (26, LABEL_172_4);
  (Wrd5.Obj) = (Rsp [2]);
  if ((Wrd5.Obj) == (current_block [OBJECT_172_0]))
    goto label_49;
  (* (--Rsp)) = (Wrd5.Obj);

DEFLABEL (label_48)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (59, Rsp));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  Rdl = (& (Rsp [6]));
  goto lambda_14;

DEFLABEL (label_49)
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_172_0]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_51;
  Wrd12 = Wrd16;

DEFLABEL (label_50)
  (* (--Rsp)) = (Wrd12.Obj);
  goto label_48;

DEFLABEL (label_51)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_172_5])), (Wrd13.pObj));

DEFLABEL (label_32)
  (Wrd12.Obj) = Rvl;
  goto label_50;

DEFLABEL (lambda_45)
DEFLABEL (lambda_14)
  DLINK_INTERRUPT_CHECK (25, LABEL_172_8);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_54;
  if (! ((Wrd5.Obj) == (current_block [OBJECT_172_2])))
    goto label_53;

DEFLABEL (label_52)
  Rvl = (current_block [OBJECT_172_2]);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_53)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_172_7]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd16.pObj) = (& ((Wrd15.pObj) [1]));
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd16.pObj)));
  (* (--Rsp)) = (Wrd18.Obj);
  goto lambda_27;

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_172_7);
  (Wrd79.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd79.Obj));
  goto label_52;

DEFLABEL (label_54)
  if (! ((Wrd6.uLng) == 1))
    goto label_67;
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd20.Obj) = ((Wrd22.pObj) [0]);

DEFLABEL (label_66)
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if ((Wrd33.uLng) == 1)
    goto label_65;
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd35.Obj);
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_172_6]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (Wrd39.Obj) = (Rsp [3]);
  (Wrd40.pObj) = (OBJECT_ADDRESS (Wrd39.Obj));
  (Wrd41.pObj) = (& ((Wrd40.pObj) [1]));
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd41.pObj)));
  (* (--Rsp)) = (Wrd43.Obj);
  goto lambda_27;

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_172_6);
  (Wrd81.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd81.Obj));

DEFLABEL (label_65)
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd45.Obj);
  (Wrd48.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_172_10]))));
  (* (--Rsp)) = (Wrd48.Obj);
  (Wrd49.Obj) = (Rsp [3]);
  (Wrd50.pObj) = (OBJECT_ADDRESS (Wrd49.Obj));
  (Wrd51.Obj) = ((Wrd50.pObj) [1]);
  (* (--Rsp)) = (Wrd51.Obj);
  (Wrd55.Obj) = (Rsp [3]);
  (Wrd56.uLng) = (OBJECT_TYPE (Wrd55.Obj));
  if (! ((Wrd56.uLng) == 1))
    goto label_64;
  (Wrd54.pObj) = (OBJECT_ADDRESS (Wrd55.Obj));
  (Wrd52.Obj) = ((Wrd54.pObj) [0]);

DEFLABEL (label_63)
  (Wrd67.uLng) = (OBJECT_TYPE (Wrd52.Obj));
  if (! ((Wrd67.uLng) == 1))
    goto label_62;
  (Wrd65.pObj) = (OBJECT_ADDRESS (Wrd52.Obj));
  (Wrd66.Obj) = ((Wrd65.pObj) [0]);
  (* (--Rsp)) = (Wrd66.Obj);

DEFLABEL (label_61)
  (Wrd76.Obj) = (Rsp [5]);
  (Wrd77.pObj) = (OBJECT_ADDRESS (Wrd76.Obj));
  (Wrd78.Obj) = ((Wrd77.pObj) [0]);
  (* (--Rsp)) = (Wrd78.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_172_10);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_57;
  (Wrd12.Obj) = (Rsp [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_56;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd9.Obj) = ((Wrd11.pObj) [1]);

DEFLABEL (label_55)
  (Rsp [0]) = (Wrd9.Obj);
  goto lambda_14;

DEFLABEL (label_56)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_172_17]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_172_4]), 1);

DEFLABEL (label_36)
  (Wrd14.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd9.Obj) = Rvl;
  goto label_55;

DEFLABEL (label_57)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_172_15]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd30.Obj) = (Rsp [2]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 1))
    goto label_60;
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd29.Obj) = ((Wrd28.pObj) [1]);
  (* (--Rsp)) = (Wrd29.Obj);

DEFLABEL (label_59)
  (Wrd40.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd40.Obj);
  goto lambda_26;

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_172_15);

DEFLABEL (label_58)
  (Wrd66.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd66.Obj));
  Rvl = (Rsp [0]);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_60)
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_172_16]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_172_4]), 1);

DEFLABEL (label_37)
  (Wrd32.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd32.Obj));
  (* (--Rsp)) = Rvl;
  goto label_59;

DEFLABEL (label_62)
  (Wrd71.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd71.Obj);
  (Wrd75.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_172_12]))));
  (* (--Rsp)) = (Wrd75.Obj);
  (* (--Rsp)) = (Wrd52.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_172_1]), 1);

DEFLABEL (label_35)
  (Wrd68.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd68.Obj));
  (* (--Rsp)) = Rvl;
  goto label_61;

DEFLABEL (label_64)
  (* (--Rsp)) = (Wrd45.Obj);
  (Wrd64.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_172_11]))));
  (* (--Rsp)) = (Wrd64.Obj);
  (* (--Rsp)) = (Wrd55.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_172_1]), 1);

DEFLABEL (label_34)
  (Wrd57.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd57.Obj));
  (Wrd52.Obj) = Rvl;
  goto label_63;

DEFLABEL (label_67)
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_172_9]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_172_1]), 1);

DEFLABEL (label_33)
  (Wrd25.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd20.Obj) = Rvl;
  goto label_66;

DEFLABEL (lambda_46)
DEFLABEL (lambda_27)
  INTERRUPT_CHECK (26, LABEL_172_13);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [1]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_172_3]);
  (Rsp [1]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_172_14]));

DEFLABEL (lambda_47)
DEFLABEL (lambda_26)
  INTERRUPT_CHECK (26, LABEL_172_20);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if ((Wrd9.uLng) == 1)
    goto label_69;
  if ((Wrd8.Obj) == (current_block [OBJECT_172_2]))
    goto label_68;
  (Wrd13.Obj) = (Rsp [5]);
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd15.pObj) = (& ((Wrd14.pObj) [1]));
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd15.pObj)));
  (Rsp [1]) = (Wrd17.Obj);
  Rsp = (& (Rsp [1]));
  goto lambda_27;

DEFLABEL (label_68)
  Rsp = (& (Rsp [3]));
  goto label_58;

DEFLABEL (label_69)
  if (! ((Wrd9.uLng) == 1))
    goto label_82;
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd22.Obj) = ((Wrd24.pObj) [0]);

DEFLABEL (label_81)
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if ((Wrd31.uLng) == 1)
    goto label_80;
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_172_19]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (Wrd35.Obj) = (Rsp [6]);
  (Wrd36.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd37.pObj) = (& ((Wrd36.pObj) [1]));
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd37.pObj)));
  (* (--Rsp)) = (Wrd39.Obj);
  goto lambda_27;

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_172_19);

DEFLABEL (label_80)
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_172_22]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (Wrd43.Obj) = (Rsp [6]);
  (Wrd44.pObj) = (OBJECT_ADDRESS (Wrd43.Obj));
  (Wrd45.Obj) = ((Wrd44.pObj) [1]);
  (* (--Rsp)) = (Wrd45.Obj);
  (Wrd49.Obj) = (Rsp [3]);
  (Wrd50.uLng) = (OBJECT_TYPE (Wrd49.Obj));
  if (! ((Wrd50.uLng) == 1))
    goto label_79;
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd49.Obj));
  (Wrd46.Obj) = ((Wrd48.pObj) [0]);

DEFLABEL (label_78)
  (Wrd57.uLng) = (OBJECT_TYPE (Wrd46.Obj));
  if (! ((Wrd57.uLng) == 1))
    goto label_77;
  (Wrd55.pObj) = (OBJECT_ADDRESS (Wrd46.Obj));
  (Wrd56.Obj) = ((Wrd55.pObj) [0]);
  (* (--Rsp)) = (Wrd56.Obj);

DEFLABEL (label_76)
  (Wrd62.Obj) = (Rsp [8]);
  (Wrd63.pObj) = (OBJECT_ADDRESS (Wrd62.Obj));
  (Wrd64.Obj) = ((Wrd63.pObj) [0]);
  (* (--Rsp)) = (Wrd64.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_22)
  INTERRUPT_CHECK (27, LABEL_172_22);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_73;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_172_18]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [6]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd11.pObj)));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd17.Obj) = (Rsp [3]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_72;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [1]);
  (* (--Rsp)) = (Wrd16.Obj);

DEFLABEL (label_71)
  Rdl = (& (Rsp [2]));
  goto lambda_14;

DEFLABEL (continuation_25)
  INTERRUPT_CHECK (27, LABEL_172_18);
  (Rsp [1]) = Rvl;
  (Wrd72.Obj) = (Rsp [0]);
  (Wrd73.uLng) = (OBJECT_TYPE (Wrd72.Obj));
  if ((Wrd73.uLng) == 1)
    goto label_70;
  INVOKE_PRIMITIVE ((current_block [OBJECT_172_5]), 2);

DEFLABEL (label_70)
  (Wrd70.pObj) = (OBJECT_ADDRESS (Wrd72.Obj));
  ((Wrd70.pObj) [1]) = Rvl;
  goto label_68;

DEFLABEL (label_72)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_172_26]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_172_4]), 1);

DEFLABEL (label_41)
  (* (--Rsp)) = Rvl;
  goto label_71;

DEFLABEL (label_73)
  (Wrd24.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd24.Obj);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if (! ((Wrd29.uLng) == 1))
    goto label_75;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd25.Obj) = ((Wrd27.pObj) [1]);

DEFLABEL (label_74)
  (Rsp [1]) = (Wrd25.Obj);
  goto lambda_26;

DEFLABEL (label_75)
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_172_25]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_172_4]), 1);

DEFLABEL (label_42)
  (Wrd25.Obj) = Rvl;
  goto label_74;

DEFLABEL (label_77)
  (Wrd61.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_172_24]))));
  (* (--Rsp)) = (Wrd61.Obj);
  (* (--Rsp)) = (Wrd46.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_172_1]), 1);

DEFLABEL (label_40)
  (* (--Rsp)) = Rvl;
  goto label_76;

DEFLABEL (label_79)
  (Wrd54.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_172_23]))));
  (* (--Rsp)) = (Wrd54.Obj);
  (* (--Rsp)) = (Wrd49.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_172_1]), 1);

DEFLABEL (label_39)
  (Wrd46.Obj) = Rvl;
  goto label_78;

DEFLABEL (label_82)
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_172_21]))));
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_172_1]), 1);

DEFLABEL (label_38)
  (Wrd22.Obj) = Rvl;
  goto label_81;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_173_4 3
#define LABEL_173_5 5
#define LABEL_173_6 7
#define LABEL_173_7 9
#define LABEL_173_8 11
#define LABEL_173_10 13
#define LABEL_173_11 15
#define LABEL_173_12 17
#define LABEL_173_9 19
#define LABEL_173_15 21
#define LABEL_173_16 23
#define LABEL_173_17 25
#define LABEL_173_18 27
#define LABEL_173_19 29
#define LABEL_173_20 31
#define LABEL_173_22 33
#define LABEL_173_23 35
#define LABEL_173_14 37
#define LABEL_173_21 39
#define LABEL_173_24 41
#define LABEL_173_25 43
#define ENVIRONMENT_LABEL_173_3 52
#define DEBUGGING_LABEL_173_2 51
#define OBJECT_173_3 50
#define OBJECT_173_2 49
#define OBJECT_173_1 48
#define OBJECT_173_0 47
#define EXECUTE_CACHE_173_13 45
#define FREE_REFERENCES_LABEL_173_0 44
#define NUMBER_OF_LINKER_SECTIONS_173_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_173 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd22;
  machine_word Wrd18;
  machine_word Wrd25;
  machine_word Wrd16;
  machine_word Wrd35;
  machine_word Wrd33;
  machine_word Wrd61;
  machine_word Wrd60;
  machine_word Wrd59;
  machine_word Wrd44;
  machine_word Wrd42;
  machine_word Wrd68;
  machine_word Wrd71;
  machine_word Wrd70;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd12;
  machine_word Wrd40;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd30;
  machine_word Wrd26;
  machine_word Wrd23;
  machine_word Wrd8;
  machine_word Wrd17;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd41;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd34;
  machine_word Wrd76;
  machine_word Wrd75;
  machine_word Wrd74;
  machine_word Wrd66;
  machine_word Wrd73;
  machine_word Wrd69;
  machine_word Wrd64;
  machine_word Wrd63;
  machine_word Wrd65;
  machine_word Wrd55;
  machine_word Wrd62;
  machine_word Wrd50;
  machine_word Wrd52;
  machine_word Wrd54;
  machine_word Wrd53;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd43;
  machine_word Wrd32;
  machine_word Wrd24;
  machine_word Wrd31;
  machine_word Wrd27;
  machine_word Wrd19;
  machine_word Wrd21;
  machine_word Wrd5;
  machine_word Wrd77;
  machine_word Wrd79;
  machine_word Wrd7;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_173_4);
      goto Z__alist_deleteB_27;

    case 1:
      current_block = (Rpc - LABEL_173_5);
      goto continuation_5;

    case 2:
      current_block = (Rpc - LABEL_173_6);
      goto continuation_2;

    case 3:
      current_block = (Rpc - LABEL_173_7);
      goto lambda_12;

    case 4:
      current_block = (Rpc - LABEL_173_8);
      goto label_29;

    case 5:
      current_block = (Rpc - LABEL_173_10);
      goto label_30;

    case 6:
      current_block = (Rpc - LABEL_173_11);
      goto label_31;

    case 7:
      current_block = (Rpc - LABEL_173_12);
      goto lambda_25;

    case 8:
      current_block = (Rpc - LABEL_173_9);
      goto continuation_8;

    case 9:
      current_block = (Rpc - LABEL_173_15);
      goto label_33;

    case 10:
      current_block = (Rpc - LABEL_173_16);
      goto label_32;

    case 11:
      current_block = (Rpc - LABEL_173_17);
      goto continuation_23;

    case 12:
      current_block = (Rpc - LABEL_173_18);
      goto continuation_17;

    case 13:
      current_block = (Rpc - LABEL_173_19);
      goto lambda_24;

    case 14:
      current_block = (Rpc - LABEL_173_20);
      goto label_34;

    case 15:
      current_block = (Rpc - LABEL_173_22);
      goto label_35;

    case 16:
      current_block = (Rpc - LABEL_173_23);
      goto label_36;

    case 17:
      current_block = (Rpc - LABEL_173_14);
      goto continuation_10;

    case 18:
      current_block = (Rpc - LABEL_173_21);
      goto continuation_20;

    case 19:
      current_block = (Rpc - LABEL_173_24);
      goto label_38;

    case 20:
      current_block = (Rpc - LABEL_173_25);
      goto label_37;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (Z__alist_deleteB_40)
DEFLABEL (Z__alist_deleteB_27)
  INTERRUPT_CHECK (26, LABEL_173_4);
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (59, Rsp));
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  Rdl = (& (Rsp [6]));
  goto lambda_12;

DEFLABEL (lambda_41)
DEFLABEL (lambda_12)
  DLINK_INTERRUPT_CHECK (25, LABEL_173_7);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_46;
  if (! ((Wrd5.Obj) == (current_block [OBJECT_173_1])))
    goto label_45;

DEFLABEL (label_44)
  Rvl = (current_block [OBJECT_173_1]);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_45)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_173_6]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd15.pObj)));
  (* (--Rsp)) = (Wrd17.Obj);
  goto lambda_25;

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_173_6);
  (Wrd77.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd77.Obj));
  goto label_44;

DEFLABEL (label_46)
  if (! ((Wrd6.uLng) == 1))
    goto label_59;
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd19.Obj) = ((Wrd21.pObj) [0]);

DEFLABEL (label_58)
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if ((Wrd32.uLng) == 1)
    goto label_57;
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd34.Obj);
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_173_5]))));
  (* (--Rsp)) = (Wrd37.Obj);
  (Wrd38.Obj) = (Rsp [3]);
  (Wrd39.pObj) = (OBJECT_ADDRESS (Wrd38.Obj));
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd39.pObj)));
  (* (--Rsp)) = (Wrd41.Obj);
  goto lambda_25;

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_173_5);
  (Wrd79.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd79.Obj));

DEFLABEL (label_57)
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd43.Obj);
  (Wrd46.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_173_9]))));
  (* (--Rsp)) = (Wrd46.Obj);
  (Wrd47.Obj) = (Rsp [3]);
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  (Wrd49.Obj) = ((Wrd48.pObj) [0]);
  (* (--Rsp)) = (Wrd49.Obj);
  (Wrd53.Obj) = (Rsp [3]);
  (Wrd54.uLng) = (OBJECT_TYPE (Wrd53.Obj));
  if (! ((Wrd54.uLng) == 1))
    goto label_56;
  (Wrd52.pObj) = (OBJECT_ADDRESS (Wrd53.Obj));
  (Wrd50.Obj) = ((Wrd52.pObj) [0]);

DEFLABEL (label_55)
  (Wrd65.uLng) = (OBJECT_TYPE (Wrd50.Obj));
  if (! ((Wrd65.uLng) == 1))
    goto label_54;
  (Wrd63.pObj) = (OBJECT_ADDRESS (Wrd50.Obj));
  (Wrd64.Obj) = ((Wrd63.pObj) [0]);
  (* (--Rsp)) = (Wrd64.Obj);

DEFLABEL (label_53)
  (Wrd74.Obj) = (Rsp [5]);
  (Wrd75.pObj) = (OBJECT_ADDRESS (Wrd74.Obj));
  (Wrd76.Obj) = ((Wrd75.pObj) [2]);
  (* (--Rsp)) = (Wrd76.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_173_9);
  (Wrd5.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd5.Obj));
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_49;
  (Wrd12.Obj) = (Rsp [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_48;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd9.Obj) = ((Wrd11.pObj) [1]);

DEFLABEL (label_47)
  (Rsp [0]) = (Wrd9.Obj);
  goto lambda_12;

DEFLABEL (label_48)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_173_16]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_173_2]), 1);

DEFLABEL (label_32)
  (Wrd14.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd9.Obj) = Rvl;
  goto label_47;

DEFLABEL (label_49)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_173_14]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd30.Obj) = (Rsp [2]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 1))
    goto label_52;
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd29.Obj) = ((Wrd28.pObj) [1]);
  (* (--Rsp)) = (Wrd29.Obj);

DEFLABEL (label_51)
  (Wrd40.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd40.Obj);
  goto lambda_24;

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_173_14);

DEFLABEL (label_50)
  (Wrd64.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd64.Obj));
  Rvl = (Rsp [0]);
  Rsp = Rdl;
  goto pop_return;

DEFLABEL (label_52)
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_173_15]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_173_2]), 1);

DEFLABEL (label_33)
  (Wrd32.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd32.Obj));
  (* (--Rsp)) = Rvl;
  goto label_51;

DEFLABEL (label_54)
  (Wrd69.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd69.Obj);
  (Wrd73.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_173_11]))));
  (* (--Rsp)) = (Wrd73.Obj);
  (* (--Rsp)) = (Wrd50.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_173_0]), 1);

DEFLABEL (label_31)
  (Wrd66.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd66.Obj));
  (* (--Rsp)) = Rvl;
  goto label_53;

DEFLABEL (label_56)
  (* (--Rsp)) = (Wrd43.Obj);
  (Wrd62.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_173_10]))));
  (* (--Rsp)) = (Wrd62.Obj);
  (* (--Rsp)) = (Wrd53.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_173_0]), 1);

DEFLABEL (label_30)
  (Wrd55.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd55.Obj));
  (Wrd50.Obj) = Rvl;
  goto label_55;

DEFLABEL (label_59)
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (59, Rdl));
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_173_8]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_173_0]), 1);

DEFLABEL (label_29)
  (Wrd24.Obj) = (* (Rsp++));
  Rdl = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd19.Obj) = Rvl;
  goto label_58;

DEFLABEL (lambda_42)
DEFLABEL (lambda_25)
  INTERRUPT_CHECK (26, LABEL_173_12);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [1]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = ((Wrd6.pObj) [3]);
  (Rsp [1]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_173_13]));

DEFLABEL (lambda_43)
DEFLABEL (lambda_24)
  INTERRUPT_CHECK (26, LABEL_173_19);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if ((Wrd9.uLng) == 1)
    goto label_61;
  if ((Wrd8.Obj) == (current_block [OBJECT_173_1]))
    goto label_60;
  (Wrd13.Obj) = (Rsp [5]);
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd14.pObj)));
  (Rsp [1]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  goto lambda_25;

DEFLABEL (label_60)
  Rsp = (& (Rsp [3]));
  goto label_50;

DEFLABEL (label_61)
  if (! ((Wrd9.uLng) == 1))
    goto label_74;
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd21.Obj) = ((Wrd23.pObj) [0]);

DEFLABEL (label_73)
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if ((Wrd30.uLng) == 1)
    goto label_72;
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_173_18]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd34.Obj) = (Rsp [6]);
  (Wrd35.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd35.pObj)));
  (* (--Rsp)) = (Wrd37.Obj);
  goto lambda_25;

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_173_18);

DEFLABEL (label_72)
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_173_21]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (Wrd41.Obj) = (Rsp [6]);
  (Wrd42.pObj) = (OBJECT_ADDRESS (Wrd41.Obj));
  (Wrd43.Obj) = ((Wrd42.pObj) [0]);
  (* (--Rsp)) = (Wrd43.Obj);
  (Wrd47.Obj) = (Rsp [3]);
  (Wrd48.uLng) = (OBJECT_TYPE (Wrd47.Obj));
  if (! ((Wrd48.uLng) == 1))
    goto label_71;
  (Wrd46.pObj) = (OBJECT_ADDRESS (Wrd47.Obj));
  (Wrd44.Obj) = ((Wrd46.pObj) [0]);

DEFLABEL (label_70)
  (Wrd55.uLng) = (OBJECT_TYPE (Wrd44.Obj));
  if (! ((Wrd55.uLng) == 1))
    goto label_69;
  (Wrd53.pObj) = (OBJECT_ADDRESS (Wrd44.Obj));
  (Wrd54.Obj) = ((Wrd53.pObj) [0]);
  (* (--Rsp)) = (Wrd54.Obj);

DEFLABEL (label_68)
  (Wrd60.Obj) = (Rsp [8]);
  (Wrd61.pObj) = (OBJECT_ADDRESS (Wrd60.Obj));
  (Wrd62.Obj) = ((Wrd61.pObj) [2]);
  (* (--Rsp)) = (Wrd62.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_173_21);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_65;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_173_17]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [6]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd11.pObj)));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd17.Obj) = (Rsp [3]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_64;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [1]);
  (* (--Rsp)) = (Wrd16.Obj);

DEFLABEL (label_63)
  Rdl = (& (Rsp [2]));
  goto lambda_12;

DEFLABEL (continuation_23)
  INTERRUPT_CHECK (27, LABEL_173_17);
  (Rsp [1]) = Rvl;
  (Wrd70.Obj) = (Rsp [0]);
  (Wrd71.uLng) = (OBJECT_TYPE (Wrd70.Obj));
  if ((Wrd71.uLng) == 1)
    goto label_62;
  INVOKE_PRIMITIVE ((current_block [OBJECT_173_3]), 2);

DEFLABEL (label_62)
  (Wrd68.pObj) = (OBJECT_ADDRESS (Wrd70.Obj));
  ((Wrd68.pObj) [1]) = Rvl;
  goto label_60;

DEFLABEL (label_64)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_173_25]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_173_2]), 1);

DEFLABEL (label_37)
  (* (--Rsp)) = Rvl;
  goto label_63;

DEFLABEL (label_65)
  (Wrd24.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd24.Obj);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if (! ((Wrd29.uLng) == 1))
    goto label_67;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd25.Obj) = ((Wrd27.pObj) [1]);

DEFLABEL (label_66)
  (Rsp [1]) = (Wrd25.Obj);
  goto lambda_24;

DEFLABEL (label_67)
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_173_24]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_173_2]), 1);

DEFLABEL (label_38)
  (Wrd25.Obj) = Rvl;
  goto label_66;

DEFLABEL (label_69)
  (Wrd59.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_173_23]))));
  (* (--Rsp)) = (Wrd59.Obj);
  (* (--Rsp)) = (Wrd44.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_173_0]), 1);

DEFLABEL (label_36)
  (* (--Rsp)) = Rvl;
  goto label_68;

DEFLABEL (label_71)
  (Wrd52.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_173_22]))));
  (* (--Rsp)) = (Wrd52.Obj);
  (* (--Rsp)) = (Wrd47.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_173_0]), 1);

DEFLABEL (label_35)
  (Wrd44.Obj) = Rvl;
  goto label_70;

DEFLABEL (label_74)
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_173_20]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_173_0]), 1);

DEFLABEL (label_34)
  (Wrd21.Obj) = Rvl;
  goto label_73;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_174_4 3
#define LABEL_174_5 5
#define LABEL_174_6 7
#define LABEL_174_7 9
#define LABEL_174_8 11
#define LABEL_174_9 13
#define LABEL_174_10 15
#define LABEL_174_11 17
#define LABEL_174_12 19
#define LABEL_174_13 21
#define ENVIRONMENT_LABEL_174_3 31
#define DEBUGGING_LABEL_174_2 30
#define OBJECT_174_7 29
#define OBJECT_174_6 28
#define OBJECT_174_5 27
#define OBJECT_174_4 26
#define OBJECT_174_3 25
#define OBJECT_174_2 24
#define OBJECT_174_1 23
#define OBJECT_174_0 22
#define FREE_REFERENCES_LABEL_174_0 22
#define NUMBER_OF_LINKER_SECTIONS_174_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_174 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd86;
  machine_word Wrd80;
  machine_word Wrd81;
  machine_word Wrd82;
  machine_word Wrd79;
  machine_word Wrd71;
  machine_word Wrd73;
  machine_word Wrd75;
  machine_word Wrd74;
  machine_word Wrd70;
  machine_word Wrd62;
  machine_word Wrd64;
  machine_word Wrd66;
  machine_word Wrd65;
  machine_word Wrd61;
  machine_word Wrd60;
  machine_word Wrd52;
  machine_word Wrd54;
  machine_word Wrd56;
  machine_word Wrd55;
  machine_word Wrd51;
  machine_word Wrd50;
  machine_word Wrd42;
  machine_word Wrd44;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd30;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd38;
  machine_word Wrd28;
  machine_word Wrd96;
  machine_word Wrd93;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd91;
  machine_word Wrd88;
  machine_word Wrd23;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd14;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_174_4);
      goto keyword_listP_15;

    case 1:
      current_block = (Rpc - LABEL_174_5);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_174_6);
      goto loop_13;

    case 3:
      current_block = (Rpc - LABEL_174_7);
      goto label_17;

    case 4:
      current_block = (Rpc - LABEL_174_8);
      goto label_23;

    case 5:
      current_block = (Rpc - LABEL_174_9);
      goto label_18;

    case 6:
      current_block = (Rpc - LABEL_174_10);
      goto label_19;

    case 7:
      current_block = (Rpc - LABEL_174_11);
      goto label_20;

    case 8:
      current_block = (Rpc - LABEL_174_12);
      goto label_21;

    case 9:
      current_block = (Rpc - LABEL_174_13);
      goto label_22;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (keyword_listP_25)
DEFLABEL (keyword_listP_15)
  INTERRUPT_CHECK (26, LABEL_174_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  goto loop_13;

DEFLABEL (loop_26)
DEFLABEL (loop_13)
  INTERRUPT_CHECK (26, LABEL_174_6);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_31;
  if ((Wrd5.Obj) == (current_block [OBJECT_174_7]))
    goto label_28;

DEFLABEL (label_29)
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_27;

DEFLABEL (label_28)
  Rvl = (current_block [OBJECT_174_4]);

DEFLABEL (label_27)
DEFLABEL (label_30)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_31)
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_174_5]))));
  (* (--Rsp)) = (Wrd14.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_51;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (* (--Rsp)) = (Wrd17.Obj);

DEFLABEL (label_50)
  (Wrd88.Obj) = (current_block [OBJECT_174_1]);
  (Wrd91.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 29L) < ((unsigned long) (Wrd91.Lng))))
    goto label_49;
  (Wrd25.uLng) = (OBJECT_DATUM (Wrd88.Obj));
  (Wrd26.Obj) = (Rsp [0]);
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if ((Wrd25.Obj) == (Wrd27.Obj))
    goto label_48;

DEFLABEL (label_47)
  (Wrd28.Obj) = (current_block [OBJECT_174_3]);
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd38.Lng) = (1 << TYPE_CODE_LENGTH);
  if (((unsigned long) 5L) < ((unsigned long) (Wrd38.Lng)))
    goto label_32;
  INVOKE_PRIMITIVE ((current_block [OBJECT_174_2]), 2);

DEFLABEL (label_32)
  (Wrd32.uLng) = (OBJECT_DATUM (Wrd28.Obj));
  (Wrd33.Obj) = (Rsp [1]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if ((Wrd32.Obj) == (Wrd34.Obj))
    goto label_34;
  (Wrd30.Obj) = (current_block [OBJECT_174_5]);
  goto label_33;

DEFLABEL (label_34)
  (Wrd30.Obj) = (current_block [OBJECT_174_4]);

DEFLABEL (label_33)
DEFLABEL (label_46)
  Rsp = (& (Rsp [3]));
  if ((Wrd30.Obj) == ((SCHEME_OBJECT) 0))
    goto label_29;

DEFLABEL (label_45)
  (Wrd45.Obj) = (Rsp [0]);
  (Wrd46.uLng) = (OBJECT_TYPE (Wrd45.Obj));
  if (! ((Wrd46.uLng) == 1))
    goto label_44;
  (Wrd44.pObj) = (OBJECT_ADDRESS (Wrd45.Obj));
  (Wrd42.Obj) = ((Wrd44.pObj) [1]);

DEFLABEL (label_43)
  (Wrd51.uLng) = (OBJECT_TYPE (Wrd42.Obj));
  if (! ((Wrd51.uLng) == 1))
    goto label_29;
  (Wrd55.Obj) = (Rsp [0]);
  (Wrd56.uLng) = (OBJECT_TYPE (Wrd55.Obj));
  if (! ((Wrd56.uLng) == 1))
    goto label_42;
  (Wrd54.pObj) = (OBJECT_ADDRESS (Wrd55.Obj));
  (Wrd52.Obj) = ((Wrd54.pObj) [1]);

DEFLABEL (label_41)
  (Wrd61.Obj) = (Rsp [1]);
  if ((Wrd52.Obj) == (Wrd61.Obj))
    goto label_29;
  (Wrd65.Obj) = (Rsp [0]);
  (Wrd66.uLng) = (OBJECT_TYPE (Wrd65.Obj));
  if (! ((Wrd66.uLng) == 1))
    goto label_40;
  (Wrd64.pObj) = (OBJECT_ADDRESS (Wrd65.Obj));
  (Wrd62.Obj) = ((Wrd64.pObj) [1]);

DEFLABEL (label_39)
  (Rsp [1]) = (Wrd62.Obj);
  (Wrd74.Obj) = (Rsp [0]);
  (Wrd75.uLng) = (OBJECT_TYPE (Wrd74.Obj));
  if (! ((Wrd75.uLng) == 1))
    goto label_38;
  (Wrd73.pObj) = (OBJECT_ADDRESS (Wrd74.Obj));
  (Wrd71.Obj) = ((Wrd73.pObj) [1]);

DEFLABEL (label_37)
  (Wrd82.uLng) = (OBJECT_TYPE (Wrd71.Obj));
  if (! ((Wrd82.uLng) == 1))
    goto label_36;
  (Wrd81.pObj) = (OBJECT_ADDRESS (Wrd71.Obj));
  (Wrd80.Obj) = ((Wrd81.pObj) [1]);

DEFLABEL (label_35)
  (Rsp [0]) = (Wrd80.Obj);
  goto loop_13;

DEFLABEL (label_36)
  (Wrd86.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_174_13]))));
  (* (--Rsp)) = (Wrd86.Obj);
  (* (--Rsp)) = (Wrd71.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_174_6]), 1);

DEFLABEL (label_22)
  (Wrd80.Obj) = Rvl;
  goto label_35;

DEFLABEL (label_38)
  (Wrd79.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_174_12]))));
  (* (--Rsp)) = (Wrd79.Obj);
  (* (--Rsp)) = (Wrd74.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_174_6]), 1);

DEFLABEL (label_21)
  (Wrd71.Obj) = Rvl;
  goto label_37;

DEFLABEL (label_40)
  (Wrd70.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_174_11]))));
  (* (--Rsp)) = (Wrd70.Obj);
  (* (--Rsp)) = (Wrd65.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_174_6]), 1);

DEFLABEL (label_20)
  (Wrd62.Obj) = Rvl;
  goto label_39;

DEFLABEL (label_42)
  (Wrd60.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_174_10]))));
  (* (--Rsp)) = (Wrd60.Obj);
  (* (--Rsp)) = (Wrd55.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_174_6]), 1);

DEFLABEL (label_19)
  (Wrd52.Obj) = Rvl;
  goto label_41;

DEFLABEL (label_44)
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_174_9]))));
  (* (--Rsp)) = (Wrd50.Obj);
  (* (--Rsp)) = (Wrd45.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_174_6]), 1);

DEFLABEL (label_18)
  (Wrd42.Obj) = Rvl;
  goto label_43;

DEFLABEL (label_48)
  Rsp = (& (Rsp [2]));
  goto label_45;

DEFLABEL (label_49)
  (Wrd93.Obj) = (Rsp [0]);
  (Wrd96.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_174_8]))));
  (* (--Rsp)) = (Wrd96.Obj);
  (* (--Rsp)) = (Wrd93.Obj);
  (* (--Rsp)) = (Wrd88.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_174_2]), 2);

DEFLABEL (label_23)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_47;
  goto label_48;

DEFLABEL (label_51)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_174_7]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_174_0]), 1);

DEFLABEL (label_17)
  (* (--Rsp)) = Rvl;
  goto label_50;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_174_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_29;
  goto label_45;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_175_4 3
#define LABEL_175_5 5
#define ENVIRONMENT_LABEL_175_3 13
#define DEBUGGING_LABEL_175_2 12
#define OBJECT_175_0 11
#define EXECUTE_CACHE_175_7 7
#define EXECUTE_CACHE_175_6 9
#define FREE_REFERENCES_LABEL_175_0 6
#define NUMBER_OF_LINKER_SECTIONS_175_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_175 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_175_4);
      goto guarantee_keyword_list_1;

    case 1:
      current_block = (Rpc - LABEL_175_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (guarantee_keyword_list_4)
DEFLABEL (guarantee_keyword_list_1)
  INTERRUPT_CHECK (26, LABEL_175_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_175_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_175_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_175_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_5;
  Rvl = (current_block [OBJECT_175_0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_5)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_175_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_176_4 3
#define ENVIRONMENT_LABEL_176_3 11
#define DEBUGGING_LABEL_176_2 10
#define OBJECT_176_2 9
#define OBJECT_176_1 8
#define OBJECT_176_0 7
#define EXECUTE_CACHE_176_5 5
#define FREE_REFERENCES_LABEL_176_0 4
#define NUMBER_OF_LINKER_SECTIONS_176_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_176 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_176_4);
      goto error_not_keyword_list_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (error_not_keyword_list_5)
DEFLABEL (error_not_keyword_list_2)
  INTERRUPT_CHECK (26, LABEL_176_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_176_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [2]);
  if ((Wrd7.Obj) == (current_block [OBJECT_176_1]))
    goto label_7;
  Wrd9 = Wrd7;
  goto label_6;

DEFLABEL (label_7)
  (Wrd9.Obj) = (current_block [OBJECT_176_2]);

DEFLABEL (label_6)
DEFLABEL (label_8)
  (Rsp [2]) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_176_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_177_4 3
#define LABEL_177_5 5
#define LABEL_177_7 7
#define LABEL_177_6 9
#define LABEL_177_9 11
#define LABEL_177_10 13
#define LABEL_177_11 15
#define LABEL_177_12 17
#define LABEL_177_13 19
#define ENVIRONMENT_LABEL_177_3 28
#define DEBUGGING_LABEL_177_2 27
#define OBJECT_177_3 26
#define OBJECT_177_2 25
#define OBJECT_177_1 24
#define OBJECT_177_0 23
#define EXECUTE_CACHE_177_8 21
#define FREE_REFERENCES_LABEL_177_0 20
#define NUMBER_OF_LINKER_SECTIONS_177_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_177 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd53;
  machine_word Wrd47;
  machine_word Wrd48;
  machine_word Wrd49;
  machine_word Wrd46;
  machine_word Wrd38;
  machine_word Wrd40;
  machine_word Wrd42;
  machine_word Wrd41;
  machine_word Wrd37;
  machine_word Wrd29;
  machine_word Wrd31;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd19;
  machine_word Wrd21;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd16;
  machine_word Wrd7;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd24;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_177_4);
      goto restricted_keyword_listP_13;

    case 1:
      current_block = (Rpc - LABEL_177_5);
      goto loop_11;

    case 2:
      current_block = (Rpc - LABEL_177_7);
      goto label_15;

    case 3:
      current_block = (Rpc - LABEL_177_6);
      goto continuation_3;

    case 4:
      current_block = (Rpc - LABEL_177_9);
      goto label_16;

    case 5:
      current_block = (Rpc - LABEL_177_10);
      goto label_17;

    case 6:
      current_block = (Rpc - LABEL_177_11);
      goto label_18;

    case 7:
      current_block = (Rpc - LABEL_177_12);
      goto label_19;

    case 8:
      current_block = (Rpc - LABEL_177_13);
      goto label_20;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (restricted_keyword_listP_22)
DEFLABEL (restricted_keyword_listP_13)
  INTERRUPT_CHECK (26, LABEL_177_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  goto loop_11;

DEFLABEL (loop_23)
DEFLABEL (loop_11)
  INTERRUPT_CHECK (26, LABEL_177_5);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_27;
  if ((Wrd5.Obj) == (current_block [OBJECT_177_1]))
    goto label_25;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_24;

DEFLABEL (label_25)
  Rvl = (current_block [OBJECT_177_2]);

DEFLABEL (label_24)
DEFLABEL (label_26)
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_27)
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_177_6]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd15.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_41;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [0]);
  (* (--Rsp)) = (Wrd18.Obj);

DEFLABEL (label_40)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_177_8]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_177_6);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_29;

DEFLABEL (label_28)
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_29)
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_39;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_38)
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd16.uLng) == 1))
    goto label_28;
  (Wrd22.Obj) = (Rsp [0]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if (! ((Wrd23.uLng) == 1))
    goto label_37;
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
  (Wrd19.Obj) = ((Wrd21.pObj) [1]);

DEFLABEL (label_36)
  (Wrd28.Obj) = (Rsp [1]);
  if ((Wrd19.Obj) == (Wrd28.Obj))
    goto label_28;
  (Wrd32.Obj) = (Rsp [0]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd33.uLng) == 1))
    goto label_35;
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd29.Obj) = ((Wrd31.pObj) [1]);

DEFLABEL (label_34)
  (Rsp [1]) = (Wrd29.Obj);
  (Wrd41.Obj) = (Rsp [0]);
  (Wrd42.uLng) = (OBJECT_TYPE (Wrd41.Obj));
  if (! ((Wrd42.uLng) == 1))
    goto label_33;
  (Wrd40.pObj) = (OBJECT_ADDRESS (Wrd41.Obj));
  (Wrd38.Obj) = ((Wrd40.pObj) [1]);

DEFLABEL (label_32)
  (Wrd49.uLng) = (OBJECT_TYPE (Wrd38.Obj));
  if (! ((Wrd49.uLng) == 1))
    goto label_31;
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd38.Obj));
  (Wrd47.Obj) = ((Wrd48.pObj) [1]);

DEFLABEL (label_30)
  (Rsp [0]) = (Wrd47.Obj);
  goto loop_11;

DEFLABEL (label_31)
  (Wrd53.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_177_13]))));
  (* (--Rsp)) = (Wrd53.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_177_3]), 1);

DEFLABEL (label_20)
  (Wrd47.Obj) = Rvl;
  goto label_30;

DEFLABEL (label_33)
  (Wrd46.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_177_12]))));
  (* (--Rsp)) = (Wrd46.Obj);
  (* (--Rsp)) = (Wrd41.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_177_3]), 1);

DEFLABEL (label_19)
  (Wrd38.Obj) = Rvl;
  goto label_32;

DEFLABEL (label_35)
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_177_11]))));
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_177_3]), 1);

DEFLABEL (label_18)
  (Wrd29.Obj) = Rvl;
  goto label_34;

DEFLABEL (label_37)
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_177_10]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_177_3]), 1);

DEFLABEL (label_17)
  (Wrd19.Obj) = Rvl;
  goto label_36;

DEFLABEL (label_39)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_177_9]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_177_3]), 1);

DEFLABEL (label_16)
  (Wrd7.Obj) = Rvl;
  goto label_38;

DEFLABEL (label_41)
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_177_7]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_177_0]), 1);

DEFLABEL (label_15)
  (* (--Rsp)) = Rvl;
  goto label_40;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_178_4 3
#define LABEL_178_5 5
#define ENVIRONMENT_LABEL_178_3 13
#define DEBUGGING_LABEL_178_2 12
#define OBJECT_178_0 11
#define EXECUTE_CACHE_178_7 7
#define EXECUTE_CACHE_178_6 9
#define FREE_REFERENCES_LABEL_178_0 6
#define NUMBER_OF_LINKER_SECTIONS_178_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_178 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_178_4);
      goto guarantee_restricted_keyword_list_1;

    case 1:
      current_block = (Rpc - LABEL_178_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (guarantee_restricted_keyword_list_4)
DEFLABEL (guarantee_restricted_keyword_list_1)
  INTERRUPT_CHECK (26, LABEL_178_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_178_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_178_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_178_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_5;
  Rvl = (current_block [OBJECT_178_0]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_5)
  (Wrd9.Obj) = (Rsp [0]);
  (Rsp [1]) = (Wrd9.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_178_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_179_4 3
#define ENVIRONMENT_LABEL_179_3 11
#define DEBUGGING_LABEL_179_2 10
#define OBJECT_179_2 9
#define OBJECT_179_1 8
#define OBJECT_179_0 7
#define EXECUTE_CACHE_179_5 5
#define FREE_REFERENCES_LABEL_179_0 4
#define NUMBER_OF_LINKER_SECTIONS_179_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_179 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_179_4);
      goto error_not_restricted_keyword_list_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (error_not_restricted_keyword_list_5)
DEFLABEL (error_not_restricted_keyword_list_2)
  INTERRUPT_CHECK (26, LABEL_179_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_179_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [2]);
  if ((Wrd7.Obj) == (current_block [OBJECT_179_1]))
    goto label_7;
  Wrd9 = Wrd7;
  goto label_6;

DEFLABEL (label_7)
  (Wrd9.Obj) = (current_block [OBJECT_179_2]);

DEFLABEL (label_6)
DEFLABEL (label_8)
  (Rsp [2]) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_179_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_180_4 3
#define LABEL_180_5 5
#define LABEL_180_6 7
#define LABEL_180_7 9
#define LABEL_180_8 11
#define LABEL_180_10 13
#define LABEL_180_9 15
#define LABEL_180_12 17
#define LABEL_180_13 19
#define LABEL_180_14 21
#define LABEL_180_15 23
#define LABEL_180_16 25
#define LABEL_180_17 27
#define ENVIRONMENT_LABEL_180_3 40
#define DEBUGGING_LABEL_180_2 39
#define OBJECT_180_7 38
#define OBJECT_180_6 37
#define OBJECT_180_5 36
#define OBJECT_180_4 35
#define OBJECT_180_3 34
#define OBJECT_180_2 33
#define OBJECT_180_1 32
#define OBJECT_180_0 31
#define EXECUTE_CACHE_180_11 29
#define FREE_REFERENCES_LABEL_180_0 28
#define NUMBER_OF_LINKER_SECTIONS_180_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_180 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd66;
  machine_word Wrd60;
  machine_word Wrd62;
  machine_word Wrd51;
  machine_word Wrd53;
  machine_word Wrd55;
  machine_word Wrd46;
  machine_word Wrd40;
  machine_word Wrd42;
  machine_word Wrd41;
  machine_word Wrd37;
  machine_word Wrd29;
  machine_word Wrd31;
  machine_word Wrd19;
  machine_word Wrd21;
  machine_word Wrd22;
  machine_word Wrd18;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd54;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd50;
  machine_word Wrd49;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd30;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd38;
  machine_word Wrd28;
  machine_word Wrd64;
  machine_word Wrd61;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd59;
  machine_word Wrd56;
  machine_word Wrd23;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd14;
  machine_word Wrd6;
  machine_word Wrd7;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_180_4);
      goto unique_keyword_listP_19;

    case 1:
      current_block = (Rpc - LABEL_180_5);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_180_6);
      goto loop_17;

    case 3:
      current_block = (Rpc - LABEL_180_7);
      goto label_21;

    case 4:
      current_block = (Rpc - LABEL_180_8);
      goto label_23;

    case 5:
      current_block = (Rpc - LABEL_180_10);
      goto label_22;

    case 6:
      current_block = (Rpc - LABEL_180_9);
      goto continuation_7;

    case 7:
      current_block = (Rpc - LABEL_180_12);
      goto label_24;

    case 8:
      current_block = (Rpc - LABEL_180_13);
      goto label_25;

    case 9:
      current_block = (Rpc - LABEL_180_14);
      goto label_26;

    case 10:
      current_block = (Rpc - LABEL_180_15);
      goto label_27;

    case 11:
      current_block = (Rpc - LABEL_180_16);
      goto label_28;

    case 12:
      current_block = (Rpc - LABEL_180_17);
      goto label_29;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unique_keyword_listP_31)
DEFLABEL (unique_keyword_listP_19)
  INTERRUPT_CHECK (26, LABEL_180_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd7.Obj) = (current_block [OBJECT_180_0]);
  (Rsp [2]) = (Wrd7.Obj);
  goto loop_17;

DEFLABEL (loop_32)
DEFLABEL (loop_17)
  INTERRUPT_CHECK (26, LABEL_180_6);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_37;
  if ((Wrd5.Obj) == (current_block [OBJECT_180_0]))
    goto label_34;

DEFLABEL (label_35)
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_33;

DEFLABEL (label_34)
  Rvl = (current_block [OBJECT_180_5]);

DEFLABEL (label_33)
DEFLABEL (label_36)
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_37)
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_180_5]))));
  (* (--Rsp)) = (Wrd14.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_63;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (* (--Rsp)) = (Wrd17.Obj);

DEFLABEL (label_62)
  (Wrd56.Obj) = (current_block [OBJECT_180_2]);
  (Wrd59.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 29L) < ((unsigned long) (Wrd59.Lng))))
    goto label_61;
  (Wrd25.uLng) = (OBJECT_DATUM (Wrd56.Obj));
  (Wrd26.Obj) = (Rsp [0]);
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if ((Wrd25.Obj) == (Wrd27.Obj))
    goto label_60;

DEFLABEL (label_59)
  (Wrd28.Obj) = (current_block [OBJECT_180_4]);
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd38.Lng) = (1 << TYPE_CODE_LENGTH);
  if (((unsigned long) 5L) < ((unsigned long) (Wrd38.Lng)))
    goto label_38;
  INVOKE_PRIMITIVE ((current_block [OBJECT_180_3]), 2);

DEFLABEL (label_38)
  (Wrd32.uLng) = (OBJECT_DATUM (Wrd28.Obj));
  (Wrd33.Obj) = (Rsp [1]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if ((Wrd32.Obj) == (Wrd34.Obj))
    goto label_40;
  (Wrd30.Obj) = (current_block [OBJECT_180_6]);
  goto label_39;

DEFLABEL (label_40)
  (Wrd30.Obj) = (current_block [OBJECT_180_5]);

DEFLABEL (label_39)
DEFLABEL (label_58)
  Rsp = (& (Rsp [3]));
  if ((Wrd30.Obj) == ((SCHEME_OBJECT) 0))
    goto label_35;

DEFLABEL (label_57)
  (Wrd44.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_180_9]))));
  (* (--Rsp)) = (Wrd44.Obj);
  (Wrd45.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd45.Obj);
  (Wrd49.Obj) = (Rsp [2]);
  (Wrd50.uLng) = (OBJECT_TYPE (Wrd49.Obj));
  if (! ((Wrd50.uLng) == 1))
    goto label_56;
  (Wrd47.pObj) = (OBJECT_ADDRESS (Wrd49.Obj));
  (Wrd48.Obj) = ((Wrd47.pObj) [0]);
  (* (--Rsp)) = (Wrd48.Obj);

DEFLABEL (label_55)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_180_11]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_180_9);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_42;

DEFLABEL (label_41)
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_42)
  (Wrd12.Obj) = (Rsp [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_54;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd9.Obj) = ((Wrd11.pObj) [1]);

DEFLABEL (label_53)
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_41;
  (Wrd22.Obj) = (Rsp [0]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if (! ((Wrd23.uLng) == 1))
    goto label_52;
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
  (Wrd19.Obj) = ((Wrd21.pObj) [1]);

DEFLABEL (label_51)
  (Wrd28.Obj) = (Rsp [1]);
  if ((Wrd19.Obj) == (Wrd28.Obj))
    goto label_41;
  (Wrd32.Obj) = (Rsp [0]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd33.uLng) == 1))
    goto label_50;
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd29.Obj) = ((Wrd31.pObj) [1]);

DEFLABEL (label_49)
  (Rsp [1]) = (Wrd29.Obj);
  (Wrd41.Obj) = (Rsp [0]);
  (Wrd42.uLng) = (OBJECT_TYPE (Wrd41.Obj));
  if (! ((Wrd42.uLng) == 1))
    goto label_48;
  (Wrd40.pObj) = (OBJECT_ADDRESS (Wrd41.Obj));
  (Wrd38.Obj) = ((Wrd40.pObj) [0]);

DEFLABEL (label_47)
  (Wrd50.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd38.Obj);
  (* (Rhp++)) = (Wrd50.Obj);
  (Wrd49.pObj) = (& (Rhp [-2]));
  (Wrd47.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd49.pObj)));
  (Rsp [2]) = (Wrd47.Obj);
  (Wrd54.Obj) = (Rsp [0]);
  (Wrd55.uLng) = (OBJECT_TYPE (Wrd54.Obj));
  if (! ((Wrd55.uLng) == 1))
    goto label_46;
  (Wrd53.pObj) = (OBJECT_ADDRESS (Wrd54.Obj));
  (Wrd51.Obj) = ((Wrd53.pObj) [1]);

DEFLABEL (label_45)
  (Wrd62.uLng) = (OBJECT_TYPE (Wrd51.Obj));
  if (! ((Wrd62.uLng) == 1))
    goto label_44;
  (Wrd61.pObj) = (OBJECT_ADDRESS (Wrd51.Obj));
  (Wrd60.Obj) = ((Wrd61.pObj) [1]);

DEFLABEL (label_43)
  (Rsp [0]) = (Wrd60.Obj);
  goto loop_17;

DEFLABEL (label_44)
  (Wrd66.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_180_17]))));
  (* (--Rsp)) = (Wrd66.Obj);
  (* (--Rsp)) = (Wrd51.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_180_7]), 1);

DEFLABEL (label_29)
  (Wrd60.Obj) = Rvl;
  goto label_43;

DEFLABEL (label_46)
  (Wrd59.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_180_16]))));
  (* (--Rsp)) = (Wrd59.Obj);
  (* (--Rsp)) = (Wrd54.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_180_7]), 1);

DEFLABEL (label_28)
  (Wrd51.Obj) = Rvl;
  goto label_45;

DEFLABEL (label_48)
  (Wrd46.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_180_15]))));
  (* (--Rsp)) = (Wrd46.Obj);
  (* (--Rsp)) = (Wrd41.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_180_1]), 1);

DEFLABEL (label_27)
  (Wrd38.Obj) = Rvl;
  goto label_47;

DEFLABEL (label_50)
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_180_14]))));
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_180_7]), 1);

DEFLABEL (label_26)
  (Wrd29.Obj) = Rvl;
  goto label_49;

DEFLABEL (label_52)
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_180_13]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_180_7]), 1);

DEFLABEL (label_25)
  (Wrd19.Obj) = Rvl;
  goto label_51;

DEFLABEL (label_54)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_180_12]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_180_7]), 1);

DEFLABEL (label_24)
  (Wrd9.Obj) = Rvl;
  goto label_53;

DEFLABEL (label_56)
  (Wrd54.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_180_10]))));
  (* (--Rsp)) = (Wrd54.Obj);
  (* (--Rsp)) = (Wrd49.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_180_1]), 1);

DEFLABEL (label_22)
  (* (--Rsp)) = Rvl;
  goto label_55;

DEFLABEL (label_60)
  Rsp = (& (Rsp [2]));
  goto label_57;

DEFLABEL (label_61)
  (Wrd61.Obj) = (Rsp [0]);
  (Wrd64.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_180_8]))));
  (* (--Rsp)) = (Wrd64.Obj);
  (* (--Rsp)) = (Wrd61.Obj);
  (* (--Rsp)) = (Wrd56.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_180_3]), 2);

DEFLABEL (label_23)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_59;
  goto label_60;

DEFLABEL (label_63)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_180_7]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_180_1]), 1);

DEFLABEL (label_21)
  (* (--Rsp)) = Rvl;
  goto label_62;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_180_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_35;
  goto label_57;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_181_4 3
#define LABEL_181_5 5
#define ENVIRONMENT_LABEL_181_3 13
#define DEBUGGING_LABEL_181_2 12
#define OBJECT_181_0 11
#define EXECUTE_CACHE_181_7 7
#define EXECUTE_CACHE_181_6 9
#define FREE_REFERENCES_LABEL_181_0 6
#define NUMBER_OF_LINKER_SECTIONS_181_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_181 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_181_4);
      goto guarantee_unique_keyword_list_1;

    case 1:
      current_block = (Rpc - LABEL_181_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (guarantee_unique_keyword_list_4)
DEFLABEL (guarantee_unique_keyword_list_1)
  INTERRUPT_CHECK (26, LABEL_181_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_181_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_181_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_181_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_5;
  Rvl = (current_block [OBJECT_181_0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_5)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_181_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_182_4 3
#define ENVIRONMENT_LABEL_182_3 11
#define DEBUGGING_LABEL_182_2 10
#define OBJECT_182_2 9
#define OBJECT_182_1 8
#define OBJECT_182_0 7
#define EXECUTE_CACHE_182_5 5
#define FREE_REFERENCES_LABEL_182_0 4
#define NUMBER_OF_LINKER_SECTIONS_182_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_182 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_182_4);
      goto error_not_unique_keyword_list_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (error_not_unique_keyword_list_5)
DEFLABEL (error_not_unique_keyword_list_2)
  INTERRUPT_CHECK (26, LABEL_182_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_182_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [2]);
  if ((Wrd7.Obj) == (current_block [OBJECT_182_1]))
    goto label_7;
  Wrd9 = Wrd7;
  goto label_6;

DEFLABEL (label_7)
  (Wrd9.Obj) = (current_block [OBJECT_182_2]);

DEFLABEL (label_6)
DEFLABEL (label_8)
  (Rsp [2]) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_182_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_183_4 3
#define LABEL_183_5 5
#define LABEL_183_6 7
#define LABEL_183_7 9
#define LABEL_183_8 11
#define LABEL_183_9 13
#define LABEL_183_10 15
#define LABEL_183_11 17
#define LABEL_183_12 19
#define LABEL_183_13 21
#define ENVIRONMENT_LABEL_183_3 31
#define DEBUGGING_LABEL_183_2 30
#define OBJECT_183_4 29
#define OBJECT_183_3 28
#define OBJECT_183_2 27
#define OBJECT_183_1 26
#define OBJECT_183_0 25
#define EXECUTE_CACHE_183_14 23
#define FREE_REFERENCES_LABEL_183_0 22
#define NUMBER_OF_LINKER_SECTIONS_183_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_183 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd32;
  machine_word Wrd30;
  machine_word Wrd11;
  machine_word Wrd29;
  machine_word Wrd58;
  machine_word Wrd52;
  machine_word Wrd53;
  machine_word Wrd54;
  machine_word Wrd51;
  machine_word Wrd43;
  machine_word Wrd45;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd70;
  machine_word Wrd73;
  machine_word Wrd72;
  machine_word Wrd67;
  machine_word Wrd59;
  machine_word Wrd61;
  machine_word Wrd63;
  machine_word Wrd62;
  machine_word Wrd42;
  machine_word Wrd41;
  machine_word Wrd33;
  machine_word Wrd35;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd17;
  machine_word Wrd19;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_183_4);
      goto get_keyword_value_16;

    case 1:
      current_block = (Rpc - LABEL_183_5);
      goto continuation_7;

    case 2:
      current_block = (Rpc - LABEL_183_6);
      goto continuation_4;

    case 3:
      current_block = (Rpc - LABEL_183_7);
      goto loop_13;

    case 4:
      current_block = (Rpc - LABEL_183_8);
      goto label_18;

    case 5:
      current_block = (Rpc - LABEL_183_9);
      goto label_19;

    case 6:
      current_block = (Rpc - LABEL_183_10);
      goto label_22;

    case 7:
      current_block = (Rpc - LABEL_183_11);
      goto label_20;

    case 8:
      current_block = (Rpc - LABEL_183_12);
      goto label_21;

    case 9:
      current_block = (Rpc - LABEL_183_13);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (get_keyword_value_24)
DEFLABEL (get_keyword_value_16)
  INTERRUPT_CHECK (26, LABEL_183_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  goto loop_13;

DEFLABEL (loop_25)
DEFLABEL (loop_13)
  INTERRUPT_CHECK (26, LABEL_183_7);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_30;
  if (! ((Wrd5.Obj) == (current_block [OBJECT_183_2])))
    goto label_28;

DEFLABEL (label_27)
  Rvl = (current_block [OBJECT_183_3]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_28)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_183_6]))));
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_29)
  (Wrd30.pObj) = (& (Rsp [2]));
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd30.pObj)));
  (* (--Rsp)) = (Wrd32.Obj);
  goto lambda_0;

DEFLABEL (label_30)
  if (! ((Wrd6.uLng) == 1))
    goto label_43;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd17.Obj) = ((Wrd19.pObj) [1]);

DEFLABEL (label_42)
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if ((Wrd26.uLng) == 1)
    goto label_31;
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_183_5]))));
  (* (--Rsp)) = (Wrd29.Obj);
  goto label_29;

DEFLABEL (label_31)
  (Wrd36.Obj) = (Rsp [0]);
  (Wrd37.uLng) = (OBJECT_TYPE (Wrd36.Obj));
  if (! ((Wrd37.uLng) == 1))
    goto label_41;
  (Wrd35.pObj) = (OBJECT_ADDRESS (Wrd36.Obj));
  (Wrd33.Obj) = ((Wrd35.pObj) [0]);

DEFLABEL (label_40)
  (Wrd42.Obj) = (Rsp [2]);
  if ((Wrd33.Obj) == (Wrd42.Obj))
    goto label_36;
  (Wrd46.Obj) = (Rsp [0]);
  (Wrd47.uLng) = (OBJECT_TYPE (Wrd46.Obj));
  if (! ((Wrd47.uLng) == 1))
    goto label_35;
  (Wrd45.pObj) = (OBJECT_ADDRESS (Wrd46.Obj));
  (Wrd43.Obj) = ((Wrd45.pObj) [1]);

DEFLABEL (label_34)
  (Wrd54.uLng) = (OBJECT_TYPE (Wrd43.Obj));
  if (! ((Wrd54.uLng) == 1))
    goto label_33;
  (Wrd53.pObj) = (OBJECT_ADDRESS (Wrd43.Obj));
  (Wrd52.Obj) = ((Wrd53.pObj) [1]);

DEFLABEL (label_32)
  (Rsp [0]) = (Wrd52.Obj);
  goto loop_13;

DEFLABEL (label_33)
  (Wrd58.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_183_12]))));
  (* (--Rsp)) = (Wrd58.Obj);
  (* (--Rsp)) = (Wrd43.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_183_0]), 1);

DEFLABEL (label_21)
  (Wrd52.Obj) = Rvl;
  goto label_32;

DEFLABEL (label_35)
  (Wrd51.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_183_11]))));
  (* (--Rsp)) = (Wrd51.Obj);
  (* (--Rsp)) = (Wrd46.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_183_0]), 1);

DEFLABEL (label_20)
  (Wrd43.Obj) = Rvl;
  goto label_34;

DEFLABEL (label_36)
  (Wrd62.Obj) = (Rsp [0]);
  (Wrd63.uLng) = (OBJECT_TYPE (Wrd62.Obj));
  if (! ((Wrd63.uLng) == 1))
    goto label_39;
  (Wrd61.pObj) = (OBJECT_ADDRESS (Wrd62.Obj));
  (Wrd59.Obj) = ((Wrd61.pObj) [1]);

DEFLABEL (label_38)
  (Rsp [2]) = (Wrd59.Obj);
  Rsp = (& (Rsp [2]));
  (Wrd72.Obj) = (Rsp [0]);
  (Wrd73.uLng) = (OBJECT_TYPE (Wrd72.Obj));
  if (! ((Wrd73.uLng) == 1))
    goto label_37;
  (Wrd70.pObj) = (OBJECT_ADDRESS (Wrd72.Obj));
  Rvl = ((Wrd70.pObj) [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_37)
  INVOKE_PRIMITIVE ((current_block [OBJECT_183_1]), 1);

DEFLABEL (label_39)
  (Wrd67.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_183_10]))));
  (* (--Rsp)) = (Wrd67.Obj);
  (* (--Rsp)) = (Wrd62.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_183_0]), 1);

DEFLABEL (label_22)
  (Wrd59.Obj) = Rvl;
  goto label_38;

DEFLABEL (label_41)
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_183_9]))));
  (* (--Rsp)) = (Wrd41.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_183_1]), 1);

DEFLABEL (label_19)
  (Wrd33.Obj) = Rvl;
  goto label_40;

DEFLABEL (label_43)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_183_8]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_183_0]), 1);

DEFLABEL (label_18)
  (Wrd17.Obj) = Rvl;
  goto label_42;

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_183_6);
  goto label_27;

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_183_5);
  goto label_31;

DEFLABEL (lambda_26)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_183_13);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [0]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_183_4]);
  (Rsp [1]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_183_14]));

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_184_4 3
#define LABEL_184_5 5
#define LABEL_184_7 7
#define LABEL_184_8 9
#define LABEL_184_6 11
#define LABEL_184_9 13
#define LABEL_184_10 15
#define LABEL_184_11 17
#define ENVIRONMENT_LABEL_184_3 22
#define DEBUGGING_LABEL_184_2 21
#define OBJECT_184_2 20
#define OBJECT_184_1 19
#define OBJECT_184_0 18
#define FREE_REFERENCES_LABEL_184_0 18
#define NUMBER_OF_LINKER_SECTIONS_184_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_184 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd37;
  machine_word Wrd34;
  machine_word Wrd31;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd15;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd7;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd27;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd12;
  machine_word Wrd14;
  machine_word Wrd11;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_184_4);
      goto keyword_list__alist_11;

    case 1:
      current_block = (Rpc - LABEL_184_5);
      goto loop_9;

    case 2:
      current_block = (Rpc - LABEL_184_7);
      goto label_13;

    case 3:
      current_block = (Rpc - LABEL_184_8);
      goto label_14;

    case 4:
      current_block = (Rpc - LABEL_184_6);
      goto continuation_8;

    case 5:
      current_block = (Rpc - LABEL_184_9);
      goto label_15;

    case 6:
      current_block = (Rpc - LABEL_184_10);
      goto label_16;

    case 7:
      current_block = (Rpc - LABEL_184_11);
      goto label_17;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (keyword_list__alist_19)
DEFLABEL (keyword_list__alist_11)
  INTERRUPT_CHECK (26, LABEL_184_4);
  goto loop_9;

DEFLABEL (loop_20)
DEFLABEL (loop_9)
  INTERRUPT_CHECK (26, LABEL_184_5);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_21;
  Rvl = (current_block [OBJECT_184_1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_21)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_184_6]))));
  (* (--Rsp)) = (Wrd11.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_31;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd12.Obj) = ((Wrd14.pObj) [1]);

DEFLABEL (label_30)
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd23.uLng) == 1))
    goto label_29;
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd22.Obj) = ((Wrd21.pObj) [1]);
  (* (--Rsp)) = (Wrd22.Obj);

DEFLABEL (label_28)
  goto loop_9;

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_184_6);
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_27;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [1]);

DEFLABEL (label_26)
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd16.uLng) == 1))
    goto label_25;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (* (--Rsp)) = (Wrd15.Obj);

DEFLABEL (label_24)
  (Wrd24.Obj) = (Rsp [2]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if (! ((Wrd25.uLng) == 1))
    goto label_23;
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd21.Obj) = ((Wrd23.pObj) [0]);

DEFLABEL (label_22)
  (Wrd30.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd21.Obj);
  (* (Rhp++)) = (Wrd30.Obj);
  (Wrd33.pObj) = (& (Rhp [-2]));
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd33.pObj)));
  (Wrd34.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd31.Obj);
  (* (Rhp++)) = (Wrd34.Obj);
  (Wrd37.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd37.pObj)));
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_23)
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_184_11]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_184_2]), 1);

DEFLABEL (label_17)
  (Wrd21.Obj) = Rvl;
  goto label_22;

DEFLABEL (label_25)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_184_10]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_184_2]), 1);

DEFLABEL (label_16)
  (* (--Rsp)) = Rvl;
  goto label_24;

DEFLABEL (label_27)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_184_9]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_184_0]), 1);

DEFLABEL (label_15)
  (Wrd5.Obj) = Rvl;
  goto label_26;

DEFLABEL (label_29)
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_184_8]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_184_0]), 1);

DEFLABEL (label_14)
  (* (--Rsp)) = Rvl;
  goto label_28;

DEFLABEL (label_31)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_184_7]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_184_0]), 1);

DEFLABEL (label_13)
  (Wrd12.Obj) = Rvl;
  goto label_30;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_185_4 3
#define LABEL_185_5 5
#define LABEL_185_7 7
#define LABEL_185_6 9
#define LABEL_185_8 11
#define LABEL_185_9 13
#define LABEL_185_10 15
#define LABEL_185_11 17
#define ENVIRONMENT_LABEL_185_3 22
#define DEBUGGING_LABEL_185_2 21
#define OBJECT_185_2 20
#define OBJECT_185_1 19
#define OBJECT_185_0 18
#define FREE_REFERENCES_LABEL_185_0 18
#define NUMBER_OF_LINKER_SECTIONS_185_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_185 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd44;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd34;
  machine_word Wrd35;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd25;
  machine_word Wrd27;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd21;
  machine_word Wrd15;
  machine_word Wrd16;
  machine_word Wrd7;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd20;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd11;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_185_4);
      goto alist__keyword_list_11;

    case 1:
      current_block = (Rpc - LABEL_185_5);
      goto loop_9;

    case 2:
      current_block = (Rpc - LABEL_185_7);
      goto label_13;

    case 3:
      current_block = (Rpc - LABEL_185_6);
      goto continuation_7;

    case 4:
      current_block = (Rpc - LABEL_185_8);
      goto label_14;

    case 5:
      current_block = (Rpc - LABEL_185_9);
      goto label_15;

    case 6:
      current_block = (Rpc - LABEL_185_10);
      goto label_16;

    case 7:
      current_block = (Rpc - LABEL_185_11);
      goto label_17;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (alist__keyword_list_19)
DEFLABEL (alist__keyword_list_11)
  INTERRUPT_CHECK (26, LABEL_185_4);
  goto loop_9;

DEFLABEL (loop_20)
DEFLABEL (loop_9)
  INTERRUPT_CHECK (26, LABEL_185_5);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_21;
  Rvl = (current_block [OBJECT_185_1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_21)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_185_6]))));
  (* (--Rsp)) = (Wrd11.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_31;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [1]);
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_30)
  goto loop_9;

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_185_6);
  (* (--Rsp)) = Rvl;
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_29;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [0]);

DEFLABEL (label_28)
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd16.uLng) == 1))
    goto label_27;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd14.Obj) = ((Wrd15.pObj) [1]);

DEFLABEL (label_26)
  (Wrd21.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd14.Obj);
  (* (Rhp++)) = (Wrd21.Obj);
  (Wrd23.pObj) = (& (Rhp [-2]));
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd23.pObj)));
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd28.Obj) = (Rsp [1]);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if (! ((Wrd29.uLng) == 1))
    goto label_25;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd28.Obj));
  (Wrd25.Obj) = ((Wrd27.pObj) [0]);

DEFLABEL (label_24)
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if (! ((Wrd36.uLng) == 1))
    goto label_23;
  (Wrd35.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd34.Obj) = ((Wrd35.pObj) [0]);

DEFLABEL (label_22)
  (Wrd41.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd34.Obj);
  (* (Rhp++)) = (Wrd41.Obj);
  (Wrd44.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd44.pObj)));
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_23)
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_185_11]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_185_2]), 1);

DEFLABEL (label_17)
  (Wrd34.Obj) = Rvl;
  goto label_22;

DEFLABEL (label_25)
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_185_10]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_185_2]), 1);

DEFLABEL (label_16)
  (Wrd25.Obj) = Rvl;
  goto label_24;

DEFLABEL (label_27)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_185_9]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_185_0]), 1);

DEFLABEL (label_15)
  (Wrd14.Obj) = Rvl;
  goto label_26;

DEFLABEL (label_29)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_185_8]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_185_2]), 1);

DEFLABEL (label_14)
  (Wrd5.Obj) = Rvl;
  goto label_28;

DEFLABEL (label_31)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_185_7]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_185_0]), 1);

DEFLABEL (label_13)
  (* (--Rsp)) = Rvl;
  goto label_30;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_186_4 3
#define LABEL_186_5 5
#define ENVIRONMENT_LABEL_186_3 11
#define DEBUGGING_LABEL_186_2 10
#define OBJECT_186_0 9
#define EXECUTE_CACHE_186_6 7
#define FREE_REFERENCES_LABEL_186_0 6
#define NUMBER_OF_LINKER_SECTIONS_186_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_186 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_186_4);
      goto last_1;

    case 1:
      current_block = (Rpc - LABEL_186_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (last_4)
DEFLABEL (last_1)
  INTERRUPT_CHECK (26, LABEL_186_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_186_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_186_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_186_5);
  (Rsp [0]) = Rvl;
  (Wrd11.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd11.uLng) == 1))
    goto label_5;
  (Wrd8.pObj) = (OBJECT_ADDRESS (Rvl));
  Rvl = ((Wrd8.pObj) [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_5)
  INVOKE_PRIMITIVE ((current_block [OBJECT_186_0]), 1);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_187_4 3
#define LABEL_187_5 5
#define LABEL_187_7 7
#define LABEL_187_8 9
#define LABEL_187_9 11
#define ENVIRONMENT_LABEL_187_3 18
#define DEBUGGING_LABEL_187_2 17
#define OBJECT_187_1 16
#define OBJECT_187_0 15
#define EXECUTE_CACHE_187_6 13
#define FREE_REFERENCES_LABEL_187_0 12
#define NUMBER_OF_LINKER_SECTIONS_187_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_187 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd25;
  machine_word Wrd17;
  machine_word Wrd19;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_187_4);
      goto last_pair_7;

    case 1:
      current_block = (Rpc - LABEL_187_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_187_7);
      goto loop_5;

    case 3:
      current_block = (Rpc - LABEL_187_8);
      goto label_9;

    case 4:
      current_block = (Rpc - LABEL_187_9);
      goto label_10;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (last_pair_12)
DEFLABEL (last_pair_7)
  INTERRUPT_CHECK (26, LABEL_187_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_187_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_187_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_187_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_187_5);
  goto loop_5;

DEFLABEL (loop_13)
DEFLABEL (loop_5)
  INTERRUPT_CHECK (26, LABEL_187_7);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_18;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [1]);

DEFLABEL (label_17)
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd14.uLng) == 1)
    goto label_14;
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_14)
  (Wrd20.Obj) = (Rsp [0]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 1))
    goto label_16;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd17.Obj) = ((Wrd19.pObj) [1]);

DEFLABEL (label_15)
  (Rsp [0]) = (Wrd17.Obj);
  goto loop_5;

DEFLABEL (label_16)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_187_9]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_187_1]), 1);

DEFLABEL (label_10)
  (Wrd17.Obj) = Rvl;
  goto label_15;

DEFLABEL (label_18)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_187_8]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_187_1]), 1);

DEFLABEL (label_9)
  (Wrd5.Obj) = Rvl;
  goto label_17;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_188_4 3
#define LABEL_188_5 5
#define LABEL_188_7 7
#define LABEL_188_8 9
#define LABEL_188_9 11
#define LABEL_188_10 13
#define LABEL_188_11 15
#define LABEL_188_12 17
#define LABEL_188_13 19
#define LABEL_188_14 21
#define ENVIRONMENT_LABEL_188_3 31
#define DEBUGGING_LABEL_188_2 30
#define OBJECT_188_4 29
#define OBJECT_188_3 28
#define OBJECT_188_2 27
#define OBJECT_188_1 26
#define OBJECT_188_0 25
#define EXECUTE_CACHE_188_6 23
#define FREE_REFERENCES_LABEL_188_0 22
#define NUMBER_OF_LINKER_SECTIONS_188_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_188 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd38;
  machine_word Wrd30;
  machine_word Wrd50;
  machine_word Wrd42;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd39;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd29;
  machine_word Wrd25;
  machine_word Wrd17;
  machine_word Wrd19;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_188_4);
      goto except_last_pair_17;

    case 1:
      current_block = (Rpc - LABEL_188_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_188_7);
      goto label_19;

    case 3:
      current_block = (Rpc - LABEL_188_8);
      goto label_20;

    case 4:
      current_block = (Rpc - LABEL_188_9);
      goto label_21;

    case 5:
      current_block = (Rpc - LABEL_188_10);
      goto loop_14;

    case 6:
      current_block = (Rpc - LABEL_188_11);
      goto label_22;

    case 7:
      current_block = (Rpc - LABEL_188_12);
      goto label_23;

    case 8:
      current_block = (Rpc - LABEL_188_13);
      goto label_25;

    case 9:
      current_block = (Rpc - LABEL_188_14);
      goto label_24;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (except_last_pair_27)
DEFLABEL (except_last_pair_17)
  INTERRUPT_CHECK (26, LABEL_188_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_188_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_188_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_188_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_188_5);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_35;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [1]);

DEFLABEL (label_34)
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd14.uLng) == 1)
    goto label_29;
  Rvl = (current_block [OBJECT_188_3]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_29)
  (Wrd20.Obj) = (Rsp [0]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 1))
    goto label_33;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd17.Obj) = ((Wrd19.pObj) [0]);

DEFLABEL (label_32)
  (Wrd29.Obj) = (current_block [OBJECT_188_3]);
  (* (Rhp++)) = (Wrd17.Obj);
  (* (Rhp++)) = (Wrd29.Obj);
  (Wrd27.pObj) = (& (Rhp [-2]));
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd27.pObj)));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd34.Obj) = (Rsp [2]);
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if (! ((Wrd35.uLng) == 1))
    goto label_31;
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd33.Obj) = ((Wrd32.pObj) [1]);
  (* (--Rsp)) = (Wrd33.Obj);

DEFLABEL (label_30)
  goto loop_14;

DEFLABEL (label_31)
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_188_9]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_188_1]), 1);

DEFLABEL (label_21)
  (* (--Rsp)) = Rvl;
  goto label_30;

DEFLABEL (label_33)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_188_8]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_188_2]), 1);

DEFLABEL (label_20)
  (Wrd17.Obj) = Rvl;
  goto label_32;

DEFLABEL (label_35)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_188_7]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_188_1]), 1);

DEFLABEL (label_19)
  (Wrd5.Obj) = Rvl;
  goto label_34;

DEFLABEL (loop_28)
DEFLABEL (loop_14)
  INTERRUPT_CHECK (26, LABEL_188_10);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_44;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [1]);

DEFLABEL (label_43)
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd14.uLng) == 1)
    goto label_36;
  Rvl = (Rsp [2]);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_36)
  (Wrd20.Obj) = (Rsp [0]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 1))
    goto label_42;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd17.Obj) = ((Wrd19.pObj) [0]);

DEFLABEL (label_41)
  (Wrd29.Obj) = (current_block [OBJECT_188_3]);
  (* (Rhp++)) = (Wrd17.Obj);
  (* (Rhp++)) = (Wrd29.Obj);
  (Wrd27.pObj) = (& (Rhp [-2]));
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd27.pObj)));
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd44.Obj) = (Rsp [2]);
  (Wrd45.uLng) = (OBJECT_TYPE (Wrd44.Obj));
  if (! ((Wrd45.uLng) == 1))
    goto label_40;
  (Wrd42.pObj) = (OBJECT_ADDRESS (Wrd44.Obj));
  ((Wrd42.pObj) [1]) = (Wrd28.Obj);

DEFLABEL (label_39)
  (Wrd33.Obj) = (Rsp [1]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if (! ((Wrd34.uLng) == 1))
    goto label_38;
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd30.Obj) = ((Wrd32.pObj) [1]);

DEFLABEL (label_37)
  (Rsp [1]) = (Wrd30.Obj);
  (Wrd39.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd39.Obj);
  Rsp = (& (Rsp [1]));
  goto loop_14;

DEFLABEL (label_38)
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_188_14]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_188_1]), 1);

DEFLABEL (label_24)
  (Wrd30.Obj) = Rvl;
  goto label_37;

DEFLABEL (label_40)
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_188_13]))));
  (* (--Rsp)) = (Wrd50.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd44.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_188_4]), 2);

DEFLABEL (label_25)
  goto label_39;

DEFLABEL (label_42)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_188_12]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_188_2]), 1);

DEFLABEL (label_23)
  (Wrd17.Obj) = Rvl;
  goto label_41;

DEFLABEL (label_44)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_188_11]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_188_1]), 1);

DEFLABEL (label_22)
  (Wrd5.Obj) = Rvl;
  goto label_43;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_189_4 3
#define LABEL_189_5 5
#define LABEL_189_7 7
#define LABEL_189_9 9
#define LABEL_189_10 11
#define LABEL_189_11 13
#define LABEL_189_12 15
#define LABEL_189_8 17
#define ENVIRONMENT_LABEL_189_3 26
#define DEBUGGING_LABEL_189_2 25
#define OBJECT_189_3 24
#define OBJECT_189_2 23
#define OBJECT_189_1 22
#define OBJECT_189_0 21
#define EXECUTE_CACHE_189_6 19
#define FREE_REFERENCES_LABEL_189_0 18
#define NUMBER_OF_LINKER_SECTIONS_189_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
list_so_code_189 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd28;
  machine_word Wrd31;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd40;
  machine_word Wrd32;
  machine_word Wrd34;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd16;
  machine_word Wrd17;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_189_4);
      goto except_last_pairB_11;

    case 1:
      current_block = (Rpc - LABEL_189_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_189_7);
      goto label_13;

    case 3:
      current_block = (Rpc - LABEL_189_9);
      goto loop_9;

    case 4:
      current_block = (Rpc - LABEL_189_10);
      goto label_14;

    case 5:
      current_block = (Rpc - LABEL_189_11);
      goto label_15;

    case 6:
      current_block = (Rpc - LABEL_189_12);
      goto label_16;

    case 7:
      current_block = (Rpc - LABEL_189_8);
      goto continuation_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (except_last_pairB_18)
DEFLABEL (except_last_pairB_11)
  INTERRUPT_CHECK (26, LABEL_189_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_189_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_189_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_189_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_189_5);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_23;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [1]);

DEFLABEL (label_22)
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd14.uLng) == 1)
    goto label_20;
  Rvl = (current_block [OBJECT_189_2]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_20)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_189_8]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd20.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd20.Obj);
  goto loop_9;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_189_8);

DEFLABEL (label_21)
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_23)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_189_7]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_189_1]), 1);

DEFLABEL (label_13)
  (Wrd5.Obj) = Rvl;
  goto label_22;

DEFLABEL (loop_19)
DEFLABEL (loop_9)
  INTERRUPT_CHECK (26, LABEL_189_9);
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_31;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_30)
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_29;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd16.Obj) = ((Wrd17.pObj) [1]);

DEFLABEL (label_28)
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd23.uLng) == 1)
    goto label_25;
  (Wrd24.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd25.Obj) = (current_block [OBJECT_189_2]);
  (Rsp [1]) = (Wrd25.Obj);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd31.uLng) == 1)
    goto label_24;
  INVOKE_PRIMITIVE ((current_block [OBJECT_189_3]), 2);

DEFLABEL (label_24)
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  ((Wrd28.pObj) [1]) = (Wrd25.Obj);
  Rsp = (& (Rsp [3]));
  goto label_21;

DEFLABEL (label_25)
  (Wrd35.Obj) = (Rsp [0]);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if (! ((Wrd36.uLng) == 1))
    goto label_27;
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd32.Obj) = ((Wrd34.pObj) [1]);

DEFLABEL (label_26)
  (Rsp [0]) = (Wrd32.Obj);
  goto loop_9;

DEFLABEL (label_27)
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_189_12]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_189_1]), 1);

DEFLABEL (label_16)
  (Wrd32.Obj) = Rvl;
  goto label_26;

DEFLABEL (label_29)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_189_11]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_189_1]), 1);

DEFLABEL (label_15)
  (Wrd16.Obj) = Rvl;
  goto label_28;

DEFLABEL (label_31)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_189_10]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_189_1]), 1);

DEFLABEL (label_14)
  (Wrd7.Obj) = Rvl;
  goto label_30;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_4 3
#define LABEL_6 5
#define LABEL_7 7
#define LABEL_8 9
#define LABEL_9 11
#define LABEL_10 13
#define LABEL_11 15
#define LABEL_12 17
#define LABEL_13 19
#define LABEL_14 21
#define ENVIRONMENT_LABEL_3 45
#define DEBUGGING_LABEL_2 44
#define PURIFICATION_ROOT 43
#define OBJECT_17 42
#define OBJECT_16 41
#define OBJECT_15 40
#define OBJECT_14 39
#define OBJECT_13 38
#define OBJECT_12 37
#define OBJECT_11 36
#define OBJECT_10 35
#define OBJECT_9 34
#define OBJECT_8 33
#define OBJECT_7 32
#define OBJECT_6 31
#define OBJECT_5 30
#define OBJECT_4 29
#define OBJECT_3 28
#define OBJECT_2 27
#define OBJECT_1 26
#define OBJECT_0 25
#define GLOBAL_EXECUTE_CACHE_5 23
#define FREE_REFERENCES_LABEL_0 22
#define NUMBER_OF_LINKER_SECTIONS_1 1

#ifndef WANT_ONLY_DATA

SCHEME_OBJECT *
list_so_b71618dfe622bc09 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd7;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_4);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_6);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_7);
      goto continuation_2;

    case 3:
      current_block = (Rpc - LABEL_8);
      goto continuation_3;

    case 4:
      current_block = (Rpc - LABEL_9);
      goto continuation_4;

    case 5:
      current_block = (Rpc - LABEL_10);
      goto continuation_5;

    case 6:
      current_block = (Rpc - LABEL_11);
      goto continuation_6;

    case 7:
      current_block = (Rpc - LABEL_12);
      goto label_11;

    case 8:
      current_block = (Rpc - LABEL_13);
      goto label_12;

    case 9:
      current_block = (Rpc - LABEL_14);
      goto expression_8;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (expression_8)
  (current_block [ENVIRONMENT_LABEL_3]) = (Rrb [REGBLOCK_ENV]);
  INVOKE_INTERFACE_4 (23, (& (current_block [LABEL_13])), current_block, (& (current_block [FREE_REFERENCES_LABEL_0])), NUMBER_OF_LINKER_SECTIONS_1);

DEFLABEL (label_12)
  (* (--Rsp)) = (ULONG_TO_FIXNUM (1UL));

DEFLABEL (label_11)
  {
    static const short sections [] =
      {
	0,
	1,
	1,
	1,
	1,
	0,
	0,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	0,
	1,
	2,
	1,
	1,
	1,
	1,
	2,
	1,
	1,
	1,
	1,
	2,
	1,
	1,
	0,
	1,
	1,
	0,
	1,
	1,
	2,
	1,
	2,
	1,
	1,
	1,
	2,
	1,
	1,
	0,
	1,
	1,
	1,
	2,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	2,
	1,
	1,
	0,
	2,
	2,
	0,
	0,
	1,
	1,
	0,
	0,
	1,
	0,
	0,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	0,
	1,
	1,
	1,
	1,
	0,
	0,
	1,
	0,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	0,
	0,
	0,
	1,
	0,
	1,
	1,
	0,
	1,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0
      };
    unsigned long counter = (OBJECT_DATUM (* Rsp));
    SCHEME_OBJECT blocks;
    SCHEME_OBJECT * sub_block;
    short section;
    if (counter > 189)
      goto label_10;
    blocks = (current_block [OBJECT_17]);
    sub_block = (OBJECT_ADDRESS (MEMORY_REF (blocks, counter)));
    (sub_block [(OBJECT_DATUM (sub_block [0]))]) = (Rrb [REGBLOCK_ENV]);
    section = (sections [counter]);
    (* Rsp) = (ULONG_TO_FIXNUM (counter + 1));
    INVOKE_INTERFACE_4 (23, (& (current_block [LABEL_12])), sub_block, (sub_block + (2 + (OBJECT_DATUM (sub_block [1])))), section);
  }

DEFLABEL (label_10)
  Rsp += 1;
  (Wrd5.Obj) = (Rrb [3]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_1]);
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_5]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_3]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_6);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_5]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_6]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_7);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_7]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_8]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_8);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_9]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_10]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_9);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_11]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_12]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_10);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_13]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_14]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4]), 3);

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_11);
  (Wrd5.Obj) = (current_block [OBJECT_15]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd7.Obj) = (current_block [OBJECT_16]);
  (Rsp [2]) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_5]));

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

static const struct liarc_code_S arr_decl_list_so_b71618dfe622bc09 [189] =
  {
    { "list_so_code_1", 1, list_so_code_1 },
    { "list_so_code_2", 1, list_so_code_2 },
    { "list_so_code_3", 1, list_so_code_3 },
    { "list_so_code_4", 1, list_so_code_4 },
    { "list_so_code_5", 1, list_so_code_5 },
    { "list_so_code_6", 1, list_so_code_6 },
    { "list_so_code_7", 1, list_so_code_7 },
    { "list_so_code_8", 1, list_so_code_8 },
    { "list_so_code_9", 1, list_so_code_9 },
    { "list_so_code_10", 5, list_so_code_10 },
    { "list_so_code_11", 3, list_so_code_11 },
    { "list_so_code_12", 5, list_so_code_12 },
    { "list_so_code_13", 5, list_so_code_13 },
    { "list_so_code_14", 4, list_so_code_14 },
    { "list_so_code_15", 1, list_so_code_15 },
    { "list_so_code_16", 6, list_so_code_16 },
    { "list_so_code_17", 5, list_so_code_17 },
    { "list_so_code_18", 5, list_so_code_18 },
    { "list_so_code_19", 5, list_so_code_19 },
    { "list_so_code_20", 1, list_so_code_20 },
    { "list_so_code_21", 1, list_so_code_21 },
    { "list_so_code_22", 2, list_so_code_22 },
    { "list_so_code_23", 1, list_so_code_23 },
    { "list_so_code_24", 2, list_so_code_24 },
    { "list_so_code_25", 1, list_so_code_25 },
    { "list_so_code_26", 2, list_so_code_26 },
    { "list_so_code_27", 1, list_so_code_27 },
    { "list_so_code_28", 9, list_so_code_28 },
    { "list_so_code_29", 2, list_so_code_29 },
    { "list_so_code_30", 5, list_so_code_30 },
    { "list_so_code_31", 9, list_so_code_31 },
    { "list_so_code_32", 3, list_so_code_32 },
    { "list_so_code_33", 3, list_so_code_33 },
    { "list_so_code_34", 1, list_so_code_34 },
    { "list_so_code_35", 8, list_so_code_35 },
    { "list_so_code_36", 1, list_so_code_36 },
    { "list_so_code_37", 1, list_so_code_37 },
    { "list_so_code_38", 19, list_so_code_38 },
    { "list_so_code_39", 3, list_so_code_39 },
    { "list_so_code_40", 3, list_so_code_40 },
    { "list_so_code_41", 5, list_so_code_41 },
    { "list_so_code_42", 7, list_so_code_42 },
    { "list_so_code_43", 3, list_so_code_43 },
    { "list_so_code_44", 9, list_so_code_44 },
    { "list_so_code_45", 6, list_so_code_45 },
    { "list_so_code_46", 4, list_so_code_46 },
    { "list_so_code_47", 2, list_so_code_47 },
    { "list_so_code_48", 1, list_so_code_48 },
    { "list_so_code_49", 1, list_so_code_49 },
    { "list_so_code_50", 2, list_so_code_50 },
    { "list_so_code_51", 2, list_so_code_51 },
    { "list_so_code_52", 1, list_so_code_52 },
    { "list_so_code_53", 1, list_so_code_53 },
    { "list_so_code_54", 5, list_so_code_54 },
    { "list_so_code_55", 8, list_so_code_55 },
    { "list_so_code_56", 4, list_so_code_56 },
    { "list_so_code_57", 2, list_so_code_57 },
    { "list_so_code_58", 1, list_so_code_58 },
    { "list_so_code_59", 5, list_so_code_59 },
    { "list_so_code_60", 8, list_so_code_60 },
    { "list_so_code_61", 5, list_so_code_61 },
    { "list_so_code_62", 8, list_so_code_62 },
    { "list_so_code_63", 1, list_so_code_63 },
    { "list_so_code_64", 1, list_so_code_64 },
    { "list_so_code_65", 2, list_so_code_65 },
    { "list_so_code_66", 2, list_so_code_66 },
    { "list_so_code_67", 2, list_so_code_67 },
    { "list_so_code_68", 2, list_so_code_68 },
    { "list_so_code_69", 3, list_so_code_69 },
    { "list_so_code_70", 3, list_so_code_70 },
    { "list_so_code_71", 3, list_so_code_71 },
    { "list_so_code_72", 3, list_so_code_72 },
    { "list_so_code_73", 3, list_so_code_73 },
    { "list_so_code_74", 3, list_so_code_74 },
    { "list_so_code_75", 3, list_so_code_75 },
    { "list_so_code_76", 3, list_so_code_76 },
    { "list_so_code_77", 4, list_so_code_77 },
    { "list_so_code_78", 4, list_so_code_78 },
    { "list_so_code_79", 4, list_so_code_79 },
    { "list_so_code_80", 4, list_so_code_80 },
    { "list_so_code_81", 4, list_so_code_81 },
    { "list_so_code_82", 4, list_so_code_82 },
    { "list_so_code_83", 4, list_so_code_83 },
    { "list_so_code_84", 4, list_so_code_84 },
    { "list_so_code_85", 4, list_so_code_85 },
    { "list_so_code_86", 4, list_so_code_86 },
    { "list_so_code_87", 4, list_so_code_87 },
    { "list_so_code_88", 4, list_so_code_88 },
    { "list_so_code_89", 4, list_so_code_89 },
    { "list_so_code_90", 4, list_so_code_90 },
    { "list_so_code_91", 4, list_so_code_91 },
    { "list_so_code_92", 4, list_so_code_92 },
    { "list_so_code_93", 1, list_so_code_93 },
    { "list_so_code_94", 2, list_so_code_94 },
    { "list_so_code_95", 3, list_so_code_95 },
    { "list_so_code_96", 4, list_so_code_96 },
    { "list_so_code_97", 5, list_so_code_97 },
    { "list_so_code_98", 6, list_so_code_98 },
    { "list_so_code_99", 7, list_so_code_99 },
    { "list_so_code_100", 8, list_so_code_100 },
    { "list_so_code_101", 9, list_so_code_101 },
    { "list_so_code_102", 10, list_so_code_102 },
    { "list_so_code_103", 1, list_so_code_103 },
    { "list_so_code_104", 1, list_so_code_104 },
    { "list_so_code_105", 17, list_so_code_105 },
    { "list_so_code_106", 13, list_so_code_106 },
    { "list_so_code_107", 1, list_so_code_107 },
    { "list_so_code_108", 1, list_so_code_108 },
    { "list_so_code_109", 5, list_so_code_109 },
    { "list_so_code_110", 5, list_so_code_110 },
    { "list_so_code_111", 42, list_so_code_111 },
    { "list_so_code_112", 3, list_so_code_112 },
    { "list_so_code_113", 29, list_so_code_113 },
    { "list_so_code_114", 32, list_so_code_114 },
    { "list_so_code_115", 32, list_so_code_115 },
    { "list_so_code_116", 32, list_so_code_116 },
    { "list_so_code_117", 32, list_so_code_117 },
    { "list_so_code_118", 32, list_so_code_118 },
    { "list_so_code_119", 4, list_so_code_119 },
    { "list_so_code_120", 2, list_so_code_120 },
    { "list_so_code_121", 9, list_so_code_121 },
    { "list_so_code_122", 14, list_so_code_122 },
    { "list_so_code_123", 6, list_so_code_123 },
    { "list_so_code_124", 2, list_so_code_124 },
    { "list_so_code_125", 19, list_so_code_125 },
    { "list_so_code_126", 6, list_so_code_126 },
    { "list_so_code_127", 6, list_so_code_127 },
    { "list_so_code_128", 8, list_so_code_128 },
    { "list_so_code_129", 8, list_so_code_129 },
    { "list_so_code_130", 6, list_so_code_130 },
    { "list_so_code_131", 6, list_so_code_131 },
    { "list_so_code_132", 14, list_so_code_132 },
    { "list_so_code_133", 14, list_so_code_133 },
    { "list_so_code_134", 15, list_so_code_134 },
    { "list_so_code_135", 15, list_so_code_135 },
    { "list_so_code_136", 2, list_so_code_136 },
    { "list_so_code_137", 2, list_so_code_137 },
    { "list_so_code_138", 5, list_so_code_138 },
    { "list_so_code_139", 6, list_so_code_139 },
    { "list_so_code_140", 7, list_so_code_140 },
    { "list_so_code_141", 7, list_so_code_141 },
    { "list_so_code_142", 7, list_so_code_142 },
    { "list_so_code_143", 6, list_so_code_143 },
    { "list_so_code_144", 4, list_so_code_144 },
    { "list_so_code_145", 13, list_so_code_145 },
    { "list_so_code_146", 15, list_so_code_146 },
    { "list_so_code_147", 16, list_so_code_147 },
    { "list_so_code_148", 15, list_so_code_148 },
    { "list_so_code_149", 12, list_so_code_149 },
    { "list_so_code_150", 14, list_so_code_150 },
    { "list_so_code_151", 15, list_so_code_151 },
    { "list_so_code_152", 14, list_so_code_152 },
    { "list_so_code_153", 2, list_so_code_153 },
    { "list_so_code_154", 2, list_so_code_154 },
    { "list_so_code_155", 1, list_so_code_155 },
    { "list_so_code_156", 1, list_so_code_156 },
    { "list_so_code_157", 14, list_so_code_157 },
    { "list_so_code_158", 8, list_so_code_158 },
    { "list_so_code_159", 5, list_so_code_159 },
    { "list_so_code_160", 5, list_so_code_160 },
    { "list_so_code_161", 6, list_so_code_161 },
    { "list_so_code_162", 7, list_so_code_162 },
    { "list_so_code_163", 6, list_so_code_163 },
    { "list_so_code_164", 19, list_so_code_164 },
    { "list_so_code_165", 21, list_so_code_165 },
    { "list_so_code_166", 21, list_so_code_166 },
    { "list_so_code_167", 22, list_so_code_167 },
    { "list_so_code_168", 21, list_so_code_168 },
    { "list_so_code_169", 19, list_so_code_169 },
    { "list_so_code_170", 21, list_so_code_170 },
    { "list_so_code_171", 21, list_so_code_171 },
    { "list_so_code_172", 22, list_so_code_172 },
    { "list_so_code_173", 21, list_so_code_173 },
    { "list_so_code_174", 10, list_so_code_174 },
    { "list_so_code_175", 2, list_so_code_175 },
    { "list_so_code_176", 1, list_so_code_176 },
    { "list_so_code_177", 9, list_so_code_177 },
    { "list_so_code_178", 2, list_so_code_178 },
    { "list_so_code_179", 1, list_so_code_179 },
    { "list_so_code_180", 13, list_so_code_180 },
    { "list_so_code_181", 2, list_so_code_181 },
    { "list_so_code_182", 1, list_so_code_182 },
    { "list_so_code_183", 10, list_so_code_183 },
    { "list_so_code_184", 8, list_so_code_184 },
    { "list_so_code_185", 8, list_so_code_185 },
    { "list_so_code_186", 2, list_so_code_186 },
    { "list_so_code_187", 5, list_so_code_187 },
    { "list_so_code_188", 10, list_so_code_188 },
    { "list_so_code_189", 8, list_so_code_189 }
  };

int
decl_list_so_b71618dfe622bc09 (void)
{
  DECLARE_SUBCODE_MULTIPLE (arr_decl_list_so_b71618dfe622bc09);
  return (0);
}

DECLARE_COMPILED_CODE ("list.so", 10, decl_list_so_b71618dfe622bc09, list_so_b71618dfe622bc09)

#endif /* !WANT_ONLY_DATA */

#ifndef WANT_ONLY_CODE

static const unsigned char prog_list_so_data_b71618dfe622bc09 [19417] =
  "\xe9\x01\xa3\x02\xc7\x2f\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\xc1\xb9"
  "\x22\x29\x21\x9d\x2b\xba\x1d\xb0\x82\x88\xc1\xbb\x22\x29\x21\x9d"
  "\x2b\xbc\x1d\xb0\x83\x88\x22\x29\x21\x9c\x2b\xbd\x1d\xb0\x84\x88"
  "\xc2\x22\x29\x21\x9d\x2b\xbe\x1d\xb0\x85\x88\x07\x08\x22\x29\x21"
  "\x9e\x2b\xbf\x1d\xb0\x86\x88\x07\x22\x29\x21\x9d\x2b\x1c\x1d\xb0"
  "\x02\x88\xc2\x1c\x1d\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\xc2"
  "\x1c\x1d\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\x22\x29\x21\x9c"
  "\x2b\x1c\x1d\xb0\x02\x88\xb1\xb3\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x08\x1d\x0d\x1c\x28\x0d"
  "\x1c\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x1b\xb3\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x1b\x08\x1d\x0d\x1c\x28\x1b\x23\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x08\x0d"
  "\x1c\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x22\x29\x21\x9c\x2b\x1c\x1d\xb0\x02\x88\x80\x81"
  "\x1d\x0d\x1c\x28\x1b\x28\x1b\x28\x0d\x23\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x07\x08"
  "\xb3\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x07\x08\xb3\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x07\xb3\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1d\x28\x0d\x1c"
  "\x23\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x06\x1d\x0c\x28\x0d"
  "\x1c\x23\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1d\x28\x0d\x1c"
  "\x28\x0d\x1c\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x06\x1d\x0c\x28\x1b\x23\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x1d\x28\x0d\x1c\x28\x0d\x1c\x23\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x06\x1d\x0c\x28\x1b\x23\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x1d\x28\x0d\x1c\x28\x0d\x1c\x23\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x06\x1d\x0c\x28\x1b\x23\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xb3\x07\x08\xb1\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x1d\x1d\x28\x0d\x1c\x28\x1b\x23\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x08\xb3\x80\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xb3"
  "\x08\xb1\x80\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x0d\x1c"
  "\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x1d\x28\x0d\x1c\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x0d\x1c\x28\x0d\x1c\x23\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x0d\x1c\x07\x0c\x08\xb3\x28\x1b\x28\x1b"
  "\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x07\x22\x29\x21\x9d\x2b\x1c"
  "\x1d\xb0\x02\x88\x07\x08\x28\x1b\x23\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x0d\x1c\x08\x07\xb1\xb3\x28\x0d\x1c\x28\x0d\x1c\x23"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0d\x1c"
  "\xb1\x28\x0d\x1c\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x0d\x1c\x1b\x1d\x28\x1b\x28\x1b\x23\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xb3\x1b\x28"
  "\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\xb1\xb3\x08\x0d\x1c\x28\x1b\x28\x1b\x23"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x0d\x1c\xb3\x08\xb1\x28"
  "\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xb1\xb3\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\xb3\xb1\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\xc3\x1c\x02\x0d\x1c\x24\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\xc2\x1c\x07\x02\x22\x29\x21\x9f\x2b\x1c"
  "\x1d\xb0\x02\x88\x22\x29\x21\x9c\x2b\x1c\x1d\xb0\x02\x88\x1b\x24"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xc2\x1b\x24\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x22\x29\x21\x9c\x2b"
  "\x1c\x1d\xb0\x02\x88\xc2\x22\x29\x21\x9d\x2b\x1c\x1d\xb0\x02\x88"
  "\x06\x0d\x1c\x1b\x02\x08\x1b\x24\x28\x0d\x1c\x28\x0d\x1c\x23\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\xb3\x0d\x1c\x1b\x02\xb1\x08\x1b\x24\x28\x0d\x1c\x28\x1b\x23"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x07\x08\x1b\x02\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1d\x28\x0d\x1c"
  "\x28\x1b\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x06"
  "\x1d\x0c\x28\x1b\x23\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0d"
  "\x1c\x08\x1b\x02\x1b\x24\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x0d\x1c\x08\x1b"
  "\x02\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0d\x1c\x0d\x1c"
  "\x81\x08\x28\x0d\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0c\x0c\xb3\x82\x80\x1b\x1b"
  "\xb1\x81\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0d\x1c\xb1"
  "\x28\x1b\x23\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0d\x1c\xb3"
  "\x28\x1b\x23\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\xb1\x28"
  "\x1b\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\xb3"
  "\x1b\xb1\x28\x1b\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x1b\xb1\x1b\xb3\x28\x1b\x23\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x1b\xb3\x28\x1b\x23\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x1b\xb1\x28\x1b\x23\x22\x29\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\xb3\x1b\xb1\x28\x1b\x23\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\xb1\x1b"
  "\xb3\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\x1b\xb3\x1b\xb1\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x21"
  "\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\xb1\x1b\xb3\x28\x1b\x23\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\xb3\x1b\xb1"
  "\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x1b\xb1\x1b\xb3\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x1b\xb3\x28\x1b\x23\x22\x29\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\xb1\x28\x1b\x23\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\xb3"
  "\x1b\xb1\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x1b\xb1\x1b\xb3\x28\x1b\x23\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\xb3\x1b\xb1"
  "\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x1b\xb1\x1b\xb3\x28\x1b\x23\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\xb3\x1b\xb1\x28\x1b"
  "\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x1b\xb1\x1b\xb3\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\xb3\x1b\xb1\x28\x1b\x23\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b"
  "\xb1\x1b\xb3\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x1b\xb3\x1b\xb1\x28\x1b\x23\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\xb1\x1b"
  "\xb3\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x1b\xb3\x1b\xb1\x28\x1b\x23\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\xb1\x1b\xb3\x28"
  "\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\x1b\xb3\x1b\xb1\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\xb1\x1b\xb3\x28\x1b\x23"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x1b\xb3\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x1b\xb1\x28\x1b\x23\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x1b\xb3\x1b\xb1\x28\x1b\x23\x22\x29\x22\x29\x21"
  "\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\xb3\x1b\xb1\x28\x1b\x23\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\xb3\x1b\xb1"
  "\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x1b\xb3\x1b\xb1\x28\x1b\x23\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\xb3\x1b\xb1"
  "\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21"
  "\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\xb3\x1b\xb1\x28\x1b\x23\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x1b\xb3\x1b\xb1\x28\x1b\x23\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x1b\xb3\x1b\xb1\x28\x1b\x23\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x1b\xb3\x1b\xb1\x28\x1b\x23\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21"
  "\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x0d\x1c\x23\x22\x29\x21\x9f\x2b"
  "\x1c\x1d\xb0\x02\x88\x28\x0d\x1c\x23\x22\x29\x21\x9f\x2b\x1c\x1d"
  "\xb0\x02\x88\x0d\x1c\x1b\x08\xb3\xb1\x28\x1b\x28\x1b\x23\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x0d\x1c\x08\xb1\xb3\x28\x1b"
  "\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x08\x28\x0d\x1c\x23\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x08\x28\x0d\x1c\x23\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x1b\x08\xb3\xb1\x28\x1b\x23\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x08\x1b"
  "\xb3\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\xc2\x1c\x1b\x0d\x1c\xb1\x08\x1d\xb3\x28"
  "\x0d\x1c\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x1d\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x21"
  "\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x1b\x1d\x08\xb1\xb3\x28\x1b\x28"
  "\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x1b\x0d\x1c\x08\xb1\xb3\x28\x1b\x28\x1b\x23\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21"
  "\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x0d\x1c\x08\xb1\xb3\x28\x1b\x28"
  "\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x0d\x1c\x08"
  "\xb1\xb3\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x1b\x0d\x1c\x08\xb1\xb3\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x1b\x0d\x1c\x08\xb1\xb3\x28\x1b\x28\x1b"
  "\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x08\x0d\x1c\xb3\xb1"
  "\x28\x0d\x1c\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x28\x1b\x23\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x0d\x1c\x08\xb1\xb3\x28\x1b\x23\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21"
  "\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\xb3\xb1\x08\x0d\x1c\x28\x1b\x28"
  "\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xb3\x08\xb1\x28\x1b\x23\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\x0d\x1c\x28\x1b\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x1b\xb1\x0d\x1c\x08\xb3\x28\x1b\x28\x1b\x28\x1b\x23"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xb3\x0d"
  "\x1c\x08\xb1\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xb3\x1b\x08\xb1\x28\x1b"
  "\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\xb3\x0d\x1c\x08\xb1\x28\x1b\x28\x0d\x23\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21"
  "\x17\x2b\x1c\x1d\xb0\x02\x88\xb3\x0d\x1c\x08\xb1\x28\x1b\x28\x0d"
  "\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xb3\x0d\x1c\x08\xb1\x80\x28"
  "\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\xb3\x0d\x1c\x08\xb1\x80\x28\x1b\x23\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x1b\x0d\x1c\xb3\x08\xb1\x28\x1b\x23\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x1b\x0d\x1c\xb3\x08\xb1\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\xb3\x0d"
  "\x1c\x08\xb1\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\xb3\x0d\x1c"
  "\x08\xb1\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x1b\x23\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x1b\x23\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0d\x1c\x08\xb3\xb1\x28\x1b"
  "\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\xb3\x0d\x1c\x08\xb1\x28\x0d\x1c\x28\x1b\x23\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\xb3\x0d\x1c\x08\xb1\x1d\x0d\x1c\x24\x28\x1b\x23\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\xb3\x08\xb1\x28\x1b\x23\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x08\xb1\xb3\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xb3\x08\xb1\x28"
  "\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x1b\x0d\x1c\xb3\x08\xb1\x28\x1b\x23\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x1b\x1b\xb3\x08\xb1\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x1b\x0d\x1c\xb3\x08\xb1\x1d\x1b\x24\x28\x1b\x23\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x1b\xb3\x08\xb1\x28\x1b\x23\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\x1b\x0d\x1c\x08\xb3\xb1\x28\x1b\x23\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\xb3\x0d\x1c\x08"
  "\xb1\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\xb3\x0d\x1c\x08\xb1"
  "\x1d\x1b\x24\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\xb3\x08\xb1"
  "\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21"
  "\x17\x2b\x1c\x1d\xb0\x02\x88\x0d\x1c\x24\x28\x1b\x23\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1d\x28\x0d\x1c\x28\x0d\x1c"
  "\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x06\x1d\x0c"
  "\x28\x1b\x23\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x22\x29\x21"
  "\x9c\x2b\x1c\x1d\xb0\x02\x88\x1b\x0d\x1c\xb3\x08\xb1\x28\x1b\x23"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\xb3\x08\xb1\x28\x1b\x23\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x0d\x1c\x08\x28\x1b\x23\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0d\x1c\x08\x28"
  "\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0d\x1c\x08\x1d\x1b\x24\x28\x1b"
  "\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21"
  "\x17\x2b\x1c\x1d\xb0\x02\x88\x08\x28\x1b\x23\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b"
  "\x0d\x1c\xb3\x08\xb1\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x1b\x0d\x1c\xb3\x08\xb1\x28\x1b\x28\x1b"
  "\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x1b\x0d\x1c\xb3\x08\xb1\x28\x1b\x28\x1b\x23\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x1b\x0d\x1c\xb3\x08\xb1\x1d\x1b\x24\x28\x1b\x23\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x1b\xb3\x08\xb1\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x0d\x1c\x08\xb3\xb1\x28"
  "\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x1b\xb3\x0d\x1c\x08\xb1\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\xb3\x0d"
  "\x1c\x08\xb1\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\xb3\x0d\x1c\x08\xb1"
  "\x1d\x1b\x24\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\xb3\x08\xb1\x28\x1b"
  "\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x08\xb3\x06\x07\x85\x1b\x02\xb1\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21"
  "\x17\x2b\x1c\x1d\xb0\x02\x88\x1d\x28\x0d\x1c\x28\x0d\x1c\x23\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x06\x1d\x0c\x28\x1b"
  "\x23\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xb3\x07\x08\xb1\x28"
  "\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1d\x28\x0d\x1c"
  "\x28\x0d\x1c\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x06\x1d\x0c\x28\x1b\x23\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\xb3\x06\x07\x85\x1b\x02\xb1\x08\x28\x1b\x23\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1d\x28\x0d"
  "\x1c\x28\x0d\x1c\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x06\x1d\x0c\x28\x1b\x23\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x0d\x1c\x1d\x08\xb1\xb3\x28\x1b\x23\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\xb1\x08\xb3\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\xb1\x08\xb3\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xb1\x28\x1b\x23"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xb3\x1b\x28\x0d"
  "\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x1b\x08\xb1\xb3\x0d\xb9\x28\x1b\x23\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x08\xb3\x0d\x1c\x28\x1b"
  "\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x21\x17\x2b\xbb\x17\xb8\x88\xb0\xb3\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x17\x1b\xb1\x1b\x0d\x0d\x0d\x1b\x1b"
  "\x0d\x1b\x1b\x0d\x1b\x1b\x0d\x1b\x0d\x1b\x1b\x1b\x1b\x0d\x1b\x1b"
  "\x1b\x1b\x0d\x1b\x1b\x1b\x0d\x0d\x1b\x0d\x1b\x0d\x1b\x0d\x1b\x1b"
  "\x1b\x0d\x1b\x0d\x1b\x0d\x0d\x0d\x0d\x1b\x1b\x1b\x0d\x0d\x1b\x1b"
  "\x1b\x1b\x1b\x1b\x1b\x1b\x0d\x1b\x1b\x1b\x1b\x1b\x1b\x0d\x1b\x17"
  "\x1b\x1b\x2a\x1b\x1b\x2a\x1b\x1b\x2a\x1b\x1b\x2a\x1b\x1b\x2a\xc3"
  "\x1b\x1b\x2a\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b"
  "\x1b\x1b\x1b\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d"
  "\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d"
  "\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x1b\x1b\x0d\x0d\x1b\x1b\x1b"
  "\x0d\x1b\x1b\x1b\x1b\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x1b\x0d"
  "\x1b\x1b\x1b\x1b\x1b\x0d\x0d\x1b\x1b\x0d\x1b\x1b\x1b\x0d\x1b\x1b"
  "\x0d\x1b\x0d\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x0d\x1b\x1b\x0d\x1b"
  "\x0d\x0d\x0d\x0d\x1b\x0d\x0d\x0d\x1b\x1b\x17\x1e\x1e\x1e\x1e\x1e"
  "\x1e\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x0c\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a"
  "\x1b\x2a\x1b\x2a\x1b\x2a\x1b\x2a\xb7\x2a\xb6\x2a\xb5\x2a\xb4\x2a"
  "\xb2\x2a\x17\x28\x0d\x26\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x02\x51\x2f\x55"
  "\x73\x65\x72\x73\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72"
  "\x65\x2f\x73\x63\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65"
  "\x2d\x39\x2e\x31\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d"
  "\x65\x2d\x63\x2d\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75"
  "\x6e\x74\x69\x6d\x65\x2f\x6c\x69\x73\x74\x2e\x69\x6e\x66\x15\x23"
  "\x5b\x70\x75\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f"
  "\x6f\x74\x5d\x02\x04\x63\x61\x72\x0b\x04\x83\x04\x03\x02\x04\x63"
  "\x64\x72\x0c\x04\x83\x04\x03\x02\x0d\x04\x84\x06\x03\x02\x10\x67"
  "\x65\x6e\x65\x72\x61\x6c\x2d\x63\x61\x72\x2d\x63\x64\x72\x0e\x04"
  "\x84\x06\x03\x02\x0f\x04\x83\x04\x03\x02\x10\x04\x83\x04\x03\x09"
  "\x02\x08\x09\x73\x65\x74\x2d\x63\x61\x72\x21\x0a\x02\x11\x04\x84"
  "\x06\x03\x0b\x02\x09\x09\x73\x65\x74\x2d\x63\x64\x72\x21\x0c\x02"
  "\x12\x04\x84\x06\x03\x0d\x02\x0a\x13\x04\xff\x03\x03\x0e\x02\x0b"
  "\x18\x0c\x81\x85\x02\x17\x0a\x81\x89\x02\x16\x08\x81\x87\x02\x15"
  "\x06\x81\x85\x02\x14\x04\xfe\x05\x0b\x10\x0f\x02\x0c\x08\x0a\x6d"
  "\x61\x6b\x65\x2d\x6c\x69\x73\x74\x10\x04\x17\x67\x75\x61\x72\x61"
  "\x6e\x74\x65\x65\x2d\x69\x6e\x64\x65\x78\x2d\x66\x69\x78\x6e\x75"
  "\x6d\x11\x02\x1b\x08\x81\x8b\x02\x1a\x06\x81\x85\x02\x19\x04\x84"
  "\x04\x07\x10\x12\x02\x0d\x0c\x20\x0c\xff\x03\x1f\x0a\x81\x83\x02"
  "\x1e\x08\x81\x83\x02\x1d\x06\x81\x83\x02\x1c\x04\x81\x83\x02\x0b"
  "\x10\x13\x02\x0e\x0c\x08\x13\x6d\x61\x6b\x65\x2d\x63\x69\x72\x63"
  "\x75\x6c\x61\x72\x2d\x6c\x69\x73\x74\x14\x04\x11\x02\x25\x0c\x81"
  "\x8d\x02\x24\x0a\x81\x8d\x02\x23\x08\x81\x8d\x02\x22\x06\x81\x85"
  "\x02\x21\x04\x84\x04\x0b\x15\x15\x02\x0f\x16\x6d\x61\x6b\x65\x2d"
  "\x69\x6e\x69\x74\x69\x61\x6c\x69\x7a\x65\x64\x2d\x6c\x69\x73\x74"
  "\x16\x04\x11\x02\x29\x0a\x81\x89\x02\x28\x08\x81\x89\x02\x27\x06"
  "\x81\x85\x02\x26\x04\x84\x06\x09\x11\x17\x02\x10\x2a\x04\x84\x06"
  "\x03\x18\x02\x11\x08\x05\x69\x6f\x74\x61\x19\x04\x11\x04\x16\x04"
  "\x11\x67\x75\x61\x72\x61\x6e\x74\x65\x65\x2d\x6e\x75\x6d\x62\x65"
  "\x72\x04\x30\x0e\x81\x85\x02\x2f\x0c\x81\x85\x02\x2e\x0a\x81\x87"
  "\x02\x2d\x08\x81\x87\x02\x2c\x06\x81\x89\x02\x2b\x04\x85\x04\x0d"
  "\x1b\x1a\x02\x12\x35\x0c\x81\x87\x02\x34\x0a\x81\x87\x02\x33\x08"
  "\x81\x85\x02\x32\x06\x81\x85\x02\x31\x04\x83\x04\x0b\x11\x1b\x02"
  "\x13\x3a\x0c\x81\x87\x02\x39\x0a\x81\x87\x02\x38\x08\x81\x85\x02"
  "\x37\x06\x81\x85\x02\x36\x04\x83\x04\x0b\x11\x1c\x02\x14\x3f\x0c"
  "\x81\x87\x02\x3e\x0a\x81\x87\x02\x3d\x08\x81\x85\x02\x3c\x06\x81"
  "\x85\x02\x3b\x04\x83\x04\x0b\x10\x1d\x02\x15\x02\x04\x0f\x65\x72"
  "\x72\x6f\x72\x3a\x6e\x6f\x74\x2d\x70\x61\x69\x72\x1e\x02\x40\x04"
  "\x84\x04\x03\x0a\x1f\x02\x16\x08\x05\x70\x61\x69\x72\x05\x1a\x65"
  "\x72\x72\x6f\x72\x3a\x77\x72\x6f\x6e\x67\x2d\x74\x79\x70\x65\x2d"
  "\x61\x72\x67\x75\x6d\x65\x6e\x74\x20\x02\x41\x04\x84\x04\x03\x0c"
  "\x21\x02\x17\x02\x03\x06\x6c\x69\x73\x74\x3f\x22\x04\x0f\x65\x72"
  "\x72\x6f\x72\x3a\x6e\x6f\x74\x2d\x6c\x69\x73\x74\x23\x03\x43\x06"
  "\x81\x85\x02\x42\x04\x84\x04\x05\x0e\x24\x02\x18\x08\x05\x6c\x69"
  "\x73\x74\x05\x20\x02\x44\x04\x84\x04\x03\x0c\x25\x02\x19\x02\x03"
  "\x0d\x64\x6f\x74\x74\x65\x64\x2d\x6c\x69\x73\x74\x3f\x26\x04\x16"
  "\x65\x72\x72\x6f\x72\x3a\x6e\x6f\x74\x2d\x64\x6f\x74\x74\x65\x64"
  "\x2d\x6c\x69\x73\x74\x27\x03\x46\x06\x81\x85\x02\x45\x04\x84\x04"
  "\x05\x0e\x28\x02\x1a\x08\x0e\x69\x6d\x70\x72\x6f\x70\x65\x72\x20"
  "\x6c\x69\x73\x74\x05\x20\x02\x47\x04\x84\x04\x03\x0c\x29\x02\x1b"
  "\x02\x03\x0f\x63\x69\x72\x63\x75\x6c\x61\x72\x2d\x6c\x69\x73\x74"
  "\x3f\x2a\x04\x18\x65\x72\x72\x6f\x72\x3a\x6e\x6f\x74\x2d\x63\x69"
  "\x72\x63\x75\x6c\x61\x72\x2d\x6c\x69\x73\x74\x2b\x03\x49\x06\x81"
  "\x85\x02\x48\x04\x84\x04\x05\x0e\x2c\x02\x1c\x08\x0e\x63\x69\x72"
  "\x63\x75\x6c\x61\x72\x20\x6c\x69\x73\x74\x05\x20\x02\x4a\x04\x84"
  "\x04\x03\x0c\x2d\x02\x1d\x53\x14\x81\x8b\x02\x52\x12\x81\x8b\x02"
  "\x51\x10\x81\x8b\x02\x50\x0e\x81\x8d\x02\x4f\x0c\x81\x89\x02\x4e"
  "\x0a\x81\x89\x02\x4d\x08\x81\x8b\x02\x4c\x06\x81\x89\x02\x4b\x04"
  "\x84\x06\x13\x1a\x2e\x02\x1e\x02\x08\x04\x0e\x6c\x69\x73\x74\x2d"
  "\x6f\x66\x2d\x74\x79\x70\x65\x3f\x2f\x05\x20\x03\x55\x06\x81\x89"
  "\x02\x54\x04\x86\x08\x05\x0f\x30\x02\x1f\x5a\x0c\x81\x89\x02\x59"
  "\x0a\x81\x89\x02\x58\x08\x81\x87\x02\x57\x06\x81\x87\x02\x56\x04"
  "\x83\x04\x0b\x11\x31\x02\x20\x63\x14\x81\x8d\x02\x62\x12\x81\x8d"
  "\x02\x61\x10\x81\x8d\x02\x60\x0e\x81\x8f\x02\x5f\x0c\x81\x8b\x02"
  "\x5e\x0a\x81\x8b\x02\x5d\x08\x81\x8d\x02\x5c\x06\x81\x8b\x02\x5b"
  "\x04\x84\x06\x13\x1a\x32\x02\x21\x03\x0e\x6c\x69\x73\x74\x3f\x2d"
  "\x3e\x6c\x65\x6e\x67\x74\x68\x33\x04\x23\x03\x66\x08\x81\x85\x02"
  "\x65\x06\x81\x87\x02\x64\x04\x84\x04\x07\x0f\x34\x02\x22\x08\x04"
  "\x16\x6c\x69\x73\x74\x2d\x6f\x66\x2d\x74\x79\x70\x65\x3f\x2d\x3e"
  "\x6c\x65\x6e\x67\x74\x68\x35\x05\x20\x03\x69\x08\x81\x89\x02\x68"
  "\x06\x81\x8b\x02\x67\x04\x86\x08\x07\x10\x36\x02\x23\x07\x6c\x65"
  "\x6e\x67\x74\x68\x37\x04\x17\x67\x75\x61\x72\x61\x6e\x74\x65\x65"
  "\x2d\x6c\x69\x73\x74\x2d\x3e\x6c\x65\x6e\x67\x74\x68\x38\x02\x6a"
  "\x04\x83\x04\x03\x0a\x39\x02\x24\x09\x6c\x65\x6e\x67\x74\x68\x3d"
  "\x3f\x3a\x15\x69\x6e\x64\x65\x78\x20\x66\x69\x78\x6e\x75\x6d\x20"
  "\x6f\x72\x20\x6c\x69\x73\x74\x05\x20\x04\x23\x03\x72\x12\x81\x85"
  "\x02\x71\x10\x81\x85\x02\x70\x0e\x81\x85\x02\x6f\x0c\x81\x85\x02"
  "\x6e\x0a\x81\x85\x02\x6d\x08\x81\x85\x02\x6c\x06\x81\x85\x02\x6b"
  "\x04\x84\x06\x11\x1e\x3b\x02\x25\x73\x04\x83\x04\x03\x3c\x02\x26"
  "\x04\x23\x02\x74\x04\x84\x04\x03\x0b\x3d\x02\x27\x06\x6c\x69\x73"
  "\x74\x3d\x3e\x04\x09\x66\x6f\x72\x2d\x65\x61\x63\x68\x3f\x04\x0f"
  "\x67\x75\x61\x72\x61\x6e\x74\x65\x65\x2d\x6c\x69\x73\x74\x40\x03"
  "\x87\x01\x28\x83\x04\x86\x01\x26\xfd\xff\x03\x85\x01\x24\xfd\xff"
  "\x03\x84\x01\x22\xfd\xff\x03\x83\x01\x20\xff\xff\x03\x82\x01\x1e"
  "\x81\x8b\x02\x81\x01\x1c\x81\x8b\x02\x80\x01\x1a\x81\x8b\x02\x7f"
  "\x18\xfd\xff\x03\x7e\x16\xfd\xff\x03\x7d\x14\xff\xff\x03\x7c\x12"
  "\x81\x8b\x02\x7b\x10\x81\x89\x02\x7a\x0e\x81\x87\x02\x79\x0c\x81"
  "\x87\x02\x78\x0a\x81\x85\x02\x77\x08\x81\x85\x02\x76\x06\x81\x85"
  "\x02\x75\x04\xfe\x05\x27\x34\x41\x02\x28\x09\x6c\x69\x73\x74\x2d"
  "\x72\x65\x66\x42\x04\x0a\x6c\x69\x73\x74\x2d\x74\x61\x69\x6c\x43"
  "\x04\x19\x65\x72\x72\x6f\x72\x3a\x62\x61\x64\x2d\x72\x61\x6e\x67"
  "\x65\x2d\x61\x72\x67\x75\x6d\x65\x6e\x74\x44\x03\x8a\x01\x08\x81"
  "\x85\x02\x89\x01\x06\x81\x87\x02\x88\x01\x04\x84\x06\x07\x11\x45"
  "\x02\x29\x0a\x6c\x69\x73\x74\x2d\x73\x65\x74\x21\x46\x0a\x02\x04"
  "\x43\x04\x44\x03\x8d\x01\x08\x81\x87\x02\x8c\x01\x06\x81\x89\x02"
  "\x8b\x01\x04\x85\x08\x07\x12\x0a\x02\x2a\x43\x04\x11\x04\x44\x03"
  "\x92\x01\x0c\x81\x89\x02\x91\x01\x0a\x81\x89\x02\x90\x01\x08\x81"
  "\x89\x02\x8f\x01\x06\x81\x85\x02\x8e\x01\x04\x84\x06\x0b\x15\x47"
  "\x02\x2b\x0a\x6c\x69\x73\x74\x2d\x68\x65\x61\x64\x48\x04\x11\x04"
  "\x44\x03\x99\x01\x10\xfd\xff\x03\x98\x01\x0e\xfd\xff\x03\x97\x01"
  "\x0c\xfd\xff\x03\x96\x01\x0a\xff\xff\x03\x95\x01\x08\xfd\xff\x03"
  "\x94\x01\x06\x81\x85\x02\x93\x01\x04\x84\x06\x0f\x1b\x44\x02\x2c"
  "\x04\x43\x04\x48\x03\x9c\x01\x08\x81\x87\x02\x9b\x01\x06\x81\x87"
  "\x02\x9a\x01\x04\x85\x08\x07\x0f\x11\x02\x2d\x0c\x0a\x6c\x69\x73"
  "\x74\x2d\x63\x6f\x70\x79\x49\x04\x23\x02\xa5\x01\x14\x81\x85\x02"
  "\xa4\x01\x12\x81\x87\x02\xa3\x01\x10\x81\x87\x02\xa2\x01\x0e\x81"
  "\x85\x02\xa1\x01\x0c\x81\x85\x02\xa0\x01\x0a\xff\xff\x03\x9f\x01"
  "\x08\x81\x89\x02\x9e\x01\x06\x81\x83\x02\x9d\x01\x04\x83\x04\x13"
  "\x1e\x4a\x02\x2e\xab\x01\x0e\x81\x85\x02\xaa\x01\x0c\x81\x87\x02"
  "\xa9\x01\x0a\x81\x83\x02\xa8\x01\x08\x81\x85\x02\xa7\x01\x06\x81"
  "\x83\x02\xa6\x01\x04\x83\x04\x0d\x12\x4b\x02\x2f\xaf\x01\x0a\x81"
  "\x85\x02\xae\x01\x08\x81\x85\x02\xad\x01\x06\x81\x83\x02\xac\x01"
  "\x04\x83\x04\x09\x0e\x4c\x02\x30\x11\x73\x79\x73\x74\x65\x6d\x2d"
  "\x70\x61\x69\x72\x2d\x63\x6f\x6e\x73\x4d\x38\x10\x77\x65\x61\x6b"
  "\x2d\x70\x61\x69\x72\x2f\x66\x61\x6c\x73\x65\x4e\x02\xb1\x01\x06"
  "\x81\x89\x02\xb0\x01\x04\x84\x06\x05\x0c\x4f\x02\x31\x0d\x6f\x62"
  "\x6a\x65\x63\x74\x2d\x74\x79\x70\x65\x3f\x50\x38\xb2\x01\x04\x83"
  "\x04\x03\x51\x02\x32\xb3\x01\x04\x83\x04\x03\x52\x02\x33\x4e\x02"
  "\xb5\x01\x06\x81\x83\x02\xb4\x01\x04\x83\x04\x05\x0a\x53\x02\x34"
  "\x15\x73\x79\x73\x74\x65\x6d\x2d\x70\x61\x69\x72\x2d\x73\x65\x74"
  "\x2d\x63\x61\x72\x21\x4e\x02\xb7\x01\x06\x81\x87\x02\xb6\x01\x04"
  "\x84\x06\x05\x0b\x54\x02\x35\xb8\x01\x04\x83\x04\x03\x55\x02\x36"
  "\x15\x73\x79\x73\x74\x65\x6d\x2d\x70\x61\x69\x72\x2d\x73\x65\x74"
  "\x2d\x63\x64\x72\x21\xb9\x01\x04\x84\x06\x03\x56\x02\x37\x10\x77"
  "\x65\x61\x6b\x2d\x6c\x69\x73\x74\x2d\x3e\x6c\x69\x73\x74\x57\x50"
  "\x38\x4e\x02\x03\x09\x72\x65\x76\x65\x72\x73\x65\x21\x58\x04\x14"
  "\x65\x72\x72\x6f\x72\x3a\x6e\x6f\x74\x2d\x77\x65\x61\x6b\x2d\x6c"
  "\x69\x73\x74\x59\x03\xbe\x01\x0c\x81\x89\x02\xbd\x01\x0a\x81\x87"
  "\x02\xbc\x01\x08\x81\x87\x02\xbb\x01\x06\x81\x87\x02\xba\x01\x04"
  "\x83\x04\x0b\x1a\x5a\x02\x38\x10\x6c\x69\x73\x74\x2d\x3e\x77\x65"
  "\x61\x6b\x2d\x6c\x69\x73\x74\x5b\x4d\x38\x4e\x02\x03\x08\x72\x65"
  "\x76\x65\x72\x73\x65\x4d\x04\x23\x03\xc6\x01\x12\x81\x87\x02\xc5"
  "\x01\x10\x81\x87\x02\xc4\x01\x0e\x81\x8d\x02\xc3\x01\x0c\x81\x8b"
  "\x02\xc2\x01\x0a\x81\x87\x02\xc1\x01\x08\x81\x87\x02\xc0\x01\x06"
  "\x81\x85\x02\xbf\x01\x04\x83\x04\x11\x21\x5c\x02\x39\x50\x38\xca"
  "\x01\x0a\x81\x87\x02\xc9\x01\x08\x81\x85\x02\xc8\x01\x06\x81\x85"
  "\x02\xc7\x01\x04\x83\x04\x09\x10\x5d\x02\x3a\x02\x03\x0b\x77\x65"
  "\x61\x6b\x2d\x6c\x69\x73\x74\x3f\x5e\x04\x59\x03\xcc\x01\x06\x81"
  "\x85\x02\xcb\x01\x04\x84\x04\x05\x0e\x5f\x02\x3b\x08\x0a\x77\x65"
  "\x61\x6b\x20\x6c\x69\x73\x74\x05\x20\x02\xcd\x01\x04\x84\x04\x03"
  "\x0c\x60\x02\x3c\x0a\x77\x65\x61\x6b\x2d\x6d\x65\x6d\x71\x61\x50"
  "\x38\x4e\x02\x04\x59\x02\xd2\x01\x0c\x81\x89\x02\xd1\x01\x0a\x81"
  "\x89\x02\xd0\x01\x08\x81\x89\x02\xcf\x01\x06\x81\x87\x02\xce\x01"
  "\x04\x84\x06\x0b\x17\x62\x02\x3d\x0c\x0b\x77\x65\x61\x6b\x2d\x64"
  "\x65\x6c\x71\x21\x63\x50\x38\x04\x59\x02\xda\x01\x12\xfd\xff\x03"
  "\xd9\x01\x10\x81\x85\x02\xd8\x01\x0e\x81\x85\x02\xd7\x01\x0c\x81"
  "\x85\x02\xd6\x01\x0a\xfd\xff\x03\xd5\x01\x08\xff\xff\x03\xd4\x01"
  "\x06\xfd\xff\x03\xd3\x01\x04\x84\x06\x11\x1c\x64\x02\x3e\x04\x63"
  "\x64\x72\x65\x04\x63\x61\x72\x66\x03\x1a\x67\x75\x61\x72\x61\x6e"
  "\x74\x65\x65\x2d\x70\x6f\x73\x69\x74\x69\x76\x65\x2d\x66\x69\x78"
  "\x6e\x75\x6d\x03\x06\x65\x76\x65\x6e\x3f\x03\xdf\x01\x0c\x81\x85"
  "\x02\xde\x01\x0a\x81\x85\x02\xdd\x01\x08\x81\x85\x02\xdc\x01\x06"
  "\x81\x83\x02\xdb\x01\x04\x83\x04\x0b\x17\x67\x02\x3f\x27\x65\x6e"
  "\x63\x6f\x64\x65\x2d\x67\x65\x6e\x65\x72\x61\x6c\x2d\x63\x61\x72"
  "\x2d\x63\x64\x72\x3a\x20\x63\x6f\x64\x65\x20\x74\x6f\x6f\x20\x6c"
  "\x61\x72\x67\x65\x2a\x65\x6e\x63\x6f\x64\x65\x2d\x67\x65\x6e\x65"
  "\x72\x61\x6c\x2d\x63\x61\x72\x2d\x63\x64\x72\x3a\x20\x49\x6e\x76"
  "\x61\x6c\x69\x64\x20\x6f\x70\x65\x72\x61\x74\x69\x6f\x6e\x65\x66"
  "\x04\x06\x65\x72\x72\x6f\x72\x02\xe7\x01\x12\x81\x85\x02\xe6\x01"
  "\x10\x81\x85\x02\xe5\x01\x0e\x81\x85\x02\xe4\x01\x0c\x81\x87\x02"
  "\xe3\x01\x0a\x81\x87\x02\xe2\x01\x08\x81\x85\x02\xe1\x01\x06\x81"
  "\x85\x02\xe0\x01\x04\x83\x04\x11\x20\x68\x02\x40\x09\x73\x61\x66"
  "\x65\x2d\x63\x61\x72\x69\x04\x1e\x02\xe8\x01\x04\x83\x04\x03\x0b"
  "\x6a\x02\x41\x09\x73\x61\x66\x65\x2d\x63\x64\x72\x6b\x04\x1e\x02"
  "\xe9\x01\x04\x83\x04\x03\x0b\x6c\x02\x42\x69\x04\x1e\x02\xeb\x01"
  "\x06\x83\x04\xea\x01\x04\x81\x83\x02\x05\x0d\x6d\x02\x43\x6b\x69"
  "\x04\x1e\x02\xed\x01\x06\x83\x04\xec\x01\x04\x81\x83\x02\x05\x0f"
  "\x6e\x02\x44\x69\x6b\x04\x1e\x02\xef\x01\x06\x83\x04\xee\x01\x04"
  "\x81\x83\x02\x05\x0f\x6f\x02\x45\x6b\x04\x1e\x02\xf1\x01\x06\x83"
  "\x04\xf0\x01\x04\x81\x83\x02\x05\x0d\x70\x02\x46\x69\x04\x1e\x02"
  "\xf4\x01\x08\x83\x04\xf3\x01\x06\x81\x83\x02\xf2\x01\x04\x81\x85"
  "\x02\x07\x0f\x71\x02\x47\x6b\x69\x04\x1e\x02\xf7\x01\x08\x83\x04"
  "\xf6\x01\x06\x81\x83\x02\xf5\x01\x04\x81\x85\x02\x07\x11\x72\x02"
  "\x48\x69\x6b\x04\x1e\x02\xfa\x01\x08\x83\x04\xf9\x01\x06\x81\x83"
  "\x02\xf8\x01\x04\x81\x85\x02\x07\x11\x73\x02\x49\x6b\x69\x04\x1e"
  "\x02\xfd\x01\x08\x83\x04\xfc\x01\x06\x81\x83\x02\xfb\x01\x04\x81"
  "\x85\x02\x07\x11\x74\x02\x4a\x69\x6b\x04\x1e\x02\x80\x02\x08\x83"
  "\x04\xff\x01\x06\x81\x83\x02\xfe\x01\x04\x81\x85\x02\x07\x11\x75"
  "\x02\x4b\x6b\x69\x04\x1e\x02\x83\x02\x08\x83\x04\x82\x02\x06\x81"
  "\x83\x02\x81\x02\x04\x81\x85\x02\x07\x11\x76\x02\x4c\x69\x6b\x04"
  "\x1e\x02\x86\x02\x08\x83\x04\x85\x02\x06\x81\x83\x02\x84\x02\x04"
  "\x81\x85\x02\x07\x11\x77\x02\x4d\x6b\x04\x1e\x02\x89\x02\x08\x83"
  "\x04\x88\x02\x06\x81\x83\x02\x87\x02\x04\x81\x85\x02\x07\x0f\x78"
  "\x02\x4e\x69\x04\x1e\x02\x8d\x02\x0a\x83\x04\x8c\x02\x08\x81\x83"
  "\x02\x8b\x02\x06\x81\x85\x02\x8a\x02\x04\x81\x87\x02\x09\x11\x79"
  "\x02\x4f\x6b\x69\x04\x1e\x02\x91\x02\x0a\x83\x04\x90\x02\x08\x81"
  "\x83\x02\x8f\x02\x06\x81\x85\x02\x8e\x02\x04\x81\x87\x02\x09\x13"
  "\x7a\x02\x50\x69\x6b\x04\x1e\x02\x95\x02\x0a\x83\x04\x94\x02\x08"
  "\x81\x83\x02\x93\x02\x06\x81\x85\x02\x92\x02\x04\x81\x87\x02\x09"
  "\x13\x7b\x02\x51\x6b\x69\x04\x1e\x02\x99\x02\x0a\x83\x04\x98\x02"
  "\x08\x81\x83\x02\x97\x02\x06\x81\x85\x02\x96\x02\x04\x81\x87\x02"
  "\x09\x13\x7c\x02\x52\x69\x6b\x04\x1e\x02\x9d\x02\x0a\x83\x04\x9c"
  "\x02\x08\x81\x83\x02\x9b\x02\x06\x81\x85\x02\x9a\x02\x04\x81\x87"
  "\x02\x09\x13\x7d\x02\x53\x6b\x69\x04\x1e\x02\xa1\x02\x0a\x83\x04"
  "\xa0\x02\x08\x81\x83\x02\x9f\x02\x06\x81\x85\x02\x9e\x02\x04\x81"
  "\x87\x02\x09\x13\x7e\x02\x54\x69\x6b\x04\x1e\x02\xa5\x02\x0a\x83"
  "\x04\xa4\x02\x08\x81\x83\x02\xa3\x02\x06\x81\x85\x02\xa2\x02\x04"
  "\x81\x87\x02\x09\x13\x7f\x02\x55\x6b\x69\x04\x1e\x02\xa9\x02\x0a"
  "\x83\x04\xa8\x02\x08\x81\x83\x02\xa7\x02\x06\x81\x85\x02\xa6\x02"
  "\x04\x81\x87\x02\x09\x13\x80\x01\x02\x56\x69\x6b\x04\x1e\x02\xad"
  "\x02\x0a\x83\x04\xac\x02\x08\x81\x83\x02\xab\x02\x06\x81\x85\x02"
  "\xaa\x02\x04\x81\x87\x02\x09\x13\x81\x01\x02\x57\x6b\x69\x04\x1e"
  "\x02\xb1\x02\x0a\x83\x04\xb0\x02\x08\x81\x83\x02\xaf\x02\x06\x81"
  "\x85\x02\xae\x02\x04\x81\x87\x02\x09\x13\x82\x01\x02\x58\x69\x6b"
  "\x04\x1e\x02\xb5\x02\x0a\x83\x04\xb4\x02\x08\x81\x83\x02\xb3\x02"
  "\x06\x81\x85\x02\xb2\x02\x04\x81\x87\x02\x09\x13\x83\x01\x02\x59"
  "\x6b\x69\x04\x1e\x02\xb9\x02\x0a\x83\x04\xb8\x02\x08\x81\x83\x02"
  "\xb7\x02\x06\x81\x85\x02\xb6\x02\x04\x81\x87\x02\x09\x13\x84\x01"
  "\x02\x5a\x69\x6b\x04\x1e\x02\xbd\x02\x0a\x83\x04\xbc\x02\x08\x81"
  "\x83\x02\xbb\x02\x06\x81\x85\x02\xba\x02\x04\x81\x87\x02\x09\x13"
  "\x85\x01\x02\x5b\x6b\x69\x04\x1e\x02\xc1\x02\x0a\x83\x04\xc0\x02"
  "\x08\x81\x83\x02\xbf\x02\x06\x81\x85\x02\xbe\x02\x04\x81\x87\x02"
  "\x09\x13\x86\x01\x02\x5c\x69\x6b\x04\x1e\x02\xc5\x02\x0a\x83\x04"
  "\xc4\x02\x08\x81\x83\x02\xc3\x02\x06\x81\x85\x02\xc2\x02\x04\x81"
  "\x87\x02\x09\x13\x87\x01\x02\x5d\x6b\x04\x1e\x02\xc9\x02\x0a\x83"
  "\x04\xc8\x02\x08\x81\x83\x02\xc7\x02\x06\x81\x85\x02\xc6\x02\x04"
  "\x81\x87\x02\x09\x11\x88\x01\x02\x5e\x69\x04\x1e\x02\xca\x02\x04"
  "\x83\x04\x03\x0b\x89\x01\x02\x5f\x6b\x69\x04\x1e\x02\xcc\x02\x06"
  "\x83\x04\xcb\x02\x04\x81\x83\x02\x05\x0f\x8a\x01\x02\x60\x6b\x69"
  "\x04\x1e\x02\xcf\x02\x08\x83\x04\xce\x02\x06\x81\x83\x02\xcd\x02"
  "\x04\x81\x85\x02\x07\x11\x8b\x01\x02\x61\x6b\x69\x04\x1e\x02\xd3"
  "\x02\x0a\x83\x04\xd2\x02\x08\x81\x83\x02\xd1\x02\x06\x81\x85\x02"
  "\xd0\x02\x04\x81\x87\x02\x09\x13\x8c\x01\x02\x62\x6b\x69\x04\x1e"
  "\x02\xd8\x02\x0c\x83\x04\xd7\x02\x0a\x81\x83\x02\xd6\x02\x08\x81"
  "\x85\x02\xd5\x02\x06\x81\x87\x02\xd4\x02\x04\x81\x89\x02\x0b\x15"
  "\x8d\x01\x02\x63\x6b\x69\x04\x1e\x02\xde\x02\x0e\x83\x04\xdd\x02"
  "\x0c\x81\x83\x02\xdc\x02\x0a\x81\x85\x02\xdb\x02\x08\x81\x87\x02"
  "\xda\x02\x06\x81\x89\x02\xd9\x02\x04\x81\x8b\x02\x0d\x17\x8e\x01"
  "\x02\x64\x6b\x69\x04\x1e\x02\xe5\x02\x10\x83\x04\xe4\x02\x0e\x81"
  "\x83\x02\xe3\x02\x0c\x81\x85\x02\xe2\x02\x0a\x81\x87\x02\xe1\x02"
  "\x08\x81\x89\x02\xe0\x02\x06\x81\x8b\x02\xdf\x02\x04\x81\x8d\x02"
  "\x0f\x19\x8f\x01\x02\x65\x6b\x69\x04\x1e\x02\xed\x02\x12\x83\x04"
  "\xec\x02\x10\x81\x83\x02\xeb\x02\x0e\x81\x85\x02\xea\x02\x0c\x81"
  "\x87\x02\xe9\x02\x0a\x81\x89\x02\xe8\x02\x08\x81\x8b\x02\xe7\x02"
  "\x06\x81\x8d\x02\xe6\x02\x04\x81\x8f\x02\x11\x1b\x90\x01\x02\x66"
  "\x6b\x69\x04\x1e\x02\xf6\x02\x14\x83\x04\xf5\x02\x12\x81\x83\x02"
  "\xf4\x02\x10\x81\x85\x02\xf3\x02\x0e\x81\x87\x02\xf2\x02\x0c\x81"
  "\x89\x02\xf1\x02\x0a\x81\x8b\x02\xf0\x02\x08\x81\x8d\x02\xef\x02"
  "\x06\x81\x8f\x02\xee\x02\x04\x81\x91\x02\x13\x1d\x91\x01\x02\x67"
  "\x6b\x69\x04\x1e\x02\x80\x03\x16\x83\x04\xff\x02\x14\x81\x83\x02"
  "\xfe\x02\x12\x81\x85\x02\xfd\x02\x10\x81\x87\x02\xfc\x02\x0e\x81"
  "\x89\x02\xfb\x02\x0c\x81\x8b\x02\xfa\x02\x0a\x81\x8d\x02\xf9\x02"
  "\x08\x81\x8f\x02\xf8\x02\x06\x81\x91\x02\xf7\x02\x04\x81\x93\x02"
  "\x15\x1f\x92\x01\x02\x68\x03\x08\x25\x61\x70\x70\x65\x6e\x64\x93"
  "\x01\x02\x81\x03\x04\xff\x03\x03\x94\x01\x02\x69\x03\x09\x25\x61"
  "\x70\x70\x65\x6e\x64\x21\x95\x01\x02\x82\x03\x04\xff\x03\x03\x96"
  "\x01\x02\x6a\x07\x61\x70\x70\x65\x6e\x64\x97\x01\x0c\x03\x58\x04"
  "\x23\x03\x93\x03\x24\x81\x83\x02\x92\x03\x22\x81\x85\x02\x91\x03"
  "\x20\x81\x87\x02\x90\x03\x1e\x81\x83\x02\x8f\x03\x1c\x81\x87\x02"
  "\x8e\x03\x1a\x81\x85\x02\x8d\x03\x18\x81\x85\x02\x8c\x03\x16\x81"
  "\x85\x02\x8b\x03\x14\x81\x85\x02\x8a\x03\x12\x81\x87\x02\x89\x03"
  "\x10\x81\x87\x02\x88\x03\x0e\x81\x85\x02\x87\x03\x0c\x81\x85\x02"
  "\x86\x03\x0a\x81\x85\x02\x85\x03\x08\x81\x83\x02\x84\x03\x06\x81"
  "\x83\x02\x83\x03\x04\x83\x04\x23\x30\x98\x01\x02\x6b\x0c\x08\x61"
  "\x70\x70\x65\x6e\x64\x21\x99\x01\x04\x23\x03\x0a\x6c\x61\x73\x74"
  "\x2d\x70\x61\x69\x72\x9a\x01\x03\xa0\x03\x1c\xfd\xff\x03\x9f\x03"
  "\x1a\xfd\xff\x03\x9e\x03\x18\xfd\xff\x03\x9d\x03\x16\xfd\xff\x03"
  "\x9c\x03\x14\xfd\xff\x03\x9b\x03\x12\xfd\xff\x03\x9a\x03\x10\xfd"
  "\xff\x03\x99\x03\x0e\xfd\xff\x03\x98\x03\x0c\xff\xff\x03\x97\x03"
  "\x0a\xfd\xff\x03\x96\x03\x08\x81\x87\x02\x95\x03\x06\x81\x85\x02"
  "\x94\x03\x04\x83\x04\x1b\x28\x9b\x01\x02\x6c\x04\x09\x72\x65\x76"
  "\x65\x72\x73\x65\x2a\x9c\x01\x02\xa1\x03\x04\x83\x04\x03\x0a\x9d"
  "\x01\x02\x6d\x04\x0a\x72\x65\x76\x65\x72\x73\x65\x2a\x21\x9e\x01"
  "\x02\xa2\x03\x04\x83\x04\x03\x0a\x9f\x01\x02\x6e\x9c\x01\x04\x23"
  "\x02\xa7\x03\x0c\x81\x89\x02\xa6\x03\x0a\x81\x89\x02\xa5\x03\x08"
  "\x81\x89\x02\xa4\x03\x06\x81\x89\x02\xa3\x03\x04\x84\x06\x0b\x15"
  "\xa0\x01\x02\x6f\x9e\x01\x0c\x04\x23\x02\xac\x03\x0c\x81\x8b\x02"
  "\xab\x03\x0a\x81\x89\x02\xaa\x03\x08\x81\x89\x02\xa9\x03\x06\x81"
  "\x89\x02\xa8\x03\x04\x84\x06\x0b\x15\xa1\x01\x02\x70\x06\x61\x70"
  "\x70\x6c\x79\xa2\x01\x0c\x04\x6d\x61\x70\xa3\x01\x02\x04\x0d\x6d"
  "\x61\x70\x70\x65\x72\x2d\x65\x72\x72\x6f\x72\xa4\x01\x03\x58\x03"
  "\xd6\x03\x56\x81\x8d\x02\xd5\x03\x54\x81\x8d\x02\xd4\x03\x52\x81"
  "\x8d\x02\xd3\x03\x50\x81\x8b\x02\xd2\x03\x4e\x81\x89\x02\xd1\x03"
  "\x4c\x81\x89\x02\xd0\x03\x4a\x81\x89\x02\xcf\x03\x48\x81\x87\x02"
  "\xce\x03\x46\x81\x87\x02\xcd\x03\x44\x81\x87\x02\xcc\x03\x42\x81"
  "\x85\x02\xcb\x03\x40\x81\x8b\x02\xca\x03\x3e\x81\x8b\x02\xc9\x03"
  "\x3c\x81\x89\x02\xc8\x03\x3a\x81\x87\x02\xc7\x03\x38\x81\x89\x02"
  "\xc6\x03\x36\x81\x87\x02\xc5\x03\x34\x81\x85\x02\xc4\x03\x32\x81"
  "\x85\x02\xc3\x03\x30\x81\x8b\x02\xc2\x03\x2e\x81\x8b\x02\xc1\x03"
  "\x2c\x81\x8b\x02\xc0\x03\x2a\x81\x8b\x02\xbf\x03\x28\x81\x8b\x02"
  "\xbe\x03\x26\x81\x8b\x02\xbd\x03\x24\x81\x8b\x02\xbc\x03\x22\x81"
  "\x8b\x02\xbb\x03\x20\x81\x8b\x02\xba\x03\x1e\x81\x91\x02\xb9\x03"
  "\x1c\x81\x8f\x02\xb8\x03\x1a\x81\x89\x02\xb7\x03\x18\x81\x8d\x02"
  "\xb6\x03\x16\x81\x87\x02\xb5\x03\x14\x81\x83\x02\xb4\x03\x12\x81"
  "\x89\x02\xb3\x03\x10\x81\x8d\x02\xb2\x03\x0e\x81\x8b\x02\xb1\x03"
  "\x0c\x81\x87\x02\xb0\x03\x0a\x81\x87\x02\xaf\x03\x08\xfd\x07\xae"
  "\x03\x06\x81\x87\x02\xad\x03\x04\x81\x89\x02\x55\x64\xa5\x01\x02"
  "\x71\x02\x04\x3f\x03\x26\x04\x23\x04\xd9\x03\x08\x81\x85\x02\xd8"
  "\x03\x06\x81\x85\x02\xd7\x03\x04\x84\x06\x07\x12\xa6\x01\x02\x72"
  "\xa2\x01\x3f\x02\x04\xa4\x01\x03\x58\x03\xf6\x03\x3c\x81\x8d\x02"
  "\xf5\x03\x3a\x81\x8f\x02\xf4\x03\x38\x81\x8d\x02\xf3\x03\x36\x81"
  "\x8d\x02\xf2\x03\x34\x81\x8d\x02\xf1\x03\x32\x81\x8d\x02\xf0\x03"
  "\x30\x81\x8d\x02\xef\x03\x2e\x81\x8d\x02\xee\x03\x2c\x81\x8d\x02"
  "\xed\x03\x2a\x81\x8d\x02\xec\x03\x28\x81\x8d\x02\xeb\x03\x26\x81"
  "\x8d\x02\xea\x03\x24\x81\x8b\x02\xe9\x03\x22\x81\x8b\x02\xe8\x03"
  "\x20\x81\x8b\x02\xe7\x03\x1e\x81\x89\x02\xe6\x03\x1c\x81\x89\x02"
  "\xe5\x03\x1a\x81\x83\x02\xe4\x03\x18\x81\x89\x02\xe3\x03\x16\x81"
  "\x8f\x02\xe2\x03\x14\x81\x8d\x02\xe1\x03\x12\x81\x8b\x02\xe0\x03"
  "\x10\x81\x8b\x02\xdf\x03\x0e\x81\x8b\x02\xde\x03\x0c\x81\x89\x02"
  "\xdd\x03\x0a\x81\x89\x02\xdc\x03\x08\x81\x87\x02\xdb\x03\x06\x81"
  "\x87\x02\xda\x03\x04\xfd\x07\x3b\x49\xa7\x01\x02\x73\xa2\x01\x05"
  "\x6d\x61\x70\x2a\xa8\x01\x04\xa4\x01\x03\x58\x03\x96\x04\x42\xfd"
  "\xff\x03\x95\x04\x40\xfd\xff\x03\x94\x04\x3e\xfd\xff\x03\x93\x04"
  "\x3c\xfd\xff\x03\x92\x04\x3a\xfd\xff\x03\x91\x04\x38\xfd\xff\x03"
  "\x90\x04\x36\xfd\xff\x03\x8f\x04\x34\xfd\xff\x03\x8e\x04\x32\xfd"
  "\xff\x03\x8d\x04\x30\xfd\xff\x03\x8c\x04\x2e\xfd\xff\x03\x8b\x04"
  "\x2c\xfd\xff\x03\x8a\x04\x2a\xfd\xff\x03\x89\x04\x28\xff\xff\x03"
  "\x88\x04\x26\xfd\xff\x03\x87\x04\x24\xfd\xff\x03\x86\x04\x22\xfd"
  "\xff\x03\x85\x04\x20\xfd\xff\x03\x84\x04\x1e\xfd\xff\x03\x83\x04"
  "\x1c\xfd\xff\x03\x82\x04\x1a\x81\x83\x02\x81\x04\x18\xff\xff\x03"
  "\x80\x04\x16\xfd\xff\x03\xff\x03\x14\xfd\xff\x03\xfe\x03\x12\xff"
  "\xff\x03\xfd\x03\x10\xfd\xff\x03\xfc\x03\x0e\xfd\xff\x03\xfb\x03"
  "\x0c\xff\xff\x03\xfa\x03\x0a\xfd\xff\x03\xf9\x03\x08\x81\x8b\x02"
  "\xf8\x03\x06\x81\x89\x02\xf7\x03\x04\xfc\x09\x41\x4e\xa9\x01\x02"
  "\x74\xa2\x01\x0b\x61\x70\x70\x65\x6e\x64\x2d\x6d\x61\x70\xaa\x01"
  "\x04\xa4\x01\x03\x58\x04\x97\x01\x04\xb6\x04\x42\xfd\xff\x03\xb5"
  "\x04\x40\xfd\xff\x03\xb4\x04\x3e\xfd\xff\x03\xb3\x04\x3c\xfd\xff"
  "\x03\xb2\x04\x3a\xfd\xff\x03\xb1\x04\x38\xfd\xff\x03\xb0\x04\x36"
  "\xfd\xff\x03\xaf\x04\x34\xfd\xff\x03\xae\x04\x32\xfd\xff\x03\xad"
  "\x04\x30\xfd\xff\x03\xac\x04\x2e\xfd\xff\x03\xab\x04\x2c\xfd\xff"
  "\x03\xaa\x04\x2a\xfd\xff\x03\xa9\x04\x28\xff\xff\x03\xa8\x04\x26"
  "\xfd\xff\x03\xa7\x04\x24\xfd\xff\x03\xa6\x04\x22\xfd\xff\x03\xa5"
  "\x04\x20\xfd\xff\x03\xa4\x04\x1e\xfd\xff\x03\xa3\x04\x1c\xfd\xff"
  "\x03\xa2\x04\x1a\x81\x83\x02\xa1\x04\x18\xff\xff\x03\xa0\x04\x16"
  "\xfd\xff\x03\x9f\x04\x14\xfd\xff\x03\x9e\x04\x12\xff\xff\x03\x9d"
  "\x04\x10\xfd\xff\x03\x9c\x04\x0e\xfd\xff\x03\x9b\x04\x0c\xff\xff"
  "\x03\x9a\x04\x0a\xfd\xff\x03\x99\x04\x08\x81\x89\x02\x98\x04\x06"
  "\x81\x87\x02\x97\x04\x04\xfd\x07\x41\x50\xab\x01\x02\x75\xa2\x01"
  "\x0c\x61\x70\x70\x65\x6e\x64\x2d\x6d\x61\x70\x2a\xac\x01\x04\xa4"
  "\x01\x03\x58\x04\x97\x01\x04\xd6\x04\x42\xfd\xff\x03\xd5\x04\x40"
  "\xfd\xff\x03\xd4\x04\x3e\xfd\xff\x03\xd3\x04\x3c\xfd\xff\x03\xd2"
  "\x04\x3a\xfd\xff\x03\xd1\x04\x38\xfd\xff\x03\xd0\x04\x36\xfd\xff"
  "\x03\xcf\x04\x34\xfd\xff\x03\xce\x04\x32\xfd\xff\x03\xcd\x04\x30"
  "\xfd\xff\x03\xcc\x04\x2e\xfd\xff\x03\xcb\x04\x2c\xfd\xff\x03\xca"
  "\x04\x2a\xfd\xff\x03\xc9\x04\x28\xff\xff\x03\xc8\x04\x26\xfd\xff"
  "\x03\xc7\x04\x24\xfd\xff\x03\xc6\x04\x22\xfd\xff\x03\xc5\x04\x20"
  "\xfd\xff\x03\xc4\x04\x1e\xfd\xff\x03\xc3\x04\x1c\xfd\xff\x03\xc2"
  "\x04\x1a\x81\x83\x02\xc1\x04\x18\xff\xff\x03\xc0\x04\x16\xfd\xff"
  "\x03\xbf\x04\x14\xfd\xff\x03\xbe\x04\x12\xff\xff\x03\xbd\x04\x10"
  "\xfd\xff\x03\xbc\x04\x0e\xfd\xff\x03\xbb\x04\x0c\xff\xff\x03\xba"
  "\x04\x0a\xfd\xff\x03\xb9\x04\x08\x81\x8b\x02\xb8\x04\x06\x81\x89"
  "\x02\xb7\x04\x04\xfc\x09\x41\x50\xad\x01\x02\x76\xa2\x01\x0c\x61"
  "\x70\x70\x65\x6e\x64\x2d\x6d\x61\x70\x21\xae\x01\x04\xa4\x01\x03"
  "\x58\x04\x99\x01\x04\xf6\x04\x42\xfd\xff\x03\xf5\x04\x40\xfd\xff"
  "\x03\xf4\x04\x3e\xfd\xff\x03\xf3\x04\x3c\xfd\xff\x03\xf2\x04\x3a"
  "\xfd\xff\x03\xf1\x04\x38\xfd\xff\x03\xf0\x04\x36\xfd\xff\x03\xef"
  "\x04\x34\xfd\xff\x03\xee\x04\x32\xfd\xff\x03\xed\x04\x30\xfd\xff"
  "\x03\xec\x04\x2e\xfd\xff\x03\xeb\x04\x2c\xfd\xff\x03\xea\x04\x2a"
  "\xfd\xff\x03\xe9\x04\x28\xff\xff\x03\xe8\x04\x26\xfd\xff\x03\xe7"
  "\x04\x24\xfd\xff\x03\xe6\x04\x22\xfd\xff\x03\xe5\x04\x20\xfd\xff"
  "\x03\xe4\x04\x1e\xfd\xff\x03\xe3\x04\x1c\xfd\xff\x03\xe2\x04\x1a"
  "\x81\x83\x02\xe1\x04\x18\xff\xff\x03\xe0\x04\x16\xfd\xff\x03\xdf"
  "\x04\x14\xfd\xff\x03\xde\x04\x12\xff\xff\x03\xdd\x04\x10\xfd\xff"
  "\x03\xdc\x04\x0e\xfd\xff\x03\xdb\x04\x0c\xff\xff\x03\xda\x04\x0a"
  "\xfd\xff\x03\xd9\x04\x08\x81\x89\x02\xd8\x04\x06\x81\x87\x02\xd7"
  "\x04\x04\xfd\x07\x41\x50\xaf\x01\x02\x77\xa2\x01\x0d\x61\x70\x70"
  "\x65\x6e\x64\x2d\x6d\x61\x70\x2a\x21\xb0\x01\x04\xa4\x01\x03\x58"
  "\x04\x99\x01\x04\x96\x05\x42\xfd\xff\x03\x95\x05\x40\xfd\xff\x03"
  "\x94\x05\x3e\xfd\xff\x03\x93\x05\x3c\xfd\xff\x03\x92\x05\x3a\xfd"
  "\xff\x03\x91\x05\x38\xfd\xff\x03\x90\x05\x36\xfd\xff\x03\x8f\x05"
  "\x34\xfd\xff\x03\x8e\x05\x32\xfd\xff\x03\x8d\x05\x30\xfd\xff\x03"
  "\x8c\x05\x2e\xfd\xff\x03\x8b\x05\x2c\xfd\xff\x03\x8a\x05\x2a\xfd"
  "\xff\x03\x89\x05\x28\xff\xff\x03\x88\x05\x26\xfd\xff\x03\x87\x05"
  "\x24\xfd\xff\x03\x86\x05\x22\xfd\xff\x03\x85\x05\x20\xfd\xff\x03"
  "\x84\x05\x1e\xfd\xff\x03\x83\x05\x1c\xfd\xff\x03\x82\x05\x1a\x81"
  "\x83\x02\x81\x05\x18\xff\xff\x03\x80\x05\x16\xfd\xff\x03\xff\x04"
  "\x14\xfd\xff\x03\xfe\x04\x12\xff\xff\x03\xfd\x04\x10\xfd\xff\x03"
  "\xfc\x04\x0e\xfd\xff\x03\xfb\x04\x0c\xff\xff\x03\xfa\x04\x0a\xfd"
  "\xff\x03\xf9\x04\x08\x81\x8b\x02\xf8\x04\x06\x81\x89\x02\xf7\x04"
  "\x04\xfc\x09\x41\x50\xb1\x01\x02\x78\x07\x72\x65\x64\x75\x63\x65"
  "\xb2\x01\x06\x08\x25\x66\x6f\x6c\x64\x2d\x31\xb3\x01\x04\x23\x03"
  "\x9a\x05\x0a\x81\x89\x02\x99\x05\x08\x81\x89\x02\x98\x05\x06\x85"
  "\x08\x97\x05\x04\x81\x87\x02\x09\x15\xb4\x01\x02\x79\x05\xb2\x01"
  "\x02\x9c\x05\x06\x81\x87\x02\x9b\x05\x04\x85\x08\x05\x0b\xb5\x01"
  "\x02\x7a\x0d\x72\x65\x64\x75\x63\x65\x2d\x72\x69\x67\x68\x74\xb6"
  "\x01\x04\x23\x02\xa5\x05\x14\xfd\xff\x03\xa4\x05\x12\xfd\xff\x03"
  "\xa3\x05\x10\xfd\xff\x03\xa2\x05\x0e\xff\xff\x03\xa1\x05\x0c\xfd"
  "\xff\x03\xa0\x05\x0a\x81\x8b\x02\x9f\x05\x08\x81\x89\x02\x9e\x05"
  "\x06\x85\x08\x9d\x05\x04\x81\x87\x02\x13\x1d\xb7\x01\x02\x7b\xa2"
  "\x01\x05\x66\x6f\x6c\x64\xb8\x01\x06\xb3\x01\x04\xa4\x01\x03\x58"
  "\x04\xb3\x05\x1e\x81\x95\x02\xb2\x05\x1c\x81\x93\x02\xb1\x05\x1a"
  "\x81\x93\x02\xb0\x05\x18\x81\x93\x02\xaf\x05\x16\x81\x93\x02\xae"
  "\x05\x14\x81\x93\x02\xad\x05\x12\x81\x93\x02\xac\x05\x10\x81\x93"
  "\x02\xab\x05\x0e\x81\x93\x02\xaa\x05\x0c\x81\x93\x02\xa9\x05\x0a"
  "\x81\x93\x02\xa8\x05\x08\x81\x93\x02\xa7\x05\x06\x81\x8d\x02\xa6"
  "\x05\x04\xfc\x09\x1d\x2c\xb9\x01\x02\x7c\x04\x23\x02\xb9\x05\x0e"
  "\x81\x8d\x02\xb8\x05\x0c\x81\x8d\x02\xb7\x05\x0a\x81\x91\x02\xb6"
  "\x05\x08\x81\x8d\x02\xb5\x05\x06\x81\x8d\x02\xb4\x05\x04\x86\x0a"
  "\x0d\x16\xba\x01\x02\x7d\x0a\x66\x6f\x6c\x64\x2d\x6c\x65\x66\x74"
  "\xbb\x01\x06\xb3\x01\x02\xbb\x05\x06\x81\x87\x02\xba\x05\x04\x85"
  "\x08\x05\x0c\xbc\x01\x02\x7e\xa2\x01\x0b\x66\x6f\x6c\x64\x2d\x72"
  "\x69\x67\x68\x74\xa2\x01\x04\x23\x04\xa4\x01\x03\x58\x04\xce\x05"
  "\x28\xfd\xff\x03\xcd\x05\x26\xfd\xff\x03\xcc\x05\x24\xfd\xff\x03"
  "\xcb\x05\x22\xfd\xff\x03\xca\x05\x20\xfd\xff\x03\xc9\x05\x1e\xfd"
  "\xff\x03\xc8\x05\x1c\xfd\xff\x03\xc7\x05\x1a\xfd\xff\x03\xc6\x05"
  "\x18\xfd\xff\x03\xc5\x05\x16\xfd\xff\x03\xc4\x05\x14\xff\xff\x03"
  "\xc3\x05\x12\xfd\xff\x03\xc2\x05\x10\xfd\xff\x03\xc1\x05\x0e\xfd"
  "\xff\x03\xc0\x05\x0c\xff\xff\x03\xbf\x05\x0a\xfd\xff\x03\xbe\x05"
  "\x08\xff\xff\x03\xbd\x05\x06\xfd\xff\x03\xbc\x05\x04\xfc\x09\x27"
  "\x36\xbd\x01\x02\x7f\x13\x66\x69\x6e\x64\x2d\x6d\x61\x74\x63\x68"
  "\x69\x6e\x67\x2d\x69\x74\x65\x6d\xbe\x01\x04\x23\x02\xd4\x05\x0e"
  "\x81\x87\x02\xd3\x05\x0c\x81\x87\x02\xd2\x05\x0a\x81\x89\x02\xd1"
  "\x05\x08\x81\x87\x02\xd0\x05\x06\x81\x87\x02\xcf\x05\x04\x84\x06"
  "\x0d\x17\xbf\x01\x02\x80\x01\xbe\x01\x04\x23\x02\xda\x05\x0e\x81"
  "\x87\x02\xd9\x05\x0c\x81\x87\x02\xd8\x05\x0a\x81\x89\x02\xd7\x05"
  "\x08\x81\x87\x02\xd6\x05\x06\x81\x87\x02\xd5\x05\x04\x84\x06\x0d"
  "\x17\xc0\x01\x02\x81\x01\x1a\x66\x69\x6e\x64\x2d\x75\x6e\x69\x71"
  "\x75\x65\x2d\x6d\x61\x74\x63\x68\x69\x6e\x67\x2d\x69\x74\x65\x6d"
  "\xc1\x01\x04\x23\x04\x0e\x74\x68\x65\x72\x65\x2d\x65\x78\x69\x73"
  "\x74\x73\x3f\x03\xe2\x05\x12\x81\x87\x02\xe1\x05\x10\x81\x8b\x02"
  "\xe0\x05\x0e\x81\x87\x02\xdf\x05\x0c\x81\x87\x02\xde\x05\x0a\x81"
  "\x89\x02\xdd\x05\x08\x81\x87\x02\xdc\x05\x06\x81\x87\x02\xdb\x05"
  "\x04\x84\x06\x11\x1d\xc2\x01\x02\x82\x01\x1e\x66\x69\x6e\x64\x2d"
  "\x75\x6e\x69\x71\x75\x65\x2d\x6e\x6f\x6e\x2d\x6d\x61\x74\x63\x68"
  "\x69\x6e\x67\x2d\x69\x74\x65\x6d\xc3\x01\x04\x23\x04\x09\x66\x6f"
  "\x72\x2d\x61\x6c\x6c\x3f\x03\xea\x05\x12\x81\x87\x02\xe9\x05\x10"
  "\x81\x87\x02\xe8\x05\x0e\x81\x8b\x02\xe7\x05\x0c\x81\x87\x02\xe6"
  "\x05\x0a\x81\x89\x02\xe5\x05\x08\x81\x87\x02\xe4\x05\x06\x81\x87"
  "\x02\xe3\x05\x04\x84\x06\x11\x1d\xc4\x01\x02\x83\x01\x15\x63\x6f"
  "\x75\x6e\x74\x2d\x6d\x61\x74\x63\x68\x69\x6e\x67\x2d\x69\x74\x65"
  "\x6d\x73\xc5\x01\x04\x23\x02\xf0\x05\x0e\x81\x89\x02\xef\x05\x0c"
  "\x81\x89\x02\xee\x05\x0a\x81\x8b\x02\xed\x05\x08\x81\x89\x02\xec"
  "\x05\x06\x81\x89\x02\xeb\x05\x04\x84\x06\x0d\x18\xc6\x01\x02\x84"
  "\x01\x19\x63\x6f\x75\x6e\x74\x2d\x6e\x6f\x6e\x2d\x6d\x61\x74\x63"
  "\x68\x69\x6e\x67\x2d\x69\x74\x65\x6d\x73\xc7\x01\x04\x23\x02\xf6"
  "\x05\x0e\x81\x89\x02\xf5\x05\x0c\x81\x89\x02\xf4\x05\x0a\x81\x8b"
  "\x02\xf3\x05\x08\x81\x89\x02\xf2\x05\x06\x81\x89\x02\xf1\x05\x04"
  "\x84\x06\x0d\x18\xc8\x01\x02\x85\x01\x0c\x14\x6b\x65\x65\x70\x2d"
  "\x6d\x61\x74\x63\x68\x69\x6e\x67\x2d\x69\x74\x65\x6d\x73\xc9\x01"
  "\x04\x23\x02\x84\x06\x1e\x81\x87\x02\x83\x06\x1c\x81\x87\x02\x82"
  "\x06\x1a\x81\x85\x02\x81\x06\x18\x81\x85\x02\x80\x06\x16\x81\x85"
  "\x02\xff\x05\x14\x81\x87\x02\xfe\x05\x12\x81\x89\x02\xfd\x05\x10"
  "\x81\x87\x02\xfc\x05\x0e\x81\x87\x02\xfb\x05\x0c\x81\x85\x02\xfa"
  "\x05\x0a\xff\xff\x03\xf9\x05\x08\x81\x8b\x02\xf8\x05\x06\x81\x85"
  "\x02\xf7\x05\x04\x84\x06\x1d\x28\xca\x01\x02\x86\x01\x0c\x16\x64"
  "\x65\x6c\x65\x74\x65\x2d\x6d\x61\x74\x63\x68\x69\x6e\x67\x2d\x69"
  "\x74\x65\x6d\x73\xcb\x01\x04\x23\x02\x92\x06\x1e\x81\x85\x02\x91"
  "\x06\x1c\x81\x87\x02\x90\x06\x1a\x81\x87\x02\x8f\x06\x18\x81\x85"
  "\x02\x8e\x06\x16\x81\x85\x02\x8d\x06\x14\x81\x87\x02\x8c\x06\x12"
  "\x81\x89\x02\x8b\x06\x10\x81\x87\x02\x8a\x06\x0e\x81\x87\x02\x89"
  "\x06\x0c\x81\x85\x02\x88\x06\x0a\xff\xff\x03\x87\x06\x08\x81\x8b"
  "\x02\x86\x06\x06\x81\x85\x02\x85\x06\x04\x84\x06\x1d\x28\xcc\x01"
  "\x02\x87\x01\x0c\x17\x64\x65\x6c\x65\x74\x65\x2d\x6d\x61\x74\x63"
  "\x68\x69\x6e\x67\x2d\x69\x74\x65\x6d\x73\x21\xcd\x01\x04\x23\x02"
  "\xa1\x06\x20\x81\x89\x02\xa0\x06\x1e\x81\x85\x02\x9f\x06\x1c\x81"
  "\x85\x02\x9e\x06\x1a\xfd\xff\x03\x9d\x06\x18\x81\x87\x02\x9c\x06"
  "\x16\x81\x85\x02\x9b\x06\x14\x81\x85\x02\x9a\x06\x12\xfd\xff\x03"
  "\x99\x06\x10\xfd\xff\x03\x98\x06\x0e\xfd\xff\x03\x97\x06\x0c\x81"
  "\x83\x02\x96\x06\x0a\xfd\xff\x03\x95\x06\x08\xff\xff\x03\x94\x06"
  "\x06\xfd\xff\x03\x93\x06\x04\x84\x06\x1f\x2a\xce\x01\x02\x88\x01"
  "\x0c\x15\x6b\x65\x65\x70\x2d\x6d\x61\x74\x63\x68\x69\x6e\x67\x2d"
  "\x69\x74\x65\x6d\x73\x21\xcf\x01\x04\x23\x02\xb0\x06\x20\x81\x85"
  "\x02\xaf\x06\x1e\x81\x89\x02\xae\x06\x1c\x81\x85\x02\xad\x06\x1a"
  "\xfd\xff\x03\xac\x06\x18\x81\x87\x02\xab\x06\x16\x81\x85\x02\xaa"
  "\x06\x14\x81\x85\x02\xa9\x06\x12\xfd\xff\x03\xa8\x06\x10\xfd\xff"
  "\x03\xa7\x06\x0e\xfd\xff\x03\xa6\x06\x0c\x81\x83\x02\xa5\x06\x0a"
  "\xfd\xff\x03\xa4\x06\x08\xff\xff\x03\xa3\x06\x06\xfd\xff\x03\xa2"
  "\x06\x04\x84\x06\x1f\x2a\xd0\x01\x02\x89\x01\x04\xcb\x01\x02\xb2"
  "\x06\x06\x81\x85\x02\xb1\x06\x04\x83\x04\x05\x0b\xd1\x01\x02\x8a"
  "\x01\x04\xcd\x01\x02\xb4\x06\x06\x81\x85\x02\xb3\x06\x04\x83\x04"
  "\x05\x0b\xd2\x01\x02\x8b\x01\x05\x6d\x65\x6d\x71\xd3\x01\x04\x23"
  "\x02\xb9\x06\x0c\x81\x87\x02\xb8\x06\x0a\x81\x87\x02\xb7\x06\x08"
  "\x81\x87\x02\xb6\x06\x06\x81\x87\x02\xb5\x06\x04\x84\x06\x0b\x15"
  "\xd4\x01\x02\x8c\x01\x05\x6d\x65\x6d\x76\xd5\x01\x04\x05\x65\x71"
  "\x76\x3f\xd6\x01\x04\x23\x03\xbf\x06\x0e\x81\x87\x02\xbe\x06\x0c"
  "\x81\x87\x02\xbd\x06\x0a\x81\x8b\x02\xbc\x06\x08\x81\x87\x02\xbb"
  "\x06\x06\x81\x87\x02\xba\x06\x04\x84\x06\x0d\x19\xd7\x01\x02\x8d"
  "\x01\x07\x6d\x65\x6d\x62\x65\x72\xd8\x01\x08\x07\x65\x71\x75\x61"
  "\x6c\x3f\xd9\x01\x02\x04\x23\x02\xc6\x06\x10\x81\x8b\x02\xc5\x06"
  "\x0e\x81\x8b\x02\xc4\x06\x0c\x81\x8f\x02\xc3\x06\x0a\x81\x8b\x02"
  "\xc2\x06\x08\x81\x8b\x02\xc1\x06\x06\x81\x87\x02\xc0\x06\x04\x85"
  "\x06\x0f\x1c\xda\x01\x02\x8e\x01\x04\x23\x02\xcd\x06\x10\x81\x89"
  "\x02\xcc\x06\x0e\x81\x89\x02\xcb\x06\x0c\x81\x8d\x02\xca\x06\x0a"
  "\x81\x89\x02\xc9\x06\x08\x81\x89\x02\xc8\x06\x06\x81\x87\x02\xc7"
  "\x06\x04\x84\x04\x0f\x18\xdb\x01\x02\x8f\x01\x04\x23\x02\xd4\x06"
  "\x10\x81\x8d\x02\xd3\x06\x0e\x81\x89\x02\xd2\x06\x0c\x81\x89\x02"
  "\xd1\x06\x0a\x81\x89\x02\xd0\x06\x08\x81\x89\x02\xcf\x06\x06\x81"
  "\x87\x02\xce\x06\x04\x84\x04\x0f\x18\xdc\x01\x02\x90\x01\x04\x23"
  "\x02\xda\x06\x0e\x81\x8b\x02\xd9\x06\x0c\x81\x8b\x02\xd8\x06\x0a"
  "\x81\x8f\x02\xd7\x06\x08\x81\x8b\x02\xd6\x06\x06\x81\x8b\x02\xd5"
  "\x06\x04\x86\x0a\x0d\x16\xdd\x01\x02\x91\x01\xde\x06\x0a\x81\x85"
  "\x02\xdd\x06\x08\x81\x87\x02\xdc\x06\x06\x81\x87\x02\xdb\x06\x04"
  "\x84\x06\x09\x0c\xde\x01\x02\x92\x01\x0c\x05\x64\x65\x6c\x71\xdf"
  "\x01\x04\x23\x02\xeb\x06\x1c\x81\x87\x02\xea\x06\x1a\x81\x87\x02"
  "\xe9\x06\x18\x81\x87\x02\xe8\x06\x16\x81\x87\x02\xe7\x06\x14\x81"
  "\x85\x02\xe6\x06\x12\x81\x85\x02\xe5\x06\x10\x81\x85\x02\xe4\x06"
  "\x0e\x81\x85\x02\xe3\x06\x0c\x81\x83\x02\xe2\x06\x0a\x81\x8b\x02"
  "\xe1\x06\x08\x81\x85\x02\xe0\x06\x06\x84\x06\xdf\x06\x04\x81\x85"
  "\x02\x1b\x26\xe0\x01\x02\x93\x01\x0c\xdf\x01\x04\x23\x04\xd6\x01"
  "\x03\xfa\x06\x20\x81\x85\x02\xf9\x06\x1e\x81\x87\x02\xf8\x06\x1c"
  "\x81\x87\x02\xf7\x06\x1a\x81\x85\x02\xf6\x06\x18\x81\x85\x02\xf5"
  "\x06\x16\x81\x87\x02\xf4\x06\x14\x81\x8b\x02\xf3\x06\x12\x81\x87"
  "\x02\xf2\x06\x10\x81\x89\x02\xf1\x06\x0e\x81\x85\x02\xf0\x06\x0c"
  "\x81\x83\x02\xef\x06\x0a\x81\x8b\x02\xee\x06\x08\x81\x85\x02\xed"
  "\x06\x06\x84\x06\xec\x06\x04\x81\x85\x02\x1f\x2c\xe1\x01\x02\x94"
  "\x01\x0c\x07\x64\x65\x6c\x65\x74\x65\xe2\x01\x08\xd9\x01\x02\x04"
  "\x23\x02\x8a\x07\x22\x81\x85\x02\x89\x07\x20\x81\x87\x02\x88\x07"
  "\x1e\x81\x87\x02\x87\x07\x1c\x81\x85\x02\x86\x07\x1a\x81\x85\x02"
  "\x85\x07\x18\x81\x8b\x02\x84\x07\x16\x81\x8f\x02\x83\x07\x14\x81"
  "\x8b\x02\x82\x07\x12\x81\x89\x02\x81\x07\x10\x81\x85\x02\x80\x07"
  "\x0e\x81\x83\x02\xff\x06\x0c\x81\x8f\x02\xfe\x06\x0a\x81\x89\x02"
  "\xfd\x06\x08\x81\x87\x02\xfc\x06\x06\x85\x06\xfb\x06\x04\x81\x89"
  "\x02\x21\x2f\xe3\x01\x02\x95\x01\x0c\x04\x23\x02\x99\x07\x20\x81"
  "\x85\x02\x98\x07\x1e\x81\x87\x02\x97\x07\x1c\x81\x87\x02\x96\x07"
  "\x1a\x81\x85\x02\x95\x07\x18\x81\x85\x02\x94\x07\x16\x81\x8b\x02"
  "\x93\x07\x14\x81\x8f\x02\x92\x07\x12\x81\x8b\x02\x91\x07\x10\x81"
  "\x89\x02\x90\x07\x0e\x81\x85\x02\x8f\x07\x0c\x81\x83\x02\x8e\x07"
  "\x0a\x81\x8f\x02\x8d\x07\x08\x81\x89\x02\x8c\x07\x06\x86\x0a\x8b"
  "\x07\x04\x81\x89\x02\x1f\x29\xe4\x01\x02\x96\x01\x0c\x06\x64\x65"
  "\x6c\x71\x21\xe5\x01\x04\x23\x02\xa5\x07\x1a\xfd\xff\x03\xa4\x07"
  "\x18\x81\x85\x02\xa3\x07\x16\x81\x89\x02\xa2\x07\x14\x81\x85\x02"
  "\xa1\x07\x12\x81\x85\x02\xa0\x07\x10\x81\x85\x02\x9f\x07\x0e\xfd"
  "\xff\x03\x9e\x07\x0c\xfd\xff\x03\x9d\x07\x0a\xfd\xff\x03\x9c\x07"
  "\x08\xff\xff\x03\x9b\x07\x06\xfd\xff\x03\x9a\x07\x04\x84\x06\x19"
  "\x24\xe6\x01\x02\x97\x01\x0c\x06\x64\x65\x6c\x76\x21\xe7\x01\x04"
  "\xd6\x01\x04\x23\x03\xb3\x07\x1e\x81\x89\x02\xb2\x07\x1c\x81\x85"
  "\x02\xb1\x07\x1a\x81\x85\x02\xb0\x07\x18\xfd\xff\x03\xaf\x07\x16"
  "\x81\x87\x02\xae\x07\x14\x81\x85\x02\xad\x07\x12\x81\x85\x02\xac"
  "\x07\x10\xfd\xff\x03\xab\x07\x0e\xfd\xff\x03\xaa\x07\x0c\xfd\xff"
  "\x03\xa9\x07\x0a\xfd\xff\x03\xa8\x07\x08\xff\xff\x03\xa7\x07\x06"
  "\xfd\xff\x03\xa6\x07\x04\x84\x06\x1d\x2a\xe8\x01\x02\x98\x01\x0c"
  "\x08\x64\x65\x6c\x65\x74\x65\x21\xe9\x01\x08\xd9\x01\x02\x04\x23"
  "\x02\xc2\x07\x20\x81\x89\x02\xc1\x07\x1e\x81\x85\x02\xc0\x07\x1c"
  "\x81\x85\x02\xbf\x07\x1a\xfd\xff\x03\xbe\x07\x18\x81\x87\x02\xbd"
  "\x07\x16\x81\x85\x02\xbc\x07\x14\x81\x85\x02\xbb\x07\x12\xfd\xff"
  "\x03\xba\x07\x10\xfd\xff\x03\xb9\x07\x0e\xfd\xff\x03\xb8\x07\x0c"
  "\xfd\xff\x03\xb7\x07\x0a\xff\xff\x03\xb6\x07\x08\xfd\xff\x03\xb5"
  "\x07\x06\x81\x87\x02\xb4\x07\x04\x85\x06\x1f\x2d\xea\x01\x02\x99"
  "\x01\x0c\x04\x23\x02\xd0\x07\x1e\x81\x89\x02\xcf\x07\x1c\x81\x85"
  "\x02\xce\x07\x1a\x81\x85\x02\xcd\x07\x18\xfd\xff\x03\xcc\x07\x16"
  "\x81\x87\x02\xcb\x07\x14\x81\x85\x02\xca\x07\x12\x81\x85\x02\xc9"
  "\x07\x10\xfd\xff\x03\xc8\x07\x0e\xfd\xff\x03\xc7\x07\x0c\xfd\xff"
  "\x03\xc6\x07\x0a\xfd\xff\x03\xc5\x07\x08\xff\xff\x03\xc4\x07\x06"
  "\xfd\xff\x03\xc3\x07\x04\x86\x0a\x1d\x27\xeb\x01\x02\x9a\x01\x06"
  "\x70\x61\x69\x72\x3f\xec\x01\x02\x04\x2f\x02\xd2\x07\x06\x81\x85"
  "\x02\xd1\x07\x04\x83\x04\x05\x0d\xed\x01\x02\x9b\x01\x02\x03\x07"
  "\x61\x6c\x69\x73\x74\x3f\xee\x01\x04\x10\x65\x72\x72\x6f\x72\x3a"
  "\x6e\x6f\x74\x2d\x61\x6c\x69\x73\x74\xef\x01\x03\xd4\x07\x06\x81"
  "\x85\x02\xd3\x07\x04\x84\x04\x05\x0e\xf0\x01\x02\x9c\x01\x08\x11"
  "\x61\x73\x73\x6f\x63\x69\x61\x74\x69\x6f\x6e\x20\x6c\x69\x73\x74"
  "\x05\x20\x02\xd5\x07\x04\x84\x04\x03\x0c\xf1\x01\x02\x9d\x01\xd6"
  "\x07\x04\x85\x08\x03\xf2\x01\x02\x9e\x01\x0c\x0b\x61\x6c\x69\x73"
  "\x74\x2d\x63\x6f\x70\x79\xf3\x01\x04\xef\x01\x02\xe4\x07\x1e\x81"
  "\x85\x02\xe3\x07\x1c\x81\x87\x02\xe2\x07\x1a\x81\x87\x02\xe1\x07"
  "\x18\x81\x87\x02\xe0\x07\x16\x81\x87\x02\xdf\x07\x14\x81\x85\x02"
  "\xde\x07\x12\x81\x85\x02\xdd\x07\x10\x81\x85\x02\xdc\x07\x0e\x81"
  "\x85\x02\xdb\x07\x0c\xff\xff\x03\xda\x07\x0a\x81\x89\x02\xd9\x07"
  "\x08\x81\x83\x02\xd8\x07\x06\x81\x83\x02\xd7\x07\x04\x83\x04\x1d"
  "\x28\xf4\x01\x02\x9f\x01\x04\x23\x02\xec\x07\x12\x81\x8d\x02\xeb"
  "\x07\x10\x81\x89\x02\xea\x07\x0e\x81\x89\x02\xe9\x07\x0c\x81\x8f"
  "\x02\xe8\x07\x0a\x81\x89\x02\xe7\x07\x08\x81\x89\x02\xe6\x07\x06"
  "\x81\x87\x02\xe5\x07\x04\x85\x06\x11\x1a\xf5\x01\x02\xa0\x01\xf1"
  "\x07\x0c\x81\x89\x02\xf0\x07\x0a\x81\x85\x02\xef\x07\x08\x81\x87"
  "\x02\xee\x07\x06\x81\x87\x02\xed\x07\x04\x85\x08\x0b\x0e\xf6\x01"
  "\x02\xa1\x01\x05\x61\x73\x73\x71\xf7\x01\x04\xef\x01\x02\xf6\x07"
  "\x0c\x81\x83\x02\xf5\x07\x0a\x81\x87\x02\xf4\x07\x08\x81\x87\x02"
  "\xf3\x07\x06\x81\x87\x02\xf2\x07\x04\x84\x06\x0b\x13\xf8\x01\x02"
  "\xa2\x01\x05\x61\x73\x73\x76\xf9\x01\x04\xd6\x01\x04\xef\x01\x03"
  "\xfc\x07\x0e\x81\x87\x02\xfb\x07\x0c\x81\x83\x02\xfa\x07\x0a\x81"
  "\x87\x02\xf9\x07\x08\x81\x87\x02\xf8\x07\x06\x81\x87\x02\xf7\x07"
  "\x04\x84\x06\x0d\x17\xfa\x01\x02\xa3\x01\x06\x61\x73\x73\x6f\x63"
  "\xfb\x01\x08\xd9\x01\x02\x04\xef\x01\x02\x83\x08\x10\x81\x8b\x02"
  "\x82\x08\x0e\x81\x83\x02\x81\x08\x0c\x81\x8b\x02\x80\x08\x0a\x81"
  "\x8b\x02\xff\x07\x08\x81\x8b\x02\xfe\x07\x06\x81\x87\x02\xfd\x07"
  "\x04\x85\x06\x0f\x1a\xfc\x01\x02\xa4\x01\x04\xef\x01\x02\x89\x08"
  "\x0e\x81\x8b\x02\x88\x08\x0c\x81\x83\x02\x87\x08\x0a\x81\x8b\x02"
  "\x86\x08\x08\x81\x8b\x02\x85\x08\x06\x81\x8b\x02\x84\x08\x04\x86"
  "\x0a\x0d\x14\xfd\x01\x02\xa5\x01\x0c\x09\x64\x65\x6c\x2d\x61\x73"
  "\x73\x71\xfe\x01\x04\xef\x01\x02\x9c\x08\x28\x81\x87\x02\x9b\x08"
  "\x26\x81\x87\x02\x9a\x08\x24\x81\x87\x02\x99\x08\x22\x81\x87\x02"
  "\x98\x08\x20\x81\x87\x02\x97\x08\x1e\x81\x85\x02\x96\x08\x1c\x81"
  "\x85\x02\x95\x08\x1a\x81\x85\x02\x94\x08\x18\x81\x85\x02\x93\x08"
  "\x16\x81\x85\x02\x92\x08\x14\x81\x85\x02\x91\x08\x12\x81\x85\x02"
  "\x90\x08\x10\x81\x83\x02\x8f\x08\x0e\x81\x8b\x02\x8e\x08\x0c\x81"
  "\x85\x02\x8d\x08\x0a\x81\x85\x02\x8c\x08\x08\x84\x06\x8b\x08\x06"
  "\x81\x85\x02\x8a\x08\x04\x81\x85\x02\x27\x32\xff\x01\x02\xa6\x01"
  "\x0c\x09\x64\x65\x6c\x2d\x61\x73\x73\x76\x80\x02\x04\xef\x01\x04"
  "\xd6\x01\x03\xb1\x08\x2c\x81\x85\x02\xb0\x08\x2a\x81\x87\x02\xaf"
  "\x08\x28\x81\x87\x02\xae\x08\x26\x81\x85\x02\xad\x08\x24\x81\x85"
  "\x02\xac\x08\x22\x81\x87\x02\xab\x08\x20\x81\x8b\x02\xaa\x08\x1e"
  "\x81\x8b\x02\xa9\x08\x1c\x81\x87\x02\xa8\x08\x1a\x81\x89\x02\xa7"
  "\x08\x18\x81\x89\x02\xa6\x08\x16\x81\x85\x02\xa5\x08\x14\x81\x85"
  "\x02\xa4\x08\x12\x81\x85\x02\xa3\x08\x10\x81\x83\x02\xa2\x08\x0e"
  "\x81\x8b\x02\xa1\x08\x0c\x81\x85\x02\xa0\x08\x0a\x81\x85\x02\x9f"
  "\x08\x08\x84\x06\x9e\x08\x06\x81\x85\x02\x9d\x08\x04\x81\x85\x02"
  "\x2b\x38\x81\x02\x02\xa7\x01\x0c\x0a\x64\x65\x6c\x2d\x61\x73\x73"
  "\x6f\x63\x82\x02\x04\xef\x01\x04\xd9\x01\x03\xc6\x08\x2c\x81\x85"
  "\x02\xc5\x08\x2a\x81\x87\x02\xc4\x08\x28\x81\x87\x02\xc3\x08\x26"
  "\x81\x85\x02\xc2\x08\x24\x81\x85\x02\xc1\x08\x22\x81\x87\x02\xc0"
  "\x08\x20\x81\x8b\x02\xbf\x08\x1e\x81\x8b\x02\xbe\x08\x1c\x81\x87"
  "\x02\xbd\x08\x1a\x81\x89\x02\xbc\x08\x18\x81\x89\x02\xbb\x08\x16"
  "\x81\x85\x02\xba\x08\x14\x81\x85\x02\xb9\x08\x12\x81\x85\x02\xb8"
  "\x08\x10\x81\x83\x02\xb7\x08\x0e\x81\x8b\x02\xb6\x08\x0c\x81\x85"
  "\x02\xb5\x08\x0a\x81\x85\x02\xb4\x08\x08\x84\x06\xb3\x08\x06\x81"
  "\x85\x02\xb2\x08\x04\x81\x85\x02\x2b\x38\x83\x02\x02\xa8\x01\x0c"
  "\x0d\x61\x6c\x69\x73\x74\x2d\x64\x65\x6c\x65\x74\x65\x84\x02\x08"
  "\xd9\x01\x02\x04\xef\x01\x02\xdc\x08\x2e\x81\x85\x02\xdb\x08\x2c"
  "\x81\x87\x02\xda\x08\x2a\x81\x87\x02\xd9\x08\x28\x81\x85\x02\xd8"
  "\x08\x26\x81\x85\x02\xd7\x08\x24\x81\x8b\x02\xd6\x08\x22\x81\x8f"
  "\x02\xd5\x08\x20\x81\x8f\x02\xd4\x08\x1e\x81\x8b\x02\xd3\x08\x1c"
  "\x81\x89\x02\xd2\x08\x1a\x81\x89\x02\xd1\x08\x18\x81\x85\x02\xd0"
  "\x08\x16\x81\x85\x02\xcf\x08\x14\x81\x85\x02\xce\x08\x12\x81\x83"
  "\x02\xcd\x08\x10\x81\x8f\x02\xcc\x08\x0e\x81\x89\x02\xcb\x08\x0c"
  "\x81\x89\x02\xca\x08\x0a\x81\x87\x02\xc9\x08\x08\x85\x06\xc8\x08"
  "\x06\x81\x89\x02\xc7\x08\x04\x81\x89\x02\x2d\x3b\x85\x02\x02\xa9"
  "\x01\x0c\x04\xef\x01\x02\xf1\x08\x2c\x81\x85\x02\xf0\x08\x2a\x81"
  "\x87\x02\xef\x08\x28\x81\x87\x02\xee\x08\x26\x81\x85\x02\xed\x08"
  "\x24\x81\x85\x02\xec\x08\x22\x81\x8b\x02\xeb\x08\x20\x81\x8f\x02"
  "\xea\x08\x1e\x81\x8f\x02\xe9\x08\x1c\x81\x8b\x02\xe8\x08\x1a\x81"
  "\x89\x02\xe7\x08\x18\x81\x89\x02\xe6\x08\x16\x81\x85\x02\xe5\x08"
  "\x14\x81\x85\x02\xe4\x08\x12\x81\x85\x02\xe3\x08\x10\x81\x83\x02"
  "\xe2\x08\x0e\x81\x8f\x02\xe1\x08\x0c\x81\x89\x02\xe0\x08\x0a\x81"
  "\x89\x02\xdf\x08\x08\x86\x0a\xde\x08\x06\x81\x89\x02\xdd\x08\x04"
  "\x81\x89\x02\x2b\x35\x86\x02\x02\xaa\x01\x0c\x0a\x64\x65\x6c\x2d"
  "\x61\x73\x73\x71\x21\x87\x02\x04\xef\x01\x02\x84\x09\x28\xfd\xff"
  "\x03\x83\x09\x26\x81\x85\x02\x82\x09\x24\x81\x89\x02\x81\x09\x22"
  "\x81\x85\x02\x80\x09\x20\x81\x85\x02\xff\x08\x1e\x81\x85\x02\xfe"
  "\x08\x1c\x81\x85\x02\xfd\x08\x1a\x81\x85\x02\xfc\x08\x18\x81\x85"
  "\x02\xfb\x08\x16\x81\x83\x02\xfa\x08\x14\xfd\xff\x03\xf9\x08\x12"
  "\xfd\xff\x03\xf8\x08\x10\xfd\xff\x03\xf7\x08\x0e\xfd\xff\x03\xf6"
  "\x08\x0c\xfd\xff\x03\xf5\x08\x0a\xff\xff\x03\xf4\x08\x08\xfd\xff"
  "\x03\xf3\x08\x06\xfd\xff\x03\xf2\x08\x04\x84\x06\x27\x32\x88\x02"
  "\x02\xab\x01\x0c\x0a\x64\x65\x6c\x2d\x61\x73\x73\x76\x21\x89\x02"
  "\x04\xd6\x01\x04\xef\x01\x03\x99\x09\x2c\x81\x89\x02\x98\x09\x2a"
  "\x81\x85\x02\x97\x09\x28\x81\x85\x02\x96\x09\x26\xfd\xff\x03\x95"
  "\x09\x24\x81\x89\x02\x94\x09\x22\x81\x89\x02\x93\x09\x20\x81\x85"
  "\x02\x92\x09\x1e\x81\x85\x02\x91\x09\x1c\x81\x85\x02\x90\x09\x1a"
  "\x81\x85\x02\x8f\x09\x18\xfd\xff\x03\x8e\x09\x16\xfd\xff\x03\x8d"
  "\x09\x14\xfd\xff\x03\x8c\x09\x12\x81\x83\x02\x8b\x09\x10\xfd\xff"
  "\x03\x8a\x09\x0e\xfd\xff\x03\x89\x09\x0c\xfd\xff\x03\x88\x09\x0a"
  "\xff\xff\x03\x87\x09\x08\xfd\xff\x03\x86\x09\x06\xfd\xff\x03\x85"
  "\x09\x04\x84\x06\x2b\x38\xd6\x01\x02\xac\x01\x0c\x0b\x64\x65\x6c"
  "\x2d\x61\x73\x73\x6f\x63\x21\x8a\x02\x04\xd9\x01\x04\xef\x01\x03"
  "\xae\x09\x2c\x81\x89\x02\xad\x09\x2a\x81\x85\x02\xac\x09\x28\x81"
  "\x85\x02\xab\x09\x26\xfd\xff\x03\xaa\x09\x24\x81\x89\x02\xa9\x09"
  "\x22\x81\x89\x02\xa8\x09\x20\x81\x85\x02\xa7\x09\x1e\x81\x85\x02"
  "\xa6\x09\x1c\x81\x85\x02\xa5\x09\x1a\x81\x85\x02\xa4\x09\x18\xfd"
  "\xff\x03\xa3\x09\x16\xfd\xff\x03\xa2\x09\x14\xfd\xff\x03\xa1\x09"
  "\x12\x81\x83\x02\xa0\x09\x10\xfd\xff\x03\x9f\x09\x0e\xfd\xff\x03"
  "\x9e\x09\x0c\xfd\xff\x03\x9d\x09\x0a\xff\xff\x03\x9c\x09\x08\xfd"
  "\xff\x03\x9b\x09\x06\xfd\xff\x03\x9a\x09\x04\x84\x06\x2b\x38\x8b"
  "\x02\x02\xad\x01\x0c\x0e\x61\x6c\x69\x73\x74\x2d\x64\x65\x6c\x65"
  "\x74\x65\x21\x8c\x02\x08\xd9\x01\x02\x04\xef\x01\x02\xc4\x09\x2e"
  "\x81\x89\x02\xc3\x09\x2c\x81\x85\x02\xc2\x09\x2a\x81\x85\x02\xc1"
  "\x09\x28\xfd\xff\x03\xc0\x09\x26\x81\x89\x02\xbf\x09\x24\x81\x89"
  "\x02\xbe\x09\x22\x81\x85\x02\xbd\x09\x20\x81\x85\x02\xbc\x09\x1e"
  "\x81\x85\x02\xbb\x09\x1c\x81\x85\x02\xba\x09\x1a\xfd\xff\x03\xb9"
  "\x09\x18\xfd\xff\x03\xb8\x09\x16\xfd\xff\x03\xb7\x09\x14\x81\x83"
  "\x02\xb6\x09\x12\xfd\xff\x03\xb5\x09\x10\xfd\xff\x03\xb4\x09\x0e"
  "\xfd\xff\x03\xb3\x09\x0c\xff\xff\x03\xb2\x09\x0a\xfd\xff\x03\xb1"
  "\x09\x08\xfd\xff\x03\xb0\x09\x06\x81\x87\x02\xaf\x09\x04\x85\x06"
  "\x2d\x3b\xd9\x01\x02\xae\x01\x0c\x04\xef\x01\x02\xd9\x09\x2c\x81"
  "\x89\x02\xd8\x09\x2a\x81\x85\x02\xd7\x09\x28\x81\x85\x02\xd6\x09"
  "\x26\xfd\xff\x03\xd5\x09\x24\x81\x89\x02\xd4\x09\x22\x81\x89\x02"
  "\xd3\x09\x20\x81\x85\x02\xd2\x09\x1e\x81\x85\x02\xd1\x09\x1c\x81"
  "\x85\x02\xd0\x09\x1a\x81\x85\x02\xcf\x09\x18\xfd\xff\x03\xce\x09"
  "\x16\xfd\xff\x03\xcd\x09\x14\xfd\xff\x03\xcc\x09\x12\x81\x83\x02"
  "\xcb\x09\x10\xfd\xff\x03\xca\x09\x0e\xfd\xff\x03\xc9\x09\x0c\xfd"
  "\xff\x03\xc8\x09\x0a\xff\xff\x03\xc7\x09\x08\xfd\xff\x03\xc6\x09"
  "\x06\xfd\xff\x03\xc5\x09\x04\x86\x0a\x2b\x35\x8d\x02\x02\xaf\x01"
  "\x50\x1e\xe3\x09\x16\x81\x85\x02\xe2\x09\x14\x81\x85\x02\xe1\x09"
  "\x12\x81\x85\x02\xe0\x09\x10\x81\x85\x02\xdf\x09\x0e\x81\x85\x02"
  "\xde\x09\x0c\x81\x83\x02\xdd\x09\x0a\x81\x87\x02\xdc\x09\x08\x81"
  "\x85\x02\xdb\x09\x06\x81\x85\x02\xda\x09\x04\x83\x04\x15\x20\x8e"
  "\x02\x02\xb0\x01\x02\x03\x0e\x6b\x65\x79\x77\x6f\x72\x64\x2d\x6c"
  "\x69\x73\x74\x3f\x8f\x02\x04\x17\x65\x72\x72\x6f\x72\x3a\x6e\x6f"
  "\x74\x2d\x6b\x65\x79\x77\x6f\x72\x64\x2d\x6c\x69\x73\x74\x90\x02"
  "\x03\xe5\x09\x06\x81\x85\x02\xe4\x09\x04\x84\x04\x05\x0e\x91\x02"
  "\x02\xb1\x01\x08\x0d\x6b\x65\x79\x77\x6f\x72\x64\x20\x6c\x69\x73"
  "\x74\x05\x20\x02\xe6\x09\x04\x84\x04\x03\x0c\x92\x02\x02\xb2\x01"
  "\x04\xd3\x01\x02\xef\x09\x14\x81\x89\x02\xee\x09\x12\x81\x89\x02"
  "\xed\x09\x10\x81\x89\x02\xec\x09\x0e\x81\x89\x02\xeb\x09\x0c\x81"
  "\x89\x02\xea\x09\x0a\x81\x89\x02\xe9\x09\x08\x81\x8d\x02\xe8\x09"
  "\x06\x81\x89\x02\xe7\x09\x04\x84\x06\x13\x1d\x93\x02\x02\xb3\x01"
  "\x02\x04\x19\x72\x65\x73\x74\x72\x69\x63\x74\x65\x64\x2d\x6b\x65"
  "\x79\x77\x6f\x72\x64\x2d\x6c\x69\x73\x74\x3f\x94\x02\x04\x22\x65"
  "\x72\x72\x6f\x72\x3a\x6e\x6f\x74\x2d\x72\x65\x73\x74\x72\x69\x63"
  "\x74\x65\x64\x2d\x6b\x65\x79\x77\x6f\x72\x64\x2d\x6c\x69\x73\x74"
  "\x95\x02\x03\xf1\x09\x06\x81\x87\x02\xf0\x09\x04\x85\x06\x05\x0e"
  "\x96\x02\x02\xb4\x01\x08\x18\x72\x65\x73\x74\x72\x69\x63\x74\x65"
  "\x64\x20\x6b\x65\x79\x77\x6f\x72\x64\x20\x6c\x69\x73\x74\x05\x20"
  "\x02\xf2\x09\x04\x84\x04\x03\x0c\x97\x02\x02\xb5\x01\x50\x1e\x04"
  "\xd3\x01\x02\xff\x09\x1c\x81\x87\x02\xfe\x09\x1a\x81\x87\x02\xfd"
  "\x09\x18\x81\x87\x02\xfc\x09\x16\x81\x87\x02\xfb\x09\x14\x81\x87"
  "\x02\xfa\x09\x12\x81\x87\x02\xf9\x09\x10\x81\x87\x02\xf8\x09\x0e"
  "\x81\x8b\x02\xf7\x09\x0c\x81\x83\x02\xf6\x09\x0a\x81\x89\x02\xf5"
  "\x09\x08\x81\x87\x02\xf4\x09\x06\x81\x87\x02\xf3\x09\x04\x83\x04"
  "\x1b\x29\x50\x02\xb6\x01\x02\x03\x15\x75\x6e\x69\x71\x75\x65\x2d"
  "\x6b\x65\x79\x77\x6f\x72\x64\x2d\x6c\x69\x73\x74\x3f\x98\x02\x04"
  "\x1e\x65\x72\x72\x6f\x72\x3a\x6e\x6f\x74\x2d\x75\x6e\x69\x71\x75"
  "\x65\x2d\x6b\x65\x79\x77\x6f\x72\x64\x2d\x6c\x69\x73\x74\x99\x02"
  "\x03\x81\x0a\x06\x81\x85\x02\x80\x0a\x04\x84\x04\x05\x0e\x9a\x02"
  "\x02\xb7\x01\x08\x14\x75\x6e\x69\x71\x75\x65\x20\x6b\x65\x79\x77"
  "\x6f\x72\x64\x20\x6c\x69\x73\x74\x05\x20\x02\x82\x0a\x04\x84\x04"
  "\x03\x0c\x20\x02\xb8\x01\x12\x67\x65\x74\x2d\x6b\x65\x79\x77\x6f"
  "\x72\x64\x2d\x76\x61\x6c\x75\x65\x9b\x02\x08\x04\x90\x02\x02\x8c"
  "\x0a\x16\x81\x83\x02\x8b\x0a\x14\x81\x87\x02\x8a\x0a\x12\x81\x87"
  "\x02\x89\x0a\x10\x81\x87\x02\x88\x0a\x0e\x81\x87\x02\x87\x0a\x0c"
  "\x81\x87\x02\x86\x0a\x0a\x81\x87\x02\x85\x0a\x08\x81\x87\x02\x84"
  "\x0a\x06\x81\x87\x02\x83\x0a\x04\x84\x06\x15\x20\x9c\x02\x02\xb9"
  "\x01\x94\x0a\x12\x81\x87\x02\x93\x0a\x10\x81\x85\x02\x92\x0a\x0e"
  "\x81\x85\x02\x91\x0a\x0c\x81\x83\x02\x90\x0a\x0a\x81\x85\x02\x8f"
  "\x0a\x08\x81\x85\x02\x8e\x0a\x06\x81\x83\x02\x8d\x0a\x04\x83\x04"
  "\x11\x17\x9d\x02\x02\xba\x01\x9c\x0a\x12\x81\x85\x02\x9b\x0a\x10"
  "\x81\x85\x02\x9a\x0a\x0e\x81\x85\x02\x99\x0a\x0c\x81\x85\x02\x98"
  "\x0a\x0a\x81\x83\x02\x97\x0a\x08\x81\x85\x02\x96\x0a\x06\x81\x83"
  "\x02\x95\x0a\x04\x83\x04\x11\x17\x9e\x02\x02\xbb\x01\x03\x9a\x01"
  "\x02\x9e\x0a\x06\x81\x83\x02\x9d\x0a\x04\x83\x04\x05\x0c\x9f\x02"
  "\x02\xbc\x01\x9a\x01\x04\x0f\x67\x75\x61\x72\x61\x6e\x74\x65\x65"
  "\x2d\x70\x61\x69\x72\xa0\x02\x02\xa3\x0a\x0c\x81\x83\x02\xa2\x0a"
  "\x0a\x81\x83\x02\xa1\x0a\x08\x81\x83\x02\xa0\x0a\x06\x81\x83\x02"
  "\x9f\x0a\x04\x83\x04\x0b\x13\xa1\x02\x02\xbd\x01\x0c\x11\x65\x78"
  "\x63\x65\x70\x74\x2d\x6c\x61\x73\x74\x2d\x70\x61\x69\x72\x04\xa0"
  "\x02\x02\xad\x0a\x16\x81\x8b\x02\xac\x0a\x14\x81\x8b\x02\xab\x0a"
  "\x12\x81\x89\x02\xaa\x0a\x10\x81\x89\x02\xa9\x0a\x0e\x81\x89\x02"
  "\xa8\x0a\x0c\x81\x87\x02\xa7\x0a\x0a\x81\x83\x02\xa6\x0a\x08\x81"
  "\x83\x02\xa5\x0a\x06\x81\x83\x02\xa4\x0a\x04\x83\x04\x15\x20\xa2"
  "\x02\x02\xbe\x01\x0c\x12\x65\x78\x63\x65\x70\x74\x2d\x6c\x61\x73"
  "\x74\x2d\x70\x61\x69\x72\x21\x0c\x04\xa0\x02\x02\xb5\x0a\x12\x81"
  "\x83\x02\xb4\x0a\x10\x81\x83\x02\xb3\x0a\x0e\x81\x83\x02\xb2\x0a"
  "\x0c\x81\x83\x02\xb1\x0a\x0a\x81\x83\x02\xb0\x0a\x08\x81\x83\x02"
  "\xaf\x0a\x06\x81\x83\x02\xae\x0a\x04\x83\x04\x11\x1b\xbe\x01\x04"
  "\xa2\x02\x04\xa1\x02\x04\x9f\x02\x04\x9e\x02\x04\x9d\x02\x04\x9c"
  "\x02\x04\x20\x04\x9a\x02\x04\x50\x04\x97\x02\x04\x96\x02\x04\x93"
  "\x02\x04\x92\x02\x04\x91\x02\x04\x8e\x02\x04\x8d\x02\x04\xd9\x01"
  "\x04\x8b\x02\x04\xd6\x01\x04\x88\x02\x04\x86\x02\x08\x85\x02\x08"
  "\x83\x02\x08\x81\x02\x08\xff\x01\x08\xfd\x01\x04\xfc\x01\x04\xfa"
  "\x01\x04\xf8\x01\x04\xf6\x01\x04\xf5\x01\x04\xf4\x01\x04\xf2\x01"
  "\x04\xf1\x01\x04\xf0\x01\x04\xed\x01\x04\xeb\x01\x04\xea\x01\x04"
  "\xe8\x01\x04\xe6\x01\x04\xe4\x01\x06\xe3\x01\x06\xe1\x01\x06\xe0"
  "\x01\x06\xde\x01\x04\xdd\x01\x04\xdc\x01\x04\xdb\x01\x04\xda\x01"
  "\x04\xd7\x01\x04\xd4\x01\x04\xd2\x01\x04\xd1\x01\x04\xd0\x01\x04"
  "\xce\x01\x04\xcc\x01\x04\xca\x01\x04\xc8\x01\x04\xc6\x01\x04\xc4"
  "\x01\x04\xc2\x01\x04\xc0\x01\x04\xbf\x01\x04\xbd\x01\x04\xbc\x01"
  "\x04\xba\x01\x04\xb9\x01\x04\xb7\x01\x06\xb5\x01\x04\xb4\x01\x06"
  "\x48\x0c\x9a\x01\x05\x6c\x61\x73\x74\x14\x61\x6c\x69\x73\x74\x2d"
  "\x3e\x6b\x65\x79\x77\x6f\x72\x64\x2d\x6c\x69\x73\x74\x14\x6b\x65"
  "\x79\x77\x6f\x72\x64\x2d\x6c\x69\x73\x74\x2d\x3e\x61\x6c\x69\x73"
  "\x74\x9b\x02\x99\x02\x1e\x67\x75\x61\x72\x61\x6e\x74\x65\x65\x2d"
  "\x75\x6e\x69\x71\x75\x65\x2d\x6b\x65\x79\x77\x6f\x72\x64\x2d\x6c"
  "\x69\x73\x74\x98\x02\x95\x02\x22\x67\x75\x61\x72\x61\x6e\x74\x65"
  "\x65\x2d\x72\x65\x73\x74\x72\x69\x63\x74\x65\x64\x2d\x6b\x65\x79"
  "\x77\x6f\x72\x64\x2d\x6c\x69\x73\x74\x94\x02\x90\x02\x17\x67\x75"
  "\x61\x72\x61\x6e\x74\x65\x65\x2d\x6b\x65\x79\x77\x6f\x72\x64\x2d"
  "\x6c\x69\x73\x74\x8f\x02\x0f\x25\x61\x6c\x69\x73\x74\x2d\x64\x65"
  "\x6c\x65\x74\x65\x21\x8c\x02\x8a\x02\x89\x02\x87\x02\x0e\x25\x61"
  "\x6c\x69\x73\x74\x2d\x64\x65\x6c\x65\x74\x65\x84\x02\x82\x02\x80"
  "\x02\xfe\x01\x07\x25\x61\x73\x73\x6f\x63\xfb\x01\xf9\x01\xf7\x01"
  "\x1d\x64\x65\x6c\x65\x74\x65\x2d\x61\x73\x73\x6f\x63\x69\x61\x74"
  "\x69\x6f\x6e\x2d\x70\x72\x6f\x63\x65\x64\x75\x72\x65\x16\x61\x73"
  "\x73\x6f\x63\x69\x61\x74\x69\x6f\x6e\x2d\x70\x72\x6f\x63\x65\x64"
  "\x75\x72\x65\xf3\x01\x0b\x61\x6c\x69\x73\x74\x2d\x63\x6f\x6e\x73"
  "\xef\x01\x10\x67\x75\x61\x72\x61\x6e\x74\x65\x65\x2d\x61\x6c\x69"
  "\x73\x74\xee\x01\x09\x25\x64\x65\x6c\x65\x74\x65\x21\xe9\x01\xe7"
  "\x01\xe5\x01\x08\x25\x64\x65\x6c\x65\x74\x65\xe2\x01\x05\x64\x65"
  "\x6c\x76\xdf\x01\x18\x64\x65\x6c\x65\x74\x65\x2d\x6d\x65\x6d\x62"
  "\x65\x72\x2d\x70\x72\x6f\x63\x65\x64\x75\x72\x65\x08\x25\x6d\x65"
  "\x6d\x62\x65\x72\x15\x61\x64\x64\x2d\x6d\x65\x6d\x62\x65\x72\x2d"
  "\x70\x72\x6f\x63\x65\x64\x75\x72\x65\x11\x6d\x65\x6d\x62\x65\x72"
  "\x2d\x70\x72\x6f\x63\x65\x64\x75\x72\x65\xd8\x01\xd5\x01\xd3\x01"
  "\x0e\x6c\x69\x73\x74\x2d\x64\x65\x6c\x65\x74\x6f\x72\x21\x0d\x6c"
  "\x69\x73\x74\x2d\x64\x65\x6c\x65\x74\x6f\x72\xcf\x01\xcd\x01\xcb"
  "\x01\xc9\x01\xc7\x01\xc5\x01\xc3\x01\xc1\x01\x17\x66\x69\x6e\x64"
  "\x2d\x6e\x6f\x6e\x2d\x6d\x61\x74\x63\x68\x69\x6e\x67\x2d\x69\x74"
  "\x65\x6d\xbe\x01\xa2\x01\xbb\x01\xb3\x01\xb8\x01\xb6\x01\x0c\x72"
  "\x65\x64\x75\x63\x65\x2d\x6c\x65\x66\x74\xb2\x01\x48\xb0\x01\xb1"
  "\x01\x04\xae\x01\xaf\x01\x04\xac\x01\xad\x01\x04\xaa\x01\xab\x01"
  "\x04\xa8\x01\xa9\x01\x04\x13\x6c\x65\x78\x69\x63\x61\x6c\x2d\x61"
  "\x73\x73\x69\x67\x6e\x6d\x65\x6e\x74\x3f\xa7\x01\x04\xb0\x01\xae"
  "\x01\xac\x01\xaa\x01\xa8\x01\x3f\xa4\x01\xa3\x01\x9e\x01\x9c\x01"
  "\x58\x4d\x95\x01\x93\x01\x99\x01\x97\x01\x06\x74\x65\x6e\x74\x68"
  "\x06\x6e\x69\x6e\x74\x68\x07\x65\x69\x67\x68\x74\x68\x08\x73\x65"
  "\x76\x65\x6e\x74\x68\x06\x73\x69\x78\x74\x68\x06\x66\x69\x66\x74"
  "\x68\x07\x66\x6f\x75\x72\x74\x68\x06\x74\x68\x69\x72\x64\x07\x73"
  "\x65\x63\x6f\x6e\x64\x06\x66\x69\x72\x73\x74\x07\x63\x64\x64\x64"
  "\x64\x72\x07\x63\x64\x64\x64\x61\x72\x07\x63\x64\x64\x61\x64\x72"
  "\x07\x63\x64\x64\x61\x61\x72\x07\x63\x64\x61\x64\x64\x72\x07\x63"
  "\x64\x61\x64\x61\x72\x07\x63\x64\x61\x61\x64\x72\x07\x63\x64\x61"
  "\x61\x61\x72\x07\x63\x61\x64\x64\x64\x72\x07\x63\x61\x64\x64\x61"
  "\x72\x07\x63\x61\x64\x61\x64\x72\x07\x63\x61\x64\x61\x61\x72\x07"
  "\x63\x61\x61\x64\x64\x72\x07\x63\x61\x61\x64\x61\x72\x07\x63\x61"
  "\x61\x61\x64\x72\x07\x63\x61\x61\x61\x61\x72\x06\x63\x64\x64\x64"
  "\x72\x06\x63\x64\x64\x61\x72\x06\x63\x64\x61\x64\x72\x06\x63\x64"
  "\x61\x61\x72\x06\x63\x61\x64\x64\x72\x06\x63\x61\x64\x61\x72\x06"
  "\x63\x61\x61\x64\x72\x06\x63\x61\x61\x61\x72\x05\x63\x64\x64\x72"
  "\x05\x63\x64\x61\x72\x05\x63\x61\x64\x72\x05\x63\x61\x61\x72\x6b"
  "\x69\x17\x65\x6e\x63\x6f\x64\x65\x2d\x67\x65\x6e\x65\x72\x61\x6c"
  "\x2d\x63\x61\x72\x2d\x63\x64\x72\x17\x64\x65\x63\x6f\x64\x65\x2d"
  "\x67\x65\x6e\x65\x72\x61\x6c\x2d\x63\x61\x72\x2d\x63\x64\x72\x63"
  "\x61\x59\x14\x67\x75\x61\x72\x61\x6e\x74\x65\x65\x2d\x77\x65\x61"
  "\x6b\x2d\x6c\x69\x73\x74\x5e\x4e\x5b\x57\x0e\x77\x65\x61\x6b\x2d"
  "\x73\x65\x74\x2d\x63\x64\x72\x21\x09\x77\x65\x61\x6b\x2d\x63\x64"
  "\x72\x0e\x77\x65\x61\x6b\x2d\x73\x65\x74\x2d\x63\x61\x72\x21\x09"
  "\x77\x65\x61\x6b\x2d\x63\x61\x72\x0f\x77\x65\x61\x6b\x2d\x70\x61"
  "\x69\x72\x2f\x63\x61\x72\x3f\x0b\x77\x65\x61\x6b\x2d\x70\x61\x69"
  "\x72\x3f\x0a\x77\x65\x61\x6b\x2d\x63\x6f\x6e\x73\x08\x63\x61\x72"
  "\x2b\x63\x64\x72\x0a\x74\x72\x65\x65\x2d\x63\x6f\x70\x79\x49\x08"
  "\x73\x75\x62\x6c\x69\x73\x74\x48\x43\x46\x42\x3e\x0b\x6e\x75\x6c"
  "\x6c\x2d\x6c\x69\x73\x74\x3f\x0a\x6e\x6f\x74\x2d\x70\x61\x69\x72"
  "\x3f\x3a\x37\x1f\x67\x75\x61\x72\x61\x6e\x74\x65\x65\x2d\x6c\x69"
  "\x73\x74\x2d\x6f\x66\x2d\x74\x79\x70\x65\x2d\x3e\x6c\x65\x6e\x67"
  "\x74\x68\x38\x35\x33\x17\x67\x75\x61\x72\x61\x6e\x74\x65\x65\x2d"
  "\x6c\x69\x73\x74\x2d\x6f\x66\x2d\x74\x79\x70\x65\x2f\x2b\x18\x67"
  "\x75\x61\x72\x61\x6e\x74\x65\x65\x2d\x63\x69\x72\x63\x75\x6c\x61"
  "\x72\x2d\x6c\x69\x73\x74\x27\x16\x67\x75\x61\x72\x61\x6e\x74\x65"
  "\x65\x2d\x64\x6f\x74\x74\x65\x64\x2d\x6c\x69\x73\x74\x23\x40\x1e"
  "\xa0\x02\x2a\x26\x22\x19\x06\x78\x63\x6f\x6e\x73\x16\x14\x0e\x63"
  "\x69\x72\x63\x75\x6c\x61\x72\x2d\x6c\x69\x73\x74\x10\x06\x63\x6f"
  "\x6e\x73\x2a\x05\x6c\x69\x73\x74\x09\x73\x65\x74\x2d\x63\x64\x72"
  "\x21\x09\x73\x65\x74\x2d\x63\x61\x72\x21\xec\x01\x06\x6e\x75\x6c"
  "\x6c\x3f\x10\x67\x65\x6e\x65\x72\x61\x6c\x2d\x63\x61\x72\x2d\x63"
  "\x64\x72\x05\x63\x6f\x6e\x73\x65\x66\x78\xa6\x01\x04\xa5\x01\x08"
  "\xa1\x01\x04\xa0\x01\x04\x9f\x01\x04\x9d\x01\x04\x9b\x01\x04\x98"
  "\x01\x04\x96\x01\x04\x94\x01\x04\x92\x01\x16\x91\x01\x14\x90\x01"
  "\x12\x8f\x01\x10\x8e\x01\x0e\x8d\x01\x0c\x8c\x01\x0a\x8b\x01\x08"
  "\x8a\x01\x06\x89\x01\x04\x88\x01\x0a\x87\x01\x0a\x86\x01\x0a\x85"
  "\x01\x0a\x84\x01\x0a\x83\x01\x0a\x82\x01\x0a\x81\x01\x0a\x80\x01"
  "\x0a\x7f\x0a\x7e\x0a\x7d\x0a\x7c\x0a\x7b\x0a\x7a\x0a\x79\x0a\x78"
  "\x08\x77\x08\x76\x08\x75\x08\x74\x08\x73\x08\x72\x08\x71\x08\x70"
  "\x06\x6f\x06\x6e\x06\x6d\x06\x6c\x04\x6a\x04\x68\x04\x67\x04\x64"
  "\x04\x62\x04\x60\x04\x5f\x04\x5d\x04\x10\x77\x65\x61\x6b\x2d\x70"
  "\x61\x69\x72\x2f\x66\x61\x6c\x73\x65\x5c\x04\x5a\x04\x56\x04\x55"
  "\x04\x54\x04\x53\x04\x52\x04\x51\x04\x4f\x04\x4c\x04\x4b\x04\x4a"
  "\x04\x11\x04\x44\x04\x47\x04\x0a\x04\x45\x04\x41\x04\x3d\x04\x3c"
  "\x04\x3b\x04\x39\x04\x36\x04\x34\x04\x32\x04\x31\x04\x30\x04\x2e"
  "\x04\x2d\x04\x2c\x04\x29\x04\x28\x04\x25\x04\x24\x04\x21\x04\x1f"
  "\x04\x1d\x04\x1c\x04\x1b\x04\x1a\x04\x18\x04\x17\x04\x15\x04\x13"
  "\x0c\x12\x04\x0f\x04\x0e\x04\x0d\x04\x0b\x04\x09\x04\x04\x04\x04"
  "\x04\x04\x78\x05\x10\x64\x65\x66\x69\x6e\x65\x2d\x6d\x75\x6c\x74"
  "\x69\x70\x6c\x65\x02\x0a\x16\x80\x80\x04\x09\x14\x81\x81\x02\x08"
  "\x12\x81\x81\x02\x07\x10\x81\x83\x02\x06\x0e\x81\x83\x02\x05\x0c"
  "\x81\x83\x02\x04\x0a\x81\x83\x02\x03\x08\x81\x83\x02\x02\x06\x81"
  "\x83\x02\x01\x04\x81\x83\x02\x15\x2e";

SCHEME_OBJECT *
list_so_data_b71618dfe622bc09 (entry_count_t dispatch_base)
{
  SCHEME_OBJECT ccb;
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES_FOR_DATA ();

  ccb = (unstackify (((unsigned char *) (& (prog_list_so_data_b71618dfe622bc09 [0]))), (sizeof (prog_list_so_data_b71618dfe622bc09)), dispatch_base));
  current_block = (OBJECT_ADDRESS (ccb));
  return (& (current_block [LABEL_14]));
}

DECLARE_COMPILED_DATA_NS ("list.so", list_so_data_b71618dfe622bc09)

#endif /* !WANT_ONLY_CODE */

DECLARE_DYNAMIC_INITIALIZATION ("list.so", "b4efe3b72af527ce")
