/* Emacs: this is -*- C -*- code, */
/* generated 2011-11-08T22:50:38-08 by Liar version 4.118. */

#include "liarc.h"

#define LABEL_1_4 3
#define LABEL_1_5 5
#define TAG_1_6 1
#define LABEL_1_7 7
#define TAG_1_8 2
#define LABEL_1_9 9
#define TAG_1_10 3
#define LABEL_1_18 11
#define LABEL_1_11 13
#define LABEL_1_12 15
#define LABEL_1_21 17
#define LABEL_1_14 19
#define TAG_1_15 8
#define LABEL_1_16 21
#define TAG_1_17 9
#define LABEL_1_19 23
#define TAG_1_20 10
#define LABEL_1_30 25
#define LABEL_1_31 27
#define LABEL_1_22 29
#define TAG_1_23 13
#define LABEL_1_24 31
#define TAG_1_25 14
#define LABEL_1_26 33
#define TAG_1_27 15
#define LABEL_1_28 35
#define TAG_1_29 16
#define LABEL_1_32 37
#define TAG_1_33 17
#define LABEL_1_39 39
#define LABEL_1_44 41
#define LABEL_1_34 43
#define TAG_1_35 20
#define LABEL_1_37 45
#define TAG_1_38 21
#define LABEL_1_40 47
#define TAG_1_41 22
#define LABEL_1_42 49
#define TAG_1_43 23
#define LABEL_1_47 51
#define LABEL_1_45 53
#define TAG_1_46 25
#define LABEL_1_48 55
#define TAG_1_49 26
#define LABEL_1_50 57
#define TAG_1_51 27
#define ENVIRONMENT_LABEL_1_3 72
#define DEBUGGING_LABEL_1_2 71
#define OBJECT_1_5 70
#define OBJECT_1_4 69
#define OBJECT_1_3 68
#define OBJECT_1_2 67
#define OBJECT_1_1 66
#define OBJECT_1_0 65
#define EXECUTE_CACHE_1_36 59
#define EXECUTE_CACHE_1_13 61
#define FREE_REFERENCE_1_0 64
#define FREE_REFERENCES_LABEL_1_0 58
#define NUMBER_OF_LINKER_SECTIONS_1_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_1 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd30;
  machine_word Wrd67;
  machine_word Wrd59;
  machine_word Wrd61;
  machine_word Wrd63;
  machine_word Wrd56;
  machine_word Wrd58;
  machine_word Wrd57;
  machine_word Wrd51;
  machine_word Wrd52;
  machine_word Wrd42;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd25;
  machine_word Wrd27;
  machine_word Wrd50;
  machine_word Wrd49;
  machine_word Wrd41;
  machine_word Wrd43;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd37;
  machine_word Wrd29;
  machine_word Wrd31;
  machine_word Wrd26;
  machine_word Wrd24;
  machine_word Wrd15;
  machine_word Wrd35;
  machine_word Wrd32;
  machine_word Wrd23;
  machine_word Wrd17;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd16;
  machine_word Wrd18;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd11;
  machine_word Wrd12;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_1_4);
      goto lp_comma_list_47;

    case 1:
      current_block = (Rpc - LABEL_1_5);
      goto lambda_57;

    case 2:
      current_block = (Rpc - LABEL_1_7);
      goto lambda_58;

    case 3:
      current_block = (Rpc - LABEL_1_9);
      goto lambda_59;

    case 4:
      current_block = (Rpc - LABEL_1_18);
      goto lambda_13;

    case 5:
      current_block = (Rpc - LABEL_1_11);
      goto continuation_15;

    case 6:
      current_block = (Rpc - LABEL_1_12);
      goto continuation_14;

    case 7:
      current_block = (Rpc - LABEL_1_21);
      goto label_49;

    case 8:
      current_block = (Rpc - LABEL_1_14);
      goto lambda_60;

    case 9:
      current_block = (Rpc - LABEL_1_16);
      goto lambda_61;

    case 10:
      current_block = (Rpc - LABEL_1_19);
      goto loop_0_11;

    case 11:
      current_block = (Rpc - LABEL_1_30);
      goto label_50;

    case 12:
      current_block = (Rpc - LABEL_1_31);
      goto label_51;

    case 13:
      current_block = (Rpc - LABEL_1_22);
      goto lambda_64;

    case 14:
      current_block = (Rpc - LABEL_1_24);
      goto lambda_65;

    case 15:
      current_block = (Rpc - LABEL_1_26);
      goto lambda_66;

    case 16:
      current_block = (Rpc - LABEL_1_28);
      goto lambda_67;

    case 17:
      current_block = (Rpc - LABEL_1_32);
      goto loop_0_37;

    case 18:
      current_block = (Rpc - LABEL_1_39);
      goto label_52;

    case 19:
      current_block = (Rpc - LABEL_1_44);
      goto label_53;

    case 20:
      current_block = (Rpc - LABEL_1_34);
      goto lambda_69;

    case 21:
      current_block = (Rpc - LABEL_1_37);
      goto lambda_21;

    case 22:
      current_block = (Rpc - LABEL_1_40);
      goto lambda_71;

    case 23:
      current_block = (Rpc - LABEL_1_42);
      goto lambda_72;

    case 24:
      current_block = (Rpc - LABEL_1_47);
      goto label_54;

    case 25:
      current_block = (Rpc - LABEL_1_45);
      goto lambda_73;

    case 26:
      current_block = (Rpc - LABEL_1_48);
      goto lambda_74;

    case 27:
      current_block = (Rpc - LABEL_1_50);
      goto lambda_75;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lp_comma_list_56)
DEFLABEL (lp_comma_list_47)
  INTERRUPT_CHECK (26, LABEL_1_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_1_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_1_5])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  Rvl = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (lambda_57)
  CLOSURE_HEADER (LABEL_1_5);

DEFLABEL (lambda_45)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd6.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_1_8);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_1_7])));
  Rhp += 1;
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd6.pObj)));
  Wrd7 = Wrd6;
  (Wrd8.Obj) = (Rsp [2]);
  ((Wrd7.pObj) [2]) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (Rsp [3]) = (Wrd5.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 7));
  (Wrd12.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_1_10);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_1_9])));
  Rhp += 4;
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd12.pObj)));
  Wrd19 = Wrd12;
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd22.Obj) = ((Wrd21.pObj) [2]);
  ((Wrd19.pObj) [2]) = (Wrd22.Obj);
  (Wrd18.Obj) = (Rsp [4]);
  ((Wrd19.pObj) [3]) = (Wrd18.Obj);
  (Wrd16.Obj) = (Rsp [2]);
  ((Wrd19.pObj) [4]) = (Wrd16.Obj);
  ((Wrd19.pObj) [5]) = (Wrd5.Obj);
  (Rsp [4]) = (Wrd11.Obj);
  Rsp = (& (Rsp [2]));
  goto lambda_13;

DEFLABEL (lambda_58)
  CLOSURE_HEADER (LABEL_1_7);

DEFLABEL (lambda_17)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_11]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_12]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_13]));

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_1_12);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_77;
  Wrd5 = Wrd9;

DEFLABEL (label_76)
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_2]), 2);

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_1_11);
  (Wrd9.Obj) = (current_block [OBJECT_1_1]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd11.Obj) = (Rsp [0]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd10.Obj) = ((Wrd12.pObj) [2]);
  (Rsp [0]) = (Wrd10.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (label_77)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_1_21])), (Wrd6.pObj));

DEFLABEL (label_49)
  (Wrd5.Obj) = Rvl;
  goto label_76;

DEFLABEL (lambda_59)
  CLOSURE_HEADER (LABEL_1_9);

DEFLABEL (lambda_43)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd6.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_1_15);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_1_14])));
  Rhp += 2;
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd6.pObj)));
  Wrd11 = Wrd6;
  (Wrd12.Obj) = (Rsp [0]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [2]);
  ((Wrd11.pObj) [2]) = (Wrd14.Obj);
  (Wrd10.Obj) = ((Wrd13.pObj) [5]);
  ((Wrd11.pObj) [3]) = (Wrd10.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd17.Obj) = ((Wrd13.pObj) [4]);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd14.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd23.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_1_17);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_1_16])));
  Rhp += 3;
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd23.pObj)));
  Wrd32 = Wrd23;
  (Wrd35.Obj) = ((Wrd13.pObj) [3]);
  ((Wrd32.pObj) [2]) = (Wrd35.Obj);
  ((Wrd32.pObj) [3]) = (Wrd17.Obj);
  ((Wrd32.pObj) [4]) = (Wrd10.Obj);
  (Rsp [3]) = (Wrd22.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (lambda_62)
DEFLABEL (lambda_13)
  INTERRUPT_CHECK (26, LABEL_1_18);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd11.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_1_20);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_1_19])));
  Rhp += 1;
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd11.pObj)));
  (* (--Rsp)) = (Wrd12.Obj);
  Wrd9 = Wrd11;
  (Wrd10.Obj) = (Rsp [2]);
  ((Wrd9.pObj) [2]) = (Wrd10.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd7.Obj) = (current_block [OBJECT_1_0]);
  (Rsp [2]) = (Wrd7.Obj);
  goto loop_0_11;

DEFLABEL (lambda_60)
  CLOSURE_HEADER (LABEL_1_14);

DEFLABEL (lambda_40)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_1_23);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_1_22])));
  Rhp += 3;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd14 = Wrd7;
  (Wrd15.Obj) = (Rsp [0]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [2]);
  ((Wrd14.pObj) [2]) = (Wrd17.Obj);
  (Wrd13.Obj) = ((Wrd16.pObj) [3]);
  ((Wrd14.pObj) [3]) = (Wrd13.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  ((Wrd14.pObj) [4]) = (Wrd9.Obj);
  (Rsp [2]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  goto lambda_13;

DEFLABEL (lambda_61)
  CLOSURE_HEADER (LABEL_1_16);

DEFLABEL (lambda_42)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (current_block [OBJECT_1_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd8.Obj) = ((Wrd7.pObj) [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = ((Wrd7.pObj) [4]);
  (* (--Rsp)) = (Wrd11.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd14.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_1_25);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_1_24])));
  Rhp += 1;
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd14.pObj)));
  Wrd15 = Wrd14;
  (Wrd18.Obj) = ((Wrd7.pObj) [2]);
  ((Wrd15.pObj) [2]) = (Wrd18.Obj);
  (Rsp [3]) = (Wrd13.Obj);
  goto lambda_17;

DEFLABEL (loop_0_63)
DEFLABEL (loop_0_11)
  INTERRUPT_CHECK (26, LABEL_1_19);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd6.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_1_27);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_1_26])));
  Rhp += 2;
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd6.pObj)));
  Wrd9 = Wrd6;
  (Wrd10.Obj) = (Rsp [0]);
  ((Wrd9.pObj) [2]) = (Wrd10.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  ((Wrd9.pObj) [3]) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 8));
  (Wrd12.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_1_29);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_1_28])));
  Rhp += 5;
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd12.pObj)));
  Wrd21 = Wrd12;
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd24.Obj) = ((Wrd23.pObj) [2]);
  ((Wrd21.pObj) [2]) = (Wrd24.Obj);
  (Wrd20.Obj) = (Rsp [4]);
  ((Wrd21.pObj) [3]) = (Wrd20.Obj);
  ((Wrd21.pObj) [4]) = (Wrd8.Obj);
  (Wrd16.Obj) = (Rsp [2]);
  ((Wrd21.pObj) [5]) = (Wrd16.Obj);
  ((Wrd21.pObj) [6]) = (Wrd5.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd26.uLng) == 1)
    goto label_79;

DEFLABEL (label_78)
  (Wrd27.Obj) = (Rsp [0]);
  (Rsp [5]) = (Wrd27.Obj);
  Rsp = (& (Rsp [5]));
  goto lambda_4;

DEFLABEL (label_79)
  if (! ((Wrd26.uLng) == 1))
    goto label_83;
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd29.Obj) = ((Wrd31.pObj) [0]);

DEFLABEL (label_82)
  if (! ((Wrd29.Obj) == (current_block [OBJECT_1_4])))
    goto label_78;
  (Wrd39.Obj) = (Rsp [0]);
  (Rsp [5]) = (Wrd39.Obj);
  (Wrd40.Obj) = (Rsp [1]);
  (Rsp [2]) = (Wrd40.Obj);
  (Wrd44.Obj) = (Rsp [3]);
  (Wrd45.uLng) = (OBJECT_TYPE (Wrd44.Obj));
  if (! ((Wrd45.uLng) == 1))
    goto label_81;
  (Wrd43.pObj) = (OBJECT_ADDRESS (Wrd44.Obj));
  (Wrd41.Obj) = ((Wrd43.pObj) [1]);

DEFLABEL (label_80)
  (Rsp [3]) = (Wrd41.Obj);
  (Wrd50.Obj) = (current_block [OBJECT_1_0]);
  (Rsp [4]) = (Wrd50.Obj);
  Rsp = (& (Rsp [2]));
  goto lambda_2;

DEFLABEL (label_81)
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_31]))));
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd44.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_5]), 1);

DEFLABEL (label_51)
  (Wrd41.Obj) = Rvl;
  goto label_80;

DEFLABEL (label_83)
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_30]))));
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_3]), 1);

DEFLABEL (label_50)
  (Wrd29.Obj) = Rvl;
  goto label_82;

DEFLABEL (lambda_64)
  CLOSURE_HEADER (LABEL_1_22);

DEFLABEL (lambda_39)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 7));
  (Wrd26.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_1_33);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_1_32])));
  Rhp += 4;
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd26.pObj)));
  (* (--Rsp)) = (Wrd27.Obj);
  Wrd22 = Wrd26;
  (Wrd23.Obj) = (Rsp [1]);
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd25.Obj) = ((Wrd24.pObj) [2]);
  ((Wrd22.pObj) [2]) = (Wrd25.Obj);
  (Wrd20.Obj) = ((Wrd24.pObj) [3]);
  ((Wrd22.pObj) [3]) = (Wrd20.Obj);
  (Wrd15.Obj) = ((Wrd24.pObj) [4]);
  ((Wrd22.pObj) [4]) = (Wrd15.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  ((Wrd22.pObj) [5]) = (Wrd10.Obj);
  Rsp = (& (Rsp [1]));
  (Rsp [0]) = (Wrd27.Obj);
  (Wrd7.Obj) = (current_block [OBJECT_1_0]);
  (Rsp [2]) = (Wrd7.Obj);
  goto loop_0_37;

DEFLABEL (lambda_65)
  CLOSURE_HEADER (LABEL_1_24);

DEFLABEL (lambda_41)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (lambda_66)
  CLOSURE_HEADER (LABEL_1_26);

DEFLABEL (lambda_2)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [3]);
  (Wrd11.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (Rsp [2]) = (Wrd5.Obj);
  (Wrd12.Obj) = ((Wrd9.pObj) [2]);
  (Rsp [0]) = (Wrd12.Obj);
  goto loop_0_11;

DEFLABEL (lambda_67)
  CLOSURE_HEADER (LABEL_1_28);

DEFLABEL (lambda_4)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [6]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = ((Wrd6.pObj) [5]);
  (* (--Rsp)) = (Wrd10.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 7));
  (Wrd13.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_1_35);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_1_34])));
  Rhp += 4;
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd13.pObj)));
  Wrd26 = Wrd13;
  (Wrd29.Obj) = ((Wrd6.pObj) [2]);
  ((Wrd26.pObj) [2]) = (Wrd29.Obj);
  (Wrd25.Obj) = ((Wrd6.pObj) [3]);
  ((Wrd26.pObj) [3]) = (Wrd25.Obj);
  (Wrd21.Obj) = ((Wrd6.pObj) [4]);
  ((Wrd26.pObj) [4]) = (Wrd21.Obj);
  ((Wrd26.pObj) [5]) = (Wrd10.Obj);
  (Rsp [2]) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_36]));

DEFLABEL (loop_0_68)
DEFLABEL (loop_0_37)
  INTERRUPT_CHECK (26, LABEL_1_32);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 9));
  (Wrd6.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_1_38);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_1_37])));
  Rhp += 6;
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd6.pObj)));
  Wrd21 = Wrd6;
  (Wrd22.Obj) = (Rsp [0]);
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
  (Wrd24.Obj) = ((Wrd23.pObj) [3]);
  ((Wrd21.pObj) [2]) = (Wrd24.Obj);
  (Wrd20.Obj) = ((Wrd23.pObj) [4]);
  ((Wrd21.pObj) [3]) = (Wrd20.Obj);
  (Wrd16.Obj) = ((Wrd23.pObj) [5]);
  ((Wrd21.pObj) [4]) = (Wrd16.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  ((Wrd21.pObj) [5]) = (Wrd12.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  ((Wrd21.pObj) [6]) = (Wrd10.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  ((Wrd21.pObj) [7]) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if ((Wrd26.uLng) == 1)
    goto label_85;

DEFLABEL (label_84)
  (Wrd27.Obj) = (Rsp [0]);
  (Rsp [4]) = (Wrd27.Obj);
  Rsp = (& (Rsp [4]));
  goto lambda_21;

DEFLABEL (label_85)
  if (! ((Wrd26.uLng) == 1))
    goto label_89;
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd29.Obj) = ((Wrd31.pObj) [0]);

DEFLABEL (label_88)
  if (! ((Wrd29.Obj) == (current_block [OBJECT_1_4])))
    goto label_84;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd40.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_1_41);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_1_40])));
  Rhp += 3;
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd40.pObj)));
  Wrd45 = Wrd40;
  (Wrd46.Obj) = (Rsp [1]);
  (Wrd47.pObj) = (OBJECT_ADDRESS (Wrd46.Obj));
  (Wrd48.Obj) = ((Wrd47.pObj) [2]);
  ((Wrd45.pObj) [2]) = (Wrd48.Obj);
  ((Wrd45.pObj) [3]) = (Wrd46.Obj);
  (Wrd42.Obj) = (Rsp [3]);
  ((Wrd45.pObj) [4]) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  (Rsp [4]) = (Wrd39.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd52.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_1_43);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_1_42])));
  Rhp += 3;
  (Wrd51.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd52.pObj)));
  Wrd57 = Wrd52;
  (Wrd58.Obj) = (Rsp [3]);
  ((Wrd57.pObj) [2]) = (Wrd58.Obj);
  (Wrd56.Obj) = (Rsp [1]);
  ((Wrd57.pObj) [3]) = (Wrd56.Obj);
  ((Wrd57.pObj) [4]) = (Wrd39.Obj);
  (Rsp [5]) = (Wrd51.Obj);
  (Wrd63.uLng) = (OBJECT_TYPE (Wrd58.Obj));
  if (! ((Wrd63.uLng) == 1))
    goto label_87;
  (Wrd61.pObj) = (OBJECT_ADDRESS (Wrd58.Obj));
  (Wrd59.Obj) = ((Wrd61.pObj) [1]);

DEFLABEL (label_86)
  (Rsp [3]) = (Wrd59.Obj);
  Rsp = (& (Rsp [3]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_36]));

DEFLABEL (label_87)
  (Wrd67.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_44]))));
  (* (--Rsp)) = (Wrd67.Obj);
  (* (--Rsp)) = (Wrd58.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_5]), 1);

DEFLABEL (label_53)
  (Wrd59.Obj) = Rvl;
  goto label_86;

DEFLABEL (label_89)
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_39]))));
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_3]), 1);

DEFLABEL (label_52)
  (Wrd29.Obj) = Rvl;
  goto label_88;

DEFLABEL (lambda_69)
  CLOSURE_HEADER (LABEL_1_34);

DEFLABEL (lambda_3)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [4]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = ((Wrd6.pObj) [5]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = ((Wrd6.pObj) [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = ((Wrd6.pObj) [3]);
  (Rsp [3]) = (Wrd14.Obj);
  goto pop_return;

DEFLABEL (lambda_70)
DEFLABEL (lambda_21)
  INTERRUPT_CHECK (26, LABEL_1_37);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [3]);
  (Wrd13.Obj) = ((Wrd9.pObj) [4]);
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd13.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (Wrd19.Obj) = ((Wrd9.pObj) [6]);
  (* (Rhp++)) = (Wrd5.Obj);
  (* (Rhp++)) = (Wrd19.Obj);
  (Wrd15.pObj) = (& (Rhp [-2]));
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd15.pObj)));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd22.Obj) = ((Wrd9.pObj) [7]);
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd25.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd26.Obj) = ((Wrd9.pObj) [5]);
  (Rsp [3]) = (Wrd26.Obj);
  goto lambda_17;

DEFLABEL (lambda_71)
  CLOSURE_HEADER (LABEL_1_40);

DEFLABEL (lambda_30)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_1_46);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_1_45])));
  Rhp += 3;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd14 = Wrd7;
  (Wrd15.Obj) = (Rsp [0]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [3]);
  ((Wrd14.pObj) [2]) = (Wrd17.Obj);
  (Wrd13.Obj) = ((Wrd16.pObj) [4]);
  ((Wrd14.pObj) [3]) = (Wrd13.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  ((Wrd14.pObj) [4]) = (Wrd9.Obj);
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd18.Obj) = ((Wrd16.pObj) [2]);
  (Rsp [0]) = (Wrd18.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (lambda_72)
  CLOSURE_HEADER (LABEL_1_42);

DEFLABEL (lambda_34)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (current_block [OBJECT_1_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [2]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd14.uLng) == 1))
    goto label_91;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [1]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_90)
  (Wrd21.Obj) = (Rsp [2]);
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd23.Obj) = ((Wrd22.pObj) [4]);
  (* (--Rsp)) = (Wrd23.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd26.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_1_49);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_1_48])));
  Rhp += 1;
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd26.pObj)));
  Wrd27 = Wrd26;
  (Wrd30.Obj) = ((Wrd22.pObj) [3]);
  ((Wrd27.pObj) [2]) = (Wrd30.Obj);
  (Rsp [3]) = (Wrd25.Obj);
  goto lambda_30;

DEFLABEL (label_91)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_47]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd13.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_1_5]), 1);

DEFLABEL (label_54)
  (* (--Rsp)) = Rvl;
  goto label_90;

DEFLABEL (lambda_73)
  CLOSURE_HEADER (LABEL_1_45);

DEFLABEL (lambda_29)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 7));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_1_51);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_1_50])));
  Rhp += 4;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd18 = Wrd7;
  (Wrd19.Obj) = (Rsp [0]);
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [2]);
  ((Wrd18.pObj) [2]) = (Wrd21.Obj);
  (Wrd17.Obj) = ((Wrd20.pObj) [3]);
  ((Wrd18.pObj) [3]) = (Wrd17.Obj);
  (Wrd13.Obj) = ((Wrd20.pObj) [4]);
  ((Wrd18.pObj) [4]) = (Wrd13.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  ((Wrd18.pObj) [5]) = (Wrd9.Obj);
  (Rsp [2]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  goto lambda_13;

DEFLABEL (lambda_74)
  CLOSURE_HEADER (LABEL_1_48);

DEFLABEL (lambda_33)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  goto lambda_21;

DEFLABEL (lambda_75)
  CLOSURE_HEADER (LABEL_1_50);

DEFLABEL (lambda_28)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [4]);
  (Wrd13.Obj) = ((Wrd9.pObj) [5]);
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd13.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (Wrd17.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd5.Obj);
  (* (Rhp++)) = (Wrd17.Obj);
  (Wrd16.pObj) = (& (Rhp [-2]));
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd16.pObj)));
  (Wrd23.Obj) = ((Wrd9.pObj) [3]);
  (* (Rhp++)) = (Wrd23.Obj);
  (* (Rhp++)) = (Wrd14.Obj);
  (Wrd20.pObj) = (& (Rhp [-2]));
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd20.pObj)));
  (Rsp [2]) = (Wrd18.Obj);
  (Wrd24.Obj) = ((Wrd9.pObj) [2]);
  (Rsp [0]) = (Wrd24.Obj);
  goto loop_0_37;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_2_4 3
#define LABEL_2_5 5
#define LABEL_2_7 7
#define TAG_2_8 2
#define LABEL_2_9 9
#define TAG_2_10 3
#define LABEL_2_11 11
#define LABEL_2_12 13
#define LABEL_2_14 15
#define ENVIRONMENT_LABEL_2_3 25
#define DEBUGGING_LABEL_2_2 24
#define OBJECT_2_0 23
#define EXECUTE_CACHE_2_13 17
#define EXECUTE_CACHE_2_6 19
#define FREE_REFERENCE_2_0 22
#define FREE_REFERENCES_LABEL_2_0 16
#define NUMBER_OF_LINKER_SECTIONS_2_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_2 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd9;
  machine_word Wrd6;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_2_4);
      goto lp_comma_list__6;

    case 1:
      current_block = (Rpc - LABEL_2_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_2_7);
      goto lambda_11;

    case 3:
      current_block = (Rpc - LABEL_2_9);
      goto lambda_12;

    case 4:
      current_block = (Rpc - LABEL_2_11);
      goto continuation_2;

    case 5:
      current_block = (Rpc - LABEL_2_12);
      goto continuation_1;

    case 6:
      current_block = (Rpc - LABEL_2_14);
      goto label_8;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lp_comma_list__10)
DEFLABEL (lp_comma_list__6)
  INTERRUPT_CHECK (26, LABEL_2_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_2_5);
  (Rsp [0]) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_2_8);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_2_7])));
  Rhp += 1;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  ((Wrd8.pObj) [2]) = Rvl;
  Rvl = (Wrd7.Obj);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (lambda_11)
  CLOSURE_HEADER (LABEL_2_7);

DEFLABEL (lambda_4)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_2_10);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_2_9])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [2]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd11.Obj) = (Rsp [0]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd10.Obj) = ((Wrd12.pObj) [2]);
  (Rsp [0]) = (Wrd10.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (lambda_12)
  CLOSURE_HEADER (LABEL_2_9);

DEFLABEL (lambda_3)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_11]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_12]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_13]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_2_12);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_15;
  Wrd5 = Wrd9;

DEFLABEL (label_14)
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_0]), 2);

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_2_11);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_13;
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [2]);
  (Rsp [0]) = (Wrd7.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (label_13)
  Rsp = (& (Rsp [3]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (label_15)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_2_14])), (Wrd6.pObj));

DEFLABEL (label_8)
  (Wrd5.Obj) = Rvl;
  goto label_14;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_3_4 3
#define LABEL_3_5 5
#define TAG_3_6 1
#define LABEL_3_7 7
#define TAG_3_8 2
#define ENVIRONMENT_LABEL_3_3 13
#define DEBUGGING_LABEL_3_2 12
#define OBJECT_3_0 11
#define EXECUTE_CACHE_3_9 9
#define FREE_REFERENCES_LABEL_3_0 8
#define NUMBER_OF_LINKER_SECTIONS_3_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_3 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_3_4);
      goto token_predicate_2;

    case 1:
      current_block = (Rpc - LABEL_3_5);
      goto lambda_6;

    case 2:
      current_block = (Rpc - LABEL_3_7);
      goto lambda_7;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (token_predicate_5)
DEFLABEL (token_predicate_2)
  INTERRUPT_CHECK (26, LABEL_3_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_3_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_3_5])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  Rvl = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (lambda_6)
  CLOSURE_HEADER (LABEL_3_5);

DEFLABEL (lambda_1)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd10.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_3_8);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_3_7])));
  Rhp += 1;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd10.pObj)));
  Wrd11 = Wrd10;
  (Wrd12.Obj) = (Rsp [1]);
  ((Wrd11.pObj) [2]) = (Wrd12.Obj);
  (Rsp [0]) = (Wrd9.Obj);
  (Rsp [1]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_3_9]));

DEFLABEL (lambda_7)
  CLOSURE_HEADER (LABEL_3_7);

DEFLABEL (lambda_0)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd8.Obj) = ((Wrd7.pObj) [2]);
  (Wrd9.Obj) = (Rsp [1]);
  if ((Wrd8.Obj) == (Wrd9.Obj))
    goto label_9;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_8;

DEFLABEL (label_9)
  Rvl = (current_block [OBJECT_3_0]);

DEFLABEL (label_8)
DEFLABEL (label_10)
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_4_4 3
#define LABEL_4_5 5
#define TAG_4_6 1
#define LABEL_4_8 7
#define LABEL_4_7 9
#define LABEL_4_9 11
#define ENVIRONMENT_LABEL_4_3 15
#define DEBUGGING_LABEL_4_2 14
#define OBJECT_4_1 13
#define OBJECT_4_0 12
#define FREE_REFERENCES_LABEL_4_0 12
#define NUMBER_OF_LINKER_SECTIONS_4_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_4 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd18;
  machine_word Wrd12;
  machine_word Wrd8;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_4_4);
      goto pair_predicate_5;

    case 1:
      current_block = (Rpc - LABEL_4_5);
      goto lambda_11;

    case 2:
      current_block = (Rpc - LABEL_4_8);
      goto label_7;

    case 3:
      current_block = (Rpc - LABEL_4_7);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_4_9);
      goto label_8;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (pair_predicate_10)
DEFLABEL (pair_predicate_5)
  INTERRUPT_CHECK (26, LABEL_4_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_4_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_4_5])));
  Rhp += 2;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd10 = Wrd7;
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd10.pObj) [2]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd10.pObj) [3]) = (Wrd9.Obj);
  Rvl = (Wrd6.Obj);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (lambda_11)
  CLOSURE_HEADER (LABEL_4_5);

DEFLABEL (lambda_4)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_12;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_12)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_7]))));
  (* (--Rsp)) = (Wrd11.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_17;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_16)
  (Wrd21.Obj) = (Rsp [2]);
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd23.Obj) = ((Wrd22.pObj) [3]);
  (* (--Rsp)) = (Wrd23.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_4_7);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_13;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_13)
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [2]);
  (Rsp [0]) = (Wrd7.Obj);
  (Wrd13.Obj) = (Rsp [1]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd14.uLng) == 1))
    goto label_15;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd10.Obj) = ((Wrd12.pObj) [1]);

DEFLABEL (label_14)
  (Rsp [1]) = (Wrd10.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (label_15)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_9]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd13.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_1]), 1);

DEFLABEL (label_8)
  (Wrd10.Obj) = Rvl;
  goto label_14;

DEFLABEL (label_17)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_8]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_4_0]), 1);

DEFLABEL (label_7)
  (* (--Rsp)) = Rvl;
  goto label_16;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_5_4 3
#define LABEL_5_5 5
#define TAG_5_6 1
#define ENVIRONMENT_LABEL_5_3 10
#define DEBUGGING_LABEL_5_2 9
#define EXECUTE_CACHE_5_7 7
#define FREE_REFERENCES_LABEL_5_0 6
#define NUMBER_OF_LINKER_SECTIONS_5_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_5 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_5_4);
      goto list_predicate_1;

    case 1:
      current_block = (Rpc - LABEL_5_5);
      goto lambda_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (list_predicate_4)
DEFLABEL (list_predicate_1)
  INTERRUPT_CHECK (26, LABEL_5_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_5_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_5_5])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  Rvl = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (lambda_5)
  CLOSURE_HEADER (LABEL_5_5);

DEFLABEL (lambda_0)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Wrd8.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd8.Obj);
  (Rsp [1]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_5_7]));

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_6_4 3
#define LABEL_6_5 5
#define TAG_6_6 1
#define ENVIRONMENT_LABEL_6_3 10
#define DEBUGGING_LABEL_6_2 9
#define EXECUTE_CACHE_6_7 7
#define FREE_REFERENCES_LABEL_6_0 6
#define NUMBER_OF_LINKER_SECTIONS_6_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_6 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_6_4);
      goto list__predicate_2;

    case 1:
      current_block = (Rpc - LABEL_6_5);
      goto lambda_6;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (list__predicate_5)
DEFLABEL (list__predicate_2)
  INTERRUPT_CHECK (26, LABEL_6_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_6_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_6_5])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  Rvl = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (lambda_6)
  CLOSURE_HEADER (LABEL_6_5);

DEFLABEL (lambda_1)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_7;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_7)
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd9.Obj) = ((Wrd11.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  (Rsp [1]) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_6_7]));

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_7_4 3
#define LABEL_7_5 5
#define LABEL_7_7 7
#define TAG_7_8 2
#define LABEL_7_9 9
#define LABEL_7_10 11
#define LABEL_7_11 13
#define LABEL_7_13 15
#define LABEL_7_14 17
#define LABEL_7_12 19
#define LABEL_7_15 21
#define LABEL_7_16 23
#define ENVIRONMENT_LABEL_7_3 34
#define DEBUGGING_LABEL_7_2 33
#define OBJECT_7_5 32
#define OBJECT_7_4 31
#define OBJECT_7_3 30
#define OBJECT_7_2 29
#define OBJECT_7_1 28
#define OBJECT_7_0 27
#define EXECUTE_CACHE_7_6 25
#define FREE_REFERENCES_LABEL_7_0 24
#define NUMBER_OF_LINKER_SECTIONS_7_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_7 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd15;
  machine_word Wrd41;
  machine_word Wrd37;
  machine_word Wrd32;
  machine_word Wrd29;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd25;
  machine_word Wrd18;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd31;
  machine_word Wrd26;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd9;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd5;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd6;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_7_4);
      goto vector_predicate_15;

    case 1:
      current_block = (Rpc - LABEL_7_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_7_7);
      goto lambda_25;

    case 3:
      current_block = (Rpc - LABEL_7_9);
      goto label_17;

    case 4:
      current_block = (Rpc - LABEL_7_10);
      goto label_18;

    case 5:
      current_block = (Rpc - LABEL_7_11);
      goto loop_11;

    case 6:
      current_block = (Rpc - LABEL_7_13);
      goto label_19;

    case 7:
      current_block = (Rpc - LABEL_7_14);
      goto label_20;

    case 8:
      current_block = (Rpc - LABEL_7_12);
      goto continuation_7;

    case 9:
      current_block = (Rpc - LABEL_7_15);
      goto label_21;

    case 10:
      current_block = (Rpc - LABEL_7_16);
      goto label_22;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (vector_predicate_24)
DEFLABEL (vector_predicate_15)
  INTERRUPT_CHECK (26, LABEL_7_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_7_5);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_7_8);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_7_7])));
  Rhp += 2;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd10 = Wrd7;
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd10.pObj) [2]) = (Wrd11.Obj);
  ((Wrd10.pObj) [3]) = Rvl;
  Rvl = (Wrd6.Obj);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (lambda_25)
  CLOSURE_HEADER (LABEL_7_7);

DEFLABEL (lambda_13)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 10)
    goto label_28;

DEFLABEL (label_27)
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_28)
  if (! ((Wrd6.uLng) == 10))
    goto label_32;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (Wrd9.Obj) = (MAKE_OBJECT (26, (Wrd13.uLng)));

DEFLABEL (label_31)
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if (! ((Wrd20.uLng) == 26))
    goto label_30;
  (Wrd21.Obj) = (Rsp [0]);
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd23.Obj) = ((Wrd22.pObj) [3]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd24.uLng) == 26))
    goto label_30;
  if (! ((Wrd9.Obj) == (Wrd23.Obj)))
    goto label_27;

DEFLABEL (label_29)
  (Wrd33.Obj) = (current_block [OBJECT_7_1]);
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd34.Obj) = (Rsp [1]);
  (Wrd35.pObj) = (OBJECT_ADDRESS (Wrd34.Obj));
  (Wrd36.Obj) = ((Wrd35.pObj) [2]);
  (* (--Rsp)) = (Wrd36.Obj);
  goto loop_11;

DEFLABEL (label_30)
  (Wrd27.Obj) = (Rsp [0]);
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd26.Obj) = ((Wrd28.pObj) [3]);
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_10]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  INVOKE_INTERFACE_0 (36);

DEFLABEL (label_18)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_27;
  goto label_29;

DEFLABEL (label_32)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_9]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_7_0]), 1);

DEFLABEL (label_17)
  (Wrd9.Obj) = Rvl;
  goto label_31;

DEFLABEL (loop_26)
DEFLABEL (loop_11)
  INTERRUPT_CHECK (26, LABEL_7_11);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_33;
  Rvl = (current_block [OBJECT_7_4]);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_33)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_12]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd26.Obj) = (Rsp [4]);
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if (! ((Wrd27.uLng) == 10))
    goto label_42;
  (Wrd18.Obj) = (Rsp [2]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd19.uLng) == 26))
    goto label_42;
  (Wrd21.Lng) = (FIXNUM_TO_LONG (Wrd18.Obj));
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd24.Obj) = ((Wrd23.pObj) [0]);
  (Wrd25.Lng) = (FIXNUM_TO_LONG (Wrd24.Obj));
  if (! (((unsigned long) (Wrd21.Lng)) < ((unsigned long) (Wrd25.Lng))))
    goto label_42;
  (Wrd13.uLng) = (OBJECT_DATUM (Wrd18.Obj));
  (Wrd16.pObj) = (& ((Wrd23.pObj) [(Wrd13.Lng)]));
  (Wrd17.Obj) = ((Wrd16.pObj) [1]);
  (* (--Rsp)) = (Wrd17.Obj);

DEFLABEL (label_41)
  (Wrd36.Obj) = (Rsp [2]);
  (Wrd37.uLng) = (OBJECT_TYPE (Wrd36.Obj));
  if (! ((Wrd37.uLng) == 1))
    goto label_40;
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd36.Obj));
  (Wrd35.Obj) = ((Wrd34.pObj) [0]);
  (* (--Rsp)) = (Wrd35.Obj);

DEFLABEL (label_39)
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_7_12);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_34;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_34)
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_38;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_37)
  (Rsp [0]) = (Wrd7.Obj);
  (Wrd21.Obj) = (Rsp [1]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if (! ((Wrd22.uLng) == 26))
    goto label_36;
  (Wrd25.Lng) = (FIXNUM_TO_LONG (Wrd21.Obj));
  (Wrd23.Lng) = ((Wrd25.Lng) + 1L);
  if (! (LONG_TO_FIXNUM_P (Wrd23.Lng)))
    goto label_36;
  (Wrd20.Obj) = (LONG_TO_FIXNUM (Wrd23.Lng));

DEFLABEL (label_35)
  (Rsp [1]) = (Wrd20.Obj);
  goto loop_11;

DEFLABEL (label_36)
  (Wrd16.Obj) = (Rsp [1]);
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_16]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_INTERFACE_0 (38);

DEFLABEL (label_22)
  (Wrd20.Obj) = Rvl;
  goto label_35;

DEFLABEL (label_38)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_15]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_7_5]), 1);

DEFLABEL (label_21)
  (Wrd7.Obj) = Rvl;
  goto label_37;

DEFLABEL (label_40)
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_14]))));
  (* (--Rsp)) = (Wrd41.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_7_3]), 1);

DEFLABEL (label_20)
  (* (--Rsp)) = Rvl;
  goto label_39;

DEFLABEL (label_42)
  (Wrd28.Obj) = (Rsp [4]);
  (Wrd29.Obj) = (Rsp [2]);
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_13]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_7_2]), 2);

DEFLABEL (label_19)
  (* (--Rsp)) = Rvl;
  goto label_41;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_8_4 3
#define LABEL_8_5 5
#define TAG_8_6 1
#define ENVIRONMENT_LABEL_8_3 8
#define DEBUGGING_LABEL_8_2 7
#define OBJECT_8_0 6
#define FREE_REFERENCES_LABEL_8_0 6
#define NUMBER_OF_LINKER_SECTIONS_8_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_8 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_8_4);
      goto opt_predicate_1;

    case 1:
      current_block = (Rpc - LABEL_8_5);
      goto lambda_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (opt_predicate_4)
DEFLABEL (opt_predicate_1)
  INTERRUPT_CHECK (26, LABEL_8_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_8_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_8_5])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  Rvl = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (lambda_5)
  CLOSURE_HEADER (LABEL_8_5);

DEFLABEL (lambda_0)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  if ((Wrd5.Obj) == ((SCHEME_OBJECT) 0))
    goto label_6;
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [2]);
  (Rsp [0]) = (Wrd7.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (label_6)
  Rvl = (current_block [OBJECT_8_0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_9_4 3
#define LABEL_9_5 5
#define TAG_9_6 1
#define LABEL_9_7 7
#define TAG_9_8 2
#define ENVIRONMENT_LABEL_9_3 12
#define DEBUGGING_LABEL_9_2 11
#define EXECUTE_CACHE_9_9 9
#define FREE_REFERENCES_LABEL_9_0 8
#define NUMBER_OF_LINKER_SECTIONS_9_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_9 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_9_4);
      goto alt_predicate_2;

    case 1:
      current_block = (Rpc - LABEL_9_5);
      goto lambda_6;

    case 2:
      current_block = (Rpc - LABEL_9_7);
      goto lambda_7;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (alt_predicate_5)
DEFLABEL (alt_predicate_2)
  INTERRUPT_CHECK (26, LABEL_9_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_9_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_9_5])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  Rvl = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (lambda_6)
  CLOSURE_HEADER (LABEL_9_5);

DEFLABEL (lambda_1)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd10.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_9_8);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_9_7])));
  Rhp += 1;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd10.pObj)));
  Wrd11 = Wrd10;
  (Wrd12.Obj) = (Rsp [1]);
  ((Wrd11.pObj) [2]) = (Wrd12.Obj);
  (Rsp [0]) = (Wrd9.Obj);
  (Rsp [1]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_9_9]));

DEFLABEL (lambda_7)
  CLOSURE_HEADER (LABEL_9_7);

DEFLABEL (lambda_0)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Wrd8.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd8.Obj);
  (Rsp [1]) = (Wrd5.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_10_4 3
#define LABEL_10_5 5
#define TAG_10_6 1
#define LABEL_10_7 7
#define TAG_10_8 2
#define ENVIRONMENT_LABEL_10_3 12
#define DEBUGGING_LABEL_10_2 11
#define EXECUTE_CACHE_10_9 9
#define FREE_REFERENCES_LABEL_10_0 8
#define NUMBER_OF_LINKER_SECTIONS_10_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_10 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_10_4);
      goto joined_predicate_2;

    case 1:
      current_block = (Rpc - LABEL_10_5);
      goto lambda_6;

    case 2:
      current_block = (Rpc - LABEL_10_7);
      goto lambda_7;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (joined_predicate_5)
DEFLABEL (joined_predicate_2)
  INTERRUPT_CHECK (26, LABEL_10_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_10_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_10_5])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  Rvl = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (lambda_6)
  CLOSURE_HEADER (LABEL_10_5);

DEFLABEL (lambda_1)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd10.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_10_8);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_10_7])));
  Rhp += 1;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd10.pObj)));
  Wrd11 = Wrd10;
  (Wrd12.Obj) = (Rsp [1]);
  ((Wrd11.pObj) [2]) = (Wrd12.Obj);
  (Rsp [0]) = (Wrd9.Obj);
  (Rsp [1]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_10_9]));

DEFLABEL (lambda_7)
  CLOSURE_HEADER (LABEL_10_7);

DEFLABEL (lambda_0)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Wrd8.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd8.Obj);
  (Rsp [1]) = (Wrd5.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_11_4 3
#define LABEL_11_5 5
#define TAG_11_6 1
#define LABEL_11_8 7
#define LABEL_11_7 9
#define LABEL_11_9 11
#define LABEL_11_10 13
#define TAG_11_11 5
#define LABEL_11_13 15
#define ENVIRONMENT_LABEL_11_3 25
#define DEBUGGING_LABEL_11_2 24
#define OBJECT_11_2 23
#define OBJECT_11_1 22
#define OBJECT_11_0 21
#define EXECUTE_CACHE_11_14 17
#define EXECUTE_CACHE_11_12 19
#define FREE_REFERENCES_LABEL_11_0 16
#define NUMBER_OF_LINKER_SECTIONS_11_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_11 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd18;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd8;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd12;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_11_4);
      goto sep_list_writer_7;

    case 1:
      current_block = (Rpc - LABEL_11_5);
      goto lambda_13;

    case 2:
      current_block = (Rpc - LABEL_11_8);
      goto label_9;

    case 3:
      current_block = (Rpc - LABEL_11_7);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_11_9);
      goto label_10;

    case 5:
      current_block = (Rpc - LABEL_11_10);
      goto lambda_14;

    case 6:
      current_block = (Rpc - LABEL_11_13);
      goto continuation_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (sep_list_writer_12)
DEFLABEL (sep_list_writer_7)
  INTERRUPT_CHECK (26, LABEL_11_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_11_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_11_5])));
  Rhp += 2;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd10 = Wrd7;
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd10.pObj) [2]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd10.pObj) [3]) = (Wrd9.Obj);
  Rvl = (Wrd6.Obj);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (lambda_13)
  CLOSURE_HEADER (LABEL_11_5);

DEFLABEL (lambda_6)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_15;
  Rvl = (current_block [OBJECT_11_1]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_15)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11_7]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_19;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (* (--Rsp)) = (Wrd15.Obj);

DEFLABEL (label_18)
  (Wrd22.Obj) = (Rsp [3]);
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
  (Wrd24.Obj) = ((Wrd23.pObj) [2]);
  (* (--Rsp)) = (Wrd24.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_11_7);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_17;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [1]);

DEFLABEL (label_16)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd16.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_11_11);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_11_10])));
  Rhp += 3;
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd16.pObj)));
  Wrd23 = Wrd16;
  (Wrd24.Obj) = (Rsp [0]);
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [2]);
  ((Wrd23.pObj) [2]) = (Wrd26.Obj);
  (Wrd22.Obj) = ((Wrd25.pObj) [3]);
  ((Wrd23.pObj) [3]) = (Wrd22.Obj);
  (Wrd18.Obj) = (Rsp [2]);
  ((Wrd23.pObj) [4]) = (Wrd18.Obj);
  (Rsp [1]) = (Wrd15.Obj);
  (Rsp [2]) = (Wrd5.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_11_12]));

DEFLABEL (label_17)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11_9]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_11_2]), 1);

DEFLABEL (label_10)
  (Wrd5.Obj) = Rvl;
  goto label_16;

DEFLABEL (label_19)
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11_8]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_11_0]), 1);

DEFLABEL (label_9)
  (* (--Rsp)) = Rvl;
  goto label_18;

DEFLABEL (lambda_14)
  CLOSURE_HEADER (LABEL_11_10);

DEFLABEL (lambda_4)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11_13]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [4]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = ((Wrd9.pObj) [3]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_11_14]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_11_13);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = ((Wrd6.pObj) [4]);
  (Wrd11.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd11.Obj);
  (Rsp [2]) = (Wrd8.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_12_4 3
#define ENVIRONMENT_LABEL_12_3 9
#define DEBUGGING_LABEL_12_2 8
#define OBJECT_12_0 7
#define EXECUTE_CACHE_12_5 5
#define FREE_REFERENCES_LABEL_12_0 4
#define NUMBER_OF_LINKER_SECTIONS_12_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_12 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_12_4);
      goto comma_list_writer_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (comma_list_writer_3)
DEFLABEL (comma_list_writer_0)
  INTERRUPT_CHECK (26, LABEL_12_4);
  (Wrd5.Obj) = (current_block [OBJECT_12_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_13_4 3
#define LABEL_13_5 5
#define TAG_13_6 1
#define LABEL_13_8 7
#define LABEL_13_10 9
#define LABEL_13_11 11
#define LABEL_13_12 13
#define LABEL_13_7 15
#define LABEL_13_15 17
#define LABEL_13_16 19
#define LABEL_13_14 21
#define LABEL_13_17 23
#define LABEL_13_18 25
#define LABEL_13_13 27
#define LABEL_13_19 29
#define LABEL_13_21 31
#define ENVIRONMENT_LABEL_13_3 42
#define DEBUGGING_LABEL_13_2 41
#define OBJECT_13_3 40
#define OBJECT_13_2 39
#define OBJECT_13_1 38
#define OBJECT_13_0 37
#define EXECUTE_CACHE_13_20 33
#define EXECUTE_CACHE_13_9 35
#define FREE_REFERENCES_LABEL_13_0 32
#define NUMBER_OF_LINKER_SECTIONS_13_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_13 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd43;
  machine_word Wrd42;
  machine_word Wrd36;
  machine_word Wrd27;
  machine_word Wrd23;
  machine_word Wrd21;
  machine_word Wrd5;
  machine_word Wrd74;
  machine_word Wrd64;
  machine_word Wrd68;
  machine_word Wrd67;
  machine_word Wrd66;
  machine_word Wrd65;
  machine_word Wrd80;
  machine_word Wrd54;
  machine_word Wrd76;
  machine_word Wrd75;
  machine_word Wrd83;
  machine_word Wrd85;
  machine_word Wrd84;
  machine_word Wrd47;
  machine_word Wrd33;
  machine_word Wrd37;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd30;
  machine_word Wrd22;
  machine_word Wrd24;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd55;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd51;
  machine_word Wrd50;
  machine_word Wrd58;
  machine_word Wrd60;
  machine_word Wrd59;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_13_4);
      goto pair_writer_14;

    case 1:
      current_block = (Rpc - LABEL_13_5);
      goto lambda_25;

    case 2:
      current_block = (Rpc - LABEL_13_8);
      goto continuation_3;

    case 3:
      current_block = (Rpc - LABEL_13_10);
      goto label_18;

    case 4:
      current_block = (Rpc - LABEL_13_11);
      goto label_16;

    case 5:
      current_block = (Rpc - LABEL_13_12);
      goto label_17;

    case 6:
      current_block = (Rpc - LABEL_13_7);
      goto continuation_4;

    case 7:
      current_block = (Rpc - LABEL_13_15);
      goto continuation_10;

    case 8:
      current_block = (Rpc - LABEL_13_16);
      goto continuation_9;

    case 9:
      current_block = (Rpc - LABEL_13_14);
      goto continuation_0;

    case 10:
      current_block = (Rpc - LABEL_13_17);
      goto label_22;

    case 11:
      current_block = (Rpc - LABEL_13_18);
      goto label_21;

    case 12:
      current_block = (Rpc - LABEL_13_13);
      goto continuation_1;

    case 13:
      current_block = (Rpc - LABEL_13_19);
      goto label_20;

    case 14:
      current_block = (Rpc - LABEL_13_21);
      goto label_19;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (pair_writer_24)
DEFLABEL (pair_writer_14)
  INTERRUPT_CHECK (26, LABEL_13_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_13_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_13_5])));
  Rhp += 3;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd12 = Wrd7;
  (Wrd13.Obj) = (Rsp [2]);
  ((Wrd12.pObj) [2]) = (Wrd13.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd12.pObj) [3]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd12.pObj) [4]) = (Wrd9.Obj);
  Rvl = (Wrd6.Obj);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (lambda_25)
  CLOSURE_HEADER (LABEL_13_5);

DEFLABEL (lambda_13)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_8]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_9]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_13_8);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_48;
  (Wrd50.Obj) = (Rsp [2]);
  (Wrd51.uLng) = (OBJECT_TYPE (Wrd50.Obj));
  if (! ((Wrd51.uLng) == 1))
    goto label_47;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd50.Obj));
  (Wrd18.Obj) = ((Wrd17.pObj) [1]);
  if ((Wrd18.Obj) == ((SCHEME_OBJECT) 0))
    goto label_43;

DEFLABEL (label_46)
  (Wrd25.Obj) = (Rsp [2]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if (! ((Wrd26.uLng) == 1))
    goto label_45;
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd22.Obj) = ((Wrd24.pObj) [1]);

DEFLABEL (label_44)
  if ((Wrd22.Obj) == (current_block [OBJECT_13_1]))
    goto label_43;
  (Wrd38.Obj) = (Rsp [1]);
  (Wrd39.pObj) = (OBJECT_ADDRESS (Wrd38.Obj));
  (Wrd40.Obj) = ((Wrd39.pObj) [2]);
  (Wrd41.uLng) = (OBJECT_TYPE (Wrd40.Obj));
  if (! ((Wrd41.uLng) == 1))
    goto label_42;
  (Wrd37.pObj) = (OBJECT_ADDRESS (Wrd40.Obj));
  (Wrd33.Obj) = ((Wrd37.pObj) [1]);

DEFLABEL (label_41)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd33.Obj);

DEFLABEL (label_40)
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_13]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_14]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [4]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_9]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_13_14);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_39;
  (Wrd75.Obj) = (Rsp [3]);
  (Wrd76.uLng) = (OBJECT_TYPE (Wrd75.Obj));
  if (! ((Wrd76.uLng) == 1))
    goto label_38;
  (Wrd54.pObj) = (OBJECT_ADDRESS (Wrd75.Obj));
  (Wrd55.Obj) = ((Wrd54.pObj) [0]);
  if ((Wrd55.Obj) == ((SCHEME_OBJECT) 0))
    goto label_37;

DEFLABEL (label_36)
  (Wrd65.Obj) = (Rsp [2]);
  (Wrd66.pObj) = (OBJECT_ADDRESS (Wrd65.Obj));
  (Wrd67.Obj) = ((Wrd66.pObj) [4]);
  (Wrd68.uLng) = (OBJECT_TYPE (Wrd67.Obj));
  if (! ((Wrd68.uLng) == 1))
    goto label_35;
  (Wrd64.pObj) = (OBJECT_ADDRESS (Wrd67.Obj));
  (Wrd60.Obj) = ((Wrd64.pObj) [1]);

DEFLABEL (label_34)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd60.Obj);

DEFLABEL (label_33)
  (Wrd5.Obj) = (Rsp [0]);
  if ((Wrd5.Obj) == ((SCHEME_OBJECT) 0))
    goto label_30;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_16]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd14.Obj) = (Rsp [5]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd15.uLng) == 1))
    goto label_32;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (* (--Rsp)) = (Wrd13.Obj);

DEFLABEL (label_31)
  (Wrd20.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd20.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_13_16);

DEFLABEL (label_30)
  (Wrd21.Obj) = (Rsp [2]);
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd23.Obj) = ((Wrd22.pObj) [3]);
  if ((Wrd23.Obj) == ((SCHEME_OBJECT) 0))
    goto label_29;
  (Wrd25.Obj) = (Rsp [0]);
  if ((Wrd25.Obj) == ((SCHEME_OBJECT) 0))
    goto label_29;
  (Wrd27.Obj) = (Rsp [1]);
  if ((Wrd27.Obj) == ((SCHEME_OBJECT) 0))
    goto label_29;
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_15]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (Wrd32.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_20]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_13_15);

DEFLABEL (label_29)
  (Wrd36.Obj) = (Rsp [1]);
  if (! ((Wrd36.Obj) == ((SCHEME_OBJECT) 0)))
    goto label_26;
  Rvl = (current_block [OBJECT_13_3]);
  Rsp = (& (Rsp [5]));
  goto pop_return;

DEFLABEL (label_26)
  (Rsp [2]) = (Wrd36.Obj);
  (Wrd42.Obj) = (Rsp [3]);
  (Wrd43.uLng) = (OBJECT_TYPE (Wrd42.Obj));
  if (! ((Wrd43.uLng) == 1))
    goto label_28;
  (Wrd41.pObj) = (OBJECT_ADDRESS (Wrd42.Obj));
  (Wrd39.Obj) = ((Wrd41.pObj) [1]);

DEFLABEL (label_27)
  (Rsp [3]) = (Wrd39.Obj);
  Rsp = (& (Rsp [2]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (label_28)
  (Wrd47.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_19]))));
  (* (--Rsp)) = (Wrd47.Obj);
  (* (--Rsp)) = (Wrd42.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_13_0]), 1);

DEFLABEL (label_20)
  (Wrd39.Obj) = Rvl;
  goto label_27;

DEFLABEL (label_32)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_21]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd14.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_13_2]), 1);

DEFLABEL (label_19)
  (* (--Rsp)) = Rvl;
  goto label_31;

DEFLABEL (label_35)
  (Wrd74.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_18]))));
  (* (--Rsp)) = (Wrd74.Obj);
  (* (--Rsp)) = (Wrd67.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_13_0]), 1);

DEFLABEL (label_21)
  (Wrd60.Obj) = Rvl;
  goto label_34;

DEFLABEL (label_37)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  goto label_33;

DEFLABEL (label_38)
  (Wrd80.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_17]))));
  (* (--Rsp)) = (Wrd80.Obj);
  (* (--Rsp)) = (Wrd75.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_13_2]), 1);

DEFLABEL (label_22)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_37;
  goto label_36;

DEFLABEL (label_39)
  (Wrd84.Obj) = (Rsp [2]);
  (Wrd85.pObj) = (OBJECT_ADDRESS (Wrd84.Obj));
  (Wrd83.Obj) = ((Wrd85.pObj) [4]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd83.Obj);
  goto label_33;

DEFLABEL (label_42)
  (Wrd47.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_12]))));
  (* (--Rsp)) = (Wrd47.Obj);
  (* (--Rsp)) = (Wrd40.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_13_0]), 1);

DEFLABEL (label_17)
  (Wrd33.Obj) = Rvl;
  goto label_41;

DEFLABEL (label_43)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  goto label_40;

DEFLABEL (label_45)
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_11]))));
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_13_0]), 1);

DEFLABEL (label_16)
  (Wrd22.Obj) = Rvl;
  goto label_44;

DEFLABEL (label_47)
  (Wrd55.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_10]))));
  (* (--Rsp)) = (Wrd55.Obj);
  (* (--Rsp)) = (Wrd50.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_13_0]), 1);

DEFLABEL (label_18)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_43;
  goto label_46;

DEFLABEL (label_48)
  (Wrd59.Obj) = (Rsp [1]);
  (Wrd60.pObj) = (OBJECT_ADDRESS (Wrd59.Obj));
  (Wrd58.Obj) = ((Wrd60.pObj) [2]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd58.Obj);
  goto label_40;

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_13_13);
  (* (--Rsp)) = Rvl;
  goto label_33;

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_13_7);
  (* (--Rsp)) = Rvl;
  goto label_40;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_14_4 3
#define LABEL_14_5 5
#define LABEL_14_6 7
#define LABEL_14_7 9
#define LABEL_14_8 11
#define LABEL_14_10 13
#define LABEL_14_11 15
#define LABEL_14_12 17
#define LABEL_14_13 19
#define LABEL_14_14 21
#define LABEL_14_15 23
#define LABEL_14_16 25
#define LABEL_14_17 27
#define LABEL_14_18 29
#define LABEL_14_19 31
#define LABEL_14_22 33
#define TAG_14_23 15
#define LABEL_14_25 35
#define LABEL_14_24 37
#define LABEL_14_26 39
#define LABEL_14_29 41
#define LABEL_14_30 43
#define LABEL_14_31 45
#define LABEL_14_32 47
#define LABEL_14_28 49
#define LABEL_14_33 51
#define LABEL_14_34 53
#define LABEL_14_35 55
#define LABEL_14_36 57
#define LABEL_14_37 59
#define LABEL_14_38 61
#define LABEL_14_27 63
#define LABEL_14_39 65
#define LABEL_14_40 67
#define LABEL_14_41 69
#define LABEL_14_42 71
#define LABEL_14_43 73
#define ENVIRONMENT_LABEL_14_3 94
#define DEBUGGING_LABEL_14_2 93
#define OBJECT_14_9 92
#define OBJECT_14_8 91
#define OBJECT_14_7 90
#define OBJECT_14_6 89
#define OBJECT_14_5 88
#define OBJECT_14_4 87
#define OBJECT_14_3 86
#define OBJECT_14_2 85
#define OBJECT_14_1 84
#define OBJECT_14_0 83
#define EXECUTE_CACHE_14_44 75
#define EXECUTE_CACHE_14_21 77
#define EXECUTE_CACHE_14_20 79
#define EXECUTE_CACHE_14_9 81
#define FREE_REFERENCES_LABEL_14_0 74
#define NUMBER_OF_LINKER_SECTIONS_14_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_14 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd47;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd31;
  machine_word Wrd28;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd33;
  machine_word Wrd42;
  machine_word Wrd68;
  machine_word Wrd69;
  machine_word Wrd58;
  machine_word Wrd59;
  machine_word Wrd60;
  machine_word Wrd51;
  machine_word Wrd53;
  machine_word Wrd52;
  machine_word Wrd13;
  machine_word Wrd9;
  machine_word Wrd104;
  machine_word Wrd105;
  machine_word Wrd96;
  machine_word Wrd97;
  machine_word Wrd98;
  machine_word Wrd89;
  machine_word Wrd90;
  machine_word Wrd122;
  machine_word Wrd83;
  machine_word Wrd82;
  machine_word Wrd79;
  machine_word Wrd117;
  machine_word Wrd116;
  machine_word Wrd111;
  machine_word Wrd143;
  machine_word Wrd137;
  machine_word Wrd138;
  machine_word Wrd139;
  machine_word Wrd135;
  machine_word Wrd127;
  machine_word Wrd129;
  machine_word Wrd131;
  machine_word Wrd130;
  machine_word Wrd24;
  machine_word Wrd21;
  machine_word Wrd11;
  machine_word Wrd15;
  machine_word Wrd7;
  machine_word Wrd25;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd22;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd14;
  machine_word Wrd8;
  machine_word Wrd61;
  machine_word Wrd56;
  machine_word Wrd55;
  machine_word Wrd57;
  machine_word Wrd54;
  machine_word Wrd46;
  machine_word Wrd48;
  machine_word Wrd50;
  machine_word Wrd49;
  machine_word Wrd45;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd32;
  machine_word Wrd34;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd81;
  machine_word Wrd80;
  machine_word Wrd72;
  machine_word Wrd74;
  machine_word Wrd76;
  machine_word Wrd75;
  machine_word Wrd71;
  machine_word Wrd70;
  machine_word Wrd62;
  machine_word Wrd64;
  machine_word Wrd66;
  machine_word Wrd65;
  machine_word Wrd87;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd6;
  machine_word Wrd106;
  machine_word Wrd100;
  machine_word Wrd101;
  machine_word Wrd102;
  machine_word Wrd99;
  machine_word Wrd91;
  machine_word Wrd93;
  machine_word Wrd95;
  machine_word Wrd94;
  machine_word Wrd125;
  machine_word Wrd120;
  machine_word Wrd119;
  machine_word Wrd121;
  machine_word Wrd118;
  machine_word Wrd110;
  machine_word Wrd112;
  machine_word Wrd114;
  machine_word Wrd113;
  machine_word Wrd109;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_14_4);
      goto vector_writer_45;

    case 1:
      current_block = (Rpc - LABEL_14_5);
      goto continuation_15;

    case 2:
      current_block = (Rpc - LABEL_14_6);
      goto continuation_12;

    case 3:
      current_block = (Rpc - LABEL_14_7);
      goto label_56;

    case 4:
      current_block = (Rpc - LABEL_14_8);
      goto label_57;

    case 5:
      current_block = (Rpc - LABEL_14_10);
      goto label_54;

    case 6:
      current_block = (Rpc - LABEL_14_11);
      goto label_55;

    case 7:
      current_block = (Rpc - LABEL_14_12);
      goto continuation_21;

    case 8:
      current_block = (Rpc - LABEL_14_13);
      goto loop_18;

    case 9:
      current_block = (Rpc - LABEL_14_14);
      goto label_52;

    case 10:
      current_block = (Rpc - LABEL_14_15);
      goto label_50;

    case 11:
      current_block = (Rpc - LABEL_14_16);
      goto label_51;

    case 12:
      current_block = (Rpc - LABEL_14_17);
      goto label_47;

    case 13:
      current_block = (Rpc - LABEL_14_18);
      goto label_48;

    case 14:
      current_block = (Rpc - LABEL_14_19);
      goto label_49;

    case 15:
      current_block = (Rpc - LABEL_14_22);
      goto lambda_74;

    case 16:
      current_block = (Rpc - LABEL_14_25);
      goto label_53;

    case 17:
      current_block = (Rpc - LABEL_14_24);
      goto continuation_23;

    case 18:
      current_block = (Rpc - LABEL_14_26);
      goto loop_42;

    case 19:
      current_block = (Rpc - LABEL_14_29);
      goto label_58;

    case 20:
      current_block = (Rpc - LABEL_14_30);
      goto label_59;

    case 21:
      current_block = (Rpc - LABEL_14_31);
      goto continuation_37;

    case 22:
      current_block = (Rpc - LABEL_14_32);
      goto continuation_35;

    case 23:
      current_block = (Rpc - LABEL_14_28);
      goto continuation_29;

    case 24:
      current_block = (Rpc - LABEL_14_33);
      goto label_69;

    case 25:
      current_block = (Rpc - LABEL_14_34);
      goto label_70;

    case 26:
      current_block = (Rpc - LABEL_14_35);
      goto label_68;

    case 27:
      current_block = (Rpc - LABEL_14_36);
      goto label_65;

    case 28:
      current_block = (Rpc - LABEL_14_37);
      goto label_66;

    case 29:
      current_block = (Rpc - LABEL_14_38);
      goto label_67;

    case 30:
      current_block = (Rpc - LABEL_14_27);
      goto continuation_30;

    case 31:
      current_block = (Rpc - LABEL_14_39);
      goto label_60;

    case 32:
      current_block = (Rpc - LABEL_14_40);
      goto label_62;

    case 33:
      current_block = (Rpc - LABEL_14_41);
      goto label_63;

    case 34:
      current_block = (Rpc - LABEL_14_42);
      goto label_64;

    case 35:
      current_block = (Rpc - LABEL_14_43);
      goto label_61;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (vector_writer_72)
DEFLABEL (vector_writer_45)
  INTERRUPT_CHECK (26, LABEL_14_4);
  (Wrd5.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd5.Obj);
  goto loop_18;

DEFLABEL (loop_73)
DEFLABEL (loop_18)
  INTERRUPT_CHECK (26, LABEL_14_13);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_81;
  if ((Wrd5.Obj) == (current_block [OBJECT_14_2]))
    goto label_77;
  (Wrd8.Obj) = (current_block [OBJECT_14_4]);
  goto label_76;

DEFLABEL (label_77)
  (Wrd8.Obj) = (current_block [OBJECT_14_3]);

DEFLABEL (label_76)
DEFLABEL (label_80)
  Rsp = (& (Rsp [1]));
  if ((Wrd8.Obj) == ((SCHEME_OBJECT) 0))
    goto label_79;

DEFLABEL (label_78)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd23.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_14_23);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_14_22])));
  Rhp += 2;
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd23.pObj)));
  Wrd26 = Wrd23;
  (Wrd27.Obj) = (Rsp [1]);
  ((Wrd26.pObj) [2]) = (Wrd27.Obj);
  (Wrd25.Obj) = (Rsp [0]);
  ((Wrd26.pObj) [3]) = (Wrd25.Obj);
  Rvl = (Wrd22.Obj);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_79)
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_12]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd18.Obj) = (Rsp [1]);
  (Wrd19.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd18.Obj);
  (* (Rhp++)) = (Wrd19.Obj);
  (Wrd16.pObj) = (& (Rhp [-2]));
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd16.pObj)));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd20.Obj) = (current_block [OBJECT_14_5]);
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14_21]));

DEFLABEL (continuation_21)
  INTERRUPT_CHECK (27, LABEL_14_12);
  goto label_78;

DEFLABEL (label_81)
  if (! ((Wrd6.uLng) == 1))
    goto label_105;
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd30.Obj) = ((Wrd29.pObj) [0]);
  if ((Wrd30.Obj) == ((SCHEME_OBJECT) 0))
    goto label_83;

DEFLABEL (label_104)
  (Wrd65.Obj) = (Rsp [0]);
  (Wrd66.uLng) = (OBJECT_TYPE (Wrd65.Obj));
  if (! ((Wrd66.uLng) == 1))
    goto label_103;
  (Wrd64.pObj) = (OBJECT_ADDRESS (Wrd65.Obj));
  (Wrd62.Obj) = ((Wrd64.pObj) [0]);

DEFLABEL (label_102)
  (Wrd71.uLng) = (OBJECT_TYPE (Wrd62.Obj));
  if ((Wrd71.uLng) == 2)
    goto label_83;
  (Wrd75.Obj) = (Rsp [0]);
  (Wrd76.uLng) = (OBJECT_TYPE (Wrd75.Obj));
  if (! ((Wrd76.uLng) == 1))
    goto label_101;
  (Wrd74.pObj) = (OBJECT_ADDRESS (Wrd75.Obj));
  (Wrd72.Obj) = ((Wrd74.pObj) [0]);

DEFLABEL (label_100)
  (Wrd81.uLng) = (OBJECT_TYPE (Wrd72.Obj));
  if ((Wrd81.uLng) == 30)
    goto label_83;

DEFLABEL (label_82)
  Rsp = (& (Rsp [1]));
  goto label_79;

DEFLABEL (label_83)
  (Wrd35.Obj) = (Rsp [0]);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if (! ((Wrd36.uLng) == 1))
    goto label_99;
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd32.Obj) = ((Wrd34.pObj) [1]);

DEFLABEL (label_98)
  (Wrd41.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd41.uLng) == 1))
    goto label_82;
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_6]))));
  (* (--Rsp)) = (Wrd45.Obj);
  (Wrd49.Obj) = (Rsp [1]);
  (Wrd50.uLng) = (OBJECT_TYPE (Wrd49.Obj));
  if (! ((Wrd50.uLng) == 1))
    goto label_97;
  (Wrd48.pObj) = (OBJECT_ADDRESS (Wrd49.Obj));
  (Wrd46.Obj) = ((Wrd48.pObj) [1]);

DEFLABEL (label_96)
  (Wrd57.uLng) = (OBJECT_TYPE (Wrd46.Obj));
  if (! ((Wrd57.uLng) == 1))
    goto label_95;
  (Wrd55.pObj) = (OBJECT_ADDRESS (Wrd46.Obj));
  (Wrd56.Obj) = ((Wrd55.pObj) [0]);
  (* (--Rsp)) = (Wrd56.Obj);

DEFLABEL (label_94)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14_20]));

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_14_6);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_89;

DEFLABEL (label_88)
  (Wrd94.Obj) = (Rsp [0]);
  (Wrd95.uLng) = (OBJECT_TYPE (Wrd94.Obj));
  if (! ((Wrd95.uLng) == 1))
    goto label_87;
  (Wrd93.pObj) = (OBJECT_ADDRESS (Wrd94.Obj));
  (Wrd91.Obj) = ((Wrd93.pObj) [1]);

DEFLABEL (label_86)
  (Wrd102.uLng) = (OBJECT_TYPE (Wrd91.Obj));
  if (! ((Wrd102.uLng) == 1))
    goto label_85;
  (Wrd101.pObj) = (OBJECT_ADDRESS (Wrd91.Obj));
  (Wrd100.Obj) = ((Wrd101.pObj) [1]);

DEFLABEL (label_84)
  (Rsp [0]) = (Wrd100.Obj);
  goto loop_18;

DEFLABEL (label_85)
  (Wrd106.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_11]))));
  (* (--Rsp)) = (Wrd106.Obj);
  (* (--Rsp)) = (Wrd91.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14_0]), 1);

DEFLABEL (label_55)
  (Wrd100.Obj) = Rvl;
  goto label_84;

DEFLABEL (label_87)
  (Wrd99.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_10]))));
  (* (--Rsp)) = (Wrd99.Obj);
  (* (--Rsp)) = (Wrd94.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14_0]), 1);

DEFLABEL (label_54)
  (Wrd91.Obj) = Rvl;
  goto label_86;

DEFLABEL (label_89)
  (Wrd109.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_5]))));
  (* (--Rsp)) = (Wrd109.Obj);
  (Wrd113.Obj) = (Rsp [1]);
  (Wrd114.uLng) = (OBJECT_TYPE (Wrd113.Obj));
  if (! ((Wrd114.uLng) == 1))
    goto label_93;
  (Wrd112.pObj) = (OBJECT_ADDRESS (Wrd113.Obj));
  (Wrd110.Obj) = ((Wrd112.pObj) [1]);

DEFLABEL (label_92)
  (Wrd121.uLng) = (OBJECT_TYPE (Wrd110.Obj));
  if (! ((Wrd121.uLng) == 1))
    goto label_91;
  (Wrd119.pObj) = (OBJECT_ADDRESS (Wrd110.Obj));
  (Wrd120.Obj) = ((Wrd119.pObj) [0]);
  (* (--Rsp)) = (Wrd120.Obj);

DEFLABEL (label_90)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14_9]));

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_14_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_82;
  goto label_88;

DEFLABEL (label_91)
  (Wrd125.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_8]))));
  (* (--Rsp)) = (Wrd125.Obj);
  (* (--Rsp)) = (Wrd110.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14_1]), 1);

DEFLABEL (label_57)
  (* (--Rsp)) = Rvl;
  goto label_90;

DEFLABEL (label_93)
  (Wrd118.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_7]))));
  (* (--Rsp)) = (Wrd118.Obj);
  (* (--Rsp)) = (Wrd113.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14_0]), 1);

DEFLABEL (label_56)
  (Wrd110.Obj) = Rvl;
  goto label_92;

DEFLABEL (label_95)
  (Wrd61.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_19]))));
  (* (--Rsp)) = (Wrd61.Obj);
  (* (--Rsp)) = (Wrd46.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14_1]), 1);

DEFLABEL (label_49)
  (* (--Rsp)) = Rvl;
  goto label_94;

DEFLABEL (label_97)
  (Wrd54.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_18]))));
  (* (--Rsp)) = (Wrd54.Obj);
  (* (--Rsp)) = (Wrd49.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14_0]), 1);

DEFLABEL (label_48)
  (Wrd46.Obj) = Rvl;
  goto label_96;

DEFLABEL (label_99)
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_17]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14_0]), 1);

DEFLABEL (label_47)
  (Wrd32.Obj) = Rvl;
  goto label_98;

DEFLABEL (label_101)
  (Wrd80.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_16]))));
  (* (--Rsp)) = (Wrd80.Obj);
  (* (--Rsp)) = (Wrd75.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14_1]), 1);

DEFLABEL (label_51)
  (Wrd72.Obj) = Rvl;
  goto label_100;

DEFLABEL (label_103)
  (Wrd70.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_15]))));
  (* (--Rsp)) = (Wrd70.Obj);
  (* (--Rsp)) = (Wrd65.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14_1]), 1);

DEFLABEL (label_50)
  (Wrd62.Obj) = Rvl;
  goto label_102;

DEFLABEL (label_105)
  (Wrd87.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_14]))));
  (* (--Rsp)) = (Wrd87.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14_1]), 1);

DEFLABEL (label_52)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_83;
  goto label_104;

DEFLABEL (lambda_74)
  CLOSURE_HEADER (LABEL_14_22);

DEFLABEL (lambda_44)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_24]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd18.Obj) = (Rsp [3]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd19.uLng) == 10))
    goto label_107;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd17.Lng))))
    goto label_107;
  (Wrd11.Obj) = ((Wrd15.pObj) [1]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_106)
  (Wrd25.Obj) = (Rsp [3]);
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd27.Obj) = ((Wrd26.pObj) [3]);
  (* (--Rsp)) = (Wrd27.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_23)
  INTERRUPT_CHECK (27, LABEL_14_24);
  (Wrd5.Obj) = (current_block [OBJECT_14_8]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd8.Obj) = ((Wrd7.pObj) [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  goto loop_42;

DEFLABEL (label_107)
  (Wrd20.Obj) = (Rsp [3]);
  (Wrd21.Obj) = (current_block [OBJECT_14_6]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_25]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14_7]), 2);

DEFLABEL (label_53)
  (* (--Rsp)) = Rvl;
  goto label_106;

DEFLABEL (loop_75)
DEFLABEL (loop_42)
  INTERRUPT_CHECK (26, LABEL_14_26);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_108;
  Rvl = (current_block [OBJECT_14_9]);
  Rsp = (& (Rsp [5]));
  goto pop_return;

DEFLABEL (label_108)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_27]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_28]))));
  (* (--Rsp)) = (Wrd14.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_139;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd17.pObj) [1]);

DEFLABEL (label_138)
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd26.uLng) == 1))
    goto label_137;
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd25.Obj) = ((Wrd24.pObj) [0]);
  (* (--Rsp)) = (Wrd25.Obj);

DEFLABEL (label_136)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14_9]));

DEFLABEL (continuation_29)
  INTERRUPT_CHECK (27, LABEL_14_28);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_131;
  (Wrd119.Obj) = (Rsp [4]);
  (Wrd120.uLng) = (OBJECT_TYPE (Wrd119.Obj));
  if (! ((Wrd120.uLng) == 10))
    goto label_130;
  (Wrd111.Obj) = (Rsp [2]);
  (Wrd112.uLng) = (OBJECT_TYPE (Wrd111.Obj));
  if (! ((Wrd112.uLng) == 26))
    goto label_130;
  (Wrd114.Lng) = (FIXNUM_TO_LONG (Wrd111.Obj));
  (Wrd116.pObj) = (OBJECT_ADDRESS (Wrd119.Obj));
  (Wrd117.Obj) = ((Wrd116.pObj) [0]);
  (Wrd118.Lng) = (FIXNUM_TO_LONG (Wrd117.Obj));
  if (! (((unsigned long) (Wrd114.Lng)) < ((unsigned long) (Wrd118.Lng))))
    goto label_130;
  (Wrd79.uLng) = (OBJECT_DATUM (Wrd111.Obj));
  (Wrd82.pObj) = (& ((Wrd116.pObj) [(Wrd79.Lng)]));
  (Wrd83.Obj) = ((Wrd82.pObj) [1]);
  if ((Wrd83.Obj) == ((SCHEME_OBJECT) 0))
    goto label_129;

DEFLABEL (label_128)
  (Wrd90.Obj) = (Rsp [1]);
  (Wrd91.uLng) = (OBJECT_TYPE (Wrd90.Obj));
  if (! ((Wrd91.uLng) == 1))
    goto label_127;
  (Wrd89.pObj) = (OBJECT_ADDRESS (Wrd90.Obj));
  (Wrd87.Obj) = ((Wrd89.pObj) [1]);

DEFLABEL (label_126)
  (Wrd98.uLng) = (OBJECT_TYPE (Wrd87.Obj));
  if (! ((Wrd98.uLng) == 1))
    goto label_125;
  (Wrd97.pObj) = (OBJECT_ADDRESS (Wrd87.Obj));
  (Wrd96.Obj) = ((Wrd97.pObj) [0]);

DEFLABEL (label_124)
  (Wrd106.uLng) = (OBJECT_TYPE (Wrd96.Obj));
  if (! ((Wrd106.uLng) == 1))
    goto label_123;
  (Wrd105.pObj) = (OBJECT_ADDRESS (Wrd96.Obj));
  (Wrd104.Obj) = ((Wrd105.pObj) [1]);

DEFLABEL (label_122)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd104.Obj);

DEFLABEL (label_121)
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_120;
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [0]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_119)
  (Wrd14.Obj) = (Rsp [1]);
  if ((Wrd14.Obj) == ((SCHEME_OBJECT) 0))
    goto label_115;
  (Wrd16.Obj) = (Rsp [0]);
  if ((Wrd16.Obj) == ((SCHEME_OBJECT) 0))
    goto label_118;
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_32]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd21.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14_44]));

DEFLABEL (continuation_35)
  INTERRUPT_CHECK (27, LABEL_14_32);

DEFLABEL (label_118)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_31]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd26.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd41.Obj) = (Rsp [7]);
  (Wrd42.uLng) = (OBJECT_TYPE (Wrd41.Obj));
  if (! ((Wrd42.uLng) == 10))
    goto label_117;
  (Wrd33.Obj) = (Rsp [5]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if (! ((Wrd34.uLng) == 26))
    goto label_117;
  (Wrd36.Lng) = (FIXNUM_TO_LONG (Wrd33.Obj));
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd41.Obj));
  (Wrd39.Obj) = ((Wrd38.pObj) [0]);
  (Wrd40.Lng) = (FIXNUM_TO_LONG (Wrd39.Obj));
  if (! (((unsigned long) (Wrd36.Lng)) < ((unsigned long) (Wrd40.Lng))))
    goto label_117;
  (Wrd28.uLng) = (OBJECT_DATUM (Wrd33.Obj));
  (Wrd31.pObj) = (& ((Wrd38.pObj) [(Wrd28.Lng)]));
  (Wrd32.Obj) = ((Wrd31.pObj) [1]);
  (* (--Rsp)) = (Wrd32.Obj);

DEFLABEL (label_116)
  (Wrd48.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd48.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_37)
  INTERRUPT_CHECK (27, LABEL_14_31);

DEFLABEL (label_115)
  (Wrd52.Obj) = (Rsp [2]);
  (Wrd53.uLng) = (OBJECT_TYPE (Wrd52.Obj));
  if (! ((Wrd53.uLng) == 1))
    goto label_114;
  (Wrd51.pObj) = (OBJECT_ADDRESS (Wrd52.Obj));
  (Wrd49.Obj) = ((Wrd51.pObj) [1]);

DEFLABEL (label_113)
  (Wrd60.uLng) = (OBJECT_TYPE (Wrd49.Obj));
  if (! ((Wrd60.uLng) == 1))
    goto label_112;
  (Wrd59.pObj) = (OBJECT_ADDRESS (Wrd49.Obj));
  (Wrd58.Obj) = ((Wrd59.pObj) [1]);

DEFLABEL (label_111)
  (Rsp [2]) = (Wrd58.Obj);
  (Wrd70.Obj) = (Rsp [3]);
  (Wrd71.uLng) = (OBJECT_TYPE (Wrd70.Obj));
  if (! ((Wrd71.uLng) == 26))
    goto label_110;
  (Wrd74.Lng) = (FIXNUM_TO_LONG (Wrd70.Obj));
  (Wrd72.Lng) = ((Wrd74.Lng) + 1L);
  if (! (LONG_TO_FIXNUM_P (Wrd72.Lng)))
    goto label_110;
  (Wrd69.Obj) = (LONG_TO_FIXNUM (Wrd72.Lng));

DEFLABEL (label_109)
  (Rsp [3]) = (Wrd69.Obj);
  Rsp = (& (Rsp [2]));
  goto loop_42;

DEFLABEL (label_110)
  (Wrd65.Obj) = (Rsp [3]);
  (Wrd68.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_42]))));
  (* (--Rsp)) = (Wrd68.Obj);
  (* (--Rsp)) = (Wrd65.Obj);
  INVOKE_INTERFACE_0 (38);

DEFLABEL (label_64)
  (Wrd69.Obj) = Rvl;
  goto label_109;

DEFLABEL (label_112)
  (Wrd64.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_41]))));
  (* (--Rsp)) = (Wrd64.Obj);
  (* (--Rsp)) = (Wrd49.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14_0]), 1);

DEFLABEL (label_63)
  (Wrd58.Obj) = Rvl;
  goto label_111;

DEFLABEL (label_114)
  (Wrd57.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_40]))));
  (* (--Rsp)) = (Wrd57.Obj);
  (* (--Rsp)) = (Wrd52.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14_0]), 1);

DEFLABEL (label_62)
  (Wrd49.Obj) = Rvl;
  goto label_113;

DEFLABEL (label_117)
  (Wrd43.Obj) = (Rsp [7]);
  (Wrd44.Obj) = (Rsp [5]);
  (Wrd47.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_43]))));
  (* (--Rsp)) = (Wrd47.Obj);
  (* (--Rsp)) = (Wrd44.Obj);
  (* (--Rsp)) = (Wrd43.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14_7]), 2);

DEFLABEL (label_61)
  (* (--Rsp)) = Rvl;
  goto label_116;

DEFLABEL (label_120)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_39]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14_1]), 1);

DEFLABEL (label_60)
  (* (--Rsp)) = Rvl;
  goto label_119;

DEFLABEL (label_123)
  (Wrd110.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_38]))));
  (* (--Rsp)) = (Wrd110.Obj);
  (* (--Rsp)) = (Wrd96.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14_0]), 1);

DEFLABEL (label_67)
  (Wrd104.Obj) = Rvl;
  goto label_122;

DEFLABEL (label_125)
  (Wrd102.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_37]))));
  (* (--Rsp)) = (Wrd102.Obj);
  (* (--Rsp)) = (Wrd87.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14_1]), 1);

DEFLABEL (label_66)
  (Wrd96.Obj) = Rvl;
  goto label_124;

DEFLABEL (label_127)
  (Wrd95.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_36]))));
  (* (--Rsp)) = (Wrd95.Obj);
  (* (--Rsp)) = (Wrd90.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14_0]), 1);

DEFLABEL (label_65)
  (Wrd87.Obj) = Rvl;
  goto label_126;

DEFLABEL (label_129)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  goto label_121;

DEFLABEL (label_130)
  (Wrd121.Obj) = (Rsp [4]);
  (Wrd122.Obj) = (Rsp [2]);
  (Wrd125.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_35]))));
  (* (--Rsp)) = (Wrd125.Obj);
  (* (--Rsp)) = (Wrd122.Obj);
  (* (--Rsp)) = (Wrd121.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14_7]), 2);

DEFLABEL (label_68)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_129;
  goto label_128;

DEFLABEL (label_131)
  (Wrd130.Obj) = (Rsp [1]);
  (Wrd131.uLng) = (OBJECT_TYPE (Wrd130.Obj));
  if (! ((Wrd131.uLng) == 1))
    goto label_135;
  (Wrd129.pObj) = (OBJECT_ADDRESS (Wrd130.Obj));
  (Wrd127.Obj) = ((Wrd129.pObj) [1]);

DEFLABEL (label_134)
  (Wrd139.uLng) = (OBJECT_TYPE (Wrd127.Obj));
  if (! ((Wrd139.uLng) == 1))
    goto label_133;
  (Wrd138.pObj) = (OBJECT_ADDRESS (Wrd127.Obj));
  (Wrd137.Obj) = ((Wrd138.pObj) [0]);

DEFLABEL (label_132)
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd137.Obj);
  goto label_121;

DEFLABEL (label_133)
  (Wrd143.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_34]))));
  (* (--Rsp)) = (Wrd143.Obj);
  (* (--Rsp)) = (Wrd127.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14_1]), 1);

DEFLABEL (label_70)
  (Wrd137.Obj) = Rvl;
  goto label_132;

DEFLABEL (label_135)
  (Wrd135.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_33]))));
  (* (--Rsp)) = (Wrd135.Obj);
  (* (--Rsp)) = (Wrd130.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14_0]), 1);

DEFLABEL (label_69)
  (Wrd127.Obj) = Rvl;
  goto label_134;

DEFLABEL (label_137)
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_30]))));
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd15.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14_1]), 1);

DEFLABEL (label_59)
  (* (--Rsp)) = Rvl;
  goto label_136;

DEFLABEL (label_139)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_29]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_14_0]), 1);

DEFLABEL (label_58)
  (Wrd15.Obj) = Rvl;
  goto label_138;

DEFLABEL (continuation_30)
  INTERRUPT_CHECK (27, LABEL_14_27);
  (* (--Rsp)) = Rvl;
  goto label_121;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_15_4 3
#define ENVIRONMENT_LABEL_15_3 6
#define DEBUGGING_LABEL_15_2 5
#define OBJECT_15_0 4
#define FREE_REFERENCES_LABEL_15_0 4
#define NUMBER_OF_LINKER_SECTIONS_15_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_15 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd7;
  machine_word Wrd10;
  machine_word Wrd9;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_15_4);
      goto opt_writer_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (opt_writer_3)
DEFLABEL (opt_writer_0)
  INTERRUPT_CHECK (26, LABEL_15_4);
  (Wrd9.Obj) = (current_block [OBJECT_15_0]);
  (Wrd10.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  Rsp = (& (Rsp [1]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_16_4 3
#define LABEL_16_5 5
#define ENVIRONMENT_LABEL_16_3 10
#define DEBUGGING_LABEL_16_2 9
#define OBJECT_16_2 8
#define OBJECT_16_1 7
#define OBJECT_16_0 6
#define FREE_REFERENCES_LABEL_16_0 6
#define NUMBER_OF_LINKER_SECTIONS_16_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_16 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd17;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_16_4);
      goto opt_writerP_2;

    case 1:
      current_block = (Rpc - LABEL_16_5);
      goto label_4;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (opt_writerP_6)
DEFLABEL (opt_writerP_2)
  INTERRUPT_CHECK (26, LABEL_16_4);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_9;

DEFLABEL (label_8)
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_7)
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_9)
  if (! ((Wrd6.uLng) == 1))
    goto label_11;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd9.Obj) = ((Wrd11.pObj) [0]);

DEFLABEL (label_10)
  if (! ((Wrd9.Obj) == (current_block [OBJECT_16_1])))
    goto label_8;
  Rvl = (current_block [OBJECT_16_2]);
  goto label_7;

DEFLABEL (label_11)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_16_5]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_16_0]), 1);

DEFLABEL (label_4)
  (Wrd9.Obj) = Rvl;
  goto label_10;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_17_4 3
#define LABEL_17_5 5
#define TAG_17_6 1
#define LABEL_17_7 7
#define ENVIRONMENT_LABEL_17_3 9
#define DEBUGGING_LABEL_17_2 8
#define FREE_REFERENCES_LABEL_17_0 8
#define NUMBER_OF_LINKER_SECTIONS_17_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_17 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_17_4);
      goto alt_writer_3;

    case 1:
      current_block = (Rpc - LABEL_17_5);
      goto lambda_7;

    case 2:
      current_block = (Rpc - LABEL_17_7);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (alt_writer_6)
DEFLABEL (alt_writer_3)
  INTERRUPT_CHECK (26, LABEL_17_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_17_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_17_5])));
  Rhp += 3;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd12 = Wrd7;
  (Wrd13.Obj) = (Rsp [2]);
  ((Wrd12.pObj) [2]) = (Wrd13.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd12.pObj) [3]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd12.pObj) [4]) = (Wrd9.Obj);
  Rvl = (Wrd6.Obj);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (lambda_7)
  CLOSURE_HEADER (LABEL_17_5);

DEFLABEL (lambda_2)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [4]);
  (* (--Rsp)) = (Wrd11.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_17_7);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_9;
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [3]);
  goto label_8;

DEFLABEL (label_9)
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd11.pObj) [2]);

DEFLABEL (label_8)
DEFLABEL (label_10)
  (Rsp [0]) = (Wrd7.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_18_4 3
#define LABEL_18_5 5
#define TAG_18_6 1
#define ENVIRONMENT_LABEL_18_3 10
#define DEBUGGING_LABEL_18_2 9
#define EXECUTE_CACHE_18_7 7
#define FREE_REFERENCES_LABEL_18_0 6
#define NUMBER_OF_LINKER_SECTIONS_18_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_18 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_18_4);
      goto token_writer_1;

    case 1:
      current_block = (Rpc - LABEL_18_5);
      goto lambda_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (token_writer_4)
DEFLABEL (token_writer_1)
  INTERRUPT_CHECK (26, LABEL_18_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_18_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_18_5])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  Rvl = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (lambda_5)
  CLOSURE_HEADER (LABEL_18_5);

DEFLABEL (lambda_0)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [1]) = (Wrd5.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_7]));

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_19_4 3
#define LABEL_19_6 5
#define LABEL_19_5 7
#define LABEL_19_8 9
#define ENVIRONMENT_LABEL_19_3 16
#define DEBUGGING_LABEL_19_2 15
#define OBJECT_19_1 14
#define OBJECT_19_0 13
#define EXECUTE_CACHE_19_7 11
#define FREE_REFERENCES_LABEL_19_0 10
#define NUMBER_OF_LINKER_SECTIONS_19_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_19 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd15;
  machine_word Wrd7;
  machine_word Wrd9;
  machine_word Wrd10;
  machine_word Wrd20;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd11;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_19_4);
      goto http_versionP_4;

    case 1:
      current_block = (Rpc - LABEL_19_6);
      goto label_6;

    case 2:
      current_block = (Rpc - LABEL_19_5);
      goto continuation_2;

    case 3:
      current_block = (Rpc - LABEL_19_8);
      goto label_7;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (http_versionP_9)
DEFLABEL (http_versionP_4)
  INTERRUPT_CHECK (26, LABEL_19_4);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_10;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_10)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_5]))));
  (* (--Rsp)) = (Wrd11.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_15;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_14)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_7]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_19_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_11;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_11)
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_13;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_12)
  (Rsp [0]) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_19_7]));

DEFLABEL (label_13)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_8]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_19_1]), 1);

DEFLABEL (label_7)
  (Wrd7.Obj) = Rvl;
  goto label_12;

DEFLABEL (label_15)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19_6]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_19_0]), 1);

DEFLABEL (label_6)
  (* (--Rsp)) = Rvl;
  goto label_14;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_20_4 3
#define LABEL_20_5 5
#define ENVIRONMENT_LABEL_20_3 13
#define DEBUGGING_LABEL_20_2 12
#define OBJECT_20_0 11
#define EXECUTE_CACHE_20_7 7
#define EXECUTE_CACHE_20_6 9
#define FREE_REFERENCES_LABEL_20_0 6
#define NUMBER_OF_LINKER_SECTIONS_20_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_20 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_20_4);
      goto guarantee_http_version_1;

    case 1:
      current_block = (Rpc - LABEL_20_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (guarantee_http_version_4)
DEFLABEL (guarantee_http_version_1)
  INTERRUPT_CHECK (26, LABEL_20_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_20_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_5;
  Rvl = (current_block [OBJECT_20_0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_5)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_21_4 3
#define ENVIRONMENT_LABEL_21_3 11
#define DEBUGGING_LABEL_21_2 10
#define OBJECT_21_2 9
#define OBJECT_21_1 8
#define OBJECT_21_0 7
#define EXECUTE_CACHE_21_5 5
#define FREE_REFERENCES_LABEL_21_0 4
#define NUMBER_OF_LINKER_SECTIONS_21_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_21 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_21_4);
      goto error_not_http_version_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (error_not_http_version_5)
DEFLABEL (error_not_http_version_2)
  INTERRUPT_CHECK (26, LABEL_21_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_21_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [2]);
  if ((Wrd7.Obj) == (current_block [OBJECT_21_1]))
    goto label_7;
  Wrd9 = Wrd7;
  goto label_6;

DEFLABEL (label_7)
  (Wrd9.Obj) = (current_block [OBJECT_21_2]);

DEFLABEL (label_6)
DEFLABEL (label_8)
  (Rsp [2]) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_22_4 3
#define ENVIRONMENT_LABEL_22_3 5
#define DEBUGGING_LABEL_22_2 4
#define FREE_REFERENCES_LABEL_22_0 4
#define NUMBER_OF_LINKER_SECTIONS_22_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_22 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd7;
  machine_word Wrd10;
  machine_word Wrd9;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_22_4);
      goto make_http_version_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (make_http_version_3)
DEFLABEL (make_http_version_0)
  INTERRUPT_CHECK (26, LABEL_22_4);
  (Wrd9.Obj) = (Rsp [0]);
  (Wrd10.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_23_4 3
#define ENVIRONMENT_LABEL_23_3 6
#define DEBUGGING_LABEL_23_2 5
#define OBJECT_23_0 4
#define FREE_REFERENCES_LABEL_23_0 4
#define NUMBER_OF_LINKER_SECTIONS_23_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_23 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd7;
  machine_word Wrd10;
  machine_word Wrd9;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_23_4);
      goto http_version_major_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (http_version_major_3)
DEFLABEL (http_version_major_0)
  INTERRUPT_CHECK (26, LABEL_23_4);
  (Wrd9.Obj) = (Rsp [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if (! ((Wrd10.uLng) == 1))
    goto label_4;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  Rvl = ((Wrd7.pObj) [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_23_0]), 1);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_24_4 3
#define ENVIRONMENT_LABEL_24_3 6
#define DEBUGGING_LABEL_24_2 5
#define OBJECT_24_0 4
#define FREE_REFERENCES_LABEL_24_0 4
#define NUMBER_OF_LINKER_SECTIONS_24_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_24 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd7;
  machine_word Wrd10;
  machine_word Wrd9;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_24_4);
      goto http_version_minor_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (http_version_minor_3)
DEFLABEL (http_version_minor_0)
  INTERRUPT_CHECK (26, LABEL_24_4);
  (Wrd9.Obj) = (Rsp [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if (! ((Wrd10.uLng) == 1))
    goto label_4;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  Rvl = ((Wrd7.pObj) [1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_24_0]), 1);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_25_4 3
#define LABEL_25_5 5
#define LABEL_25_6 7
#define LABEL_25_7 9
#define LABEL_25_8 11
#define LABEL_25_9 13
#define ENVIRONMENT_LABEL_25_3 18
#define DEBUGGING_LABEL_25_2 17
#define OBJECT_25_2 16
#define OBJECT_25_1 15
#define OBJECT_25_0 14
#define FREE_REFERENCES_LABEL_25_0 14
#define NUMBER_OF_LINKER_SECTIONS_25_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_25 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd56;
  machine_word Wrd54;
  machine_word Wrd53;
  machine_word Wrd51;
  machine_word Wrd43;
  machine_word Wrd45;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd42;
  machine_word Wrd34;
  machine_word Wrd36;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd30;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd14;
  machine_word Wrd16;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd13;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd9;
  machine_word Wrd8;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_25_4);
      goto http_version_P_5;

    case 1:
      current_block = (Rpc - LABEL_25_5);
      goto label_7;

    case 2:
      current_block = (Rpc - LABEL_25_6);
      goto label_8;

    case 3:
      current_block = (Rpc - LABEL_25_7);
      goto label_9;

    case 4:
      current_block = (Rpc - LABEL_25_8);
      goto label_10;

    case 5:
      current_block = (Rpc - LABEL_25_9);
      goto label_11;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (http_version_P_13)
DEFLABEL (http_version_P_5)
  INTERRUPT_CHECK (26, LABEL_25_4);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_27;
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [0]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_26)
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_25;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd14.Obj) = ((Wrd16.pObj) [0]);

DEFLABEL (label_24)
  (Wrd23.Obj) = (* (Rsp++));
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd24.uLng) == 26))
    goto label_23;
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd25.uLng) == 26))
    goto label_23;
  if ((Wrd14.Obj) == (Wrd23.Obj))
    goto label_16;

DEFLABEL (label_15)
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_14)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_16)
  (Wrd37.Obj) = (Rsp [0]);
  (Wrd38.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if (! ((Wrd38.uLng) == 1))
    goto label_22;
  (Wrd36.pObj) = (OBJECT_ADDRESS (Wrd37.Obj));
  (Wrd34.Obj) = ((Wrd36.pObj) [1]);

DEFLABEL (label_21)
  (Rsp [0]) = (Wrd34.Obj);
  (Wrd46.Obj) = (Rsp [1]);
  (Wrd47.uLng) = (OBJECT_TYPE (Wrd46.Obj));
  if (! ((Wrd47.uLng) == 1))
    goto label_20;
  (Wrd45.pObj) = (OBJECT_ADDRESS (Wrd46.Obj));
  (Wrd43.Obj) = ((Wrd45.pObj) [1]);

DEFLABEL (label_19)
  (Rsp [1]) = (Wrd43.Obj);
  (Wrd53.Obj) = (Rsp [0]);
  (Wrd54.uLng) = (OBJECT_TYPE (Wrd53.Obj));
  if ((Wrd54.uLng) == 26)
    goto label_18;

DEFLABEL (label_17)
  INVOKE_INTERFACE_0 (36);

DEFLABEL (label_18)
  (Wrd56.uLng) = (OBJECT_TYPE (Wrd43.Obj));
  if (! ((Wrd56.uLng) == 26))
    goto label_17;
  if (! ((Wrd53.Obj) == (Wrd43.Obj)))
    goto label_15;
  Rvl = (current_block [OBJECT_25_2]);
  goto label_14;

DEFLABEL (label_20)
  (Wrd51.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25_9]))));
  (* (--Rsp)) = (Wrd51.Obj);
  (* (--Rsp)) = (Wrd46.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_25_1]), 1);

DEFLABEL (label_11)
  (Wrd43.Obj) = Rvl;
  goto label_19;

DEFLABEL (label_22)
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25_8]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_25_1]), 1);

DEFLABEL (label_10)
  (Wrd34.Obj) = Rvl;
  goto label_21;

DEFLABEL (label_23)
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25_7]))));
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd14.Obj);
  INVOKE_INTERFACE_0 (36);

DEFLABEL (label_9)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_15;
  goto label_16;

DEFLABEL (label_25)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25_6]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_25_0]), 1);

DEFLABEL (label_8)
  (Wrd14.Obj) = Rvl;
  goto label_24;

DEFLABEL (label_27)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25_5]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_25_0]), 1);

DEFLABEL (label_7)
  (* (--Rsp)) = Rvl;
  goto label_26;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_26_4 3
#define LABEL_26_5 5
#define LABEL_26_6 7
#define LABEL_26_7 9
#define LABEL_26_8 11
#define LABEL_26_9 13
#define LABEL_26_10 15
#define LABEL_26_11 17
#define LABEL_26_12 19
#define ENVIRONMENT_LABEL_26_3 24
#define DEBUGGING_LABEL_26_2 23
#define OBJECT_26_2 22
#define OBJECT_26_1 21
#define OBJECT_26_0 20
#define FREE_REFERENCES_LABEL_26_0 20
#define NUMBER_OF_LINKER_SECTIONS_26_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_26 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd87;
  machine_word Wrd85;
  machine_word Wrd83;
  machine_word Wrd81;
  machine_word Wrd80;
  machine_word Wrd78;
  machine_word Wrd70;
  machine_word Wrd72;
  machine_word Wrd74;
  machine_word Wrd73;
  machine_word Wrd69;
  machine_word Wrd61;
  machine_word Wrd63;
  machine_word Wrd65;
  machine_word Wrd64;
  machine_word Wrd57;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd50;
  machine_word Wrd49;
  machine_word Wrd41;
  machine_word Wrd43;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd40;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd30;
  machine_word Wrd93;
  machine_word Wrd92;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd14;
  machine_word Wrd16;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd13;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd9;
  machine_word Wrd8;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_26_4);
      goto http_version_P_8;

    case 1:
      current_block = (Rpc - LABEL_26_5);
      goto label_10;

    case 2:
      current_block = (Rpc - LABEL_26_6);
      goto label_11;

    case 3:
      current_block = (Rpc - LABEL_26_7);
      goto label_12;

    case 4:
      current_block = (Rpc - LABEL_26_8);
      goto label_13;

    case 5:
      current_block = (Rpc - LABEL_26_9);
      goto label_14;

    case 6:
      current_block = (Rpc - LABEL_26_10);
      goto label_15;

    case 7:
      current_block = (Rpc - LABEL_26_11);
      goto label_16;

    case 8:
      current_block = (Rpc - LABEL_26_12);
      goto label_17;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (http_version_P_19)
DEFLABEL (http_version_P_8)
  INTERRUPT_CHECK (26, LABEL_26_4);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_40;
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [0]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_39)
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_38;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd14.Obj) = ((Wrd16.pObj) [0]);

DEFLABEL (label_37)
  (Wrd23.Obj) = (* (Rsp++));
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd24.uLng) == 26))
    goto label_36;
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd25.uLng) == 26))
    goto label_36;
  (Wrd92.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  (Wrd93.Lng) = (FIXNUM_TO_LONG (Wrd23.Obj));
  if ((Wrd92.Lng) < (Wrd93.Lng))
    goto label_25;

DEFLABEL (label_35)
  (Wrd35.Obj) = (Rsp [1]);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if (! ((Wrd36.uLng) == 1))
    goto label_34;
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd34.Obj) = ((Wrd33.pObj) [0]);
  (* (--Rsp)) = (Wrd34.Obj);

DEFLABEL (label_33)
  (Wrd44.Obj) = (Rsp [1]);
  (Wrd45.uLng) = (OBJECT_TYPE (Wrd44.Obj));
  if (! ((Wrd45.uLng) == 1))
    goto label_32;
  (Wrd43.pObj) = (OBJECT_ADDRESS (Wrd44.Obj));
  (Wrd41.Obj) = ((Wrd43.pObj) [0]);

DEFLABEL (label_31)
  (Wrd50.Obj) = (* (Rsp++));
  (Wrd51.uLng) = (OBJECT_TYPE (Wrd41.Obj));
  if (! ((Wrd51.uLng) == 26))
    goto label_30;
  (Wrd52.uLng) = (OBJECT_TYPE (Wrd50.Obj));
  if (! ((Wrd52.uLng) == 26))
    goto label_30;
  if ((Wrd41.Obj) == (Wrd50.Obj))
    goto label_22;

DEFLABEL (label_21)
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_20)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_22)
  (Wrd64.Obj) = (Rsp [0]);
  (Wrd65.uLng) = (OBJECT_TYPE (Wrd64.Obj));
  if (! ((Wrd65.uLng) == 1))
    goto label_29;
  (Wrd63.pObj) = (OBJECT_ADDRESS (Wrd64.Obj));
  (Wrd61.Obj) = ((Wrd63.pObj) [1]);

DEFLABEL (label_28)
  (Rsp [0]) = (Wrd61.Obj);
  (Wrd73.Obj) = (Rsp [1]);
  (Wrd74.uLng) = (OBJECT_TYPE (Wrd73.Obj));
  if (! ((Wrd74.uLng) == 1))
    goto label_27;
  (Wrd72.pObj) = (OBJECT_ADDRESS (Wrd73.Obj));
  (Wrd70.Obj) = ((Wrd72.pObj) [1]);

DEFLABEL (label_26)
  (Rsp [1]) = (Wrd70.Obj);
  (Wrd80.Obj) = (Rsp [0]);
  (Wrd81.uLng) = (OBJECT_TYPE (Wrd80.Obj));
  if ((Wrd81.uLng) == 26)
    goto label_24;

DEFLABEL (label_23)
  INVOKE_INTERFACE_0 (39);

DEFLABEL (label_24)
  (Wrd83.uLng) = (OBJECT_TYPE (Wrd70.Obj));
  if (! ((Wrd83.uLng) == 26))
    goto label_23;
  (Wrd85.Lng) = (FIXNUM_TO_LONG (Wrd80.Obj));
  (Wrd87.Lng) = (FIXNUM_TO_LONG (Wrd70.Obj));
  if (! ((Wrd85.Lng) < (Wrd87.Lng)))
    goto label_21;

DEFLABEL (label_25)
  Rvl = (current_block [OBJECT_26_2]);
  goto label_20;

DEFLABEL (label_27)
  (Wrd78.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_12]))));
  (* (--Rsp)) = (Wrd78.Obj);
  (* (--Rsp)) = (Wrd73.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_26_1]), 1);

DEFLABEL (label_17)
  (Wrd70.Obj) = Rvl;
  goto label_26;

DEFLABEL (label_29)
  (Wrd69.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_11]))));
  (* (--Rsp)) = (Wrd69.Obj);
  (* (--Rsp)) = (Wrd64.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_26_1]), 1);

DEFLABEL (label_16)
  (Wrd61.Obj) = Rvl;
  goto label_28;

DEFLABEL (label_30)
  (Wrd57.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_10]))));
  (* (--Rsp)) = (Wrd57.Obj);
  (* (--Rsp)) = (Wrd50.Obj);
  (* (--Rsp)) = (Wrd41.Obj);
  INVOKE_INTERFACE_0 (36);

DEFLABEL (label_15)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_21;
  goto label_22;

DEFLABEL (label_32)
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_9]))));
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd44.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_26_0]), 1);

DEFLABEL (label_14)
  (Wrd41.Obj) = Rvl;
  goto label_31;

DEFLABEL (label_34)
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_8]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_26_0]), 1);

DEFLABEL (label_13)
  (* (--Rsp)) = Rvl;
  goto label_33;

DEFLABEL (label_36)
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_7]))));
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd14.Obj);
  INVOKE_INTERFACE_0 (39);

DEFLABEL (label_12)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_35;
  goto label_25;

DEFLABEL (label_38)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_6]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_26_0]), 1);

DEFLABEL (label_11)
  (Wrd14.Obj) = Rvl;
  goto label_37;

DEFLABEL (label_40)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_5]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_26_0]), 1);

DEFLABEL (label_10)
  (* (--Rsp)) = Rvl;
  goto label_39;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_27_4 3
#define LABEL_27_5 5
#define LABEL_27_7 7
#define LABEL_27_11 9
#define LABEL_27_13 11
#define LABEL_27_9 13
#define LABEL_27_12 15
#define LABEL_27_16 17
#define TAG_27_17 7
#define LABEL_27_19 19
#define LABEL_27_15 21
#define LABEL_27_18 23
#define LABEL_27_20 25
#define LABEL_27_24 27
#define LABEL_27_21 29
#define TAG_27_22 13
#define LABEL_27_23 31
#define LABEL_27_25 33
#define LABEL_27_26 35
#define LABEL_27_29 37
#define LABEL_27_28 39
#define LABEL_27_31 41
#define LABEL_27_33 43
#define LABEL_27_35 45
#define LABEL_27_34 47
#define LABEL_27_36 49
#define LABEL_27_37 51
#define LABEL_27_39 53
#define LABEL_27_38 55
#define LABEL_27_40 57
#define LABEL_27_41 59
#define LABEL_27_44 61
#define LABEL_27_42 63
#define LABEL_27_46 65
#define LABEL_27_43 67
#define LABEL_27_45 69
#define LABEL_27_47 71
#define ENVIRONMENT_LABEL_27_3 99
#define DEBUGGING_LABEL_27_2 98
#define OBJECT_27_2 97
#define OBJECT_27_1 96
#define OBJECT_27_0 95
#define EXECUTE_CACHE_27_49 73
#define EXECUTE_CACHE_27_48 75
#define EXECUTE_CACHE_27_32 77
#define EXECUTE_CACHE_27_30 79
#define EXECUTE_CACHE_27_27 81
#define EXECUTE_CACHE_27_14 83
#define EXECUTE_CACHE_27_10 85
#define EXECUTE_CACHE_27_8 87
#define EXECUTE_CACHE_27_6 89
#define FREE_REFERENCE_27_2 92
#define FREE_REFERENCE_27_1 93
#define FREE_REFERENCE_27_0 94
#define FREE_REFERENCES_LABEL_27_0 72
#define NUMBER_OF_LINKER_SECTIONS_27_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_27 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd21;
  machine_word Wrd25;
  machine_word Wrd19;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd11;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd12;
  machine_word Wrd10;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_27_4);
      goto parse_http_version_44;

    case 1:
      current_block = (Rpc - LABEL_27_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_27_7);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_27_11);
      goto continuation_3;

    case 4:
      current_block = (Rpc - LABEL_27_13);
      goto label_46;

    case 5:
      current_block = (Rpc - LABEL_27_9);
      goto continuation_2;

    case 6:
      current_block = (Rpc - LABEL_27_12);
      goto continuation_4;

    case 7:
      current_block = (Rpc - LABEL_27_16);
      goto lambda_55;

    case 8:
      current_block = (Rpc - LABEL_27_19);
      goto Z___ks13__40;

    case 9:
      current_block = (Rpc - LABEL_27_15);
      goto continuation_5;

    case 10:
      current_block = (Rpc - LABEL_27_18);
      goto continuation_6;

    case 11:
      current_block = (Rpc - LABEL_27_20);
      goto continuation_9;

    case 12:
      current_block = (Rpc - LABEL_27_24);
      goto label_47;

    case 13:
      current_block = (Rpc - LABEL_27_21);
      goto lambda_57;

    case 14:
      current_block = (Rpc - LABEL_27_23);
      goto continuation_37;

    case 15:
      current_block = (Rpc - LABEL_27_25);
      goto continuation_10;

    case 16:
      current_block = (Rpc - LABEL_27_26);
      goto continuation_11;

    case 17:
      current_block = (Rpc - LABEL_27_29);
      goto label_48;

    case 18:
      current_block = (Rpc - LABEL_27_28);
      goto continuation_13;

    case 19:
      current_block = (Rpc - LABEL_27_31);
      goto continuation_14;

    case 20:
      current_block = (Rpc - LABEL_27_33);
      goto continuation_15;

    case 21:
      current_block = (Rpc - LABEL_27_35);
      goto label_49;

    case 22:
      current_block = (Rpc - LABEL_27_34);
      goto continuation_16;

    case 23:
      current_block = (Rpc - LABEL_27_36);
      goto Z___ks6__31;

    case 24:
      current_block = (Rpc - LABEL_27_37);
      goto continuation_18;

    case 25:
      current_block = (Rpc - LABEL_27_39);
      goto label_50;

    case 26:
      current_block = (Rpc - LABEL_27_38);
      goto continuation_19;

    case 27:
      current_block = (Rpc - LABEL_27_40);
      goto continuation_20;

    case 28:
      current_block = (Rpc - LABEL_27_41);
      goto continuation_21;

    case 29:
      current_block = (Rpc - LABEL_27_44);
      goto label_51;

    case 30:
      current_block = (Rpc - LABEL_27_42);
      goto continuation_24;

    case 31:
      current_block = (Rpc - LABEL_27_46);
      goto label_52;

    case 32:
      current_block = (Rpc - LABEL_27_43);
      goto continuation_23;

    case 33:
      current_block = (Rpc - LABEL_27_45);
      goto continuation_25;

    case 34:
      current_block = (Rpc - LABEL_27_47);
      goto continuation_26;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (parse_http_version_54)
DEFLABEL (parse_http_version_44)
  INTERRUPT_CHECK (26, LABEL_27_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_27_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_27_5);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_27_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_27_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_27_7);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_62;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_11]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_27_6]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_27_11);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_12]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_27_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_61;
  Wrd8 = Wrd12;

DEFLABEL (label_60)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_27_14]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_27_12);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_59;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_27_17);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_27_16])));
  Rhp += 2;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  Wrd11 = Wrd8;
  (Wrd12.Obj) = (Rsp [2]);
  ((Wrd11.pObj) [2]) = (Wrd12.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  ((Wrd11.pObj) [3]) = (Wrd10.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  goto Z___ks13__40;

DEFLABEL (label_59)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_15]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_27_10]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_27_15);
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_61)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_27_13])), (Wrd9.pObj));

DEFLABEL (label_46)
  (Wrd8.Obj) = Rvl;
  goto label_60;

DEFLABEL (label_62)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_9]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_27_10]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_27_9);
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (lambda_55)
  CLOSURE_HEADER (LABEL_27_16);

DEFLABEL (lambda_7)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_18]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_27_10]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_27_18);
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (Z___ks13__56)
DEFLABEL (Z___ks13__40)
  INTERRUPT_CHECK (26, LABEL_27_19);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_20]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_27_6]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_27_20);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 7));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_27_22);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_27_21])));
  Rhp += 4;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd14 = Wrd7;
  (Wrd15.Obj) = (Rsp [4]);
  ((Wrd14.pObj) [2]) = (Wrd15.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  ((Wrd14.pObj) [3]) = (Wrd13.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd14.pObj) [4]) = (Wrd11.Obj);
  ((Wrd14.pObj) [5]) = Rvl;
  (Rsp [1]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_23]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_27_0]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_65;
  Wrd19 = Wrd23;

DEFLABEL (label_64)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd25.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd25.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_27_14]));

DEFLABEL (continuation_37)
  INTERRUPT_CHECK (27, LABEL_27_23);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_63;
  goto Z___ks13__40;

DEFLABEL (label_63)
  (Wrd7.Obj) = (Rsp [0]);
  (Rsp [3]) = (Wrd7.Obj);
  Rsp = (& (Rsp [3]));
  goto lambda_36;

DEFLABEL (label_65)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_27_24])), (Wrd20.pObj));

DEFLABEL (label_47)
  (Wrd19.Obj) = Rvl;
  goto label_64;

DEFLABEL (lambda_57)
  CLOSURE_HEADER (LABEL_27_21);

DEFLABEL (lambda_36)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_25]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [5]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_27_10]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_27_25);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_26]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_27_27]));

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_27_26);
  (Wrd11.Obj) = (MAKE_OBJECT (0, 1));
  (* (Rhp++)) = (Wrd11.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (10, (Wrd7.pObj)));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_28]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd17.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_27_1]));
  (Wrd20.Obj) = ((Wrd17.pObj) [0]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if ((Wrd21.uLng) == 50)
    goto label_71;
  Wrd16 = Wrd20;

DEFLABEL (label_70)
  (* (--Rsp)) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_27_30]));

DEFLABEL (continuation_13)
  INTERRUPT_CHECK (27, LABEL_27_28);
  (Rsp [0]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_31]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_27_1]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [2]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_27_32]));

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_27_31);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_66;
  (Wrd14.Obj) = (Rsp [1]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd13.Obj) = ((Wrd15.pObj) [4]);
  (Rsp [1]) = (Wrd13.Obj);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_66)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_33]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [2]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_27_6]));

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_27_33);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_34]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_27_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_69;
  Wrd8 = Wrd12;

DEFLABEL (label_68)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (Rsp [4]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [2]);
  (* (--Rsp)) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_27_14]));

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_27_34);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_67;
  goto Z___ks6__31;

DEFLABEL (label_67)
  (Wrd8.Obj) = (Rsp [2]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [4]);
  (Rsp [2]) = (Wrd7.Obj);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_69)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_27_35])), (Wrd9.pObj));

DEFLABEL (label_49)
  (Wrd8.Obj) = Rvl;
  goto label_68;

DEFLABEL (label_71)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_27_29])), (Wrd17.pObj));

DEFLABEL (label_48)
  (Wrd16.Obj) = Rvl;
  goto label_70;

DEFLABEL (Z___ks6__58)
DEFLABEL (Z___ks6__31)
  INTERRUPT_CHECK (26, LABEL_27_36);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_37]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_27_6]));

DEFLABEL (continuation_18)
  INTERRUPT_CHECK (27, LABEL_27_37);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_38]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_27_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_78;
  Wrd8 = Wrd12;

DEFLABEL (label_77)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (Rsp [5]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [2]);
  (* (--Rsp)) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_27_14]));

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_27_38);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_72;
  Rsp = (& (Rsp [1]));
  goto Z___ks6__31;

DEFLABEL (label_72)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_40]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [5]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [2]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_27_10]));

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_27_40);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_41]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [5]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_27_27]));

DEFLABEL (continuation_21)
  INTERRUPT_CHECK (27, LABEL_27_41);
  (Wrd11.Obj) = (MAKE_OBJECT (0, 1));
  (* (Rhp++)) = (Wrd11.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (10, (Wrd8.pObj)));
  (Rsp [1]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_42]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_43]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd18.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_27_1]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_76;
  Wrd19 = Wrd23;

DEFLABEL (label_75)
  (* (--Rsp)) = (Wrd19.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_27_30]));

DEFLABEL (continuation_23)
  INTERRUPT_CHECK (27, LABEL_27_43);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_27_49]));

DEFLABEL (continuation_24)
  INTERRUPT_CHECK (27, LABEL_27_42);
  (Rsp [2]) = Rvl;
  Rsp = (& (Rsp [2]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_45]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd11.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_27_2]));
  (Wrd14.Obj) = ((Wrd11.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_74;
  Wrd10 = Wrd14;

DEFLABEL (label_73)
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_47]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd19.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd19.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_27_48]));

DEFLABEL (continuation_26)
  INTERRUPT_CHECK (27, LABEL_27_47);
  (Rsp [1]) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_27_2]), 2);

DEFLABEL (label_74)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_27_46])), (Wrd11.pObj));

DEFLABEL (label_52)
  (Wrd10.Obj) = Rvl;
  goto label_73;

DEFLABEL (label_76)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_27_44])), (Wrd20.pObj));

DEFLABEL (label_51)
  (Wrd19.Obj) = Rvl;
  goto label_75;

DEFLABEL (label_78)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_27_39])), (Wrd9.pObj));

DEFLABEL (label_50)
  (Wrd8.Obj) = Rvl;
  goto label_77;

DEFLABEL (continuation_25)
  INTERRUPT_CHECK (27, LABEL_27_45);
  (Wrd12.Obj) = (MAKE_OBJECT (0, 1));
  (* (Rhp++)) = (Wrd12.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (10, (Wrd8.pObj)));
  Rsp = (& (Rsp [1]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_28_4 3
#define LABEL_28_5 5
#define LABEL_28_8 7
#define LABEL_28_7 9
#define LABEL_28_10 11
#define LABEL_28_11 13
#define ENVIRONMENT_LABEL_28_3 24
#define DEBUGGING_LABEL_28_2 23
#define OBJECT_28_3 22
#define OBJECT_28_2 21
#define OBJECT_28_1 20
#define OBJECT_28_0 19
#define EXECUTE_CACHE_28_9 15
#define EXECUTE_CACHE_28_6 17
#define FREE_REFERENCES_LABEL_28_0 14
#define NUMBER_OF_LINKER_SECTIONS_28_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_28 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd17;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_28_4);
      goto write_http_version_5;

    case 1:
      current_block = (Rpc - LABEL_28_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_28_8);
      goto label_7;

    case 3:
      current_block = (Rpc - LABEL_28_7);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_28_10);
      goto continuation_3;

    case 5:
      current_block = (Rpc - LABEL_28_11);
      goto label_8;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (write_http_version_10)
DEFLABEL (write_http_version_5)
  INTERRUPT_CHECK (26, LABEL_28_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_28_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_28_0]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_28_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_28_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_28_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd12.Obj) = (Rsp [2]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_14;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [0]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_13)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_28_9]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_28_7);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_28_10]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_28_2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_28_6]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_28_10);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_12;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [1]);

DEFLABEL (label_11)
  (Rsp [0]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_28_9]));

DEFLABEL (label_12)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_28_11]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_28_3]), 1);

DEFLABEL (label_8)
  (Wrd5.Obj) = Rvl;
  goto label_11;

DEFLABEL (label_14)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_28_8]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_28_1]), 1);

DEFLABEL (label_7)
  (* (--Rsp)) = Rvl;
  goto label_13;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_29_4 3
#define LABEL_29_5 5
#define LABEL_29_7 7
#define ENVIRONMENT_LABEL_29_3 17
#define DEBUGGING_LABEL_29_2 16
#define OBJECT_29_2 15
#define OBJECT_29_1 14
#define OBJECT_29_0 13
#define EXECUTE_CACHE_29_6 9
#define FREE_ASSIGNMENT_29_0 12
#define FREE_REFERENCES_LABEL_29_0 8
#define NUMBER_OF_LINKER_SECTIONS_29_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_29 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd6;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_29_4);
      goto lambda_1;

    case 1:
      current_block = (Rpc - LABEL_29_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_29_7);
      goto label_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_5)
DEFLABEL (lambda_1)
  INTERRUPT_CHECK (26, LABEL_29_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_29_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_29_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_29_1]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_29_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_29_5);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_29_0]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_8;

DEFLABEL (label_7)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_6)
  Rvl = (current_block [OBJECT_29_2]);
  goto pop_return;

DEFLABEL (label_8)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_7;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_29_7])), (Wrd6.pObj), Rvl);

DEFLABEL (label_3)
  goto label_6;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_30_4 3
#define LABEL_30_5 5
#define LABEL_30_7 7
#define ENVIRONMENT_LABEL_30_3 16
#define DEBUGGING_LABEL_30_2 15
#define OBJECT_30_1 14
#define OBJECT_30_0 13
#define EXECUTE_CACHE_30_6 9
#define FREE_ASSIGNMENT_30_0 12
#define FREE_REFERENCES_LABEL_30_0 8
#define NUMBER_OF_LINKER_SECTIONS_30_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_30 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd6;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_30_4);
      goto lambda_1;

    case 1:
      current_block = (Rpc - LABEL_30_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_30_7);
      goto label_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_5)
DEFLABEL (lambda_1)
  INTERRUPT_CHECK (26, LABEL_30_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_30_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_30_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_30_5);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_30_0]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_8;

DEFLABEL (label_7)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_6)
  Rvl = (current_block [OBJECT_30_1]);
  goto pop_return;

DEFLABEL (label_8)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_7;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_30_7])), (Wrd6.pObj), Rvl);

DEFLABEL (label_3)
  goto label_6;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_31_4 3
#define LABEL_31_5 5
#define ENVIRONMENT_LABEL_31_3 12
#define DEBUGGING_LABEL_31_2 11
#define OBJECT_31_1 10
#define OBJECT_31_0 9
#define EXECUTE_CACHE_31_6 7
#define FREE_REFERENCES_LABEL_31_0 6
#define NUMBER_OF_LINKER_SECTIONS_31_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_31 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd13;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_31_4);
      goto http_statusP_1;

    case 1:
      current_block = (Rpc - LABEL_31_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (http_statusP_4)
DEFLABEL (http_statusP_1)
  INTERRUPT_CHECK (26, LABEL_31_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_31_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_31_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_5;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_5)
  (Wrd7.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_31_0]);
  (Rsp [1]) = (Wrd8.Obj);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if ((Wrd11.uLng) == 26)
    goto label_6;
  INVOKE_INTERFACE_0 (39);

DEFLABEL (label_6)
  (Wrd13.Lng) = (FIXNUM_TO_LONG (Wrd7.Obj));
  if ((Wrd13.Lng) < 1000L)
    goto label_8;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_7;

DEFLABEL (label_8)
  Rvl = (current_block [OBJECT_31_1]);

DEFLABEL (label_7)
DEFLABEL (label_9)
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_32_4 3
#define LABEL_32_5 5
#define ENVIRONMENT_LABEL_32_3 13
#define DEBUGGING_LABEL_32_2 12
#define OBJECT_32_0 11
#define EXECUTE_CACHE_32_7 7
#define EXECUTE_CACHE_32_6 9
#define FREE_REFERENCES_LABEL_32_0 6
#define NUMBER_OF_LINKER_SECTIONS_32_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_32 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_32_4);
      goto guarantee_http_status_1;

    case 1:
      current_block = (Rpc - LABEL_32_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (guarantee_http_status_4)
DEFLABEL (guarantee_http_status_1)
  INTERRUPT_CHECK (26, LABEL_32_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_32_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_32_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_32_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_5;
  Rvl = (current_block [OBJECT_32_0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_5)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_32_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_33_4 3
#define ENVIRONMENT_LABEL_33_3 11
#define DEBUGGING_LABEL_33_2 10
#define OBJECT_33_2 9
#define OBJECT_33_1 8
#define OBJECT_33_0 7
#define EXECUTE_CACHE_33_5 5
#define FREE_REFERENCES_LABEL_33_0 4
#define NUMBER_OF_LINKER_SECTIONS_33_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_33 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_33_4);
      goto error_not_http_status_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (error_not_http_status_5)
DEFLABEL (error_not_http_status_2)
  INTERRUPT_CHECK (26, LABEL_33_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_33_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [2]);
  if ((Wrd7.Obj) == (current_block [OBJECT_33_1]))
    goto label_7;
  Wrd9 = Wrd7;
  goto label_6;

DEFLABEL (label_7)
  (Wrd9.Obj) = (current_block [OBJECT_33_2]);

DEFLABEL (label_6)
DEFLABEL (label_8)
  (Rsp [2]) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_33_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_34_4 3
#define ENVIRONMENT_LABEL_34_3 9
#define DEBUGGING_LABEL_34_2 8
#define OBJECT_34_0 7
#define EXECUTE_CACHE_34_5 5
#define FREE_REFERENCES_LABEL_34_0 4
#define NUMBER_OF_LINKER_SECTIONS_34_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_34 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_34_4);
      goto http_status_major_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (http_status_major_3)
DEFLABEL (http_status_major_0)
  INTERRUPT_CHECK (26, LABEL_34_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_34_0]);
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_35_4 3
#define LABEL_35_5 5
#define LABEL_35_8 7
#define LABEL_35_10 9
#define LABEL_35_13 11
#define LABEL_35_14 13
#define LABEL_35_7 15
#define LABEL_35_17 17
#define LABEL_35_15 19
#define LABEL_35_11 21
#define LABEL_35_18 23
#define ENVIRONMENT_LABEL_35_3 39
#define DEBUGGING_LABEL_35_2 38
#define EXECUTE_CACHE_35_19 25
#define EXECUTE_CACHE_35_16 27
#define EXECUTE_CACHE_35_12 29
#define EXECUTE_CACHE_35_9 31
#define EXECUTE_CACHE_35_6 33
#define FREE_REFERENCE_35_1 36
#define FREE_REFERENCE_35_0 37
#define FREE_REFERENCES_LABEL_35_0 24
#define NUMBER_OF_LINKER_SECTIONS_35_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_35 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd6;
  machine_word Wrd33;
  machine_word Wrd10;
  machine_word Wrd15;
  machine_word Wrd11;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd27;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd28;
  machine_word Wrd26;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_35_4);
      goto parse_http_status_9;

    case 1:
      current_block = (Rpc - LABEL_35_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_35_8);
      goto label_11;

    case 3:
      current_block = (Rpc - LABEL_35_10);
      goto continuation_3;

    case 4:
      current_block = (Rpc - LABEL_35_13);
      goto continuation_2;

    case 5:
      current_block = (Rpc - LABEL_35_14);
      goto label_13;

    case 6:
      current_block = (Rpc - LABEL_35_7);
      goto continuation_1;

    case 7:
      current_block = (Rpc - LABEL_35_17);
      goto label_12;

    case 8:
      current_block = (Rpc - LABEL_35_15);
      goto continuation_4;

    case 9:
      current_block = (Rpc - LABEL_35_11);
      goto continuation_5;

    case 10:
      current_block = (Rpc - LABEL_35_18);
      goto label_14;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (parse_http_status_16)
DEFLABEL (parse_http_status_9)
  INTERRUPT_CHECK (26, LABEL_35_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_35_5);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_35_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_23;
  Wrd8 = Wrd12;

DEFLABEL (label_22)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_9]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_35_7);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_18;

DEFLABEL (label_17)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_15]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd20.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd21.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd21.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_16]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_35_15);
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_18)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_13]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd11.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_35_0]));
  (Wrd14.Obj) = ((Wrd11.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_21;
  Wrd10 = Wrd14;

DEFLABEL (label_20)
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_19)
  (Wrd33.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd33.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_9]));

DEFLABEL (label_21)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_35_17])), (Wrd11.pObj));

DEFLABEL (label_12)
  (Wrd10.Obj) = Rvl;
  goto label_20;

DEFLABEL (label_23)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_35_8])), (Wrd9.pObj));

DEFLABEL (label_11)
  (Wrd8.Obj) = Rvl;
  goto label_22;

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_35_13);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_17;
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_10]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd28.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_35_0]));
  (Wrd31.Obj) = ((Wrd28.pObj) [0]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if ((Wrd32.uLng) == 50)
    goto label_25;
  Wrd27 = Wrd31;

DEFLABEL (label_24)
  (* (--Rsp)) = (Wrd27.Obj);
  goto label_19;

DEFLABEL (label_25)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_35_14])), (Wrd28.pObj));

DEFLABEL (label_13)
  (Wrd27.Obj) = Rvl;
  goto label_24;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_35_10);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_17;
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_11]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (Wrd39.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd39.Obj);
  (Wrd40.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd40.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_12]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_35_11);
  (Wrd11.Obj) = (MAKE_OBJECT (0, 1));
  (* (Rhp++)) = (Wrd11.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (10, (Wrd8.pObj)));
  (Rsp [1]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_35_1]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_27;
  Wrd12 = Wrd16;

DEFLABEL (label_26)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_19]));

DEFLABEL (label_27)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_35_18])), (Wrd13.pObj));

DEFLABEL (label_14)
  (Wrd12.Obj) = Rvl;
  goto label_26;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_36_4 3
#define LABEL_36_5 5
#define LABEL_36_6 7
#define ENVIRONMENT_LABEL_36_3 18
#define DEBUGGING_LABEL_36_2 17
#define OBJECT_36_1 16
#define OBJECT_36_0 15
#define EXECUTE_CACHE_36_9 9
#define EXECUTE_CACHE_36_8 11
#define EXECUTE_CACHE_36_7 13
#define FREE_REFERENCES_LABEL_36_0 8
#define NUMBER_OF_LINKER_SECTIONS_36_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_36 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_36_4);
      goto write_http_status_2;

    case 1:
      current_block = (Rpc - LABEL_36_5);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_36_6);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (write_http_status_5)
DEFLABEL (write_http_status_2)
  INTERRUPT_CHECK (26, LABEL_36_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_36_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_36_1]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36_6]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_36_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_36_6);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_36_9]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_36_5);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_36_8]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_37_4 3
#define LABEL_37_5 5
#define ENVIRONMENT_LABEL_37_3 13
#define DEBUGGING_LABEL_37_2 12
#define OBJECT_37_0 11
#define EXECUTE_CACHE_37_7 7
#define EXECUTE_CACHE_37_6 9
#define FREE_REFERENCES_LABEL_37_0 6
#define NUMBER_OF_LINKER_SECTIONS_37_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_37 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_37_4);
      goto guarantee_http_header_1;

    case 1:
      current_block = (Rpc - LABEL_37_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (guarantee_http_header_4)
DEFLABEL (guarantee_http_header_1)
  INTERRUPT_CHECK (26, LABEL_37_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_37_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_5;
  Rvl = (current_block [OBJECT_37_0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_5)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_38_4 3
#define ENVIRONMENT_LABEL_38_3 11
#define DEBUGGING_LABEL_38_2 10
#define OBJECT_38_2 9
#define OBJECT_38_1 8
#define OBJECT_38_0 7
#define EXECUTE_CACHE_38_5 5
#define FREE_REFERENCES_LABEL_38_0 4
#define NUMBER_OF_LINKER_SECTIONS_38_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_38 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_38_4);
      goto error_not_http_header_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (error_not_http_header_5)
DEFLABEL (error_not_http_header_2)
  INTERRUPT_CHECK (26, LABEL_38_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_38_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [2]);
  if ((Wrd7.Obj) == (current_block [OBJECT_38_1]))
    goto label_7;
  Wrd9 = Wrd7;
  goto label_6;

DEFLABEL (label_7)
  (Wrd9.Obj) = (current_block [OBJECT_38_2]);

DEFLABEL (label_6)
DEFLABEL (label_8)
  (Rsp [2]) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_38_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_39_4 3
#define LABEL_39_5 5
#define ENVIRONMENT_LABEL_39_3 11
#define DEBUGGING_LABEL_39_2 10
#define OBJECT_39_0 9
#define EXECUTE_CACHE_39_6 7
#define FREE_REFERENCES_LABEL_39_0 6
#define NUMBER_OF_LINKER_SECTIONS_39_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_39 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_39_4);
      goto lambda_1;

    case 1:
      current_block = (Rpc - LABEL_39_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_4)
DEFLABEL (lambda_1)
  INTERRUPT_CHECK (26, LABEL_39_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_39_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_39_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_39_5);
  (Wrd10.Obj) = (current_block [OBJECT_39_0]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd8.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  Rsp = (& (Rsp [1]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_40_4 3
#define LABEL_40_5 5
#define LABEL_40_7 7
#define LABEL_40_12 9
#define LABEL_40_11 11
#define LABEL_40_9 13
#define LABEL_40_14 15
#define LABEL_40_15 17
#define TAG_40_16 7
#define LABEL_40_21 19
#define LABEL_40_13 21
#define LABEL_40_23 23
#define LABEL_40_18 25
#define LABEL_40_22 27
#define ENVIRONMENT_LABEL_40_3 50
#define DEBUGGING_LABEL_40_2 49
#define OBJECT_40_5 48
#define OBJECT_40_4 47
#define OBJECT_40_3 46
#define OBJECT_40_2 45
#define OBJECT_40_1 44
#define OBJECT_40_0 43
#define EXECUTE_CACHE_40_24 29
#define EXECUTE_CACHE_40_20 31
#define EXECUTE_CACHE_40_19 33
#define EXECUTE_CACHE_40_17 35
#define EXECUTE_CACHE_40_10 37
#define EXECUTE_CACHE_40_8 39
#define EXECUTE_CACHE_40_6 41
#define FREE_REFERENCES_LABEL_40_0 28
#define NUMBER_OF_LINKER_SECTIONS_40_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_40 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd12;
  machine_word Wrd28;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd16;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd11;
  machine_word Wrd20;
  machine_word Wrd26;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd13;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd21;
  machine_word Wrd10;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_40_4);
      goto make_http_header_13;

    case 1:
      current_block = (Rpc - LABEL_40_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_40_7);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_40_12);
      goto label_15;

    case 4:
      current_block = (Rpc - LABEL_40_11);
      goto continuation_4;

    case 5:
      current_block = (Rpc - LABEL_40_9);
      goto continuation_2;

    case 6:
      current_block = (Rpc - LABEL_40_14);
      goto continuation_11;

    case 7:
      current_block = (Rpc - LABEL_40_15);
      goto lambda_20;

    case 8:
      current_block = (Rpc - LABEL_40_21);
      goto label_16;

    case 9:
      current_block = (Rpc - LABEL_40_13);
      goto continuation_6;

    case 10:
      current_block = (Rpc - LABEL_40_23);
      goto label_17;

    case 11:
      current_block = (Rpc - LABEL_40_18);
      goto continuation_3;

    case 12:
      current_block = (Rpc - LABEL_40_22);
      goto continuation_8;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (make_http_header_19)
DEFLABEL (make_http_header_13)
  INTERRUPT_CHECK (26, LABEL_40_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_40_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_40_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_40_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_40_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_40_7);
  (* (--Rsp)) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_21;
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_9]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd30.Obj) = (current_block [OBJECT_40_0]);
  (* (--Rsp)) = (Wrd30.Obj);
  (Wrd31.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd31.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_40_10]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_40_9);
  (Wrd5.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_18]))));
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_40_19]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_40_18);
  (Rsp [2]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_40_20]));

DEFLABEL (label_21)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_11]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd21.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd21.uLng) == 62))
    goto label_26;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd18.Obj) = ((Wrd17.pObj) [0]);
  (Wrd19.Lng) = (FIXNUM_TO_LONG (Wrd18.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd19.Lng))))
    goto label_26;
  (Wrd13.Obj) = ((Wrd17.pObj) [4]);
  (* (--Rsp)) = (Wrd13.Obj);

DEFLABEL (label_25)
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_40_11);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_22;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_14]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd11.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_40_16);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_40_15])));
  Rhp += 2;
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd11.pObj)));
  Wrd14 = Wrd11;
  (Wrd15.Obj) = (Rsp [3]);
  ((Wrd14.pObj) [2]) = (Wrd15.Obj);
  (Wrd13.Obj) = (Rsp [1]);
  ((Wrd14.pObj) [3]) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_40_17]));

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_40_14);
  (Wrd5.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd5.Obj);
  (Rsp [1]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_40_20]));

DEFLABEL (label_22)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_13]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd19.Obj) = (current_block [OBJECT_40_0]);
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd20.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_40_10]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_40_13);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_22]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_40_4]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd19.Obj) = (Rsp [3]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd20.uLng) == 62))
    goto label_24;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (Wrd18.Lng) = (FIXNUM_TO_LONG (Wrd17.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd18.Lng))))
    goto label_24;
  (Wrd12.Obj) = ((Wrd16.pObj) [3]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_23)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_40_24]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_40_22);
  (Wrd5.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd6.Obj);
  (Rsp [2]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_40_20]));

DEFLABEL (label_24)
  (Wrd21.Obj) = (Rsp [3]);
  (Wrd22.Obj) = (current_block [OBJECT_40_5]);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_23]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_40_2]), 2);

DEFLABEL (label_17)
  (* (--Rsp)) = Rvl;
  goto label_23;

DEFLABEL (label_26)
  (Wrd22.Obj) = (Rsp [2]);
  (Wrd23.Obj) = (current_block [OBJECT_40_1]);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_12]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_40_2]), 2);

DEFLABEL (label_15)
  (* (--Rsp)) = Rvl;
  goto label_25;

DEFLABEL (lambda_20)
  CLOSURE_HEADER (LABEL_40_15);

DEFLABEL (lambda_10)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [3]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 62))
    goto label_28;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd17.Lng))))
    goto label_28;
  (Wrd9.Obj) = ((Wrd15.pObj) [5]);
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_27)
  (Wrd30.Obj) = (Rsp [1]);
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd29.Obj) = ((Wrd31.pObj) [2]);
  (Rsp [1]) = (Wrd29.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (label_28)
  (Wrd23.Obj) = (Rsp [0]);
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd22.Obj) = ((Wrd24.pObj) [3]);
  (Wrd25.Obj) = (current_block [OBJECT_40_3]);
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40_21]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd22.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_40_2]), 2);

DEFLABEL (label_16)
  (* (--Rsp)) = Rvl;
  goto label_27;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_41_4 3
#define LABEL_41_5 5
#define LABEL_41_7 7
#define TAG_41_8 2
#define LABEL_41_12 9
#define LABEL_41_13 11
#define LABEL_41_14 13
#define LABEL_41_15 15
#define LABEL_41_17 17
#define LABEL_41_18 19
#define LABEL_41_19 21
#define LABEL_41_20 23
#define LABEL_41_21 25
#define LABEL_41_22 27
#define LABEL_41_23 29
#define LABEL_41_24 31
#define LABEL_41_25 33
#define LABEL_41_10 35
#define LABEL_41_26 37
#define LABEL_41_27 39
#define ENVIRONMENT_LABEL_41_3 57
#define DEBUGGING_LABEL_41_2 56
#define OBJECT_41_2 55
#define OBJECT_41_1 54
#define OBJECT_41_0 53
#define EXECUTE_CACHE_41_29 41
#define EXECUTE_CACHE_41_28 43
#define EXECUTE_CACHE_41_16 45
#define EXECUTE_CACHE_41_11 47
#define EXECUTE_CACHE_41_9 49
#define EXECUTE_CACHE_41_6 51
#define FREE_REFERENCES_LABEL_41_0 40
#define NUMBER_OF_LINKER_SECTIONS_41_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_41 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd28;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd19;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd40;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd31;
  machine_word Wrd111;
  machine_word Wrd105;
  machine_word Wrd106;
  machine_word Wrd107;
  machine_word Wrd104;
  machine_word Wrd96;
  machine_word Wrd98;
  machine_word Wrd100;
  machine_word Wrd99;
  machine_word Wrd95;
  machine_word Wrd87;
  machine_word Wrd89;
  machine_word Wrd91;
  machine_word Wrd90;
  machine_word Wrd85;
  machine_word Wrd79;
  machine_word Wrd80;
  machine_word Wrd81;
  machine_word Wrd78;
  machine_word Wrd70;
  machine_word Wrd72;
  machine_word Wrd74;
  machine_word Wrd73;
  machine_word Wrd69;
  machine_word Wrd68;
  machine_word Wrd62;
  machine_word Wrd63;
  machine_word Wrd64;
  machine_word Wrd61;
  machine_word Wrd53;
  machine_word Wrd55;
  machine_word Wrd57;
  machine_word Wrd56;
  machine_word Wrd52;
  machine_word Wrd51;
  machine_word Wrd43;
  machine_word Wrd45;
  machine_word Wrd47;
  machine_word Wrd46;
  machine_word Wrd141;
  machine_word Wrd133;
  machine_word Wrd135;
  machine_word Wrd137;
  machine_word Wrd136;
  machine_word Wrd132;
  machine_word Wrd124;
  machine_word Wrd126;
  machine_word Wrd128;
  machine_word Wrd127;
  machine_word Wrd123;
  machine_word Wrd122;
  machine_word Wrd114;
  machine_word Wrd116;
  machine_word Wrd118;
  machine_word Wrd117;
  machine_word Wrd10;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_41_4);
      goto convert_http_headers_24;

    case 1:
      current_block = (Rpc - LABEL_41_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_41_7);
      goto lambda_41;

    case 3:
      current_block = (Rpc - LABEL_41_12);
      goto continuation_4;

    case 4:
      current_block = (Rpc - LABEL_41_13);
      goto label_36;

    case 5:
      current_block = (Rpc - LABEL_41_14);
      goto label_37;

    case 6:
      current_block = (Rpc - LABEL_41_15);
      goto label_38;

    case 7:
      current_block = (Rpc - LABEL_41_17);
      goto continuation_9;

    case 8:
      current_block = (Rpc - LABEL_41_18);
      goto label_28;

    case 9:
      current_block = (Rpc - LABEL_41_19);
      goto label_29;

    case 10:
      current_block = (Rpc - LABEL_41_20);
      goto label_30;

    case 11:
      current_block = (Rpc - LABEL_41_21);
      goto label_31;

    case 12:
      current_block = (Rpc - LABEL_41_22);
      goto label_32;

    case 13:
      current_block = (Rpc - LABEL_41_23);
      goto label_33;

    case 14:
      current_block = (Rpc - LABEL_41_24);
      goto label_34;

    case 15:
      current_block = (Rpc - LABEL_41_25);
      goto label_35;

    case 16:
      current_block = (Rpc - LABEL_41_10);
      goto continuation_1;

    case 17:
      current_block = (Rpc - LABEL_41_26);
      goto label_27;

    case 18:
      current_block = (Rpc - LABEL_41_27);
      goto label_26;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (convert_http_headers_40)
DEFLABEL (convert_http_headers_24)
  INTERRUPT_CHECK (26, LABEL_41_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_41_5);
  (Wrd5.Obj) = (Rsp [0]);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_41_8);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_41_7])));
  Rhp += 1;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  Wrd9 = Wrd8;
  (Wrd10.Obj) = (Rsp [1]);
  ((Wrd9.pObj) [2]) = (Wrd10.Obj);
  (Rsp [0]) = (Wrd7.Obj);
  (Rsp [1]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_9]));

DEFLABEL (lambda_41)
  CLOSURE_HEADER (LABEL_41_7);

DEFLABEL (lambda_23)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_10]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_11]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_41_10);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_42;
  Rvl = (Rsp [1]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_42)
  (Wrd9.Obj) = (Rsp [1]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 1)
    goto label_49;

DEFLABEL (label_48)
  (Wrd11.Obj) = (Rsp [1]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if ((Wrd12.uLng) == 1)
    goto label_44;

DEFLABEL (label_43)
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd13.Obj) = ((Wrd15.pObj) [2]);
  (Wrd16.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd16.Obj);
  (Rsp [1]) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_29]));

DEFLABEL (label_44)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_17]))));
  (* (--Rsp)) = (Wrd19.Obj);
  if (! ((Wrd12.uLng) == 1))
    goto label_46;
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd22.Obj) = ((Wrd21.pObj) [0]);
  (* (--Rsp)) = (Wrd22.Obj);

DEFLABEL (label_45)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_28]));

DEFLABEL (label_46)
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_27]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_1]), 1);

DEFLABEL (label_26)
DEFLABEL (label_47)
  (* (--Rsp)) = Rvl;
  goto label_45;

DEFLABEL (label_49)
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_12]))));
  (* (--Rsp)) = (Wrd31.Obj);
  if (! ((Wrd10.uLng) == 1))
    goto label_50;
  (Wrd33.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd34.Obj) = ((Wrd33.pObj) [0]);
  (* (--Rsp)) = (Wrd34.Obj);
  goto label_45;

DEFLABEL (label_50)
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_26]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_1]), 1);

DEFLABEL (label_27)
  goto label_47;

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_41_17);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_43;
  (Wrd46.Obj) = (Rsp [1]);
  (Wrd47.uLng) = (OBJECT_TYPE (Wrd46.Obj));
  if (! ((Wrd47.uLng) == 1))
    goto label_66;
  (Wrd45.pObj) = (OBJECT_ADDRESS (Wrd46.Obj));
  (Wrd43.Obj) = ((Wrd45.pObj) [1]);

DEFLABEL (label_65)
  (Wrd52.uLng) = (OBJECT_TYPE (Wrd43.Obj));
  if (! ((Wrd52.uLng) == 1))
    goto label_43;
  (Wrd56.Obj) = (Rsp [1]);
  (Wrd57.uLng) = (OBJECT_TYPE (Wrd56.Obj));
  if (! ((Wrd57.uLng) == 1))
    goto label_64;
  (Wrd55.pObj) = (OBJECT_ADDRESS (Wrd56.Obj));
  (Wrd53.Obj) = ((Wrd55.pObj) [1]);

DEFLABEL (label_63)
  (Wrd64.uLng) = (OBJECT_TYPE (Wrd53.Obj));
  if (! ((Wrd64.uLng) == 1))
    goto label_62;
  (Wrd63.pObj) = (OBJECT_ADDRESS (Wrd53.Obj));
  (Wrd62.Obj) = ((Wrd63.pObj) [0]);

DEFLABEL (label_61)
  (Wrd69.uLng) = (OBJECT_TYPE (Wrd62.Obj));
  if (! ((Wrd69.uLng) == 30))
    goto label_43;
  (Wrd73.Obj) = (Rsp [1]);
  (Wrd74.uLng) = (OBJECT_TYPE (Wrd73.Obj));
  if (! ((Wrd74.uLng) == 1))
    goto label_60;
  (Wrd72.pObj) = (OBJECT_ADDRESS (Wrd73.Obj));
  (Wrd70.Obj) = ((Wrd72.pObj) [1]);

DEFLABEL (label_59)
  (Wrd81.uLng) = (OBJECT_TYPE (Wrd70.Obj));
  if (! ((Wrd81.uLng) == 1))
    goto label_58;
  (Wrd80.pObj) = (OBJECT_ADDRESS (Wrd70.Obj));
  (Wrd79.Obj) = ((Wrd80.pObj) [1]);

DEFLABEL (label_57)
  if (! ((Wrd79.Obj) == (current_block [OBJECT_41_2])))
    goto label_43;
  (Wrd90.Obj) = (Rsp [1]);
  (Wrd91.uLng) = (OBJECT_TYPE (Wrd90.Obj));
  if (! ((Wrd91.uLng) == 1))
    goto label_56;
  (Wrd89.pObj) = (OBJECT_ADDRESS (Wrd90.Obj));
  (Wrd87.Obj) = ((Wrd89.pObj) [0]);

DEFLABEL (label_55)
  (Rsp [0]) = (Wrd87.Obj);
  (Wrd99.Obj) = (Rsp [1]);
  (Wrd100.uLng) = (OBJECT_TYPE (Wrd99.Obj));
  if (! ((Wrd100.uLng) == 1))
    goto label_54;
  (Wrd98.pObj) = (OBJECT_ADDRESS (Wrd99.Obj));
  (Wrd96.Obj) = ((Wrd98.pObj) [1]);

DEFLABEL (label_53)
  (Wrd107.uLng) = (OBJECT_TYPE (Wrd96.Obj));
  if (! ((Wrd107.uLng) == 1))
    goto label_52;
  (Wrd106.pObj) = (OBJECT_ADDRESS (Wrd96.Obj));
  (Wrd105.Obj) = ((Wrd106.pObj) [0]);

DEFLABEL (label_51)
  (Rsp [1]) = (Wrd105.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_16]));

DEFLABEL (label_52)
  (Wrd111.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_25]))));
  (* (--Rsp)) = (Wrd111.Obj);
  (* (--Rsp)) = (Wrd96.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_1]), 1);

DEFLABEL (label_35)
  (Wrd105.Obj) = Rvl;
  goto label_51;

DEFLABEL (label_54)
  (Wrd104.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_24]))));
  (* (--Rsp)) = (Wrd104.Obj);
  (* (--Rsp)) = (Wrd99.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_0]), 1);

DEFLABEL (label_34)
  (Wrd96.Obj) = Rvl;
  goto label_53;

DEFLABEL (label_56)
  (Wrd95.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_23]))));
  (* (--Rsp)) = (Wrd95.Obj);
  (* (--Rsp)) = (Wrd90.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_1]), 1);

DEFLABEL (label_33)
  (Wrd87.Obj) = Rvl;
  goto label_55;

DEFLABEL (label_58)
  (Wrd85.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_22]))));
  (* (--Rsp)) = (Wrd85.Obj);
  (* (--Rsp)) = (Wrd70.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_0]), 1);

DEFLABEL (label_32)
  (Wrd79.Obj) = Rvl;
  goto label_57;

DEFLABEL (label_60)
  (Wrd78.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_21]))));
  (* (--Rsp)) = (Wrd78.Obj);
  (* (--Rsp)) = (Wrd73.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_0]), 1);

DEFLABEL (label_31)
  (Wrd70.Obj) = Rvl;
  goto label_59;

DEFLABEL (label_62)
  (Wrd68.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_20]))));
  (* (--Rsp)) = (Wrd68.Obj);
  (* (--Rsp)) = (Wrd53.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_1]), 1);

DEFLABEL (label_30)
  (Wrd62.Obj) = Rvl;
  goto label_61;

DEFLABEL (label_64)
  (Wrd61.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_19]))));
  (* (--Rsp)) = (Wrd61.Obj);
  (* (--Rsp)) = (Wrd56.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_0]), 1);

DEFLABEL (label_29)
  (Wrd53.Obj) = Rvl;
  goto label_63;

DEFLABEL (label_66)
  (Wrd51.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_18]))));
  (* (--Rsp)) = (Wrd51.Obj);
  (* (--Rsp)) = (Wrd46.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_0]), 1);

DEFLABEL (label_28)
  (Wrd43.Obj) = Rvl;
  goto label_65;

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_41_12);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_48;
  (Wrd117.Obj) = (Rsp [1]);
  (Wrd118.uLng) = (OBJECT_TYPE (Wrd117.Obj));
  if (! ((Wrd118.uLng) == 1))
    goto label_72;
  (Wrd116.pObj) = (OBJECT_ADDRESS (Wrd117.Obj));
  (Wrd114.Obj) = ((Wrd116.pObj) [1]);

DEFLABEL (label_71)
  (Wrd123.uLng) = (OBJECT_TYPE (Wrd114.Obj));
  if (! ((Wrd123.uLng) == 30))
    goto label_48;
  (Wrd127.Obj) = (Rsp [1]);
  (Wrd128.uLng) = (OBJECT_TYPE (Wrd127.Obj));
  if (! ((Wrd128.uLng) == 1))
    goto label_70;
  (Wrd126.pObj) = (OBJECT_ADDRESS (Wrd127.Obj));
  (Wrd124.Obj) = ((Wrd126.pObj) [0]);

DEFLABEL (label_69)
  (Rsp [0]) = (Wrd124.Obj);
  (Wrd136.Obj) = (Rsp [1]);
  (Wrd137.uLng) = (OBJECT_TYPE (Wrd136.Obj));
  if (! ((Wrd137.uLng) == 1))
    goto label_68;
  (Wrd135.pObj) = (OBJECT_ADDRESS (Wrd136.Obj));
  (Wrd133.Obj) = ((Wrd135.pObj) [1]);

DEFLABEL (label_67)
  (Rsp [1]) = (Wrd133.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_16]));

DEFLABEL (label_68)
  (Wrd141.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_15]))));
  (* (--Rsp)) = (Wrd141.Obj);
  (* (--Rsp)) = (Wrd136.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_0]), 1);

DEFLABEL (label_38)
  (Wrd133.Obj) = Rvl;
  goto label_67;

DEFLABEL (label_70)
  (Wrd132.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_14]))));
  (* (--Rsp)) = (Wrd132.Obj);
  (* (--Rsp)) = (Wrd127.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_1]), 1);

DEFLABEL (label_37)
  (Wrd124.Obj) = Rvl;
  goto label_69;

DEFLABEL (label_72)
  (Wrd122.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_13]))));
  (* (--Rsp)) = (Wrd122.Obj);
  (* (--Rsp)) = (Wrd117.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_0]), 1);

DEFLABEL (label_36)
  (Wrd114.Obj) = Rvl;
  goto label_71;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_42_4 3
#define LABEL_42_5 5
#define ENVIRONMENT_LABEL_42_3 13
#define DEBUGGING_LABEL_42_2 12
#define OBJECT_42_0 11
#define EXECUTE_CACHE_42_6 7
#define FREE_REFERENCE_42_0 10
#define FREE_REFERENCES_LABEL_42_0 6
#define NUMBER_OF_LINKER_SECTIONS_42_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_42 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_42_4);
      goto guarantee_http_headers_0;

    case 1:
      current_block = (Rpc - LABEL_42_5);
      goto label_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (guarantee_http_headers_4)
DEFLABEL (guarantee_http_headers_0)
  INTERRUPT_CHECK (26, LABEL_42_4);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_42_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_6;
  Wrd5 = Wrd9;

DEFLABEL (label_5)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_42_0]);
  (Rsp [2]) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_6]));

DEFLABEL (label_6)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_42_5])), (Wrd6.pObj));

DEFLABEL (label_2)
  (Wrd5.Obj) = Rvl;
  goto label_5;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_43_4 3
#define LABEL_43_9 5
#define LABEL_43_5 7
#define LABEL_43_6 9
#define TAG_43_7 3
#define LABEL_43_11 11
#define ENVIRONMENT_LABEL_43_3 22
#define DEBUGGING_LABEL_43_2 21
#define OBJECT_43_1 20
#define OBJECT_43_0 19
#define EXECUTE_CACHE_43_12 13
#define EXECUTE_CACHE_43_10 15
#define EXECUTE_CACHE_43_8 17
#define FREE_REFERENCES_LABEL_43_0 12
#define NUMBER_OF_LINKER_SECTIONS_43_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_43 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd9;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_43_4);
      goto http_header_5;

    case 1:
      current_block = (Rpc - LABEL_43_9);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_43_5);
      goto continuation_2;

    case 3:
      current_block = (Rpc - LABEL_43_6);
      goto lambda_9;

    case 4:
      current_block = (Rpc - LABEL_43_11);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (http_header_8)
DEFLABEL (http_header_5)
  INTERRUPT_CHECK (26, LABEL_43_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd10.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_43_7);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_43_6])));
  Rhp += 1;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd10.pObj)));
  Wrd11 = Wrd10;
  (Wrd12.Obj) = (Rsp [2]);
  ((Wrd11.pObj) [2]) = (Wrd12.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_43_8]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_43_5);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_11;

DEFLABEL (label_10)
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_11)
  (Wrd9.Obj) = (Rsp [3]);
  if ((Wrd9.Obj) == ((SCHEME_OBJECT) 0))
    goto label_10;
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_9]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_43_0]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_43_10]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_43_9);
  goto label_10;

DEFLABEL (lambda_9)
  CLOSURE_HEADER (LABEL_43_6);

DEFLABEL (lambda_1)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43_11]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_43_12]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_43_11);
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [2]);
  if (Rvl == (Wrd9.Obj))
    goto label_13;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_12;

DEFLABEL (label_13)
  Rvl = (current_block [OBJECT_43_1]);

DEFLABEL (label_12)
DEFLABEL (label_14)
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_44_4 3
#define LABEL_44_5 5
#define LABEL_44_7 7
#define ENVIRONMENT_LABEL_44_3 16
#define DEBUGGING_LABEL_44_2 15
#define EXECUTE_CACHE_44_9 9
#define EXECUTE_CACHE_44_8 11
#define EXECUTE_CACHE_44_6 13
#define FREE_REFERENCES_LABEL_44_0 8
#define NUMBER_OF_LINKER_SECTIONS_44_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_44 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_44_4);
      goto http_tokenP_2;

    case 1:
      current_block = (Rpc - LABEL_44_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_44_7);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (http_tokenP_5)
DEFLABEL (http_tokenP_2)
  INTERRUPT_CHECK (26, LABEL_44_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_44_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_44_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_44_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_6;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_6)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_44_7]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_44_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_44_7);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_44_9]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_45_4 3
#define LABEL_45_5 5
#define ENVIRONMENT_LABEL_45_3 13
#define DEBUGGING_LABEL_45_2 12
#define OBJECT_45_0 11
#define EXECUTE_CACHE_45_7 7
#define EXECUTE_CACHE_45_6 9
#define FREE_REFERENCES_LABEL_45_0 6
#define NUMBER_OF_LINKER_SECTIONS_45_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_45 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_45_4);
      goto guarantee_http_token_1;

    case 1:
      current_block = (Rpc - LABEL_45_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (guarantee_http_token_4)
DEFLABEL (guarantee_http_token_1)
  INTERRUPT_CHECK (26, LABEL_45_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_45_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_45_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_5;
  Rvl = (current_block [OBJECT_45_0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_5)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_45_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_46_4 3
#define ENVIRONMENT_LABEL_46_3 11
#define DEBUGGING_LABEL_46_2 10
#define OBJECT_46_2 9
#define OBJECT_46_1 8
#define OBJECT_46_0 7
#define EXECUTE_CACHE_46_5 5
#define FREE_REFERENCES_LABEL_46_0 4
#define NUMBER_OF_LINKER_SECTIONS_46_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_46 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_46_4);
      goto error_not_http_token_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (error_not_http_token_5)
DEFLABEL (error_not_http_token_2)
  INTERRUPT_CHECK (26, LABEL_46_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_46_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [2]);
  if ((Wrd7.Obj) == (current_block [OBJECT_46_1]))
    goto label_7;
  Wrd9 = Wrd7;
  goto label_6;

DEFLABEL (label_7)
  (Wrd9.Obj) = (current_block [OBJECT_46_2]);

DEFLABEL (label_6)
DEFLABEL (label_8)
  (Rsp [2]) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_46_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_47_4 3
#define LABEL_47_5 5
#define ENVIRONMENT_LABEL_47_3 12
#define DEBUGGING_LABEL_47_2 11
#define EXECUTE_CACHE_47_7 7
#define EXECUTE_CACHE_47_6 9
#define FREE_REFERENCES_LABEL_47_0 6
#define NUMBER_OF_LINKER_SECTIONS_47_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_47 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_47_4);
      goto write_http_token_1;

    case 1:
      current_block = (Rpc - LABEL_47_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (write_http_token_4)
DEFLABEL (write_http_token_1)
  INTERRUPT_CHECK (26, LABEL_47_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_47_5);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_47_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_48_4 3
#define ENVIRONMENT_LABEL_48_3 8
#define DEBUGGING_LABEL_48_2 7
#define EXECUTE_CACHE_48_5 5
#define FREE_REFERENCES_LABEL_48_0 4
#define NUMBER_OF_LINKER_SECTIONS_48_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_48 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_48_4);
      goto http_token_stringP_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (http_token_stringP_4)
DEFLABEL (http_token_stringP_1)
  INTERRUPT_CHECK (26, LABEL_48_4);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 30)
    goto label_5;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_5)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_48_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_49_4 3
#define LABEL_49_5 5
#define ENVIRONMENT_LABEL_49_3 13
#define DEBUGGING_LABEL_49_2 12
#define OBJECT_49_0 11
#define EXECUTE_CACHE_49_7 7
#define EXECUTE_CACHE_49_6 9
#define FREE_REFERENCES_LABEL_49_0 6
#define NUMBER_OF_LINKER_SECTIONS_49_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_49 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_49_4);
      goto guarantee_http_token_string_1;

    case 1:
      current_block = (Rpc - LABEL_49_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (guarantee_http_token_string_4)
DEFLABEL (guarantee_http_token_string_1)
  INTERRUPT_CHECK (26, LABEL_49_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_49_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_49_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_49_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_5;
  Rvl = (current_block [OBJECT_49_0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_5)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_49_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_50_4 3
#define ENVIRONMENT_LABEL_50_3 11
#define DEBUGGING_LABEL_50_2 10
#define OBJECT_50_2 9
#define OBJECT_50_1 8
#define OBJECT_50_0 7
#define EXECUTE_CACHE_50_5 5
#define FREE_REFERENCES_LABEL_50_0 4
#define NUMBER_OF_LINKER_SECTIONS_50_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_50 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_50_4);
      goto error_not_http_token_string_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (error_not_http_token_string_5)
DEFLABEL (error_not_http_token_string_2)
  INTERRUPT_CHECK (26, LABEL_50_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_50_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [2]);
  if ((Wrd7.Obj) == (current_block [OBJECT_50_1]))
    goto label_7;
  Wrd9 = Wrd7;
  goto label_6;

DEFLABEL (label_7)
  (Wrd9.Obj) = (current_block [OBJECT_50_2]);

DEFLABEL (label_6)
DEFLABEL (label_8)
  (Rsp [2]) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_50_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_51_4 3
#define LABEL_51_5 5
#define ENVIRONMENT_LABEL_51_3 12
#define DEBUGGING_LABEL_51_2 11
#define EXECUTE_CACHE_51_6 7
#define FREE_REFERENCE_51_0 10
#define FREE_REFERENCES_LABEL_51_0 6
#define NUMBER_OF_LINKER_SECTIONS_51_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_51 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_51_4);
      goto string_is_http_tokenP_0;

    case 1:
      current_block = (Rpc - LABEL_51_5);
      goto label_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (string_is_http_tokenP_4)
DEFLABEL (string_is_http_tokenP_0)
  INTERRUPT_CHECK (26, LABEL_51_4);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_51_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_6;
  Wrd5 = Wrd9;

DEFLABEL (label_5)
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_51_6]));

DEFLABEL (label_6)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_51_5])), (Wrd6.pObj));

DEFLABEL (label_2)
  (Wrd5.Obj) = Rvl;
  goto label_5;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_52_4 3
#define LABEL_52_5 5
#define LABEL_52_7 7
#define LABEL_52_11 9
#define LABEL_52_13 11
#define LABEL_52_9 13
#define ENVIRONMENT_LABEL_52_3 28
#define DEBUGGING_LABEL_52_2 27
#define EXECUTE_CACHE_52_14 15
#define EXECUTE_CACHE_52_12 17
#define EXECUTE_CACHE_52_10 19
#define EXECUTE_CACHE_52_8 21
#define EXECUTE_CACHE_52_6 23
#define FREE_REFERENCE_52_0 26
#define FREE_REFERENCES_LABEL_52_0 14
#define NUMBER_OF_LINKER_SECTIONS_52_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_52 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd12;
  machine_word Wrd17;
  machine_word Wrd13;
  machine_word Wrd6;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_52_4);
      goto parse_http_token_7;

    case 1:
      current_block = (Rpc - LABEL_52_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_52_7);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_52_11);
      goto continuation_3;

    case 4:
      current_block = (Rpc - LABEL_52_13);
      goto label_9;

    case 5:
      current_block = (Rpc - LABEL_52_9);
      goto continuation_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (parse_http_token_11)
DEFLABEL (parse_http_token_7)
  INTERRUPT_CHECK (26, LABEL_52_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_52_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_52_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_52_5);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_52_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_52_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_52_7);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_14;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_52_11]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_52_12]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_52_11);
  (Wrd11.Obj) = (MAKE_OBJECT (0, 1));
  (* (Rhp++)) = (Wrd11.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (10, (Wrd8.pObj)));
  (Rsp [1]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_52_0]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_13;
  Wrd12 = Wrd16;

DEFLABEL (label_12)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_52_14]));

DEFLABEL (label_13)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_52_13])), (Wrd13.pObj));

DEFLABEL (label_9)
  (Wrd12.Obj) = Rvl;
  goto label_12;

DEFLABEL (label_14)
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_52_9]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_52_10]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_52_9);
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_53_4 3
#define LABEL_53_5 5
#define LABEL_53_8 7
#define LABEL_53_7 9
#define LABEL_53_12 11
#define LABEL_53_10 13
#define LABEL_53_13 15
#define LABEL_53_15 17
#define LABEL_53_14 19
#define LABEL_53_16 21
#define ENVIRONMENT_LABEL_53_3 33
#define DEBUGGING_LABEL_53_2 32
#define OBJECT_53_0 31
#define EXECUTE_CACHE_53_11 23
#define EXECUTE_CACHE_53_9 25
#define EXECUTE_CACHE_53_6 27
#define FREE_REFERENCE_53_0 30
#define FREE_REFERENCES_LABEL_53_0 22
#define NUMBER_OF_LINKER_SECTIONS_53_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_53 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_53_4);
      goto match_http_token_11;

    case 1:
      current_block = (Rpc - LABEL_53_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_53_8);
      goto label_13;

    case 3:
      current_block = (Rpc - LABEL_53_7);
      goto continuation_1;

    case 4:
      current_block = (Rpc - LABEL_53_12);
      goto Z___ks2__8;

    case 5:
      current_block = (Rpc - LABEL_53_10);
      goto continuation_2;

    case 6:
      current_block = (Rpc - LABEL_53_13);
      goto continuation_4;

    case 7:
      current_block = (Rpc - LABEL_53_15);
      goto label_14;

    case 8:
      current_block = (Rpc - LABEL_53_14);
      goto continuation_5;

    case 9:
      current_block = (Rpc - LABEL_53_16);
      goto continuation_6;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (match_http_token_16)
DEFLABEL (match_http_token_11)
  INTERRUPT_CHECK (26, LABEL_53_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_53_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_53_5);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_53_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_20;
  Wrd8 = Wrd12;

DEFLABEL (label_19)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_53_9]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_53_7);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_18;
  Rsp = (& (Rsp [1]));
  goto Z___ks2__8;

DEFLABEL (label_18)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_10]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_53_11]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_53_10);
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_20)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_53_8])), (Wrd9.pObj));

DEFLABEL (label_13)
  (Wrd8.Obj) = Rvl;
  goto label_19;

DEFLABEL (Z___ks2__17)
DEFLABEL (Z___ks2__8)
  INTERRUPT_CHECK (26, LABEL_53_12);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_13]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_53_6]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_53_13);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_14]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_53_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_23;
  Wrd8 = Wrd12;

DEFLABEL (label_22)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_53_9]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_53_14);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_21;
  Rsp = (& (Rsp [1]));
  goto Z___ks2__8;

DEFLABEL (label_21)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_53_16]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_53_11]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_53_16);
  Rvl = (current_block [OBJECT_53_0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_23)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_53_15])), (Wrd9.pObj));

DEFLABEL (label_14)
  (Wrd8.Obj) = Rvl;
  goto label_22;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_54_4 3
#define ENVIRONMENT_LABEL_54_3 6
#define DEBUGGING_LABEL_54_2 5
#define OBJECT_54_0 4
#define FREE_REFERENCES_LABEL_54_0 4
#define NUMBER_OF_LINKER_SECTIONS_54_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_54 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd7;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_54_4);
      goto http_textP_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (http_textP_3)
DEFLABEL (http_textP_0)
  INTERRUPT_CHECK (26, LABEL_54_4);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.uLng) = (OBJECT_TYPE (Wrd6.Obj));
  if ((Wrd7.uLng) == 30)
    goto label_5;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_4;

DEFLABEL (label_5)
  Rvl = (current_block [OBJECT_54_0]);

DEFLABEL (label_4)
DEFLABEL (label_6)
  Rsp = (& (Rsp [1]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_55_4 3
#define LABEL_55_5 5
#define ENVIRONMENT_LABEL_55_3 13
#define DEBUGGING_LABEL_55_2 12
#define OBJECT_55_0 11
#define EXECUTE_CACHE_55_7 7
#define EXECUTE_CACHE_55_6 9
#define FREE_REFERENCES_LABEL_55_0 6
#define NUMBER_OF_LINKER_SECTIONS_55_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_55 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_55_4);
      goto guarantee_http_text_1;

    case 1:
      current_block = (Rpc - LABEL_55_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (guarantee_http_text_4)
DEFLABEL (guarantee_http_text_1)
  INTERRUPT_CHECK (26, LABEL_55_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_55_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_55_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_55_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_5;
  Rvl = (current_block [OBJECT_55_0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_5)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_55_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_56_4 3
#define ENVIRONMENT_LABEL_56_3 11
#define DEBUGGING_LABEL_56_2 10
#define OBJECT_56_2 9
#define OBJECT_56_1 8
#define OBJECT_56_0 7
#define EXECUTE_CACHE_56_5 5
#define FREE_REFERENCES_LABEL_56_0 4
#define NUMBER_OF_LINKER_SECTIONS_56_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_56 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_56_4);
      goto error_not_http_text_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (error_not_http_text_5)
DEFLABEL (error_not_http_text_2)
  INTERRUPT_CHECK (26, LABEL_56_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_56_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [2]);
  if ((Wrd7.Obj) == (current_block [OBJECT_56_1]))
    goto label_7;
  Wrd9 = Wrd7;
  goto label_6;

DEFLABEL (label_7)
  (Wrd9.Obj) = (current_block [OBJECT_56_2]);

DEFLABEL (label_6)
DEFLABEL (label_8)
  (Rsp [2]) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_56_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_57_4 3
#define LABEL_57_5 5
#define LABEL_57_8 7
#define LABEL_57_7 9
#define ENVIRONMENT_LABEL_57_3 19
#define DEBUGGING_LABEL_57_2 18
#define OBJECT_57_0 17
#define EXECUTE_CACHE_57_9 11
#define EXECUTE_CACHE_57_6 13
#define FREE_REFERENCE_57_0 16
#define FREE_REFERENCES_LABEL_57_0 10
#define NUMBER_OF_LINKER_SECTIONS_57_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_57 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_57_4);
      goto write_quoted_string_2;

    case 1:
      current_block = (Rpc - LABEL_57_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_57_8);
      goto label_4;

    case 3:
      current_block = (Rpc - LABEL_57_7);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (write_quoted_string_6)
DEFLABEL (write_quoted_string_2)
  INTERRUPT_CHECK (26, LABEL_57_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_57_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_57_0]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_57_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_57_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_57_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_57_0]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_8;
  Wrd9 = Wrd13;

DEFLABEL (label_7)
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd15.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_57_9]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_57_7);
  (Wrd5.Obj) = (current_block [OBJECT_57_0]);
  (Rsp [0]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_57_6]));

DEFLABEL (label_8)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_57_8])), (Wrd10.pObj));

DEFLABEL (label_4)
  (Wrd9.Obj) = Rvl;
  goto label_7;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_58_4 3
#define LABEL_58_5 5
#define LABEL_58_6 7
#define LABEL_58_8 9
#define LABEL_58_7 11
#define LABEL_58_11 13
#define LABEL_58_9 15
#define ENVIRONMENT_LABEL_58_3 27
#define DEBUGGING_LABEL_58_2 26
#define OBJECT_58_4 25
#define OBJECT_58_3 24
#define OBJECT_58_2 23
#define OBJECT_58_1 22
#define OBJECT_58_0 21
#define EXECUTE_CACHE_58_12 17
#define EXECUTE_CACHE_58_10 19
#define FREE_REFERENCES_LABEL_58_0 16
#define NUMBER_OF_LINKER_SECTIONS_58_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_58 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd12;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd36;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd23;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd13;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd11;
  machine_word Wrd10;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_58_4);
      goto Z__write_with_quotations_12;

    case 1:
      current_block = (Rpc - LABEL_58_5);
      goto label_14;

    case 2:
      current_block = (Rpc - LABEL_58_6);
      goto do_loop_9;

    case 3:
      current_block = (Rpc - LABEL_58_8);
      goto label_15;

    case 4:
      current_block = (Rpc - LABEL_58_7);
      goto continuation_4;

    case 5:
      current_block = (Rpc - LABEL_58_11);
      goto continuation_6;

    case 6:
      current_block = (Rpc - LABEL_58_9);
      goto continuation_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (Z__write_with_quotations_17)
DEFLABEL (Z__write_with_quotations_12)
  INTERRUPT_CHECK (26, LABEL_58_4);
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 30))
    goto label_20;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd8.Obj) = ((Wrd7.pObj) [1]);
  (Wrd9.Obj) = (MAKE_OBJECT (26, (Wrd8.uLng)));
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_19)
  (Wrd16.Obj) = (current_block [OBJECT_58_1]);
  (* (--Rsp)) = (Wrd16.Obj);
  goto do_loop_9;

DEFLABEL (label_20)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_58_5]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_58_0]), 1);

DEFLABEL (label_14)
  (* (--Rsp)) = Rvl;
  goto label_19;

DEFLABEL (do_loop_18)
DEFLABEL (do_loop_9)
  INTERRUPT_CHECK (26, LABEL_58_6);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.Lng) = (FIXNUM_TO_LONG (Wrd5.Obj));
  (Wrd7.Obj) = (Rsp [1]);
  (Wrd8.Lng) = (FIXNUM_TO_LONG (Wrd7.Obj));
  if ((Wrd6.Lng) < (Wrd8.Lng))
    goto label_21;
  Rvl = (current_block [OBJECT_58_3]);
  Rsp = (& (Rsp [5]));
  goto pop_return;

DEFLABEL (label_21)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_58_7]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd30.Obj) = (Rsp [3]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 30))
    goto label_25;
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd23.uLng) == 26))
    goto label_25;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd30.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [1]);
  (Wrd29.Lng) = (FIXNUM_TO_LONG (Wrd28.Obj));
  if (! (((unsigned long) (Wrd6.Lng)) < ((unsigned long) (Wrd29.Lng))))
    goto label_25;
  (Wrd16.uLng) = (OBJECT_DATUM (Wrd5.Obj));
  (Wrd19.pChr) = (& ((Wrd27.pChr) [(Wrd16.Lng)]));
  (Wrd20.uLng) = ((unsigned long) (((unsigned char *) (Wrd19.pChr)) [(ADDRESS_UNITS_PER_OBJECT * 2)]));
  (Wrd21.Obj) = (MAKE_OBJECT (2, (Wrd20.uLng)));
  (* (--Rsp)) = (Wrd21.Obj);

DEFLABEL (label_24)
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_58_9]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (Wrd40.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd40.Obj);
  (Wrd41.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd41.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_58_10]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_58_9);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_23;

DEFLABEL (label_22)
  (Wrd7.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [7]);
  (Rsp [1]) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_58_12]));

DEFLABEL (label_23)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_58_11]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (current_block [OBJECT_58_4]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_58_12]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_58_11);
  goto label_22;

DEFLABEL (label_25)
  (Wrd32.Obj) = (Rsp [3]);
  (Wrd33.Obj) = (Rsp [1]);
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_58_8]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_58_2]), 2);

DEFLABEL (label_15)
  (* (--Rsp)) = Rvl;
  goto label_24;

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_58_7);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.Lng) = (FIXNUM_TO_LONG (Wrd6.Obj));
  (Wrd8.Lng) = ((Wrd7.Lng) + 1L);
  (Wrd5.Obj) = (LONG_TO_FIXNUM (Wrd8.Lng));
  (Rsp [0]) = (Wrd5.Obj);
  goto do_loop_9;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_59_4 3
#define LABEL_59_5 5
#define LABEL_59_7 7
#define LABEL_59_8 9
#define LABEL_59_10 11
#define LABEL_59_12 13
#define LABEL_59_13 15
#define ENVIRONMENT_LABEL_59_3 28
#define DEBUGGING_LABEL_59_2 27
#define OBJECT_59_3 26
#define OBJECT_59_2 25
#define OBJECT_59_1 24
#define OBJECT_59_0 23
#define EXECUTE_CACHE_59_11 17
#define EXECUTE_CACHE_59_9 19
#define EXECUTE_CACHE_59_6 21
#define FREE_REFERENCES_LABEL_59_0 16
#define NUMBER_OF_LINKER_SECTIONS_59_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_59 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd12;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd24;
  machine_word Wrd21;
  machine_word Wrd25;
  machine_word Wrd28;
  machine_word Wrd30;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd35;
  machine_word Wrd32;
  machine_word Wrd36;
  machine_word Wrd39;
  machine_word Wrd41;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd16;
  machine_word Wrd6;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_59_4);
      goto commentP_12;

    case 1:
      current_block = (Rpc - LABEL_59_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_59_7);
      goto loop_9;

    case 3:
      current_block = (Rpc - LABEL_59_8);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_59_10);
      goto continuation_3;

    case 5:
      current_block = (Rpc - LABEL_59_12);
      goto label_15;

    case 6:
      current_block = (Rpc - LABEL_59_13);
      goto label_14;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (commentP_17)
DEFLABEL (commentP_12)
  INTERRUPT_CHECK (26, LABEL_59_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_59_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_59_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_59_5);
  (Rsp [0]) = Rvl;
  (Wrd6.Obj) = (current_block [OBJECT_59_0]);
  (* (--Rsp)) = (Wrd6.Obj);
  goto loop_9;

DEFLABEL (loop_18)
DEFLABEL (loop_9)
  INTERRUPT_CHECK (26, LABEL_59_7);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_59_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_59_9]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_59_8);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_59_10]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_59_11]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_59_10);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_23;
  (Wrd7.Obj) = (Rsp [1]);
  (Rsp [2]) = (Wrd7.Obj);
  Rsp = (& (Rsp [2]));
  (Wrd9.Obj) = (Rsp [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 26)
    goto label_19;
  INVOKE_INTERFACE_0 (45);

DEFLABEL (label_19)
  (Wrd12.Lng) = (FIXNUM_TO_LONG (Wrd9.Obj));
  if ((Wrd12.Lng) == 0)
    goto label_21;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_20;

DEFLABEL (label_21)
  Rvl = (current_block [OBJECT_59_3]);

DEFLABEL (label_20)
DEFLABEL (label_22)
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_23)
  (Wrd16.Obj) = (Rsp [0]);
  if ((Wrd16.Obj) == (current_block [OBJECT_59_1]))
    goto label_28;
  if ((Wrd16.Obj) == (current_block [OBJECT_59_2]))
    goto label_25;

DEFLABEL (label_24)
  Rsp = (& (Rsp [1]));
  goto loop_9;

DEFLABEL (label_25)
  (Wrd26.Obj) = (Rsp [1]);
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if (! ((Wrd27.uLng) == 26))
    goto label_27;
  (Wrd30.Lng) = (FIXNUM_TO_LONG (Wrd26.Obj));
  (Wrd28.Lng) = ((Wrd30.Lng) - 1L);
  if (! (LONG_TO_FIXNUM_P (Wrd28.Lng)))
    goto label_27;
  (Wrd25.Obj) = (LONG_TO_FIXNUM (Wrd28.Lng));

DEFLABEL (label_26)
  (Rsp [1]) = (Wrd25.Obj);
  goto label_24;

DEFLABEL (label_27)
  (Wrd21.Obj) = (Rsp [1]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_59_13]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_INTERFACE_0 (34);

DEFLABEL (label_14)
  (Wrd25.Obj) = Rvl;
  goto label_26;

DEFLABEL (label_28)
  (Wrd37.Obj) = (Rsp [1]);
  (Wrd38.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if (! ((Wrd38.uLng) == 26))
    goto label_30;
  (Wrd41.Lng) = (FIXNUM_TO_LONG (Wrd37.Obj));
  (Wrd39.Lng) = ((Wrd41.Lng) + 1L);
  if (! (LONG_TO_FIXNUM_P (Wrd39.Lng)))
    goto label_30;
  (Wrd36.Obj) = (LONG_TO_FIXNUM (Wrd39.Lng));

DEFLABEL (label_29)
  (Rsp [1]) = (Wrd36.Obj);
  goto label_24;

DEFLABEL (label_30)
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_59_12]))));
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_INTERFACE_0 (38);

DEFLABEL (label_15)
  (Wrd36.Obj) = Rvl;
  goto label_29;

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_60_4 3
#define LABEL_60_5 5
#define LABEL_60_8 7
#define LABEL_60_7 9
#define ENVIRONMENT_LABEL_60_3 20
#define DEBUGGING_LABEL_60_2 19
#define OBJECT_60_1 18
#define OBJECT_60_0 17
#define EXECUTE_CACHE_60_9 11
#define EXECUTE_CACHE_60_6 13
#define FREE_REFERENCE_60_0 16
#define FREE_REFERENCES_LABEL_60_0 10
#define NUMBER_OF_LINKER_SECTIONS_60_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_60 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_60_4);
      goto write_comment_2;

    case 1:
      current_block = (Rpc - LABEL_60_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_60_8);
      goto label_4;

    case 3:
      current_block = (Rpc - LABEL_60_7);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (write_comment_6)
DEFLABEL (write_comment_2)
  INTERRUPT_CHECK (26, LABEL_60_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_60_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_60_0]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_60_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_60_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_60_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_60_0]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_8;
  Wrd9 = Wrd13;

DEFLABEL (label_7)
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd15.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_60_9]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_60_7);
  (Wrd5.Obj) = (current_block [OBJECT_60_1]);
  (Rsp [0]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_60_6]));

DEFLABEL (label_8)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_60_8])), (Wrd10.pObj));

DEFLABEL (label_4)
  (Wrd9.Obj) = Rvl;
  goto label_7;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_61_4 3
#define LABEL_61_5 5
#define LABEL_61_6 7
#define LABEL_61_9 9
#define ENVIRONMENT_LABEL_61_3 19
#define DEBUGGING_LABEL_61_2 18
#define OBJECT_61_0 17
#define EXECUTE_CACHE_61_10 11
#define EXECUTE_CACHE_61_8 13
#define EXECUTE_CACHE_61_7 15
#define FREE_REFERENCES_LABEL_61_0 10
#define NUMBER_OF_LINKER_SECTIONS_61_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_61 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_61_4);
      goto read_http_headers_7;

    case 1:
      current_block = (Rpc - LABEL_61_5);
      goto loop_5;

    case 2:
      current_block = (Rpc - LABEL_61_6);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_61_9);
      goto continuation_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (read_http_headers_10)
DEFLABEL (read_http_headers_7)
  INTERRUPT_CHECK (26, LABEL_61_4);
  (Wrd5.Obj) = (current_block [OBJECT_61_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  goto loop_5;

DEFLABEL (loop_11)
DEFLABEL (loop_5)
  INTERRUPT_CHECK (26, LABEL_61_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_61_6]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_61_7]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_61_6);
  (* (--Rsp)) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_12;
  (Wrd11.Obj) = (Rsp [1]);
  (Rsp [2]) = (Wrd11.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_61_8]));

DEFLABEL (label_12)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_61_9]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_61_10]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_61_9);
  (Wrd9.Obj) = (Rsp [1]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (Rsp [1]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  goto loop_5;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_62_4 3
#define LABEL_62_5 5
#define TAG_62_6 1
#define LABEL_62_7 7
#define LABEL_62_8 9
#define ENVIRONMENT_LABEL_62_3 19
#define DEBUGGING_LABEL_62_2 18
#define OBJECT_62_0 17
#define EXECUTE_CACHE_62_11 11
#define EXECUTE_CACHE_62_10 13
#define EXECUTE_CACHE_62_9 15
#define FREE_REFERENCES_LABEL_62_0 10
#define NUMBER_OF_LINKER_SECTIONS_62_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_62 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd15;
  machine_word Wrd11;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd18;
  machine_word Wrd7;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd8;
  machine_word Wrd9;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_62_4);
      goto Z__call_parser_3;

    case 1:
      current_block = (Rpc - LABEL_62_5);
      goto lambda_7;

    case 2:
      current_block = (Rpc - LABEL_62_7);
      goto lambda_0;

    case 3:
      current_block = (Rpc - LABEL_62_8);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (Z__call_parser_6)
DEFLABEL (Z__call_parser_3)
  INTERRUPT_CHECK (26, LABEL_62_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd6.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd9.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_62_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_62_5])));
  Rhp += 2;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd9.pObj)));
  Wrd12 = Wrd9;
  (Wrd13.Obj) = (Rsp [3]);
  ((Wrd12.pObj) [2]) = (Wrd13.Obj);
  ((Wrd12.pObj) [3]) = (Wrd6.Obj);
  (Rsp [3]) = (Wrd8.Obj);
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_7]))));
  (Rsp [2]) = (Wrd14.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (lambda_7)
  CLOSURE_HEADER (LABEL_62_5);

DEFLABEL (lambda_2)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  if ((Wrd7.Obj) == ((SCHEME_OBJECT) 0))
    goto label_9;
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_8]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd14.Obj) = ((Wrd6.pObj) [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (current_block [OBJECT_62_0]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_62_10]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_62_8);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_62_11]));

DEFLABEL (label_9)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62_8]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd21.Obj) = ((Wrd6.pObj) [3]);
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd22.Obj) = (current_block [OBJECT_62_0]);
  (* (--Rsp)) = (Wrd22.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_62_9]));

DEFLABEL (lambda_8)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_62_7);
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_63_4 3
#define ENVIRONMENT_LABEL_63_3 8
#define DEBUGGING_LABEL_63_2 7
#define EXECUTE_CACHE_63_5 5
#define FREE_REFERENCES_LABEL_63_0 4
#define NUMBER_OF_LINKER_SECTIONS_63_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_63 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_63_4);
      goto Z__unparsed_value_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (Z__unparsed_value_3)
DEFLABEL (Z__unparsed_value_0)
  INTERRUPT_CHECK (26, LABEL_63_4);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_63_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_64_4 3
#define LABEL_64_5 5
#define LABEL_64_7 7
#define LABEL_64_8 9
#define TAG_64_9 3
#define LABEL_64_12 11
#define LABEL_64_13 13
#define LABEL_64_15 15
#define LABEL_64_17 17
#define LABEL_64_23 19
#define LABEL_64_19 21
#define LABEL_64_20 23
#define ENVIRONMENT_LABEL_64_3 46
#define DEBUGGING_LABEL_64_2 45
#define OBJECT_64_3 44
#define OBJECT_64_2 43
#define OBJECT_64_1 42
#define OBJECT_64_0 41
#define EXECUTE_CACHE_64_22 25
#define EXECUTE_CACHE_64_21 27
#define EXECUTE_CACHE_64_18 29
#define EXECUTE_CACHE_64_16 31
#define EXECUTE_CACHE_64_14 33
#define EXECUTE_CACHE_64_11 35
#define EXECUTE_CACHE_64_10 37
#define EXECUTE_CACHE_64_6 39
#define FREE_REFERENCES_LABEL_64_0 24
#define NUMBER_OF_LINKER_SECTIONS_64_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_64 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd6;
  machine_word Wrd23;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd17;
  machine_word Wrd27;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd26;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_64_4);
      goto write_http_headers_12;

    case 1:
      current_block = (Rpc - LABEL_64_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_64_7);
      goto continuation_11;

    case 3:
      current_block = (Rpc - LABEL_64_8);
      goto lambda_17;

    case 4:
      current_block = (Rpc - LABEL_64_12);
      goto continuation_2;

    case 5:
      current_block = (Rpc - LABEL_64_13);
      goto continuation_1;

    case 6:
      current_block = (Rpc - LABEL_64_15);
      goto continuation_7;

    case 7:
      current_block = (Rpc - LABEL_64_17);
      goto continuation_3;

    case 8:
      current_block = (Rpc - LABEL_64_23);
      goto label_14;

    case 9:
      current_block = (Rpc - LABEL_64_19);
      goto continuation_9;

    case 10:
      current_block = (Rpc - LABEL_64_20);
      goto continuation_8;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (write_http_headers_16)
DEFLABEL (write_http_headers_12)
  INTERRUPT_CHECK (26, LABEL_64_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_64_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_64_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd10.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_64_9);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_64_8])));
  Rhp += 1;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd10.pObj)));
  Wrd11 = Wrd10;
  (Wrd12.Obj) = (Rsp [3]);
  ((Wrd11.pObj) [2]) = (Wrd12.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_10]));

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_64_7);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_11]));

DEFLABEL (lambda_17)
  CLOSURE_HEADER (LABEL_64_8);

DEFLABEL (lambda_10)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_12]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_13]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_14]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_64_13);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_17]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_18]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_64_17);
  (* (--Rsp)) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_18;
  (Wrd26.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd26.Obj);
  (Wrd28.Obj) = (Rsp [3]);
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd28.Obj));
  (Wrd27.Obj) = ((Wrd29.pObj) [2]);
  (Rsp [1]) = (Wrd27.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_22]));

DEFLABEL (label_18)
  (Wrd17.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd17.uLng) == 62))
    goto label_20;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd15.Lng))))
    goto label_20;
  (Wrd7.Obj) = ((Wrd13.pObj) [2]);

DEFLABEL (label_19)
  (Rsp [0]) = (Wrd7.Obj);
  (Wrd24.Obj) = (Rsp [3]);
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd23.Obj) = ((Wrd25.pObj) [2]);
  (Rsp [1]) = (Wrd23.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_16]));

DEFLABEL (label_20)
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.Obj) = (current_block [OBJECT_64_2]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_23]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_64_3]), 2);

DEFLABEL (label_14)
  (Wrd7.Obj) = Rvl;
  goto label_19;

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_64_12);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_15]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_64_1]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_16]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_64_15);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_19]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64_20]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_21]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_64_20);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_16]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_64_19);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [1]) = (Wrd5.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_64_11]));

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_65_4 3
#define LABEL_65_5 5
#define TAG_65_6 1
#define LABEL_65_9 7
#define LABEL_65_8 9
#define ENVIRONMENT_LABEL_65_3 18
#define DEBUGGING_LABEL_65_2 17
#define EXECUTE_CACHE_65_10 11
#define EXECUTE_CACHE_65_7 13
#define FREE_REFERENCE_65_0 16
#define FREE_REFERENCES_LABEL_65_0 10
#define NUMBER_OF_LINKER_SECTIONS_65_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_65 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_65_4);
      goto lp_token_2;

    case 1:
      current_block = (Rpc - LABEL_65_5);
      goto lambda_7;

    case 2:
      current_block = (Rpc - LABEL_65_9);
      goto label_4;

    case 3:
      current_block = (Rpc - LABEL_65_8);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lp_token_6)
DEFLABEL (lp_token_2)
  INTERRUPT_CHECK (26, LABEL_65_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_65_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_65_5])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [1]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_65_7]));

DEFLABEL (lambda_7)
  CLOSURE_HEADER (LABEL_65_5);

DEFLABEL (lambda_1)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_65_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_65_0]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_9;
  Wrd9 = Wrd13;

DEFLABEL (label_8)
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_65_10]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_65_8);
  (Rsp [2]) = Rvl;
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [2]);
  (Rsp [0]) = (Wrd6.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (label_9)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_65_9])), (Wrd10.pObj));

DEFLABEL (label_4)
  (Wrd9.Obj) = Rvl;
  goto label_8;

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_66_5 3
#define LABEL_66_7 5
#define LABEL_66_8 7
#define LABEL_66_4 9
#define LABEL_66_10 11
#define LABEL_66_6 13
#define LABEL_66_12 15
#define ENVIRONMENT_LABEL_66_3 27
#define DEBUGGING_LABEL_66_2 26
#define OBJECT_66_2 25
#define OBJECT_66_1 24
#define OBJECT_66_0 23
#define EXECUTE_CACHE_66_11 17
#define EXECUTE_CACHE_66_9 19
#define FREE_REFERENCE_66_0 22
#define FREE_REFERENCES_LABEL_66_0 16
#define NUMBER_OF_LINKER_SECTIONS_66_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_66 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd14;
  machine_word Wrd8;
  machine_word Wrd9;
  machine_word Wrd19;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd10;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd39;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd40;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd38;
  machine_word Wrd34;
  machine_word Wrd26;
  machine_word Wrd28;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd25;
  machine_word Wrd22;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_66_5);
      goto continuation_2;

    case 1:
      current_block = (Rpc - LABEL_66_7);
      goto label_10;

    case 2:
      current_block = (Rpc - LABEL_66_8);
      goto label_11;

    case 3:
      current_block = (Rpc - LABEL_66_4);
      goto lp_token_string_7;

    case 4:
      current_block = (Rpc - LABEL_66_10);
      goto label_9;

    case 5:
      current_block = (Rpc - LABEL_66_6);
      goto continuation_6;

    case 6:
      current_block = (Rpc - LABEL_66_12);
      goto label_12;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lp_token_string_14)
DEFLABEL (lp_token_string_7)
  INTERRUPT_CHECK (26, LABEL_66_4);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_16;

DEFLABEL (label_15)
  Rsp = (& (Rsp [2]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (label_16)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_66_5]))));
  (* (--Rsp)) = (Wrd10.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_24;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (* (--Rsp)) = (Wrd13.Obj);

DEFLABEL (label_23)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_66_11]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_66_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_15;
  (Wrd22.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_66_6]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd29.Obj) = (Rsp [2]);
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd29.Obj));
  if (! ((Wrd30.uLng) == 1))
    goto label_22;
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd29.Obj));
  (Wrd26.Obj) = ((Wrd28.pObj) [0]);

DEFLABEL (label_21)
  (Wrd38.Obj) = (current_block [OBJECT_66_1]);
  (* (Rhp++)) = (Wrd38.Obj);
  (* (Rhp++)) = (Wrd26.Obj);
  (Wrd36.pObj) = (& (Rhp [-2]));
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd36.pObj)));
  (* (--Rsp)) = (Wrd37.Obj);
  (Wrd40.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_66_0]));
  (Wrd43.Obj) = ((Wrd40.pObj) [0]);
  (Wrd44.uLng) = (OBJECT_TYPE (Wrd43.Obj));
  if ((Wrd44.uLng) == 50)
    goto label_20;
  Wrd39 = Wrd43;

DEFLABEL (label_19)
  (* (--Rsp)) = (Wrd39.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_66_9]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_66_6);
  (Rsp [2]) = Rvl;
  (Wrd9.Obj) = (Rsp [1]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if (! ((Wrd10.uLng) == 1))
    goto label_18;
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [1]);

DEFLABEL (label_17)
  (Rsp [1]) = (Wrd6.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (label_18)
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_66_12]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_66_2]), 1);

DEFLABEL (label_12)
  (Wrd6.Obj) = Rvl;
  goto label_17;

DEFLABEL (label_20)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_66_8])), (Wrd40.pObj));

DEFLABEL (label_11)
  (Wrd39.Obj) = Rvl;
  goto label_19;

DEFLABEL (label_22)
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_66_7]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd29.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_66_0]), 1);

DEFLABEL (label_10)
  (Wrd26.Obj) = Rvl;
  goto label_21;

DEFLABEL (label_24)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_66_10]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_66_0]), 1);

DEFLABEL (label_9)
  (* (--Rsp)) = Rvl;
  goto label_23;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_67_4 3
#define LABEL_67_5 5
#define TAG_67_6 1
#define LABEL_67_8 7
#define TAG_67_9 2
#define ENVIRONMENT_LABEL_67_3 14
#define DEBUGGING_LABEL_67_2 13
#define EXECUTE_CACHE_67_10 9
#define EXECUTE_CACHE_67_7 11
#define FREE_REFERENCES_LABEL_67_0 8
#define NUMBER_OF_LINKER_SECTIONS_67_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_67 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd17;
  machine_word Wrd14;
  machine_word Wrd10;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_67_4);
      goto lp_text_2;

    case 1:
      current_block = (Rpc - LABEL_67_5);
      goto lambda_6;

    case 2:
      current_block = (Rpc - LABEL_67_8);
      goto lambda_7;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lp_text_5)
DEFLABEL (lp_text_2)
  INTERRUPT_CHECK (26, LABEL_67_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_67_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_67_5])));
  Rhp += 3;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd12 = Wrd7;
  (Wrd13.Obj) = (Rsp [2]);
  ((Wrd12.pObj) [2]) = (Wrd13.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd12.pObj) [3]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd12.pObj) [4]) = (Wrd9.Obj);
  (Rsp [2]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_7]));

DEFLABEL (lambda_6)
  CLOSURE_HEADER (LABEL_67_5);

DEFLABEL (lambda_1)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = ((Wrd6.pObj) [4]);
  (* (--Rsp)) = (Wrd10.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd13.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_67_9);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_67_8])));
  Rhp += 1;
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd13.pObj)));
  Wrd14 = Wrd13;
  (Wrd17.Obj) = ((Wrd6.pObj) [2]);
  ((Wrd14.pObj) [2]) = (Wrd17.Obj);
  (Rsp [2]) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_67_10]));

DEFLABEL (lambda_7)
  CLOSURE_HEADER (LABEL_67_8);

DEFLABEL (lambda_0)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_68_5 3
#define LABEL_68_7 5
#define LABEL_68_8 7
#define LABEL_68_4 9
#define LABEL_68_10 11
#define LABEL_68_6 13
#define LABEL_68_12 15
#define ENVIRONMENT_LABEL_68_3 27
#define DEBUGGING_LABEL_68_2 26
#define OBJECT_68_2 25
#define OBJECT_68_1 24
#define OBJECT_68_0 23
#define EXECUTE_CACHE_68_11 17
#define EXECUTE_CACHE_68_9 19
#define FREE_REFERENCE_68_0 22
#define FREE_REFERENCES_LABEL_68_0 16
#define NUMBER_OF_LINKER_SECTIONS_68_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_68 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd14;
  machine_word Wrd8;
  machine_word Wrd9;
  machine_word Wrd19;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd10;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd39;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd40;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd38;
  machine_word Wrd34;
  machine_word Wrd26;
  machine_word Wrd28;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd25;
  machine_word Wrd22;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_68_5);
      goto continuation_2;

    case 1:
      current_block = (Rpc - LABEL_68_7);
      goto label_10;

    case 2:
      current_block = (Rpc - LABEL_68_8);
      goto label_11;

    case 3:
      current_block = (Rpc - LABEL_68_4);
      goto lp_quoted_string_7;

    case 4:
      current_block = (Rpc - LABEL_68_10);
      goto label_9;

    case 5:
      current_block = (Rpc - LABEL_68_6);
      goto continuation_6;

    case 6:
      current_block = (Rpc - LABEL_68_12);
      goto label_12;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lp_quoted_string_14)
DEFLABEL (lp_quoted_string_7)
  INTERRUPT_CHECK (26, LABEL_68_4);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_16;

DEFLABEL (label_15)
  Rsp = (& (Rsp [2]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (label_16)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_68_5]))));
  (* (--Rsp)) = (Wrd10.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_24;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (* (--Rsp)) = (Wrd13.Obj);

DEFLABEL (label_23)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_68_11]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_68_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_15;
  (Wrd22.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_68_6]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd29.Obj) = (Rsp [2]);
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd29.Obj));
  if (! ((Wrd30.uLng) == 1))
    goto label_22;
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd29.Obj));
  (Wrd26.Obj) = ((Wrd28.pObj) [0]);

DEFLABEL (label_21)
  (Wrd38.Obj) = (current_block [OBJECT_68_1]);
  (* (Rhp++)) = (Wrd38.Obj);
  (* (Rhp++)) = (Wrd26.Obj);
  (Wrd36.pObj) = (& (Rhp [-2]));
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd36.pObj)));
  (* (--Rsp)) = (Wrd37.Obj);
  (Wrd40.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_68_0]));
  (Wrd43.Obj) = ((Wrd40.pObj) [0]);
  (Wrd44.uLng) = (OBJECT_TYPE (Wrd43.Obj));
  if ((Wrd44.uLng) == 50)
    goto label_20;
  Wrd39 = Wrd43;

DEFLABEL (label_19)
  (* (--Rsp)) = (Wrd39.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_68_9]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_68_6);
  (Rsp [2]) = Rvl;
  (Wrd9.Obj) = (Rsp [1]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if (! ((Wrd10.uLng) == 1))
    goto label_18;
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [1]);

DEFLABEL (label_17)
  (Rsp [1]) = (Wrd6.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (label_18)
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_68_12]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_68_2]), 1);

DEFLABEL (label_12)
  (Wrd6.Obj) = Rvl;
  goto label_17;

DEFLABEL (label_20)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_68_8])), (Wrd40.pObj));

DEFLABEL (label_11)
  (Wrd39.Obj) = Rvl;
  goto label_19;

DEFLABEL (label_22)
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_68_7]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd29.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_68_0]), 1);

DEFLABEL (label_10)
  (Wrd26.Obj) = Rvl;
  goto label_21;

DEFLABEL (label_24)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_68_10]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_68_0]), 1);

DEFLABEL (label_9)
  (* (--Rsp)) = Rvl;
  goto label_23;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_69_5 3
#define LABEL_69_7 5
#define LABEL_69_8 7
#define LABEL_69_4 9
#define LABEL_69_10 11
#define LABEL_69_6 13
#define LABEL_69_12 15
#define ENVIRONMENT_LABEL_69_3 27
#define DEBUGGING_LABEL_69_2 26
#define OBJECT_69_2 25
#define OBJECT_69_1 24
#define OBJECT_69_0 23
#define EXECUTE_CACHE_69_11 17
#define EXECUTE_CACHE_69_9 19
#define FREE_REFERENCE_69_0 22
#define FREE_REFERENCES_LABEL_69_0 16
#define NUMBER_OF_LINKER_SECTIONS_69_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_69 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd14;
  machine_word Wrd8;
  machine_word Wrd9;
  machine_word Wrd19;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd10;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd39;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd40;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd38;
  machine_word Wrd34;
  machine_word Wrd26;
  machine_word Wrd28;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd25;
  machine_word Wrd22;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_69_5);
      goto continuation_2;

    case 1:
      current_block = (Rpc - LABEL_69_7);
      goto label_10;

    case 2:
      current_block = (Rpc - LABEL_69_8);
      goto label_11;

    case 3:
      current_block = (Rpc - LABEL_69_4);
      goto lp_comment_7;

    case 4:
      current_block = (Rpc - LABEL_69_10);
      goto label_9;

    case 5:
      current_block = (Rpc - LABEL_69_6);
      goto continuation_6;

    case 6:
      current_block = (Rpc - LABEL_69_12);
      goto label_12;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lp_comment_14)
DEFLABEL (lp_comment_7)
  INTERRUPT_CHECK (26, LABEL_69_4);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_16;

DEFLABEL (label_15)
  Rsp = (& (Rsp [2]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (label_16)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_69_5]))));
  (* (--Rsp)) = (Wrd10.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_24;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [0]);
  (* (--Rsp)) = (Wrd13.Obj);

DEFLABEL (label_23)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_69_11]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_69_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_15;
  (Wrd22.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_69_6]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd29.Obj) = (Rsp [2]);
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd29.Obj));
  if (! ((Wrd30.uLng) == 1))
    goto label_22;
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd29.Obj));
  (Wrd26.Obj) = ((Wrd28.pObj) [0]);

DEFLABEL (label_21)
  (Wrd38.Obj) = (current_block [OBJECT_69_1]);
  (* (Rhp++)) = (Wrd38.Obj);
  (* (Rhp++)) = (Wrd26.Obj);
  (Wrd36.pObj) = (& (Rhp [-2]));
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd36.pObj)));
  (* (--Rsp)) = (Wrd37.Obj);
  (Wrd40.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_69_0]));
  (Wrd43.Obj) = ((Wrd40.pObj) [0]);
  (Wrd44.uLng) = (OBJECT_TYPE (Wrd43.Obj));
  if ((Wrd44.uLng) == 50)
    goto label_20;
  Wrd39 = Wrd43;

DEFLABEL (label_19)
  (* (--Rsp)) = (Wrd39.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_69_9]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_69_6);
  (Rsp [2]) = Rvl;
  (Wrd9.Obj) = (Rsp [1]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if (! ((Wrd10.uLng) == 1))
    goto label_18;
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [1]);

DEFLABEL (label_17)
  (Rsp [1]) = (Wrd6.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (label_18)
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_69_12]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_69_2]), 1);

DEFLABEL (label_12)
  (Wrd6.Obj) = Rvl;
  goto label_17;

DEFLABEL (label_20)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_69_8])), (Wrd40.pObj));

DEFLABEL (label_11)
  (Wrd39.Obj) = Rvl;
  goto label_19;

DEFLABEL (label_22)
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_69_7]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd29.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_69_0]), 1);

DEFLABEL (label_10)
  (Wrd26.Obj) = Rvl;
  goto label_21;

DEFLABEL (label_24)
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_69_10]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_69_0]), 1);

DEFLABEL (label_9)
  (* (--Rsp)) = Rvl;
  goto label_23;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_70_5 3
#define LABEL_70_6 5
#define LABEL_70_4 7
#define LABEL_70_7 9
#define ENVIRONMENT_LABEL_70_3 18
#define DEBUGGING_LABEL_70_2 17
#define OBJECT_70_3 16
#define OBJECT_70_2 15
#define OBJECT_70_1 14
#define OBJECT_70_0 13
#define EXECUTE_CACHE_70_8 11
#define FREE_REFERENCES_LABEL_70_0 10
#define NUMBER_OF_LINKER_SECTIONS_70_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_70 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd20;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd24;
  machine_word Wrd26;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd23;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_70_5);
      goto continuation_2;

    case 1:
      current_block = (Rpc - LABEL_70_6);
      goto label_7;

    case 2:
      current_block = (Rpc - LABEL_70_4);
      goto lp_lws_4;

    case 3:
      current_block = (Rpc - LABEL_70_7);
      goto label_6;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lp_lws_9)
DEFLABEL (lp_lws_4)
  INTERRUPT_CHECK (26, LABEL_70_4);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_11;

DEFLABEL (label_10)
  Rsp = (& (Rsp [2]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (label_11)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_70_5]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_70_2]);
  (* (--Rsp)) = (Wrd11.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_15;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_14)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_70_8]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_70_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_10;
  (Wrd23.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd27.Obj) = (Rsp [1]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if (! ((Wrd28.uLng) == 1))
    goto label_13;
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd24.Obj) = ((Wrd26.pObj) [1]);

DEFLABEL (label_12)
  (Rsp [1]) = (Wrd24.Obj);
  (Wrd33.Obj) = (current_block [OBJECT_70_1]);
  (Rsp [2]) = (Wrd33.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (label_13)
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_70_6]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd27.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_70_0]), 1);

DEFLABEL (label_7)
  (Wrd24.Obj) = Rvl;
  goto label_12;

DEFLABEL (label_15)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_70_7]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_70_3]), 1);

DEFLABEL (label_6)
  (* (--Rsp)) = Rvl;
  goto label_14;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_71_4 3
#define LABEL_71_5 5
#define TAG_71_6 1
#define LABEL_71_8 7
#define LABEL_71_9 9
#define LABEL_71_11 11
#define ENVIRONMENT_LABEL_71_3 21
#define DEBUGGING_LABEL_71_2 20
#define OBJECT_71_0 19
#define EXECUTE_CACHE_71_10 13
#define EXECUTE_CACHE_71_7 15
#define FREE_REFERENCE_71_0 18
#define FREE_REFERENCES_LABEL_71_0 12
#define NUMBER_OF_LINKER_SECTIONS_71_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_71 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_71_4);
      goto lp___3;

    case 1:
      current_block = (Rpc - LABEL_71_5);
      goto lambda_8;

    case 2:
      current_block = (Rpc - LABEL_71_8);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_71_9);
      goto continuation_0;

    case 4:
      current_block = (Rpc - LABEL_71_11);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lp___7)
DEFLABEL (lp___3)
  INTERRUPT_CHECK (26, LABEL_71_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_71_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_71_5])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [1]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_71_7]));

DEFLABEL (lambda_8)
  CLOSURE_HEADER (LABEL_71_5);

DEFLABEL (lambda_2)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_71_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_71_9]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_71_10]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_71_9);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_71_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_11;
  Wrd5 = Wrd9;

DEFLABEL (label_10)
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_71_0]), 2);

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_71_8);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_9;
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [2]);
  (Rsp [0]) = (Wrd7.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (label_9)
  Rsp = (& (Rsp [3]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (label_11)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_71_11])), (Wrd6.pObj));

DEFLABEL (label_5)
  (Wrd5.Obj) = Rvl;
  goto label_10;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_72_4 3
#define LABEL_72_5 5
#define TAG_72_6 1
#define LABEL_72_7 7
#define TAG_72_8 2
#define LABEL_72_9 9
#define TAG_72_10 3
#define LABEL_72_12 11
#define LABEL_72_13 13
#define LABEL_72_18 15
#define LABEL_72_15 17
#define TAG_72_16 7
#define ENVIRONMENT_LABEL_72_3 31
#define DEBUGGING_LABEL_72_2 30
#define OBJECT_72_2 29
#define OBJECT_72_1 28
#define OBJECT_72_0 27
#define EXECUTE_CACHE_72_17 19
#define EXECUTE_CACHE_72_14 21
#define EXECUTE_CACHE_72_11 23
#define FREE_REFERENCE_72_0 26
#define FREE_REFERENCES_LABEL_72_0 18
#define NUMBER_OF_LINKER_SECTIONS_72_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_72 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd18;
  machine_word Wrd5;
  machine_word Wrd8;
  machine_word Wrd23;
  machine_word Wrd19;
  machine_word Wrd20;
  machine_word Wrd13;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd6;
  machine_word Wrd7;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd12;
  machine_word Wrd11;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_72_4);
      goto lp_parameters_11;

    case 1:
      current_block = (Rpc - LABEL_72_5);
      goto loop_0_9;

    case 2:
      current_block = (Rpc - LABEL_72_7);
      goto lambda_17;

    case 3:
      current_block = (Rpc - LABEL_72_9);
      goto lambda_18;

    case 4:
      current_block = (Rpc - LABEL_72_12);
      goto continuation_6;

    case 5:
      current_block = (Rpc - LABEL_72_13);
      goto continuation_5;

    case 6:
      current_block = (Rpc - LABEL_72_18);
      goto label_13;

    case 7:
      current_block = (Rpc - LABEL_72_15);
      goto lambda_19;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lp_parameters_15)
DEFLABEL (lp_parameters_11)
  INTERRUPT_CHECK (26, LABEL_72_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd11.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_72_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_72_5])));
  Rhp += 1;
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd11.pObj)));
  (* (--Rsp)) = (Wrd12.Obj);
  Wrd9 = Wrd11;
  (Wrd10.Obj) = (Rsp [2]);
  ((Wrd9.pObj) [2]) = (Wrd10.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd7.Obj) = (current_block [OBJECT_72_0]);
  (Rsp [2]) = (Wrd7.Obj);
  goto loop_0_9;

DEFLABEL (loop_0_16)
DEFLABEL (loop_0_9)
  INTERRUPT_CHECK (26, LABEL_72_5);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 7));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_72_8);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_72_7])));
  Rhp += 4;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd14 = Wrd7;
  (Wrd15.Obj) = (Rsp [0]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [2]);
  ((Wrd14.pObj) [2]) = (Wrd17.Obj);
  (Wrd13.Obj) = (Rsp [3]);
  ((Wrd14.pObj) [3]) = (Wrd13.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  ((Wrd14.pObj) [4]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [1]);
  ((Wrd14.pObj) [5]) = (Wrd9.Obj);
  (Rsp [3]) = (Wrd6.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd20.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_72_10);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_72_9])));
  Rhp += 2;
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd20.pObj)));
  Wrd23 = Wrd20;
  ((Wrd23.pObj) [2]) = (Wrd15.Obj);
  ((Wrd23.pObj) [3]) = (Wrd11.Obj);
  (Rsp [2]) = (Wrd19.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_72_11]));

DEFLABEL (lambda_17)
  CLOSURE_HEADER (LABEL_72_7);

DEFLABEL (lambda_8)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_72_12]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_72_13]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [4]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_72_14]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_72_13);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_72_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_21;
  Wrd5 = Wrd9;

DEFLABEL (label_20)
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_72_2]), 2);

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_72_12);
  (Wrd9.Obj) = (current_block [OBJECT_72_1]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [5]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd15.Obj) = ((Wrd11.pObj) [2]);
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = ((Wrd11.pObj) [3]);
  (Rsp [3]) = (Wrd16.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (label_21)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_72_18])), (Wrd6.pObj));

DEFLABEL (label_13)
  (Wrd5.Obj) = Rvl;
  goto label_20;

DEFLABEL (lambda_18)
  CLOSURE_HEADER (LABEL_72_9);

DEFLABEL (lambda_4)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_72_16);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_72_15])));
  Rhp += 3;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd14 = Wrd7;
  (Wrd15.Obj) = (Rsp [0]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [2]);
  ((Wrd14.pObj) [2]) = (Wrd17.Obj);
  (Wrd13.Obj) = ((Wrd16.pObj) [3]);
  ((Wrd14.pObj) [3]) = (Wrd13.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  ((Wrd14.pObj) [4]) = (Wrd9.Obj);
  (Rsp [2]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_72_17]));

DEFLABEL (lambda_19)
  CLOSURE_HEADER (LABEL_72_15);

DEFLABEL (lambda_3)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [4]);
  (Wrd11.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (Wrd17.Obj) = ((Wrd9.pObj) [3]);
  (* (Rhp++)) = (Wrd17.Obj);
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd14.pObj) = (& (Rhp [-2]));
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd14.pObj)));
  (Rsp [2]) = (Wrd12.Obj);
  (Wrd18.Obj) = ((Wrd9.pObj) [2]);
  (Rsp [0]) = (Wrd18.Obj);
  goto loop_0_9;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_73_4 3
#define LABEL_73_5 5
#define TAG_73_6 1
#define LABEL_73_8 7
#define TAG_73_9 2
#define LABEL_73_11 9
#define TAG_73_12 3
#define LABEL_73_14 11
#define LABEL_73_15 13
#define LABEL_73_17 15
#define ENVIRONMENT_LABEL_73_3 30
#define DEBUGGING_LABEL_73_2 29
#define OBJECT_73_1 28
#define OBJECT_73_0 27
#define EXECUTE_CACHE_73_16 17
#define EXECUTE_CACHE_73_13 19
#define EXECUTE_CACHE_73_10 21
#define EXECUTE_CACHE_73_7 23
#define FREE_REFERENCE_73_0 26
#define FREE_REFERENCES_LABEL_73_0 16
#define NUMBER_OF_LINKER_SECTIONS_73_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_73 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd23;
  machine_word Wrd19;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_73_4);
      goto lp_parameter_8;

    case 1:
      current_block = (Rpc - LABEL_73_5);
      goto lambda_13;

    case 2:
      current_block = (Rpc - LABEL_73_8);
      goto lambda_14;

    case 3:
      current_block = (Rpc - LABEL_73_11);
      goto lambda_15;

    case 4:
      current_block = (Rpc - LABEL_73_14);
      goto continuation_3;

    case 5:
      current_block = (Rpc - LABEL_73_15);
      goto continuation_2;

    case 6:
      current_block = (Rpc - LABEL_73_17);
      goto label_10;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lp_parameter_12)
DEFLABEL (lp_parameter_8)
  INTERRUPT_CHECK (26, LABEL_73_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_73_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_73_5])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [1]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_73_7]));

DEFLABEL (lambda_13)
  CLOSURE_HEADER (LABEL_73_5);

DEFLABEL (lambda_7)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_73_9);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_73_8])));
  Rhp += 2;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd10 = Wrd7;
  (Wrd11.Obj) = (Rsp [0]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [2]);
  ((Wrd10.pObj) [2]) = (Wrd13.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  ((Wrd10.pObj) [3]) = (Wrd9.Obj);
  (Rsp [2]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_73_10]));

DEFLABEL (lambda_14)
  CLOSURE_HEADER (LABEL_73_8);

DEFLABEL (lambda_6)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_73_12);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_73_11])));
  Rhp += 3;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd14 = Wrd7;
  (Wrd15.Obj) = (Rsp [0]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [2]);
  ((Wrd14.pObj) [2]) = (Wrd17.Obj);
  (Wrd13.Obj) = ((Wrd16.pObj) [3]);
  ((Wrd14.pObj) [3]) = (Wrd13.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  ((Wrd14.pObj) [4]) = (Wrd9.Obj);
  (Rsp [2]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_73_13]));

DEFLABEL (lambda_15)
  CLOSURE_HEADER (LABEL_73_11);

DEFLABEL (lambda_5)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_73_14]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_73_15]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd14.Obj) = (Rsp [2]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [3]);
  (Wrd19.Obj) = ((Wrd15.pObj) [4]);
  (* (Rhp++)) = (Wrd16.Obj);
  (* (Rhp++)) = (Wrd19.Obj);
  (Wrd13.pObj) = (& (Rhp [-2]));
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd13.pObj)));
  (Wrd23.Obj) = (Rsp [4]);
  (* (Rhp++)) = (Wrd11.Obj);
  (* (Rhp++)) = (Wrd23.Obj);
  (Wrd21.pObj) = (& (Rhp [-2]));
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd21.pObj)));
  (* (--Rsp)) = (Wrd22.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_73_16]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_73_15);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_73_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_17;
  Wrd5 = Wrd9;

DEFLABEL (label_16)
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_73_1]), 2);

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_73_14);
  (Wrd9.Obj) = (current_block [OBJECT_73_0]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd11.Obj) = (Rsp [0]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd10.Obj) = ((Wrd12.pObj) [2]);
  (Rsp [0]) = (Wrd10.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (label_17)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_73_17])), (Wrd6.pObj));

DEFLABEL (label_10)
  (Wrd5.Obj) = Rvl;
  goto label_16;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_74_4 3
#define LABEL_74_5 5
#define TAG_74_6 1
#define LABEL_74_8 7
#define TAG_74_9 2
#define LABEL_74_10 9
#define TAG_74_11 3
#define LABEL_74_12 11
#define TAG_74_13 4
#define LABEL_74_15 13
#define LABEL_74_16 15
#define LABEL_74_23 17
#define LABEL_74_18 19
#define TAG_74_19 8
#define LABEL_74_21 21
#define TAG_74_22 9
#define ENVIRONMENT_LABEL_74_3 36
#define DEBUGGING_LABEL_74_2 35
#define OBJECT_74_1 34
#define OBJECT_74_0 33
#define EXECUTE_CACHE_74_20 23
#define EXECUTE_CACHE_74_17 25
#define EXECUTE_CACHE_74_14 27
#define EXECUTE_CACHE_74_7 29
#define FREE_REFERENCE_74_0 32
#define FREE_REFERENCES_LABEL_74_0 22
#define NUMBER_OF_LINKER_SECTIONS_74_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_74 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd22;
  machine_word Wrd18;
  machine_word Wrd13;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd24;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd19;
  machine_word Wrd20;
  machine_word Wrd14;
  machine_word Wrd15;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_74_4);
      goto lp_parameter__13;

    case 1:
      current_block = (Rpc - LABEL_74_5);
      goto lambda_18;

    case 2:
      current_block = (Rpc - LABEL_74_8);
      goto lambda_4;

    case 3:
      current_block = (Rpc - LABEL_74_10);
      goto lambda_20;

    case 4:
      current_block = (Rpc - LABEL_74_12);
      goto lambda_21;

    case 5:
      current_block = (Rpc - LABEL_74_15);
      goto continuation_2;

    case 6:
      current_block = (Rpc - LABEL_74_16);
      goto continuation_1;

    case 7:
      current_block = (Rpc - LABEL_74_23);
      goto label_15;

    case 8:
      current_block = (Rpc - LABEL_74_18);
      goto lambda_22;

    case 9:
      current_block = (Rpc - LABEL_74_21);
      goto lambda_23;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lp_parameter__17)
DEFLABEL (lp_parameter__13)
  INTERRUPT_CHECK (26, LABEL_74_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_74_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_74_5])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [1]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_74_7]));

DEFLABEL (lambda_18)
  CLOSURE_HEADER (LABEL_74_5);

DEFLABEL (lambda_12)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd6.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_74_9);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_74_8])));
  Rhp += 2;
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd6.pObj)));
  Wrd9 = Wrd6;
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [2]);
  ((Wrd9.pObj) [2]) = (Wrd12.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  ((Wrd9.pObj) [3]) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd15.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_74_11);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_74_10])));
  Rhp += 1;
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd15.pObj)));
  ((Wrd15.pObj) [2]) = (Wrd5.Obj);
  (Rsp [3]) = (Wrd14.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd20.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_74_13);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_74_12])));
  Rhp += 3;
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd20.pObj)));
  Wrd25 = Wrd20;
  (Wrd26.Obj) = (Rsp [4]);
  ((Wrd25.pObj) [2]) = (Wrd26.Obj);
  (Wrd24.Obj) = (Rsp [2]);
  ((Wrd25.pObj) [3]) = (Wrd24.Obj);
  ((Wrd25.pObj) [4]) = (Wrd5.Obj);
  (Rsp [4]) = (Wrd19.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_74_14]));

DEFLABEL (lambda_19)
DEFLABEL (lambda_4)
  INTERRUPT_CHECK (26, LABEL_74_8);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_74_15]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_74_16]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd14.Obj) = (Rsp [2]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [3]);
  (Wrd17.Obj) = (Rsp [4]);
  (* (Rhp++)) = (Wrd16.Obj);
  (* (Rhp++)) = (Wrd17.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_74_17]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_74_16);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_74_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_25;
  Wrd5 = Wrd9;

DEFLABEL (label_24)
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_74_1]), 2);

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_74_15);
  (Wrd9.Obj) = (current_block [OBJECT_74_0]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd11.Obj) = (Rsp [0]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd10.Obj) = ((Wrd12.pObj) [2]);
  (Rsp [0]) = (Wrd10.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (label_25)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_74_23])), (Wrd6.pObj));

DEFLABEL (label_15)
  (Wrd5.Obj) = Rvl;
  goto label_24;

DEFLABEL (lambda_20)
  CLOSURE_HEADER (LABEL_74_10);

DEFLABEL (lambda_7)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_74_19);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_74_18])));
  Rhp += 2;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd10 = Wrd7;
  (Wrd11.Obj) = (Rsp [0]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [2]);
  ((Wrd10.pObj) [2]) = (Wrd13.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  ((Wrd10.pObj) [3]) = (Wrd9.Obj);
  (Rsp [2]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_74_20]));

DEFLABEL (lambda_21)
  CLOSURE_HEADER (LABEL_74_12);

DEFLABEL (lambda_10)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd8.Obj) = (current_block [OBJECT_74_0]);
  (* (Rhp++)) = (Wrd8.Obj);
  (* (Rhp++)) = ((SCHEME_OBJECT) 0);
  (Wrd6.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd6.pObj)));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd15.Obj) = ((Wrd11.pObj) [4]);
  (* (--Rsp)) = (Wrd15.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd18.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_74_22);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_74_21])));
  Rhp += 1;
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd18.pObj)));
  Wrd19 = Wrd18;
  (Wrd22.Obj) = ((Wrd11.pObj) [2]);
  ((Wrd19.pObj) [2]) = (Wrd22.Obj);
  (Rsp [3]) = (Wrd17.Obj);
  goto lambda_4;

DEFLABEL (lambda_22)
  CLOSURE_HEADER (LABEL_74_18);

DEFLABEL (lambda_6)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [3]);
  (Wrd11.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (Rsp [2]) = (Wrd5.Obj);
  (Wrd12.Obj) = ((Wrd9.pObj) [2]);
  (Rsp [0]) = (Wrd12.Obj);
  goto lambda_4;

DEFLABEL (lambda_23)
  CLOSURE_HEADER (LABEL_74_21);

DEFLABEL (lambda_9)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_75_4 3
#define LABEL_75_5 5
#define TAG_75_6 1
#define LABEL_75_10 7
#define LABEL_75_15 9
#define LABEL_75_7 11
#define TAG_75_8 4
#define LABEL_75_11 13
#define TAG_75_12 5
#define LABEL_75_13 15
#define TAG_75_14 6
#define LABEL_75_18 17
#define LABEL_75_16 19
#define TAG_75_17 8
#define LABEL_75_19 21
#define TAG_75_20 9
#define ENVIRONMENT_LABEL_75_3 30
#define DEBUGGING_LABEL_75_2 29
#define OBJECT_75_3 28
#define OBJECT_75_2 27
#define OBJECT_75_1 26
#define OBJECT_75_0 25
#define EXECUTE_CACHE_75_9 23
#define FREE_REFERENCES_LABEL_75_0 22
#define NUMBER_OF_LINKER_SECTIONS_75_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_75 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd30;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd20;
  machine_word Wrd9;
  machine_word Wrd15;
  machine_word Wrd13;
  machine_word Wrd14;
  machine_word Wrd44;
  machine_word Wrd36;
  machine_word Wrd38;
  machine_word Wrd40;
  machine_word Wrd33;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd28;
  machine_word Wrd29;
  machine_word Wrd21;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd10;
  machine_word Wrd16;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd11;
  machine_word Wrd12;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd5;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_75_4);
      goto lp___14;

    case 1:
      current_block = (Rpc - LABEL_75_5);
      goto lambda_21;

    case 2:
      current_block = (Rpc - LABEL_75_10);
      goto label_16;

    case 3:
      current_block = (Rpc - LABEL_75_15);
      goto label_17;

    case 4:
      current_block = (Rpc - LABEL_75_7);
      goto lambda_22;

    case 5:
      current_block = (Rpc - LABEL_75_11);
      goto lambda_23;

    case 6:
      current_block = (Rpc - LABEL_75_13);
      goto lambda_24;

    case 7:
      current_block = (Rpc - LABEL_75_18);
      goto label_18;

    case 8:
      current_block = (Rpc - LABEL_75_16);
      goto lambda_25;

    case 9:
      current_block = (Rpc - LABEL_75_19);
      goto lambda_26;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lp___20)
DEFLABEL (lp___14)
  INTERRUPT_CHECK (26, LABEL_75_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd6.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_75_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_75_5])));
  Rhp += 1;
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd6.pObj)));
  Wrd7 = Wrd6;
  (Wrd8.Obj) = (Rsp [1]);
  ((Wrd7.pObj) [2]) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (Rsp [2]) = (Wrd5.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd12.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_75_8);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_75_7])));
  Rhp += 3;
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd12.pObj)));
  Wrd17 = Wrd12;
  (Wrd18.Obj) = (Rsp [3]);
  ((Wrd17.pObj) [2]) = (Wrd18.Obj);
  (Wrd16.Obj) = (Rsp [1]);
  ((Wrd17.pObj) [3]) = (Wrd16.Obj);
  ((Wrd17.pObj) [4]) = (Wrd5.Obj);
  (Rsp [3]) = (Wrd11.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_75_9]));

DEFLABEL (lambda_21)
  CLOSURE_HEADER (LABEL_75_5);

DEFLABEL (lambda_10)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_28;

DEFLABEL (label_27)
  Rsp = (& (Rsp [3]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (label_28)
  if (! ((Wrd6.uLng) == 1))
    goto label_32;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd8.Obj) = ((Wrd10.pObj) [0]);

DEFLABEL (label_31)
  if (! ((Wrd8.Obj) == (current_block [OBJECT_75_1])))
    goto label_27;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd19.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_75_12);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_75_11])));
  Rhp += 2;
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd19.pObj)));
  Wrd22 = Wrd19;
  (Wrd23.Obj) = (Rsp [0]);
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd25.Obj) = ((Wrd24.pObj) [2]);
  ((Wrd22.pObj) [2]) = (Wrd25.Obj);
  (Wrd21.Obj) = (Rsp [2]);
  ((Wrd22.pObj) [3]) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  (Rsp [3]) = (Wrd18.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd29.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_75_14);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_75_13])));
  Rhp += 3;
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd29.pObj)));
  Wrd34 = Wrd29;
  (Wrd35.Obj) = (Rsp [4]);
  ((Wrd34.pObj) [2]) = (Wrd35.Obj);
  (Wrd33.Obj) = (Rsp [2]);
  ((Wrd34.pObj) [3]) = (Wrd33.Obj);
  ((Wrd34.pObj) [4]) = (Wrd18.Obj);
  (Rsp [4]) = (Wrd28.Obj);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if (! ((Wrd40.uLng) == 1))
    goto label_30;
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd36.Obj) = ((Wrd38.pObj) [1]);

DEFLABEL (label_29)
  (Rsp [2]) = (Wrd36.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_75_9]));

DEFLABEL (label_30)
  (Wrd44.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_75_15]))));
  (* (--Rsp)) = (Wrd44.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_75_2]), 1);

DEFLABEL (label_17)
  (Wrd36.Obj) = Rvl;
  goto label_29;

DEFLABEL (label_32)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_75_10]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_75_0]), 1);

DEFLABEL (label_16)
  (Wrd8.Obj) = Rvl;
  goto label_31;

DEFLABEL (lambda_22)
  CLOSURE_HEADER (LABEL_75_7);

DEFLABEL (lambda_12)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (current_block [OBJECT_75_3]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd8.Obj) = ((Wrd7.pObj) [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = ((Wrd7.pObj) [4]);
  (* (--Rsp)) = (Wrd11.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd14.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_75_17);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_75_16])));
  Rhp += 1;
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd14.pObj)));
  Wrd15 = Wrd14;
  (Wrd18.Obj) = ((Wrd7.pObj) [2]);
  ((Wrd15.pObj) [2]) = (Wrd18.Obj);
  (Rsp [3]) = (Wrd13.Obj);
  goto lambda_10;

DEFLABEL (lambda_23)
  CLOSURE_HEADER (LABEL_75_11);

DEFLABEL (lambda_4)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [3]);
  (Wrd11.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (Rsp [2]) = (Wrd5.Obj);
  (Wrd12.Obj) = ((Wrd9.pObj) [2]);
  (Rsp [0]) = (Wrd12.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (lambda_24)
  CLOSURE_HEADER (LABEL_75_13);

DEFLABEL (lambda_8)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (current_block [OBJECT_75_3]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [3]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd14.uLng) == 1))
    goto label_34;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [1]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_33)
  (Wrd21.Obj) = (Rsp [2]);
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd23.Obj) = ((Wrd22.pObj) [4]);
  (* (--Rsp)) = (Wrd23.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd26.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_75_20);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_75_19])));
  Rhp += 1;
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd26.pObj)));
  Wrd27 = Wrd26;
  (Wrd30.Obj) = ((Wrd22.pObj) [2]);
  ((Wrd27.pObj) [2]) = (Wrd30.Obj);
  (Rsp [3]) = (Wrd25.Obj);
  goto lambda_4;

DEFLABEL (label_34)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_75_18]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd13.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_75_2]), 1);

DEFLABEL (label_18)
  (* (--Rsp)) = Rvl;
  goto label_33;

DEFLABEL (lambda_25)
  CLOSURE_HEADER (LABEL_75_16);

DEFLABEL (lambda_11)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (lambda_26)
  CLOSURE_HEADER (LABEL_75_19);

DEFLABEL (lambda_7)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_76_4 3
#define LABEL_76_5 5
#define TAG_76_6 1
#define LABEL_76_10 7
#define LABEL_76_15 9
#define LABEL_76_7 11
#define TAG_76_8 4
#define LABEL_76_11 13
#define TAG_76_12 5
#define LABEL_76_13 15
#define TAG_76_14 6
#define LABEL_76_18 17
#define LABEL_76_16 19
#define TAG_76_17 8
#define LABEL_76_19 21
#define TAG_76_20 9
#define ENVIRONMENT_LABEL_76_3 30
#define DEBUGGING_LABEL_76_2 29
#define OBJECT_76_3 28
#define OBJECT_76_2 27
#define OBJECT_76_1 26
#define OBJECT_76_0 25
#define EXECUTE_CACHE_76_9 23
#define FREE_REFERENCES_LABEL_76_0 22
#define NUMBER_OF_LINKER_SECTIONS_76_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_76 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd30;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd20;
  machine_word Wrd9;
  machine_word Wrd15;
  machine_word Wrd13;
  machine_word Wrd14;
  machine_word Wrd44;
  machine_word Wrd36;
  machine_word Wrd38;
  machine_word Wrd40;
  machine_word Wrd33;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd28;
  machine_word Wrd29;
  machine_word Wrd21;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd10;
  machine_word Wrd16;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd11;
  machine_word Wrd12;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd5;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_76_4);
      goto lp_semicolon_14;

    case 1:
      current_block = (Rpc - LABEL_76_5);
      goto lambda_21;

    case 2:
      current_block = (Rpc - LABEL_76_10);
      goto label_16;

    case 3:
      current_block = (Rpc - LABEL_76_15);
      goto label_17;

    case 4:
      current_block = (Rpc - LABEL_76_7);
      goto lambda_22;

    case 5:
      current_block = (Rpc - LABEL_76_11);
      goto lambda_23;

    case 6:
      current_block = (Rpc - LABEL_76_13);
      goto lambda_24;

    case 7:
      current_block = (Rpc - LABEL_76_18);
      goto label_18;

    case 8:
      current_block = (Rpc - LABEL_76_16);
      goto lambda_25;

    case 9:
      current_block = (Rpc - LABEL_76_19);
      goto lambda_26;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lp_semicolon_20)
DEFLABEL (lp_semicolon_14)
  INTERRUPT_CHECK (26, LABEL_76_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd6.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_76_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_76_5])));
  Rhp += 1;
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd6.pObj)));
  Wrd7 = Wrd6;
  (Wrd8.Obj) = (Rsp [1]);
  ((Wrd7.pObj) [2]) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (Rsp [2]) = (Wrd5.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd12.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_76_8);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_76_7])));
  Rhp += 3;
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd12.pObj)));
  Wrd17 = Wrd12;
  (Wrd18.Obj) = (Rsp [3]);
  ((Wrd17.pObj) [2]) = (Wrd18.Obj);
  (Wrd16.Obj) = (Rsp [1]);
  ((Wrd17.pObj) [3]) = (Wrd16.Obj);
  ((Wrd17.pObj) [4]) = (Wrd5.Obj);
  (Rsp [3]) = (Wrd11.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_76_9]));

DEFLABEL (lambda_21)
  CLOSURE_HEADER (LABEL_76_5);

DEFLABEL (lambda_10)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_28;

DEFLABEL (label_27)
  Rsp = (& (Rsp [3]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (label_28)
  if (! ((Wrd6.uLng) == 1))
    goto label_32;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd8.Obj) = ((Wrd10.pObj) [0]);

DEFLABEL (label_31)
  if (! ((Wrd8.Obj) == (current_block [OBJECT_76_1])))
    goto label_27;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd19.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_76_12);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_76_11])));
  Rhp += 2;
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd19.pObj)));
  Wrd22 = Wrd19;
  (Wrd23.Obj) = (Rsp [0]);
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd25.Obj) = ((Wrd24.pObj) [2]);
  ((Wrd22.pObj) [2]) = (Wrd25.Obj);
  (Wrd21.Obj) = (Rsp [2]);
  ((Wrd22.pObj) [3]) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  (Rsp [3]) = (Wrd18.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd29.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_76_14);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_76_13])));
  Rhp += 3;
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd29.pObj)));
  Wrd34 = Wrd29;
  (Wrd35.Obj) = (Rsp [4]);
  ((Wrd34.pObj) [2]) = (Wrd35.Obj);
  (Wrd33.Obj) = (Rsp [2]);
  ((Wrd34.pObj) [3]) = (Wrd33.Obj);
  ((Wrd34.pObj) [4]) = (Wrd18.Obj);
  (Rsp [4]) = (Wrd28.Obj);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if (! ((Wrd40.uLng) == 1))
    goto label_30;
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd36.Obj) = ((Wrd38.pObj) [1]);

DEFLABEL (label_29)
  (Rsp [2]) = (Wrd36.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_76_9]));

DEFLABEL (label_30)
  (Wrd44.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_76_15]))));
  (* (--Rsp)) = (Wrd44.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_76_2]), 1);

DEFLABEL (label_17)
  (Wrd36.Obj) = Rvl;
  goto label_29;

DEFLABEL (label_32)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_76_10]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_76_0]), 1);

DEFLABEL (label_16)
  (Wrd8.Obj) = Rvl;
  goto label_31;

DEFLABEL (lambda_22)
  CLOSURE_HEADER (LABEL_76_7);

DEFLABEL (lambda_12)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (current_block [OBJECT_76_3]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd8.Obj) = ((Wrd7.pObj) [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = ((Wrd7.pObj) [4]);
  (* (--Rsp)) = (Wrd11.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd14.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_76_17);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_76_16])));
  Rhp += 1;
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd14.pObj)));
  Wrd15 = Wrd14;
  (Wrd18.Obj) = ((Wrd7.pObj) [2]);
  ((Wrd15.pObj) [2]) = (Wrd18.Obj);
  (Rsp [3]) = (Wrd13.Obj);
  goto lambda_10;

DEFLABEL (lambda_23)
  CLOSURE_HEADER (LABEL_76_11);

DEFLABEL (lambda_4)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [3]);
  (Wrd11.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (Rsp [2]) = (Wrd5.Obj);
  (Wrd12.Obj) = ((Wrd9.pObj) [2]);
  (Rsp [0]) = (Wrd12.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (lambda_24)
  CLOSURE_HEADER (LABEL_76_13);

DEFLABEL (lambda_8)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (current_block [OBJECT_76_3]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [3]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd14.uLng) == 1))
    goto label_34;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [1]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_33)
  (Wrd21.Obj) = (Rsp [2]);
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd23.Obj) = ((Wrd22.pObj) [4]);
  (* (--Rsp)) = (Wrd23.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd26.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_76_20);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_76_19])));
  Rhp += 1;
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd26.pObj)));
  Wrd27 = Wrd26;
  (Wrd30.Obj) = ((Wrd22.pObj) [2]);
  ((Wrd27.pObj) [2]) = (Wrd30.Obj);
  (Rsp [3]) = (Wrd25.Obj);
  goto lambda_4;

DEFLABEL (label_34)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_76_18]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd13.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_76_2]), 1);

DEFLABEL (label_18)
  (* (--Rsp)) = Rvl;
  goto label_33;

DEFLABEL (lambda_25)
  CLOSURE_HEADER (LABEL_76_16);

DEFLABEL (lambda_11)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (lambda_26)
  CLOSURE_HEADER (LABEL_76_19);

DEFLABEL (lambda_7)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_77_4 3
#define LABEL_77_5 5
#define ENVIRONMENT_LABEL_77_3 12
#define DEBUGGING_LABEL_77_2 11
#define EXECUTE_CACHE_77_6 7
#define FREE_REFERENCE_77_0 10
#define FREE_REFERENCES_LABEL_77_0 6
#define NUMBER_OF_LINKER_SECTIONS_77_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_77 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd7;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_77_4);
      goto value_params_predicate_0;

    case 1:
      current_block = (Rpc - LABEL_77_5);
      goto label_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (value_params_predicate_4)
DEFLABEL (value_params_predicate_0)
  INTERRUPT_CHECK (26, LABEL_77_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_77_0]));
  (Wrd11.Obj) = ((Wrd8.pObj) [0]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if ((Wrd12.uLng) == 50)
    goto label_6;
  Wrd7 = Wrd11;

DEFLABEL (label_5)
  (Rsp [1]) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_77_6]));

DEFLABEL (label_6)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_77_5])), (Wrd8.pObj));

DEFLABEL (label_2)
  (Wrd7.Obj) = Rvl;
  goto label_5;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_78_4 3
#define LABEL_78_7 5
#define LABEL_78_5 7
#define LABEL_78_6 9
#define ENVIRONMENT_LABEL_78_3 20
#define DEBUGGING_LABEL_78_2 19
#define EXECUTE_CACHE_78_10 11
#define EXECUTE_CACHE_78_9 13
#define EXECUTE_CACHE_78_8 15
#define FREE_REFERENCE_78_0 18
#define FREE_REFERENCES_LABEL_78_0 10
#define NUMBER_OF_LINKER_SECTIONS_78_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_78 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd19;
  machine_word Wrd13;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd14;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_78_4);
      goto value_params_writer_2;

    case 1:
      current_block = (Rpc - LABEL_78_7);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_78_5);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_78_6);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (value_params_writer_6)
DEFLABEL (value_params_writer_2)
  INTERRUPT_CHECK (26, LABEL_78_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_78_5]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_78_6]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd14.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_78_0]));
  (Wrd17.Obj) = ((Wrd14.pObj) [0]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if ((Wrd18.uLng) == 50)
    goto label_8;
  Wrd13 = Wrd17;

DEFLABEL (label_7)
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd19.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd19.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_78_8]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_78_6);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_78_10]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_78_5);
  (Rsp [2]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_78_9]));

DEFLABEL (label_8)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_78_7])), (Wrd14.pObj));

DEFLABEL (label_4)
  (Wrd13.Obj) = Rvl;
  goto label_7;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_79_4 3
#define LABEL_79_5 5
#define TAG_79_6 1
#define LABEL_79_8 7
#define TAG_79_9 2
#define LABEL_79_11 9
#define LABEL_79_12 11
#define LABEL_79_14 13
#define ENVIRONMENT_LABEL_79_3 26
#define DEBUGGING_LABEL_79_2 25
#define OBJECT_79_1 24
#define OBJECT_79_0 23
#define EXECUTE_CACHE_79_13 15
#define EXECUTE_CACHE_79_10 17
#define EXECUTE_CACHE_79_7 19
#define FREE_REFERENCE_79_0 22
#define FREE_REFERENCES_LABEL_79_0 14
#define NUMBER_OF_LINKER_SECTIONS_79_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_79 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_79_4);
      goto lp_token_params_6;

    case 1:
      current_block = (Rpc - LABEL_79_5);
      goto lambda_11;

    case 2:
      current_block = (Rpc - LABEL_79_8);
      goto lambda_12;

    case 3:
      current_block = (Rpc - LABEL_79_11);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_79_12);
      goto continuation_1;

    case 5:
      current_block = (Rpc - LABEL_79_14);
      goto label_8;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lp_token_params_10)
DEFLABEL (lp_token_params_6)
  INTERRUPT_CHECK (26, LABEL_79_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_79_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_79_5])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [1]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_79_7]));

DEFLABEL (lambda_11)
  CLOSURE_HEADER (LABEL_79_5);

DEFLABEL (lambda_5)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_79_9);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_79_8])));
  Rhp += 2;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd10 = Wrd7;
  (Wrd11.Obj) = (Rsp [0]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [2]);
  ((Wrd10.pObj) [2]) = (Wrd13.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  ((Wrd10.pObj) [3]) = (Wrd9.Obj);
  (Rsp [2]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_79_10]));

DEFLABEL (lambda_12)
  CLOSURE_HEADER (LABEL_79_8);

DEFLABEL (lambda_4)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_79_11]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_79_12]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd14.Obj) = (Rsp [2]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [3]);
  (Wrd17.Obj) = (Rsp [4]);
  (* (Rhp++)) = (Wrd16.Obj);
  (* (Rhp++)) = (Wrd17.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_79_13]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_79_12);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_79_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_14;
  Wrd5 = Wrd9;

DEFLABEL (label_13)
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_79_1]), 2);

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_79_11);
  (Wrd9.Obj) = (current_block [OBJECT_79_0]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd11.Obj) = (Rsp [0]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd10.Obj) = ((Wrd12.pObj) [2]);
  (Rsp [0]) = (Wrd10.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (label_14)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_79_14])), (Wrd6.pObj));

DEFLABEL (label_8)
  (Wrd5.Obj) = Rvl;
  goto label_13;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_80_4 3
#define LABEL_80_5 5
#define LABEL_80_7 7
#define ENVIRONMENT_LABEL_80_3 15
#define DEBUGGING_LABEL_80_2 14
#define OBJECT_80_2 13
#define OBJECT_80_1 12
#define OBJECT_80_0 11
#define EXECUTE_CACHE_80_6 9
#define FREE_REFERENCES_LABEL_80_0 8
#define NUMBER_OF_LINKER_SECTIONS_80_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_80 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd15;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_80_4);
      goto qparamP_2;

    case 1:
      current_block = (Rpc - LABEL_80_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_80_7);
      goto label_4;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (qparamP_6)
DEFLABEL (qparamP_2)
  INTERRUPT_CHECK (26, LABEL_80_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_80_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_80_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_80_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_9;
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_12;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [0]);

DEFLABEL (label_11)
  if ((Wrd7.Obj) == (current_block [OBJECT_80_1]))
    goto label_8;

DEFLABEL (label_9)
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_7;

DEFLABEL (label_8)
  Rvl = (current_block [OBJECT_80_2]);

DEFLABEL (label_7)
DEFLABEL (label_10)
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_12)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_80_7]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_80_0]), 1);

DEFLABEL (label_4)
  (Wrd7.Obj) = Rvl;
  goto label_11;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_81_4 3
#define LABEL_81_5 5
#define TAG_81_6 1
#define LABEL_81_8 7
#define TAG_81_9 2
#define LABEL_81_10 9
#define TAG_81_11 3
#define LABEL_81_12 11
#define TAG_81_13 4
#define LABEL_81_15 13
#define LABEL_81_16 15
#define LABEL_81_23 17
#define LABEL_81_18 19
#define TAG_81_19 8
#define LABEL_81_21 21
#define TAG_81_22 9
#define LABEL_81_24 23
#define LABEL_81_25 25
#define LABEL_81_26 27
#define ENVIRONMENT_LABEL_81_3 44
#define DEBUGGING_LABEL_81_2 43
#define OBJECT_81_2 42
#define OBJECT_81_1 41
#define OBJECT_81_0 40
#define EXECUTE_CACHE_81_20 29
#define EXECUTE_CACHE_81_17 31
#define EXECUTE_CACHE_81_14 33
#define EXECUTE_CACHE_81_7 35
#define FREE_REFERENCE_81_1 38
#define FREE_REFERENCE_81_0 39
#define FREE_REFERENCES_LABEL_81_0 28
#define NUMBER_OF_LINKER_SECTIONS_81_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_81 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd18;
  machine_word Wrd13;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd24;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd19;
  machine_word Wrd20;
  machine_word Wrd14;
  machine_word Wrd15;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_81_4);
      goto lp_token_qparam_14;

    case 1:
      current_block = (Rpc - LABEL_81_5);
      goto lambda_20;

    case 2:
      current_block = (Rpc - LABEL_81_8);
      goto lambda_4;

    case 3:
      current_block = (Rpc - LABEL_81_10);
      goto lambda_22;

    case 4:
      current_block = (Rpc - LABEL_81_12);
      goto lambda_23;

    case 5:
      current_block = (Rpc - LABEL_81_15);
      goto continuation_2;

    case 6:
      current_block = (Rpc - LABEL_81_16);
      goto continuation_1;

    case 7:
      current_block = (Rpc - LABEL_81_23);
      goto label_16;

    case 8:
      current_block = (Rpc - LABEL_81_18);
      goto lambda_24;

    case 9:
      current_block = (Rpc - LABEL_81_21);
      goto lambda_25;

    case 10:
      current_block = (Rpc - LABEL_81_24);
      goto continuation_6;

    case 11:
      current_block = (Rpc - LABEL_81_25);
      goto continuation_5;

    case 12:
      current_block = (Rpc - LABEL_81_26);
      goto label_17;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lp_token_qparam_19)
DEFLABEL (lp_token_qparam_14)
  INTERRUPT_CHECK (26, LABEL_81_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_81_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_81_5])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [1]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_81_7]));

DEFLABEL (lambda_20)
  CLOSURE_HEADER (LABEL_81_5);

DEFLABEL (lambda_13)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd6.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_81_9);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_81_8])));
  Rhp += 2;
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd6.pObj)));
  Wrd9 = Wrd6;
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [2]);
  ((Wrd9.pObj) [2]) = (Wrd12.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  ((Wrd9.pObj) [3]) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd15.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_81_11);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_81_10])));
  Rhp += 1;
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd15.pObj)));
  ((Wrd15.pObj) [2]) = (Wrd5.Obj);
  (Rsp [3]) = (Wrd14.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd20.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_81_13);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_81_12])));
  Rhp += 3;
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd20.pObj)));
  Wrd25 = Wrd20;
  (Wrd26.Obj) = (Rsp [4]);
  ((Wrd25.pObj) [2]) = (Wrd26.Obj);
  (Wrd24.Obj) = (Rsp [2]);
  ((Wrd25.pObj) [3]) = (Wrd24.Obj);
  ((Wrd25.pObj) [4]) = (Wrd5.Obj);
  (Rsp [4]) = (Wrd19.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_81_14]));

DEFLABEL (lambda_21)
DEFLABEL (lambda_4)
  INTERRUPT_CHECK (26, LABEL_81_8);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_81_15]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_81_16]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd14.Obj) = (Rsp [2]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [3]);
  (Wrd17.Obj) = (Rsp [4]);
  (* (Rhp++)) = (Wrd16.Obj);
  (* (Rhp++)) = (Wrd17.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_81_17]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_81_16);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_81_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_27;
  Wrd5 = Wrd9;

DEFLABEL (label_26)
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_81_2]), 2);

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_81_15);
  (Wrd9.Obj) = (current_block [OBJECT_81_1]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd11.Obj) = (Rsp [0]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd10.Obj) = ((Wrd12.pObj) [2]);
  (Rsp [0]) = (Wrd10.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (label_27)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_81_23])), (Wrd6.pObj));

DEFLABEL (label_16)
  (Wrd5.Obj) = Rvl;
  goto label_26;

DEFLABEL (lambda_22)
  CLOSURE_HEADER (LABEL_81_10);

DEFLABEL (lambda_9)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_81_19);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_81_18])));
  Rhp += 2;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd10 = Wrd7;
  (Wrd11.Obj) = (Rsp [0]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [2]);
  ((Wrd10.pObj) [2]) = (Wrd13.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  ((Wrd10.pObj) [3]) = (Wrd9.Obj);
  (Rsp [2]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_81_20]));

DEFLABEL (lambda_23)
  CLOSURE_HEADER (LABEL_81_12);

DEFLABEL (lambda_11)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (current_block [OBJECT_81_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd8.Obj) = ((Wrd7.pObj) [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = ((Wrd7.pObj) [4]);
  (* (--Rsp)) = (Wrd11.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd14.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_81_22);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_81_21])));
  Rhp += 1;
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd14.pObj)));
  Wrd15 = Wrd14;
  (Wrd18.Obj) = ((Wrd7.pObj) [2]);
  ((Wrd15.pObj) [2]) = (Wrd18.Obj);
  (Rsp [3]) = (Wrd13.Obj);
  goto lambda_4;

DEFLABEL (lambda_24)
  CLOSURE_HEADER (LABEL_81_18);

DEFLABEL (lambda_8)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_81_24]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_81_25]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_81_17]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_81_25);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_81_1]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_30;
  Wrd5 = Wrd9;

DEFLABEL (label_29)
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_81_2]), 2);

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_81_24);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_28;
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [3]);
  (Wrd13.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd12.Obj);
  (* (Rhp++)) = (Wrd13.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  (Rsp [2]) = (Wrd7.Obj);
  (Wrd14.Obj) = ((Wrd11.pObj) [2]);
  (Rsp [0]) = (Wrd14.Obj);
  goto lambda_4;

DEFLABEL (label_28)
  Rsp = (& (Rsp [3]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (label_30)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_81_26])), (Wrd6.pObj));

DEFLABEL (label_17)
  (Wrd5.Obj) = Rvl;
  goto label_29;

DEFLABEL (lambda_25)
  CLOSURE_HEADER (LABEL_81_21);

DEFLABEL (lambda_10)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_82_4 3
#define LABEL_82_6 5
#define LABEL_82_5 7
#define LABEL_82_8 9
#define ENVIRONMENT_LABEL_82_3 18
#define DEBUGGING_LABEL_82_2 17
#define OBJECT_82_3 16
#define OBJECT_82_2 15
#define OBJECT_82_1 14
#define OBJECT_82_0 13
#define EXECUTE_CACHE_82_7 11
#define FREE_REFERENCES_LABEL_82_0 10
#define NUMBER_OF_LINKER_SECTIONS_82_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_82 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd7;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd22;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd13;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_82_4);
      goto lambda_5;

    case 1:
      current_block = (Rpc - LABEL_82_6);
      goto label_7;

    case 2:
      current_block = (Rpc - LABEL_82_5);
      goto continuation_3;

    case 3:
      current_block = (Rpc - LABEL_82_8);
      goto label_8;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_10)
DEFLABEL (lambda_5)
  INTERRUPT_CHECK (26, LABEL_82_4);
  (Wrd5.Obj) = (Rsp [0]);
  if ((Wrd5.Obj) == (current_block [OBJECT_82_0]))
    goto label_21;
  (Wrd8.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd8.uLng) == 1)
    goto label_12;
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_11)
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_12)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82_5]))));
  (* (--Rsp)) = (Wrd13.Obj);
  if (! ((Wrd8.uLng) == 1))
    goto label_20;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (* (--Rsp)) = (Wrd16.Obj);

DEFLABEL (label_19)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_82_7]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_82_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_15;
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_18;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_17)
  if ((Wrd7.Obj) == (current_block [OBJECT_82_0]))
    goto label_14;

DEFLABEL (label_15)
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_13;

DEFLABEL (label_14)
  Rvl = (current_block [OBJECT_82_1]);

DEFLABEL (label_13)
DEFLABEL (label_16)
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_18)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82_8]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_82_3]), 1);

DEFLABEL (label_8)
  (Wrd7.Obj) = Rvl;
  goto label_17;

DEFLABEL (label_20)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82_6]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_82_2]), 1);

DEFLABEL (label_7)
  (* (--Rsp)) = Rvl;
  goto label_19;

DEFLABEL (label_21)
  Rvl = (current_block [OBJECT_82_1]);
  goto label_11;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_83_4 3
#define LABEL_83_5 5
#define TAG_83_6 1
#define LABEL_83_7 7
#define TAG_83_8 2
#define LABEL_83_9 9
#define TAG_83_10 3
#define LABEL_83_12 11
#define TAG_83_13 4
#define LABEL_83_14 13
#define TAG_83_15 5
#define LABEL_83_16 15
#define TAG_83_17 6
#define LABEL_83_18 17
#define TAG_83_19 7
#define LABEL_83_21 19
#define LABEL_83_22 21
#define LABEL_83_30 23
#define LABEL_83_24 25
#define TAG_83_25 11
#define LABEL_83_26 27
#define TAG_83_27 12
#define LABEL_83_28 29
#define LABEL_83_29 31
#define LABEL_83_33 33
#define LABEL_83_31 35
#define LABEL_83_32 37
#define LABEL_83_36 39
#define LABEL_83_34 41
#define TAG_83_35 19
#define LABEL_83_37 43
#define TAG_83_38 20
#define LABEL_83_39 45
#define TAG_83_40 21
#define LABEL_83_41 47
#define TAG_83_42 22
#define ENVIRONMENT_LABEL_83_3 64
#define DEBUGGING_LABEL_83_2 63
#define OBJECT_83_2 62
#define OBJECT_83_1 61
#define OBJECT_83_0 60
#define EXECUTE_CACHE_83_43 49
#define EXECUTE_CACHE_83_23 51
#define EXECUTE_CACHE_83_20 53
#define EXECUTE_CACHE_83_11 55
#define FREE_REFERENCE_83_1 58
#define FREE_REFERENCE_83_0 59
#define FREE_REFERENCES_LABEL_83_0 48
#define NUMBER_OF_LINKER_SECTIONS_83_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_83 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd26;
  machine_word Wrd31;
  machine_word Wrd28;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd24;
  machine_word Wrd21;
  machine_word Wrd18;
  machine_word Wrd8;
  machine_word Wrd32;
  machine_word Wrd33;
  machine_word Wrd30;
  machine_word Wrd27;
  machine_word Wrd5;
  machine_word Wrd23;
  machine_word Wrd19;
  machine_word Wrd20;
  machine_word Wrd13;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd6;
  machine_word Wrd7;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd12;
  machine_word Wrd11;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_83_4);
      goto lp_accept_params_32;

    case 1:
      current_block = (Rpc - LABEL_83_5);
      goto loop_0_30;

    case 2:
      current_block = (Rpc - LABEL_83_7);
      goto lambda_40;

    case 3:
      current_block = (Rpc - LABEL_83_9);
      goto lambda_41;

    case 4:
      current_block = (Rpc - LABEL_83_12);
      goto lambda_11;

    case 5:
      current_block = (Rpc - LABEL_83_14);
      goto lambda_43;

    case 6:
      current_block = (Rpc - LABEL_83_16);
      goto lambda_44;

    case 7:
      current_block = (Rpc - LABEL_83_18);
      goto lambda_45;

    case 8:
      current_block = (Rpc - LABEL_83_21);
      goto continuation_9;

    case 9:
      current_block = (Rpc - LABEL_83_22);
      goto continuation_8;

    case 10:
      current_block = (Rpc - LABEL_83_30);
      goto label_34;

    case 11:
      current_block = (Rpc - LABEL_83_24);
      goto lambda_46;

    case 12:
      current_block = (Rpc - LABEL_83_26);
      goto lambda_47;

    case 13:
      current_block = (Rpc - LABEL_83_28);
      goto continuation_2;

    case 14:
      current_block = (Rpc - LABEL_83_29);
      goto continuation_1;

    case 15:
      current_block = (Rpc - LABEL_83_33);
      goto label_35;

    case 16:
      current_block = (Rpc - LABEL_83_31);
      goto continuation_13;

    case 17:
      current_block = (Rpc - LABEL_83_32);
      goto continuation_12;

    case 18:
      current_block = (Rpc - LABEL_83_36);
      goto label_36;

    case 19:
      current_block = (Rpc - LABEL_83_34);
      goto loop_1_22;

    case 20:
      current_block = (Rpc - LABEL_83_37);
      goto lambda_49;

    case 21:
      current_block = (Rpc - LABEL_83_39);
      goto lambda_50;

    case 22:
      current_block = (Rpc - LABEL_83_41);
      goto lambda_51;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lp_accept_params_38)
DEFLABEL (lp_accept_params_32)
  INTERRUPT_CHECK (26, LABEL_83_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd11.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_83_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_83_5])));
  Rhp += 1;
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd11.pObj)));
  (* (--Rsp)) = (Wrd12.Obj);
  Wrd9 = Wrd11;
  (Wrd10.Obj) = (Rsp [2]);
  ((Wrd9.pObj) [2]) = (Wrd10.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd7.Obj) = (current_block [OBJECT_83_0]);
  (Rsp [2]) = (Wrd7.Obj);
  goto loop_0_30;

DEFLABEL (loop_0_39)
DEFLABEL (loop_0_30)
  INTERRUPT_CHECK (26, LABEL_83_5);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 7));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_83_8);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_83_7])));
  Rhp += 4;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd14 = Wrd7;
  (Wrd15.Obj) = (Rsp [0]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [2]);
  ((Wrd14.pObj) [2]) = (Wrd17.Obj);
  (Wrd13.Obj) = (Rsp [3]);
  ((Wrd14.pObj) [3]) = (Wrd13.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  ((Wrd14.pObj) [4]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [1]);
  ((Wrd14.pObj) [5]) = (Wrd9.Obj);
  (Rsp [3]) = (Wrd6.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd20.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_83_10);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_83_9])));
  Rhp += 2;
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd20.pObj)));
  Wrd23 = Wrd20;
  ((Wrd23.pObj) [2]) = (Wrd15.Obj);
  ((Wrd23.pObj) [3]) = (Wrd11.Obj);
  (Rsp [2]) = (Wrd19.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_83_11]));

DEFLABEL (lambda_40)
  CLOSURE_HEADER (LABEL_83_7);

DEFLABEL (lambda_29)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd6.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_83_13);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_83_12])));
  Rhp += 2;
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd6.pObj)));
  Wrd11 = Wrd6;
  (Wrd12.Obj) = (Rsp [0]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [2]);
  ((Wrd11.pObj) [2]) = (Wrd14.Obj);
  (Wrd10.Obj) = ((Wrd13.pObj) [4]);
  ((Wrd11.pObj) [3]) = (Wrd10.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd17.Obj) = ((Wrd13.pObj) [5]);
  (* (--Rsp)) = (Wrd17.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd20.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_83_15);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_83_14])));
  Rhp += 3;
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd20.pObj)));
  Wrd27 = Wrd20;
  (Wrd30.Obj) = ((Wrd13.pObj) [3]);
  ((Wrd27.pObj) [2]) = (Wrd30.Obj);
  ((Wrd27.pObj) [3]) = (Wrd17.Obj);
  ((Wrd27.pObj) [4]) = (Wrd5.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd33.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_83_17);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_83_16])));
  Rhp += 1;
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd33.pObj)));
  ((Wrd33.pObj) [2]) = (Wrd5.Obj);
  (Rsp [1]) = (Wrd32.Obj);
  (Rsp [2]) = (Wrd19.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_83_11]));

DEFLABEL (lambda_41)
  CLOSURE_HEADER (LABEL_83_9);

DEFLABEL (lambda_6)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_83_19);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_83_18])));
  Rhp += 3;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd14 = Wrd7;
  (Wrd15.Obj) = (Rsp [0]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [2]);
  ((Wrd14.pObj) [2]) = (Wrd17.Obj);
  (Wrd13.Obj) = ((Wrd16.pObj) [3]);
  ((Wrd14.pObj) [3]) = (Wrd13.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  ((Wrd14.pObj) [4]) = (Wrd9.Obj);
  (Rsp [2]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_83_20]));

DEFLABEL (lambda_42)
DEFLABEL (lambda_11)
  INTERRUPT_CHECK (26, LABEL_83_12);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_83_21]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_83_22]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd14.Obj) = (Rsp [2]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [3]);
  (Wrd17.Obj) = (Rsp [4]);
  (* (Rhp++)) = (Wrd16.Obj);
  (* (Rhp++)) = (Wrd17.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_83_23]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_83_22);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_83_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_53;
  Wrd5 = Wrd9;

DEFLABEL (label_52)
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_83_2]), 2);

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_83_21);
  (Wrd9.Obj) = (current_block [OBJECT_83_1]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd11.Obj) = (Rsp [0]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd10.Obj) = ((Wrd12.pObj) [2]);
  (Rsp [0]) = (Wrd10.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (label_53)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_83_30])), (Wrd6.pObj));

DEFLABEL (label_34)
  (Wrd5.Obj) = Rvl;
  goto label_52;

DEFLABEL (lambda_43)
  CLOSURE_HEADER (LABEL_83_14);

DEFLABEL (lambda_27)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (current_block [OBJECT_83_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd8.Obj) = ((Wrd7.pObj) [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = ((Wrd7.pObj) [4]);
  (* (--Rsp)) = (Wrd11.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd14.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_83_25);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_83_24])));
  Rhp += 1;
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd14.pObj)));
  Wrd15 = Wrd14;
  (Wrd18.Obj) = ((Wrd7.pObj) [2]);
  ((Wrd15.pObj) [2]) = (Wrd18.Obj);
  (Rsp [3]) = (Wrd13.Obj);
  goto lambda_11;

DEFLABEL (lambda_44)
  CLOSURE_HEADER (LABEL_83_16);

DEFLABEL (lambda_25)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_83_27);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_83_26])));
  Rhp += 2;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd10 = Wrd7;
  (Wrd11.Obj) = (Rsp [0]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [2]);
  ((Wrd10.pObj) [2]) = (Wrd13.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  ((Wrd10.pObj) [3]) = (Wrd9.Obj);
  (Rsp [2]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_83_20]));

DEFLABEL (lambda_45)
  CLOSURE_HEADER (LABEL_83_18);

DEFLABEL (lambda_5)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_83_28]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_83_29]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_83_23]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_83_29);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_83_1]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_56;
  Wrd5 = Wrd9;

DEFLABEL (label_55)
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_83_2]), 2);

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_83_28);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_54;
  Rsp = (& (Rsp [3]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (label_54)
  (Wrd11.Obj) = (Rsp [0]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [4]);
  (Wrd14.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd13.Obj);
  (* (Rhp++)) = (Wrd14.Obj);
  (Wrd10.pObj) = (& (Rhp [-2]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd10.pObj)));
  (Wrd20.Obj) = ((Wrd12.pObj) [3]);
  (* (Rhp++)) = (Wrd20.Obj);
  (* (Rhp++)) = (Wrd8.Obj);
  (Wrd17.pObj) = (& (Rhp [-2]));
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd17.pObj)));
  (Rsp [2]) = (Wrd15.Obj);
  (Wrd21.Obj) = ((Wrd12.pObj) [2]);
  (Rsp [0]) = (Wrd21.Obj);
  goto loop_0_30;

DEFLABEL (label_56)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_83_33])), (Wrd6.pObj));

DEFLABEL (label_35)
  (Wrd5.Obj) = Rvl;
  goto label_55;

DEFLABEL (lambda_46)
  CLOSURE_HEADER (LABEL_83_24);

DEFLABEL (lambda_26)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (lambda_47)
  CLOSURE_HEADER (LABEL_83_26);

DEFLABEL (lambda_24)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_83_31]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_83_32]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_83_23]));

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_83_32);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_83_1]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_59;
  Wrd5 = Wrd9;

DEFLABEL (label_58)
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_83_2]), 2);

DEFLABEL (continuation_13)
  INTERRUPT_CHECK (27, LABEL_83_31);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_57;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd23.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_83_35);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_83_34])));
  Rhp += 3;
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd23.pObj)));
  (* (--Rsp)) = (Wrd24.Obj);
  Wrd19 = Wrd23;
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd22.Obj) = ((Wrd21.pObj) [2]);
  ((Wrd19.pObj) [2]) = (Wrd22.Obj);
  (Wrd17.Obj) = ((Wrd21.pObj) [3]);
  ((Wrd19.pObj) [3]) = (Wrd17.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  ((Wrd19.pObj) [4]) = (Wrd12.Obj);
  Rsp = (& (Rsp [1]));
  (Rsp [0]) = (Wrd24.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_83_0]);
  (Rsp [2]) = (Wrd9.Obj);
  goto loop_1_22;

DEFLABEL (label_57)
  Rsp = (& (Rsp [3]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (label_59)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_83_36])), (Wrd6.pObj));

DEFLABEL (label_36)
  (Wrd5.Obj) = Rvl;
  goto label_58;

DEFLABEL (loop_1_48)
DEFLABEL (loop_1_22)
  INTERRUPT_CHECK (26, LABEL_83_34);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 9));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_83_38);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_83_37])));
  Rhp += 6;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd22 = Wrd7;
  (Wrd23.Obj) = (Rsp [0]);
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd25.Obj) = ((Wrd24.pObj) [2]);
  ((Wrd22.pObj) [2]) = (Wrd25.Obj);
  (Wrd21.Obj) = ((Wrd24.pObj) [3]);
  ((Wrd22.pObj) [3]) = (Wrd21.Obj);
  (Wrd17.Obj) = ((Wrd24.pObj) [4]);
  ((Wrd22.pObj) [4]) = (Wrd17.Obj);
  (Wrd13.Obj) = (Rsp [3]);
  ((Wrd22.pObj) [5]) = (Wrd13.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  ((Wrd22.pObj) [6]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [1]);
  ((Wrd22.pObj) [7]) = (Wrd9.Obj);
  (Rsp [3]) = (Wrd6.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd28.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_83_40);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_83_39])));
  Rhp += 2;
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd28.pObj)));
  Wrd31 = Wrd28;
  ((Wrd31.pObj) [2]) = (Wrd23.Obj);
  ((Wrd31.pObj) [3]) = (Wrd11.Obj);
  (Rsp [2]) = (Wrd27.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_83_11]));

DEFLABEL (lambda_49)
  CLOSURE_HEADER (LABEL_83_37);

DEFLABEL (lambda_21)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [3]);
  (Wrd13.Obj) = ((Wrd9.pObj) [4]);
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd13.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (Wrd19.Obj) = ((Wrd9.pObj) [6]);
  (* (Rhp++)) = (Wrd5.Obj);
  (* (Rhp++)) = (Wrd19.Obj);
  (Wrd15.pObj) = (& (Rhp [-2]));
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd15.pObj)));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd22.Obj) = ((Wrd9.pObj) [7]);
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd25.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd26.Obj) = ((Wrd9.pObj) [5]);
  (Rsp [3]) = (Wrd26.Obj);
  goto lambda_11;

DEFLABEL (lambda_50)
  CLOSURE_HEADER (LABEL_83_39);

DEFLABEL (lambda_18)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_83_42);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_83_41])));
  Rhp += 3;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd14 = Wrd7;
  (Wrd15.Obj) = (Rsp [0]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [2]);
  ((Wrd14.pObj) [2]) = (Wrd17.Obj);
  (Wrd13.Obj) = ((Wrd16.pObj) [3]);
  ((Wrd14.pObj) [3]) = (Wrd13.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  ((Wrd14.pObj) [4]) = (Wrd9.Obj);
  (Rsp [2]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_83_43]));

DEFLABEL (lambda_51)
  CLOSURE_HEADER (LABEL_83_41);

DEFLABEL (lambda_17)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [4]);
  (Wrd11.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (Wrd17.Obj) = ((Wrd9.pObj) [3]);
  (* (Rhp++)) = (Wrd17.Obj);
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd14.pObj) = (& (Rhp [-2]));
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd14.pObj)));
  (Rsp [2]) = (Wrd12.Obj);
  (Wrd18.Obj) = ((Wrd9.pObj) [2]);
  (Rsp [0]) = (Wrd18.Obj);
  goto loop_1_22;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_84_4 3
#define LABEL_84_5 5
#define LABEL_84_7 7
#define LABEL_84_9 9
#define LABEL_84_8 11
#define LABEL_84_12 13
#define LABEL_84_11 15
#define LABEL_84_14 17
#define LABEL_84_15 19
#define LABEL_84_16 21
#define ENVIRONMENT_LABEL_84_3 37
#define DEBUGGING_LABEL_84_2 36
#define OBJECT_84_2 35
#define OBJECT_84_1 34
#define OBJECT_84_0 33
#define EXECUTE_CACHE_84_17 23
#define EXECUTE_CACHE_84_13 25
#define EXECUTE_CACHE_84_10 27
#define EXECUTE_CACHE_84_6 29
#define FREE_REFERENCE_84_0 32
#define FREE_REFERENCES_LABEL_84_0 22
#define NUMBER_OF_LINKER_SECTIONS_84_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_84 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd21;
  machine_word Wrd15;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd30;
  machine_word Wrd22;
  machine_word Wrd24;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd18;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd20;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd11;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_84_4);
      goto accept_paramsP_11;

    case 1:
      current_block = (Rpc - LABEL_84_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_84_7);
      goto loop_9;

    case 3:
      current_block = (Rpc - LABEL_84_9);
      goto label_13;

    case 4:
      current_block = (Rpc - LABEL_84_8);
      goto continuation_4;

    case 5:
      current_block = (Rpc - LABEL_84_12);
      goto label_14;

    case 6:
      current_block = (Rpc - LABEL_84_11);
      goto continuation_6;

    case 7:
      current_block = (Rpc - LABEL_84_14);
      goto label_17;

    case 8:
      current_block = (Rpc - LABEL_84_15);
      goto label_15;

    case 9:
      current_block = (Rpc - LABEL_84_16);
      goto label_16;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (accept_paramsP_19)
DEFLABEL (accept_paramsP_11)
  INTERRUPT_CHECK (26, LABEL_84_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_84_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_84_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_84_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_21;
  goto loop_9;

DEFLABEL (label_21)
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (loop_20)
DEFLABEL (loop_9)
  INTERRUPT_CHECK (26, LABEL_84_7);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_22;
  Rvl = (current_block [OBJECT_84_1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_22)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_84_8]))));
  (* (--Rsp)) = (Wrd11.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_34;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_33)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_84_10]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_84_8);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_23;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_23)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_84_11]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd13.Obj) = (Rsp [1]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd14.uLng) == 1))
    goto label_32;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [0]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_31)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_84_13]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_84_11);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_28;
  (Wrd8.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_84_0]));
  (Wrd11.Obj) = ((Wrd8.pObj) [0]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if ((Wrd12.uLng) == 50)
    goto label_27;
  Wrd7 = Wrd11;

DEFLABEL (label_26)
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd16.Obj) = (Rsp [1]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 1))
    goto label_25;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd13.Obj) = ((Wrd15.pObj) [1]);

DEFLABEL (label_24)
  (Rsp [1]) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_84_17]));

DEFLABEL (label_25)
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_84_16]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_84_2]), 1);

DEFLABEL (label_16)
  (Wrd13.Obj) = Rvl;
  goto label_24;

DEFLABEL (label_27)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_84_15])), (Wrd8.pObj));

DEFLABEL (label_15)
  (Wrd7.Obj) = Rvl;
  goto label_26;

DEFLABEL (label_28)
  (Wrd25.Obj) = (Rsp [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if (! ((Wrd26.uLng) == 1))
    goto label_30;
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd22.Obj) = ((Wrd24.pObj) [1]);

DEFLABEL (label_29)
  (Rsp [0]) = (Wrd22.Obj);
  goto loop_9;

DEFLABEL (label_30)
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_84_14]))));
  (* (--Rsp)) = (Wrd30.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_84_2]), 1);

DEFLABEL (label_17)
  (Wrd22.Obj) = Rvl;
  goto label_29;

DEFLABEL (label_32)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_84_12]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd13.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_84_0]), 1);

DEFLABEL (label_14)
  (* (--Rsp)) = Rvl;
  goto label_31;

DEFLABEL (label_34)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_84_9]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_84_0]), 1);

DEFLABEL (label_13)
  (* (--Rsp)) = Rvl;
  goto label_33;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_85_4 3
#define LABEL_85_5 5
#define LABEL_85_6 7
#define LABEL_85_7 9
#define ENVIRONMENT_LABEL_85_3 15
#define DEBUGGING_LABEL_85_2 14
#define OBJECT_85_3 13
#define OBJECT_85_2 12
#define OBJECT_85_1 11
#define OBJECT_85_0 10
#define FREE_REFERENCES_LABEL_85_0 10
#define NUMBER_OF_LINKER_SECTIONS_85_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_85 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd37;
  machine_word Wrd29;
  machine_word Wrd31;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_85_4);
      goto params_are_expectationP_5;

    case 1:
      current_block = (Rpc - LABEL_85_5);
      goto label_7;

    case 2:
      current_block = (Rpc - LABEL_85_6);
      goto label_8;

    case 3:
      current_block = (Rpc - LABEL_85_7);
      goto label_9;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (params_are_expectationP_11)
DEFLABEL (params_are_expectationP_5)
  INTERRUPT_CHECK (26, LABEL_85_4);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_12;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_12)
  if (! ((Wrd6.uLng) == 1))
    goto label_22;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd9.Obj) = ((Wrd11.pObj) [0]);

DEFLABEL (label_21)
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if (! ((Wrd20.uLng) == 1))
    goto label_20;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd19.Obj) = ((Wrd18.pObj) [1]);
  (* (--Rsp)) = (Wrd19.Obj);

DEFLABEL (label_19)
  (Wrd25.Obj) = (Rsp [0]);
  if ((Wrd25.Obj) == ((SCHEME_OBJECT) 0))
    goto label_14;
  Rvl = (Wrd25.Obj);

DEFLABEL (label_13)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_14)
  (Wrd32.Obj) = (Rsp [1]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd33.uLng) == 1))
    goto label_18;
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd29.Obj) = ((Wrd31.pObj) [1]);

DEFLABEL (label_17)
  if ((Wrd29.Obj) == (current_block [OBJECT_85_2]))
    goto label_16;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_15;

DEFLABEL (label_16)
  Rvl = (current_block [OBJECT_85_3]);

DEFLABEL (label_15)
  goto label_13;

DEFLABEL (label_18)
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_85_7]))));
  (* (--Rsp)) = (Wrd37.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_85_1]), 1);

DEFLABEL (label_9)
  (Wrd29.Obj) = Rvl;
  goto label_17;

DEFLABEL (label_20)
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_85_6]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_85_1]), 1);

DEFLABEL (label_8)
  (* (--Rsp)) = Rvl;
  goto label_19;

DEFLABEL (label_22)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_85_5]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_85_0]), 1);

DEFLABEL (label_7)
  (Wrd9.Obj) = Rvl;
  goto label_21;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_86_4 3
#define LABEL_86_5 5
#define TAG_86_6 1
#define LABEL_86_7 7
#define TAG_86_8 2
#define LABEL_86_10 9
#define LABEL_86_11 11
#define LABEL_86_13 13
#define LABEL_86_15 15
#define TAG_86_16 6
#define LABEL_86_17 17
#define ENVIRONMENT_LABEL_86_3 30
#define DEBUGGING_LABEL_86_2 29
#define OBJECT_86_1 28
#define OBJECT_86_0 27
#define EXECUTE_CACHE_86_18 19
#define EXECUTE_CACHE_86_14 21
#define EXECUTE_CACHE_86_12 23
#define EXECUTE_CACHE_86_9 25
#define FREE_REFERENCES_LABEL_86_0 18
#define NUMBER_OF_LINKER_SECTIONS_86_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_86 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_86_4);
      goto lp_numeric_token_9;

    case 1:
      current_block = (Rpc - LABEL_86_5);
      goto lambda_13;

    case 2:
      current_block = (Rpc - LABEL_86_7);
      goto lambda_14;

    case 3:
      current_block = (Rpc - LABEL_86_10);
      goto continuation_4;

    case 4:
      current_block = (Rpc - LABEL_86_11);
      goto continuation_3;

    case 5:
      current_block = (Rpc - LABEL_86_13);
      goto continuation_5;

    case 6:
      current_block = (Rpc - LABEL_86_15);
      goto lambda_15;

    case 7:
      current_block = (Rpc - LABEL_86_17);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lp_numeric_token_12)
DEFLABEL (lp_numeric_token_9)
  INTERRUPT_CHECK (26, LABEL_86_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_86_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_86_5])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  Rvl = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (lambda_13)
  CLOSURE_HEADER (LABEL_86_5);

DEFLABEL (lambda_8)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_86_8);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_86_7])));
  Rhp += 2;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd10 = Wrd7;
  (Wrd11.Obj) = (Rsp [0]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [2]);
  ((Wrd10.pObj) [2]) = (Wrd13.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  ((Wrd10.pObj) [3]) = (Wrd9.Obj);
  (Rsp [2]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_86_9]));

DEFLABEL (lambda_14)
  CLOSURE_HEADER (LABEL_86_7);

DEFLABEL (lambda_7)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_86_10]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_86_11]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_86_12]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_86_11);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd6.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_86_16);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_86_15])));
  Rhp += 1;
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd6.pObj)));
  Wrd7 = Wrd6;
  (Wrd8.Obj) = (Rsp [2]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [2]);
  ((Wrd7.pObj) [2]) = (Wrd10.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_86_0]), 2);

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_86_10);
  (* (--Rsp)) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_16;
  Rsp = (& (Rsp [4]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (label_16)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_86_13]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_86_14]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_86_13);
  (Rsp [3]) = Rvl;
  (Wrd7.Obj) = (Rsp [1]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [3]);
  (Rsp [1]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (lambda_15)
  CLOSURE_HEADER (LABEL_86_15);

DEFLABEL (lambda_2)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_86_17]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd9.Obj) = (Rsp [2]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_86_18]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_86_17);
  (Rsp [1]) = Rvl;
  Rsp = (& (Rsp [1]));
  (Wrd6.Obj) = (Rsp [0]);
  if ((Wrd6.Obj) == ((SCHEME_OBJECT) 0))
    goto label_18;
  (Wrd13.Obj) = (current_block [OBJECT_86_1]);
  (* (Rhp++)) = (Wrd6.Obj);
  (* (Rhp++)) = (Wrd13.Obj);
  (Wrd10.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd10.pObj)));
  goto label_17;

DEFLABEL (label_18)
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_17)
DEFLABEL (label_19)
  Rsp = (& (Rsp [1]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_87_4 3
#define ENVIRONMENT_LABEL_87_3 9
#define DEBUGGING_LABEL_87_2 8
#define OBJECT_87_0 7
#define EXECUTE_CACHE_87_5 5
#define FREE_REFERENCES_LABEL_87_0 4
#define NUMBER_OF_LINKER_SECTIONS_87_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_87 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_87_4);
      goto write_opt_decimal_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (write_opt_decimal_3)
DEFLABEL (write_opt_decimal_0)
  INTERRUPT_CHECK (26, LABEL_87_4);
  (Wrd5.Obj) = (Rsp [0]);
  if ((Wrd5.Obj) == ((SCHEME_OBJECT) 0))
    goto label_4;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_87_5]));

DEFLABEL (label_4)
  Rvl = (current_block [OBJECT_87_0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_88_4 3
#define LABEL_88_5 5
#define TAG_88_6 1
#define LABEL_88_8 7
#define LABEL_88_9 9
#define LABEL_88_10 11
#define TAG_88_11 4
#define LABEL_88_12 13
#define LABEL_88_13 15
#define LABEL_88_15 17
#define ENVIRONMENT_LABEL_88_3 31
#define DEBUGGING_LABEL_88_2 30
#define OBJECT_88_4 29
#define OBJECT_88_3 28
#define OBJECT_88_2 27
#define OBJECT_88_1 26
#define OBJECT_88_0 25
#define EXECUTE_CACHE_88_14 19
#define EXECUTE_CACHE_88_7 21
#define FREE_REFERENCE_88_0 24
#define FREE_REFERENCES_LABEL_88_0 18
#define NUMBER_OF_LINKER_SECTIONS_88_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_88 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd11;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd17;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd31;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd28;
  machine_word Wrd29;
  machine_word Wrd26;
  machine_word Wrd18;
  machine_word Wrd20;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd16;
  machine_word Wrd10;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_88_4);
      goto lp_mime_type_10;

    case 1:
      current_block = (Rpc - LABEL_88_5);
      goto lambda_17;

    case 2:
      current_block = (Rpc - LABEL_88_8);
      goto label_12;

    case 3:
      current_block = (Rpc - LABEL_88_9);
      goto label_13;

    case 4:
      current_block = (Rpc - LABEL_88_10);
      goto lambda_18;

    case 5:
      current_block = (Rpc - LABEL_88_12);
      goto continuation_6;

    case 6:
      current_block = (Rpc - LABEL_88_13);
      goto continuation_5;

    case 7:
      current_block = (Rpc - LABEL_88_15);
      goto label_14;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lp_mime_type_16)
DEFLABEL (lp_mime_type_10)
  INTERRUPT_CHECK (26, LABEL_88_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_88_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_88_5])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [1]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_88_7]));

DEFLABEL (lambda_17)
  CLOSURE_HEADER (LABEL_88_5);

DEFLABEL (lambda_9)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_20;

DEFLABEL (label_19)
  Rsp = (& (Rsp [3]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (label_20)
  if (! ((Wrd6.uLng) == 1))
    goto label_24;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd8.Obj) = ((Wrd10.pObj) [0]);

DEFLABEL (label_23)
  if (! ((Wrd8.Obj) == (current_block [OBJECT_88_1])))
    goto label_19;
  (Wrd21.Obj) = (Rsp [1]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if (! ((Wrd22.uLng) == 1))
    goto label_22;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd18.Obj) = ((Wrd20.pObj) [1]);

DEFLABEL (label_21)
  (Rsp [1]) = (Wrd18.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd29.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_88_11);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_88_10])));
  Rhp += 2;
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd29.pObj)));
  Wrd32 = Wrd29;
  (Wrd33.Obj) = (Rsp [0]);
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd35.Obj) = ((Wrd34.pObj) [2]);
  ((Wrd32.pObj) [2]) = (Wrd35.Obj);
  (Wrd31.Obj) = (Rsp [2]);
  ((Wrd32.pObj) [3]) = (Wrd31.Obj);
  (Rsp [2]) = (Wrd28.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_88_7]));

DEFLABEL (label_22)
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_88_9]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_88_2]), 1);

DEFLABEL (label_13)
  (Wrd18.Obj) = Rvl;
  goto label_21;

DEFLABEL (label_24)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_88_8]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_88_0]), 1);

DEFLABEL (label_12)
  (Wrd8.Obj) = Rvl;
  goto label_23;

DEFLABEL (lambda_18)
  CLOSURE_HEADER (LABEL_88_10);

DEFLABEL (lambda_8)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_88_12]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_88_13]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd14.Obj) = (Rsp [2]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [3]);
  (Wrd17.Obj) = (Rsp [4]);
  (* (Rhp++)) = (Wrd16.Obj);
  (* (Rhp++)) = (Wrd17.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_88_14]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_88_13);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_88_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_26;
  Wrd5 = Wrd9;

DEFLABEL (label_25)
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_88_4]), 2);

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_88_12);
  (Wrd9.Obj) = (current_block [OBJECT_88_3]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd11.Obj) = (Rsp [0]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd10.Obj) = ((Wrd12.pObj) [2]);
  (Rsp [0]) = (Wrd10.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (label_26)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_88_15])), (Wrd6.pObj));

DEFLABEL (label_14)
  (Wrd5.Obj) = Rvl;
  goto label_25;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_89_4 3
#define LABEL_89_5 5
#define LABEL_89_9 7
#define LABEL_89_7 9
#define TAG_89_8 3
#define LABEL_89_10 11
#define LABEL_89_12 13
#define LABEL_89_13 15
#define LABEL_89_17 17
#define LABEL_89_18 19
#define LABEL_89_15 21
#define LABEL_89_20 23
#define LABEL_89_22 25
#define LABEL_89_23 27
#define LABEL_89_24 29
#define ENVIRONMENT_LABEL_89_3 50
#define DEBUGGING_LABEL_89_2 49
#define OBJECT_89_1 48
#define OBJECT_89_0 47
#define EXECUTE_CACHE_89_21 31
#define EXECUTE_CACHE_89_19 33
#define EXECUTE_CACHE_89_16 35
#define EXECUTE_CACHE_89_14 37
#define EXECUTE_CACHE_89_11 39
#define EXECUTE_CACHE_89_6 41
#define FREE_REFERENCE_89_0 44
#define FREE_ASSIGNMENT_89_0 46
#define FREE_REFERENCES_LABEL_89_0 30
#define NUMBER_OF_LINKER_SECTIONS_89_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_89 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd14;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd11;
  machine_word Wrd6;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_89_4);
      goto lambda_19;

    case 1:
      current_block = (Rpc - LABEL_89_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_89_9);
      goto label_21;

    case 3:
      current_block = (Rpc - LABEL_89_7);
      goto lambda_25;

    case 4:
      current_block = (Rpc - LABEL_89_10);
      goto continuation_2;

    case 5:
      current_block = (Rpc - LABEL_89_12);
      goto continuation_4;

    case 6:
      current_block = (Rpc - LABEL_89_13);
      goto continuation_5;

    case 7:
      current_block = (Rpc - LABEL_89_17);
      goto lambda_3;

    case 8:
      current_block = (Rpc - LABEL_89_18);
      goto label_22;

    case 9:
      current_block = (Rpc - LABEL_89_15);
      goto continuation_6;

    case 10:
      current_block = (Rpc - LABEL_89_20);
      goto continuation_7;

    case 11:
      current_block = (Rpc - LABEL_89_22);
      goto continuation_8;

    case 12:
      current_block = (Rpc - LABEL_89_23);
      goto continuation_9;

    case 13:
      current_block = (Rpc - LABEL_89_24);
      goto continuation_10;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_24)
DEFLABEL (lambda_19)
  INTERRUPT_CHECK (26, LABEL_89_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_89_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_89_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_89_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_89_5);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_89_8);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_89_7])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  ((Wrd7.pObj) [2]) = Rvl;
  Rsp = (& (Rsp [1]));
  (Wrd11.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_89_0]));
  (Wrd19.Obj) = ((Wrd11.pObj) [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if ((Wrd20.uLng) == 50)
    goto label_29;

DEFLABEL (label_28)
  ((Wrd11.pObj) [0]) = (Wrd6.Obj);

DEFLABEL (label_27)
  Rvl = (current_block [OBJECT_89_1]);
  goto pop_return;

DEFLABEL (label_29)
  if ((Wrd19.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_28;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_89_9])), (Wrd11.pObj), (Wrd6.Obj));

DEFLABEL (label_21)
  goto label_27;

DEFLABEL (lambda_25)
  CLOSURE_HEADER (LABEL_89_7);

DEFLABEL (lambda_17)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_89_10]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_89_11]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_89_10);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_89_12]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_89_11]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_89_12);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_89_13]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_89_14]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_89_13);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_30;
  (Rsp [4]) = Rvl;
  Rsp = (& (Rsp [4]));
  goto lambda_3;

DEFLABEL (label_30)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_89_15]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_89_16]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_89_15);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_89_20]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_89_21]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_89_20);
  (Rsp [0]) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_31;
  (Rsp [4]) = Rvl;
  Rsp = (& (Rsp [4]));
  goto lambda_3;

DEFLABEL (label_31)
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_89_22]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_89_16]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_89_22);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_89_23]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [5]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_89_23);
  (Rsp [1]) = Rvl;
  Rsp = (& (Rsp [1]));
  (Wrd6.Obj) = (Rsp [0]);
  if ((Wrd6.Obj) == ((SCHEME_OBJECT) 0))
    goto label_32;
  (Rsp [3]) = (Wrd6.Obj);
  Rsp = (& (Rsp [3]));
  goto lambda_3;

DEFLABEL (label_32)
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_89_24]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_89_16]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_89_24);
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (lambda_26)
DEFLABEL (lambda_3)
  INTERRUPT_CHECK (26, LABEL_89_17);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_89_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_34;
  Wrd5 = Wrd9;

DEFLABEL (label_33)
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_89_19]));

DEFLABEL (label_34)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_89_18])), (Wrd6.pObj));

DEFLABEL (label_22)
  (Wrd5.Obj) = Rvl;
  goto label_33;

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_90_4 3
#define LABEL_90_5 5
#define LABEL_90_7 7
#define ENVIRONMENT_LABEL_90_3 17
#define DEBUGGING_LABEL_90_2 16
#define OBJECT_90_0 15
#define EXECUTE_CACHE_90_9 9
#define EXECUTE_CACHE_90_8 11
#define EXECUTE_CACHE_90_6 13
#define FREE_REFERENCES_LABEL_90_0 8
#define NUMBER_OF_LINKER_SECTIONS_90_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_90 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_90_4);
      goto http_dateP_2;

    case 1:
      current_block = (Rpc - LABEL_90_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_90_7);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (http_dateP_5)
DEFLABEL (http_dateP_2)
  INTERRUPT_CHECK (26, LABEL_90_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_90_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_90_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_90_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_6;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_6)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_90_7]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_90_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_90_7);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_90_0]);
  (Rsp [1]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_90_9]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_91_4 3
#define ENVIRONMENT_LABEL_91_3 8
#define DEBUGGING_LABEL_91_2 7
#define EXECUTE_CACHE_91_5 5
#define FREE_REFERENCES_LABEL_91_0 4
#define NUMBER_OF_LINKER_SECTIONS_91_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_91 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_91_4);
      goto write_http_date_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (write_http_date_3)
DEFLABEL (write_http_date_0)
  INTERRUPT_CHECK (26, LABEL_91_4);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_91_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_92_4 3
#define LABEL_92_5 5
#define TAG_92_6 1
#define LABEL_92_12 7
#define LABEL_92_15 9
#define LABEL_92_8 11
#define TAG_92_9 4
#define LABEL_92_10 13
#define TAG_92_11 5
#define LABEL_92_13 15
#define TAG_92_14 6
#define LABEL_92_16 17
#define LABEL_92_17 19
#define LABEL_92_19 21
#define TAG_92_20 9
#define LABEL_92_21 23
#define LABEL_92_24 25
#define LABEL_92_23 27
#define LABEL_92_26 29
#define LABEL_92_25 31
#define LABEL_92_29 33
#define ENVIRONMENT_LABEL_92_3 57
#define DEBUGGING_LABEL_92_2 56
#define OBJECT_92_8 55
#define OBJECT_92_7 54
#define OBJECT_92_6 53
#define OBJECT_92_5 52
#define OBJECT_92_4 51
#define OBJECT_92_3 50
#define OBJECT_92_2 49
#define OBJECT_92_1 48
#define OBJECT_92_0 47
#define EXECUTE_CACHE_92_28 35
#define EXECUTE_CACHE_92_27 37
#define EXECUTE_CACHE_92_22 39
#define EXECUTE_CACHE_92_18 41
#define EXECUTE_CACHE_92_7 43
#define FREE_REFERENCE_92_0 46
#define FREE_REFERENCES_LABEL_92_0 34
#define NUMBER_OF_LINKER_SECTIONS_92_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_92 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd26;
  machine_word Wrd28;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd23;
  machine_word Wrd49;
  machine_word Wrd41;
  machine_word Wrd43;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd38;
  machine_word Wrd36;
  machine_word Wrd37;
  machine_word Wrd33;
  machine_word Wrd25;
  machine_word Wrd27;
  machine_word Wrd22;
  machine_word Wrd18;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd13;
  machine_word Wrd14;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_92_4);
      goto lp_hostport_22;

    case 1:
      current_block = (Rpc - LABEL_92_5);
      goto lambda_30;

    case 2:
      current_block = (Rpc - LABEL_92_12);
      goto label_24;

    case 3:
      current_block = (Rpc - LABEL_92_15);
      goto label_25;

    case 4:
      current_block = (Rpc - LABEL_92_8);
      goto lambda_10;

    case 5:
      current_block = (Rpc - LABEL_92_10);
      goto lambda_32;

    case 6:
      current_block = (Rpc - LABEL_92_13);
      goto lambda_33;

    case 7:
      current_block = (Rpc - LABEL_92_16);
      goto continuation_7;

    case 8:
      current_block = (Rpc - LABEL_92_17);
      goto continuation_6;

    case 9:
      current_block = (Rpc - LABEL_92_19);
      goto lambda_34;

    case 10:
      current_block = (Rpc - LABEL_92_21);
      goto continuation_8;

    case 11:
      current_block = (Rpc - LABEL_92_24);
      goto continuation_0;

    case 12:
      current_block = (Rpc - LABEL_92_23);
      goto lambda_4;

    case 13:
      current_block = (Rpc - LABEL_92_26);
      goto label_26;

    case 14:
      current_block = (Rpc - LABEL_92_25);
      goto continuation_1;

    case 15:
      current_block = (Rpc - LABEL_92_29);
      goto label_27;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lp_hostport_29)
DEFLABEL (lp_hostport_22)
  INTERRUPT_CHECK (26, LABEL_92_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_92_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_92_5])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [1]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_92_7]));

DEFLABEL (lambda_30)
  CLOSURE_HEADER (LABEL_92_5);

DEFLABEL (lambda_21)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd6.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_92_9);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_92_8])));
  Rhp += 2;
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd6.pObj)));
  Wrd9 = Wrd6;
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [2]);
  ((Wrd9.pObj) [2]) = (Wrd12.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  ((Wrd9.pObj) [3]) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd14.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_92_11);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_92_10])));
  Rhp += 3;
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd14.pObj)));
  Wrd19 = Wrd14;
  (Wrd20.Obj) = (Rsp [4]);
  ((Wrd19.pObj) [2]) = (Wrd20.Obj);
  (Wrd18.Obj) = (Rsp [2]);
  ((Wrd19.pObj) [3]) = (Wrd18.Obj);
  ((Wrd19.pObj) [4]) = (Wrd5.Obj);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd22.uLng) == 1)
    goto label_37;

DEFLABEL (label_36)
  (Wrd23.Obj) = (Rsp [0]);
  (Rsp [5]) = (Wrd23.Obj);
  Rsp = (& (Rsp [5]));
  goto lambda_13;

DEFLABEL (label_37)
  if (! ((Wrd22.uLng) == 1))
    goto label_41;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd25.Obj) = ((Wrd27.pObj) [0]);

DEFLABEL (label_40)
  if (! ((Wrd25.Obj) == (current_block [OBJECT_92_1])))
    goto label_36;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd37.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_92_14);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_92_13])));
  Rhp += 1;
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd37.pObj)));
  Wrd38 = Wrd37;
  (Wrd39.Obj) = (Rsp [1]);
  ((Wrd38.pObj) [2]) = (Wrd39.Obj);
  (Rsp [4]) = (Wrd36.Obj);
  (Wrd40.Obj) = (Rsp [0]);
  (Rsp [5]) = (Wrd40.Obj);
  (Wrd44.Obj) = (Rsp [3]);
  (Wrd45.uLng) = (OBJECT_TYPE (Wrd44.Obj));
  if (! ((Wrd45.uLng) == 1))
    goto label_39;
  (Wrd43.pObj) = (OBJECT_ADDRESS (Wrd44.Obj));
  (Wrd41.Obj) = ((Wrd43.pObj) [1]);

DEFLABEL (label_38)
  (Rsp [3]) = (Wrd41.Obj);
  Rsp = (& (Rsp [3]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_92_7]));

DEFLABEL (label_39)
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_92_15]))));
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd44.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_92_2]), 1);

DEFLABEL (label_25)
  (Wrd41.Obj) = Rvl;
  goto label_38;

DEFLABEL (label_41)
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_92_12]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_92_0]), 1);

DEFLABEL (label_24)
  (Wrd25.Obj) = Rvl;
  goto label_40;

DEFLABEL (lambda_31)
DEFLABEL (lambda_10)
  INTERRUPT_CHECK (26, LABEL_92_8);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_92_16]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_92_17]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd14.Obj) = (Rsp [2]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [3]);
  (Wrd17.Obj) = (Rsp [4]);
  (* (Rhp++)) = (Wrd16.Obj);
  (* (Rhp++)) = (Wrd17.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_92_18]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_92_17);
  (* (--Rsp)) = Rvl;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_92_23]))));
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_92_4]), 2);

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_92_16);
  (* (--Rsp)) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_42;
  Rsp = (& (Rsp [4]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (label_42)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_92_21]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_92_22]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_92_21);
  (Rsp [3]) = Rvl;
  (Wrd7.Obj) = (Rsp [1]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [2]);
  (Rsp [1]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (lambda_32)
  CLOSURE_HEADER (LABEL_92_10);

DEFLABEL (lambda_13)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd8.Obj) = (current_block [OBJECT_92_3]);
  (* (Rhp++)) = (Wrd8.Obj);
  (* (Rhp++)) = ((SCHEME_OBJECT) 0);
  (Wrd6.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd6.pObj)));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd15.Obj) = ((Wrd11.pObj) [4]);
  (* (--Rsp)) = (Wrd15.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd18.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_92_20);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_92_19])));
  Rhp += 1;
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd18.pObj)));
  Wrd19 = Wrd18;
  (Wrd22.Obj) = ((Wrd11.pObj) [2]);
  ((Wrd19.pObj) [2]) = (Wrd22.Obj);
  (Rsp [3]) = (Wrd17.Obj);
  goto lambda_10;

DEFLABEL (lambda_33)
  CLOSURE_HEADER (LABEL_92_13);

DEFLABEL (lambda_18)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  goto lambda_10;

DEFLABEL (lambda_34)
  CLOSURE_HEADER (LABEL_92_19);

DEFLABEL (lambda_12)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (lambda_35)
DEFLABEL (lambda_4)
  INTERRUPT_CHECK (26, LABEL_92_23);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_92_25]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_92_24]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  if ((Wrd11.Obj) == ((SCHEME_OBJECT) 0))
    goto label_50;
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_92_5]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_92_28]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_92_24);
  (* (--Rsp)) = Rvl;

DEFLABEL (label_49)
  (Wrd19.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_92_0]));
  (Wrd22.Obj) = ((Wrd19.pObj) [0]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if ((Wrd23.uLng) == 50)
    goto label_48;
  Wrd18 = Wrd22;

DEFLABEL (label_47)
  (* (--Rsp)) = (Wrd18.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_92_27]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_92_25);
  (Rsp [1]) = Rvl;
  Rsp = (& (Rsp [1]));
  (Wrd6.Obj) = (Rsp [0]);
  if ((Wrd6.Obj) == ((SCHEME_OBJECT) 0))
    goto label_46;
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd6.Obj));
  if (! ((Wrd18.uLng) == 10))
    goto label_45;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd16.Lng))))
    goto label_45;
  (Wrd8.Obj) = ((Wrd14.pObj) [1]);

DEFLABEL (label_44)
  (Wrd28.Obj) = (current_block [OBJECT_92_8]);
  (* (Rhp++)) = (Wrd8.Obj);
  (* (Rhp++)) = (Wrd28.Obj);
  (Wrd26.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd26.pObj)));

DEFLABEL (label_43)
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_45)
  (Wrd19.Obj) = (Rsp [0]);
  (Wrd20.Obj) = (current_block [OBJECT_92_6]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_92_29]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_92_7]), 2);

DEFLABEL (label_27)
  (Wrd8.Obj) = Rvl;
  goto label_44;

DEFLABEL (label_46)
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_43;

DEFLABEL (label_48)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_92_26])), (Wrd19.pObj));

DEFLABEL (label_26)
  (Wrd18.Obj) = Rvl;
  goto label_47;

DEFLABEL (label_50)
  (Wrd17.Obj) = (Rsp [2]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd17.Obj);
  goto label_49;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_93_4 3
#define LABEL_93_5 5
#define LABEL_93_7 7
#define LABEL_93_12 9
#define LABEL_93_11 11
#define LABEL_93_13 13
#define LABEL_93_9 15
#define ENVIRONMENT_LABEL_93_3 29
#define DEBUGGING_LABEL_93_2 28
#define OBJECT_93_0 27
#define EXECUTE_CACHE_93_14 17
#define EXECUTE_CACHE_93_10 19
#define EXECUTE_CACHE_93_8 21
#define EXECUTE_CACHE_93_6 23
#define FREE_REFERENCE_93_0 26
#define FREE_REFERENCES_LABEL_93_0 16
#define NUMBER_OF_LINKER_SECTIONS_93_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_93 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd11;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_93_4);
      goto parse_hostport_8;

    case 1:
      current_block = (Rpc - LABEL_93_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_93_7);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_93_12);
      goto label_10;

    case 4:
      current_block = (Rpc - LABEL_93_11);
      goto continuation_3;

    case 5:
      current_block = (Rpc - LABEL_93_13);
      goto continuation_4;

    case 6:
      current_block = (Rpc - LABEL_93_9);
      goto continuation_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (parse_hostport_12)
DEFLABEL (parse_hostport_8)
  INTERRUPT_CHECK (26, LABEL_93_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_93_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_93_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_93_5);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_93_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_93_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_93_7);
  (* (--Rsp)) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_13;
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_93_9]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd24.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd25.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd25.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_93_10]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_93_9);
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_13)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_93_11]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rsp)) = Rvl;
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_93_0]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_15;
  Wrd11 = Wrd15;

DEFLABEL (label_14)
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_93_13]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd20.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_93_14]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_93_13);
  (Rsp [1]) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_93_0]), 2);

DEFLABEL (label_15)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_93_12])), (Wrd12.pObj));

DEFLABEL (label_10)
  (Wrd11.Obj) = Rvl;
  goto label_14;

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_93_11);
  (Wrd12.Obj) = (MAKE_OBJECT (0, 1));
  (* (Rhp++)) = (Wrd12.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (10, (Wrd8.pObj)));
  Rsp = (& (Rsp [3]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_94_4 3
#define LABEL_94_5 5
#define TAG_94_6 1
#define LABEL_94_8 7
#define TAG_94_9 2
#define ENVIRONMENT_LABEL_94_3 14
#define DEBUGGING_LABEL_94_2 13
#define EXECUTE_CACHE_94_10 9
#define EXECUTE_CACHE_94_7 11
#define FREE_REFERENCES_LABEL_94_0 8
#define NUMBER_OF_LINKER_SECTIONS_94_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_94 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd17;
  machine_word Wrd14;
  machine_word Wrd10;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_94_4);
      goto lp_hostport_token_2;

    case 1:
      current_block = (Rpc - LABEL_94_5);
      goto lambda_6;

    case 2:
      current_block = (Rpc - LABEL_94_8);
      goto lambda_7;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lp_hostport_token_5)
DEFLABEL (lp_hostport_token_2)
  INTERRUPT_CHECK (26, LABEL_94_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_94_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_94_5])));
  Rhp += 3;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd12 = Wrd7;
  (Wrd13.Obj) = (Rsp [2]);
  ((Wrd12.pObj) [2]) = (Wrd13.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd12.pObj) [3]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd12.pObj) [4]) = (Wrd9.Obj);
  (Rsp [2]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_94_7]));

DEFLABEL (lambda_6)
  CLOSURE_HEADER (LABEL_94_5);

DEFLABEL (lambda_1)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = ((Wrd6.pObj) [4]);
  (* (--Rsp)) = (Wrd10.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd13.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_94_9);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_94_8])));
  Rhp += 1;
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd13.pObj)));
  Wrd14 = Wrd13;
  (Wrd17.Obj) = ((Wrd6.pObj) [2]);
  ((Wrd14.pObj) [2]) = (Wrd17.Obj);
  (Rsp [2]) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_94_10]));

DEFLABEL (lambda_7)
  CLOSURE_HEADER (LABEL_94_8);

DEFLABEL (lambda_0)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_95_4 3
#define LABEL_95_5 5
#define LABEL_95_7 7
#define LABEL_95_8 9
#define LABEL_95_10 11
#define LABEL_95_13 13
#define LABEL_95_16 15
#define LABEL_95_18 17
#define LABEL_95_14 19
#define LABEL_95_17 21
#define LABEL_95_21 23
#define LABEL_95_19 25
#define LABEL_95_20 27
#define LABEL_95_26 29
#define LABEL_95_23 31
#define LABEL_95_28 33
#define LABEL_95_29 35
#define LABEL_95_31 37
#define LABEL_95_33 39
#define LABEL_95_25 41
#define LABEL_95_27 43
#define LABEL_95_30 45
#define LABEL_95_32 47
#define LABEL_95_34 49
#define ENVIRONMENT_LABEL_95_3 72
#define DEBUGGING_LABEL_95_2 71
#define OBJECT_95_3 70
#define OBJECT_95_2 69
#define OBJECT_95_1 68
#define OBJECT_95_0 67
#define EXECUTE_CACHE_95_24 51
#define EXECUTE_CACHE_95_22 53
#define EXECUTE_CACHE_95_15 55
#define EXECUTE_CACHE_95_12 57
#define EXECUTE_CACHE_95_11 59
#define EXECUTE_CACHE_95_9 61
#define EXECUTE_CACHE_95_6 63
#define FREE_REFERENCE_95_0 66
#define FREE_REFERENCES_LABEL_95_0 50
#define NUMBER_OF_LINKER_SECTIONS_95_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_95 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd30;
  machine_word Wrd24;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd25;
  machine_word Wrd23;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd35;
  machine_word Wrd32;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd9;
  machine_word Wrd10;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_95_4);
      goto language_tagP_30;

    case 1:
      current_block = (Rpc - LABEL_95_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_95_7);
      goto lambda_27;

    case 3:
      current_block = (Rpc - LABEL_95_8);
      goto continuation_29;

    case 4:
      current_block = (Rpc - LABEL_95_10);
      goto continuation_15;

    case 5:
      current_block = (Rpc - LABEL_95_13);
      goto continuation_16;

    case 6:
      current_block = (Rpc - LABEL_95_16);
      goto lambda_13;

    case 7:
      current_block = (Rpc - LABEL_95_18);
      goto Z___ks2__24;

    case 8:
      current_block = (Rpc - LABEL_95_14);
      goto continuation_17;

    case 9:
      current_block = (Rpc - LABEL_95_17);
      goto continuation_1;

    case 10:
      current_block = (Rpc - LABEL_95_21);
      goto label_32;

    case 11:
      current_block = (Rpc - LABEL_95_19);
      goto continuation_19;

    case 12:
      current_block = (Rpc - LABEL_95_20);
      goto continuation_2;

    case 13:
      current_block = (Rpc - LABEL_95_26);
      goto continuation_21;

    case 14:
      current_block = (Rpc - LABEL_95_23);
      goto continuation_20;

    case 15:
      current_block = (Rpc - LABEL_95_28);
      goto Z___l1__10;

    case 16:
      current_block = (Rpc - LABEL_95_29);
      goto label_35;

    case 17:
      current_block = (Rpc - LABEL_95_31);
      goto label_33;

    case 18:
      current_block = (Rpc - LABEL_95_33);
      goto label_34;

    case 19:
      current_block = (Rpc - LABEL_95_25);
      goto continuation_3;

    case 20:
      current_block = (Rpc - LABEL_95_27);
      goto continuation_22;

    case 21:
      current_block = (Rpc - LABEL_95_30);
      goto continuation_7;

    case 22:
      current_block = (Rpc - LABEL_95_32);
      goto continuation_8;

    case 23:
      current_block = (Rpc - LABEL_95_34);
      goto label_36;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (language_tagP_38)
DEFLABEL (language_tagP_30)
  INTERRUPT_CHECK (26, LABEL_95_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_95_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_95_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_95_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_43;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_43)
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_95_7]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_95_8]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_95_9]));

DEFLABEL (continuation_29)
  INTERRUPT_CHECK (27, LABEL_95_8);
  (Rsp [1]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_95_12]));

DEFLABEL (lambda_39)
DEFLABEL (lambda_27)
  INTERRUPT_CHECK (26, LABEL_95_7);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_95_10]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_95_11]));

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_95_10);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_95_13]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  goto lambda_13;

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_95_13);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_44;
  Rsp = (& (Rsp [1]));
  goto Z___ks2__24;

DEFLABEL (label_44)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_95_14]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_95_15]));

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_95_14);
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (lambda_40)
DEFLABEL (lambda_13)
  INTERRUPT_CHECK (26, LABEL_95_16);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_95_17]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_95_11]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_95_17);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_95_20]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_95_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_47;
  Wrd8 = Wrd12;

DEFLABEL (label_46)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_95_22]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_95_20);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_45;
  (Wrd7.Obj) = (current_block [OBJECT_95_1]);
  (Rsp [0]) = (Wrd7.Obj);
  goto Z___l1__10;

DEFLABEL (label_45)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_95_25]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_95_15]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_95_25);
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_47)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_95_21])), (Wrd9.pObj));

DEFLABEL (label_32)
  (Wrd8.Obj) = Rvl;
  goto label_46;

DEFLABEL (Z___ks2__41)
DEFLABEL (Z___ks2__24)
  INTERRUPT_CHECK (26, LABEL_95_18);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_95_19]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_95_11]));

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_95_19);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_95_23]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_95_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_95_24]));

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_95_23);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_48;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_95_26]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  goto lambda_13;

DEFLABEL (continuation_21)
  INTERRUPT_CHECK (27, LABEL_95_26);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_48;
  Rsp = (& (Rsp [1]));
  goto Z___ks2__24;

DEFLABEL (label_48)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_95_27]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_95_15]));

DEFLABEL (continuation_22)
  INTERRUPT_CHECK (27, LABEL_95_27);
  Rvl = (current_block [OBJECT_95_3]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (Z___l1__42)
DEFLABEL (Z___l1__10)
  INTERRUPT_CHECK (26, LABEL_95_28);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd6.uLng) == 26))
    goto label_56;
  (Wrd8.Lng) = (FIXNUM_TO_LONG (Wrd5.Obj));
  if ((Wrd8.Lng) > 1L)
    goto label_53;

DEFLABEL (label_52)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_95_30]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_95_0]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_51;
  Wrd14 = Wrd18;

DEFLABEL (label_50)
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_49)
  (Wrd30.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd30.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_95_22]));

DEFLABEL (label_51)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_95_31])), (Wrd15.pObj));

DEFLABEL (label_33)
  (Wrd14.Obj) = Rvl;
  goto label_50;

DEFLABEL (label_53)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_95_32]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd25.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_95_0]));
  (Wrd28.Obj) = ((Wrd25.pObj) [0]);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if ((Wrd29.uLng) == 50)
    goto label_55;
  Wrd24 = Wrd28;

DEFLABEL (label_54)
  (* (--Rsp)) = (Wrd24.Obj);
  goto label_49;

DEFLABEL (label_55)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_95_33])), (Wrd25.pObj));

DEFLABEL (label_34)
  (Wrd24.Obj) = Rvl;
  goto label_54;

DEFLABEL (label_56)
  (Wrd32.Obj) = (current_block [OBJECT_95_2]);
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_95_29]))));
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_INTERFACE_0 (37);

DEFLABEL (label_35)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_52;
  goto label_53;

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_95_30);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_57;

DEFLABEL (label_57)
  Rvl = (current_block [OBJECT_95_3]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_95_32);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_58;
  Rvl = (current_block [OBJECT_95_3]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_58)
  (Wrd12.Obj) = (Rsp [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 26))
    goto label_60;
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  (Wrd14.Lng) = ((Wrd16.Lng) - 1L);
  if (! (LONG_TO_FIXNUM_P (Wrd14.Lng)))
    goto label_60;
  (Wrd11.Obj) = (LONG_TO_FIXNUM (Wrd14.Lng));

DEFLABEL (label_59)
  (Rsp [0]) = (Wrd11.Obj);
  goto Z___l1__10;

DEFLABEL (label_60)
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_95_34]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_INTERFACE_0 (34);

DEFLABEL (label_36)
  (Wrd11.Obj) = Rvl;
  goto label_59;

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_96_4 3
#define LABEL_96_5 5
#define TAG_96_6 1
#define LABEL_96_7 7
#define TAG_96_8 2
#define LABEL_96_9 9
#define TAG_96_10 3
#define LABEL_96_12 11
#define TAG_96_13 4
#define LABEL_96_15 13
#define LABEL_96_22 15
#define LABEL_96_23 17
#define LABEL_96_16 19
#define LABEL_96_18 21
#define TAG_96_19 9
#define LABEL_96_20 23
#define LABEL_96_21 25
#define LABEL_96_28 27
#define LABEL_96_24 29
#define LABEL_96_25 31
#define LABEL_96_27 33
#define ENVIRONMENT_LABEL_96_3 55
#define DEBUGGING_LABEL_96_2 54
#define OBJECT_96_6 53
#define OBJECT_96_5 52
#define OBJECT_96_4 51
#define OBJECT_96_3 50
#define OBJECT_96_2 49
#define OBJECT_96_1 48
#define OBJECT_96_0 47
#define EXECUTE_CACHE_96_29 35
#define EXECUTE_CACHE_96_26 37
#define EXECUTE_CACHE_96_17 39
#define EXECUTE_CACHE_96_14 41
#define EXECUTE_CACHE_96_11 43
#define FREE_REFERENCE_96_0 46
#define FREE_REFERENCES_LABEL_96_0 34
#define NUMBER_OF_LINKER_SECTIONS_96_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_96 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd34;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd28;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd14;
  machine_word Wrd19;
  machine_word Wrd17;
  machine_word Wrd18;
  machine_word Wrd9;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd20;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd15;
  machine_word Wrd16;
  machine_word Wrd10;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd5;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_96_4);
      goto lp_entity_tag_20;

    case 1:
      current_block = (Rpc - LABEL_96_5);
      goto lambda_5;

    case 2:
      current_block = (Rpc - LABEL_96_7);
      goto lambda_28;

    case 3:
      current_block = (Rpc - LABEL_96_9);
      goto lambda_29;

    case 4:
      current_block = (Rpc - LABEL_96_12);
      goto lambda_30;

    case 5:
      current_block = (Rpc - LABEL_96_15);
      goto continuation_8;

    case 6:
      current_block = (Rpc - LABEL_96_22);
      goto label_22;

    case 7:
      current_block = (Rpc - LABEL_96_23);
      goto label_23;

    case 8:
      current_block = (Rpc - LABEL_96_16);
      goto continuation_7;

    case 9:
      current_block = (Rpc - LABEL_96_18);
      goto lambda_31;

    case 10:
      current_block = (Rpc - LABEL_96_20);
      goto continuation_2;

    case 11:
      current_block = (Rpc - LABEL_96_21);
      goto continuation_1;

    case 12:
      current_block = (Rpc - LABEL_96_28);
      goto label_24;

    case 13:
      current_block = (Rpc - LABEL_96_24);
      goto continuation_14;

    case 14:
      current_block = (Rpc - LABEL_96_25);
      goto lambda_13;

    case 15:
      current_block = (Rpc - LABEL_96_27);
      goto lambda_6;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lp_entity_tag_26)
DEFLABEL (lp_entity_tag_20)
  INTERRUPT_CHECK (26, LABEL_96_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd6.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_96_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_96_5])));
  Rhp += 1;
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd6.pObj)));
  Wrd7 = Wrd6;
  (Wrd8.Obj) = (Rsp [1]);
  ((Wrd7.pObj) [2]) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd11.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_96_8);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_96_7])));
  Rhp += 1;
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd11.pObj)));
  ((Wrd11.pObj) [2]) = (Wrd5.Obj);
  (Rsp [2]) = (Wrd10.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd16.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_96_10);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_96_9])));
  Rhp += 3;
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd16.pObj)));
  Wrd21 = Wrd16;
  (Wrd22.Obj) = (Rsp [3]);
  ((Wrd21.pObj) [2]) = (Wrd22.Obj);
  (Wrd20.Obj) = (Rsp [1]);
  ((Wrd21.pObj) [3]) = (Wrd20.Obj);
  ((Wrd21.pObj) [4]) = (Wrd5.Obj);
  (Rsp [3]) = (Wrd15.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_96_11]));

DEFLABEL (lambda_27)
DEFLABEL (lambda_5)
  INTERRUPT_CHECK (26, LABEL_96_5);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_96_13);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_96_12])));
  Rhp += 2;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd10 = Wrd7;
  (Wrd11.Obj) = (Rsp [0]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [2]);
  ((Wrd10.pObj) [2]) = (Wrd13.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  ((Wrd10.pObj) [3]) = (Wrd9.Obj);
  (Rsp [2]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_96_14]));

DEFLABEL (lambda_28)
  CLOSURE_HEADER (LABEL_96_7);

DEFLABEL (lambda_15)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_96_15]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_96_16]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_96_17]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_96_16);
  (* (--Rsp)) = Rvl;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_96_27]))));
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_96_4]), 2);

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_96_15);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_35;

DEFLABEL (label_34)
  Rsp = (& (Rsp [3]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (label_35)
  (Wrd7.Obj) = (Rsp [1]);
  (Wrd8.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd8.uLng) == 1))
    goto label_34;
  if (! ((Wrd8.uLng) == 1))
    goto label_39;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd10.Obj) = ((Wrd12.pObj) [0]);

DEFLABEL (label_38)
  if (! ((Wrd10.Obj) == (current_block [OBJECT_96_2])))
    goto label_34;
  (Wrd23.Obj) = (Rsp [1]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd24.uLng) == 1))
    goto label_37;
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd20.Obj) = ((Wrd22.pObj) [1]);

DEFLABEL (label_36)
  (Rsp [1]) = (Wrd20.Obj);
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_96_24]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (Wrd32.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd32.Obj);
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_96_25]))));
  (* (--Rsp)) = (Wrd34.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_96_26]));

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_96_24);
  (Rsp [2]) = Rvl;
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [2]);
  (Rsp [0]) = (Wrd6.Obj);
  goto lambda_5;

DEFLABEL (label_37)
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_96_23]))));
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_96_3]), 1);

DEFLABEL (label_23)
  (Wrd20.Obj) = Rvl;
  goto label_36;

DEFLABEL (label_39)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_96_22]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_96_1]), 1);

DEFLABEL (label_22)
  (Wrd10.Obj) = Rvl;
  goto label_38;

DEFLABEL (lambda_29)
  CLOSURE_HEADER (LABEL_96_9);

DEFLABEL (lambda_18)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd8.Obj) = (current_block [OBJECT_96_0]);
  (* (Rhp++)) = (Wrd8.Obj);
  (* (Rhp++)) = ((SCHEME_OBJECT) 0);
  (Wrd6.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd6.pObj)));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd15.Obj) = ((Wrd11.pObj) [4]);
  (* (--Rsp)) = (Wrd15.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd18.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_96_19);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_96_18])));
  Rhp += 1;
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd18.pObj)));
  Wrd19 = Wrd18;
  (Wrd22.Obj) = ((Wrd11.pObj) [2]);
  ((Wrd19.pObj) [2]) = (Wrd22.Obj);
  (Rsp [3]) = (Wrd17.Obj);
  goto lambda_5;

DEFLABEL (lambda_30)
  CLOSURE_HEADER (LABEL_96_12);

DEFLABEL (lambda_4)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_96_20]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_96_21]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd14.Obj) = (Rsp [2]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [3]);
  (Wrd17.Obj) = (Rsp [4]);
  (* (Rhp++)) = (Wrd16.Obj);
  (* (Rhp++)) = (Wrd17.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_96_17]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_96_21);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_96_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_41;
  Wrd5 = Wrd9;

DEFLABEL (label_40)
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_96_4]), 2);

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_96_20);
  (Wrd9.Obj) = (current_block [OBJECT_96_0]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd11.Obj) = (Rsp [0]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd10.Obj) = ((Wrd12.pObj) [2]);
  (Rsp [0]) = (Wrd10.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (label_41)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_96_28])), (Wrd6.pObj));

DEFLABEL (label_24)
  (Wrd5.Obj) = Rvl;
  goto label_40;

DEFLABEL (lambda_31)
  CLOSURE_HEADER (LABEL_96_18);

DEFLABEL (lambda_17)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (lambda_32)
DEFLABEL (lambda_13)
  INTERRUPT_CHECK (26, LABEL_96_25);
  Rvl = (current_block [OBJECT_96_5]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (lambda_33)
DEFLABEL (lambda_6)
  INTERRUPT_CHECK (26, LABEL_96_27);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_96_6]);
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_96_29]));

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_97_4 3
#define ENVIRONMENT_LABEL_97_3 10
#define DEBUGGING_LABEL_97_2 9
#define OBJECT_97_1 8
#define OBJECT_97_0 7
#define EXECUTE_CACHE_97_5 5
#define FREE_REFERENCES_LABEL_97_0 4
#define NUMBER_OF_LINKER_SECTIONS_97_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_97 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd7;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_97_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_97_4);
  (Wrd5.Obj) = (Rsp [0]);
  if ((Wrd5.Obj) == ((SCHEME_OBJECT) 0))
    goto label_4;
  (Wrd7.Obj) = (current_block [OBJECT_97_1]);
  (Rsp [0]) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_97_5]));

DEFLABEL (label_4)
  Rvl = (current_block [OBJECT_97_0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_98_4 3
#define LABEL_98_5 5
#define TAG_98_6 1
#define LABEL_98_8 7
#define LABEL_98_9 9
#define LABEL_98_11 11
#define ENVIRONMENT_LABEL_98_3 21
#define DEBUGGING_LABEL_98_2 20
#define OBJECT_98_0 19
#define EXECUTE_CACHE_98_10 13
#define EXECUTE_CACHE_98_7 15
#define FREE_REFERENCE_98_0 18
#define FREE_REFERENCES_LABEL_98_0 12
#define NUMBER_OF_LINKER_SECTIONS_98_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_98 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_98_4);
      goto lp_bytes_unit_3;

    case 1:
      current_block = (Rpc - LABEL_98_5);
      goto lambda_8;

    case 2:
      current_block = (Rpc - LABEL_98_8);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_98_9);
      goto continuation_0;

    case 4:
      current_block = (Rpc - LABEL_98_11);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lp_bytes_unit_7)
DEFLABEL (lp_bytes_unit_3)
  INTERRUPT_CHECK (26, LABEL_98_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_98_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_98_5])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [1]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_98_7]));

DEFLABEL (lambda_8)
  CLOSURE_HEADER (LABEL_98_5);

DEFLABEL (lambda_2)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_98_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_98_9]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_98_10]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_98_9);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_98_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_11;
  Wrd5 = Wrd9;

DEFLABEL (label_10)
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_98_0]), 2);

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_98_8);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_9;
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [2]);
  (Rsp [0]) = (Wrd7.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (label_9)
  Rsp = (& (Rsp [3]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (label_11)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_98_11])), (Wrd6.pObj));

DEFLABEL (label_5)
  (Wrd5.Obj) = Rvl;
  goto label_10;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_99_4 3
#define LABEL_99_5 5
#define LABEL_99_6 7
#define LABEL_99_7 9
#define LABEL_99_8 11
#define LABEL_99_9 13
#define LABEL_99_10 15
#define LABEL_99_11 17
#define ENVIRONMENT_LABEL_99_3 22
#define DEBUGGING_LABEL_99_2 21
#define OBJECT_99_2 20
#define OBJECT_99_1 19
#define OBJECT_99_0 18
#define FREE_REFERENCES_LABEL_99_0 18
#define NUMBER_OF_LINKER_SECTIONS_99_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_99 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd50;
  machine_word Wrd53;
  machine_word Wrd52;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd42;
  machine_word Wrd34;
  machine_word Wrd36;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd33;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd59;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd55;
  machine_word Wrd54;
  machine_word Wrd66;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd62;
  machine_word Wrd61;
  machine_word Wrd73;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd69;
  machine_word Wrd68;
  machine_word Wrd80;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd76;
  machine_word Wrd75;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_99_4);
      goto lambda_7;

    case 1:
      current_block = (Rpc - LABEL_99_5);
      goto label_15;

    case 2:
      current_block = (Rpc - LABEL_99_6);
      goto label_14;

    case 3:
      current_block = (Rpc - LABEL_99_7);
      goto label_13;

    case 4:
      current_block = (Rpc - LABEL_99_8);
      goto label_12;

    case 5:
      current_block = (Rpc - LABEL_99_9);
      goto label_9;

    case 6:
      current_block = (Rpc - LABEL_99_10);
      goto label_10;

    case 7:
      current_block = (Rpc - LABEL_99_11);
      goto label_11;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_17)
DEFLABEL (lambda_7)
  INTERRUPT_CHECK (26, LABEL_99_4);
  (Wrd75.Obj) = (Rsp [0]);
  (Wrd76.uLng) = (OBJECT_TYPE (Wrd75.Obj));
  if (! ((Wrd76.uLng) == 1))
    goto label_34;
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd75.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [0]);
  if ((Wrd7.Obj) == ((SCHEME_OBJECT) 0))
    goto label_32;

DEFLABEL (label_31)
  (Wrd61.Obj) = (Rsp [0]);
  (Wrd62.uLng) = (OBJECT_TYPE (Wrd61.Obj));
  if (! ((Wrd62.uLng) == 1))
    goto label_30;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd61.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  if ((Wrd17.Obj) == ((SCHEME_OBJECT) 0))
    goto label_20;

DEFLABEL (label_29)
  (Wrd54.Obj) = (Rsp [0]);
  (Wrd55.uLng) = (OBJECT_TYPE (Wrd54.Obj));
  if (! ((Wrd55.uLng) == 1))
    goto label_28;
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd54.Obj));
  (Wrd23.Obj) = ((Wrd22.pObj) [1]);
  if ((Wrd23.Obj) == ((SCHEME_OBJECT) 0))
    goto label_20;

DEFLABEL (label_27)
  (Wrd28.Obj) = (Rsp [0]);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if (! ((Wrd29.uLng) == 1))
    goto label_26;
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd28.Obj));
  (Wrd27.Obj) = ((Wrd26.pObj) [1]);
  (* (--Rsp)) = (Wrd27.Obj);

DEFLABEL (label_25)
  (Wrd37.Obj) = (Rsp [1]);
  (Wrd38.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if (! ((Wrd38.uLng) == 1))
    goto label_24;
  (Wrd36.pObj) = (OBJECT_ADDRESS (Wrd37.Obj));
  (Wrd34.Obj) = ((Wrd36.pObj) [0]);

DEFLABEL (label_23)
  (Wrd43.Obj) = (* (Rsp++));
  (Wrd44.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if (! ((Wrd44.uLng) == 26))
    goto label_22;
  (Wrd45.uLng) = (OBJECT_TYPE (Wrd43.Obj));
  if (! ((Wrd45.uLng) == 26))
    goto label_22;
  (Wrd52.Lng) = (FIXNUM_TO_LONG (Wrd34.Obj));
  (Wrd53.Lng) = (FIXNUM_TO_LONG (Wrd43.Obj));
  if ((Wrd52.Lng) > (Wrd53.Lng))
    goto label_19;

DEFLABEL (label_20)
  Rvl = (current_block [OBJECT_99_2]);
  goto label_18;

DEFLABEL (label_19)
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_18)
DEFLABEL (label_21)
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_22)
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_99_11]))));
  (* (--Rsp)) = (Wrd50.Obj);
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  INVOKE_INTERFACE_0 (37);

DEFLABEL (label_11)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_20;
  goto label_19;

DEFLABEL (label_24)
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_99_10]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_99_0]), 1);

DEFLABEL (label_10)
  (Wrd34.Obj) = Rvl;
  goto label_23;

DEFLABEL (label_26)
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_99_9]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_99_1]), 1);

DEFLABEL (label_9)
  (* (--Rsp)) = Rvl;
  goto label_25;

DEFLABEL (label_28)
  (Wrd59.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_99_8]))));
  (* (--Rsp)) = (Wrd59.Obj);
  (* (--Rsp)) = (Wrd54.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_99_1]), 1);

DEFLABEL (label_12)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_20;
  goto label_27;

DEFLABEL (label_30)
  (Wrd66.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_99_7]))));
  (* (--Rsp)) = (Wrd66.Obj);
  (* (--Rsp)) = (Wrd61.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_99_0]), 1);

DEFLABEL (label_13)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_20;
  goto label_29;

DEFLABEL (label_32)
  (Wrd68.Obj) = (Rsp [0]);
  (Wrd69.uLng) = (OBJECT_TYPE (Wrd68.Obj));
  if (! ((Wrd69.uLng) == 1))
    goto label_33;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd68.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [1]);
  if ((Wrd11.Obj) == ((SCHEME_OBJECT) 0))
    goto label_19;
  goto label_31;

DEFLABEL (label_33)
  (Wrd73.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_99_6]))));
  (* (--Rsp)) = (Wrd73.Obj);
  (* (--Rsp)) = (Wrd68.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_99_1]), 1);

DEFLABEL (label_14)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_19;
  goto label_31;

DEFLABEL (label_34)
  (Wrd80.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_99_5]))));
  (* (--Rsp)) = (Wrd80.Obj);
  (* (--Rsp)) = (Wrd75.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_99_0]), 1);

DEFLABEL (label_15)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_32;
  goto label_31;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_100_4 3
#define LABEL_100_5 5
#define TAG_100_6 1
#define LABEL_100_8 7
#define LABEL_100_9 9
#define LABEL_100_11 11
#define LABEL_100_13 13
#define LABEL_100_14 15
#define LABEL_100_16 17
#define LABEL_100_17 19
#define LABEL_100_20 21
#define LABEL_100_18 23
#define LABEL_100_21 25
#define TAG_100_22 11
#define LABEL_100_23 27
#define LABEL_100_24 29
#define LABEL_100_26 31
#define TAG_100_27 14
#define LABEL_100_28 33
#define LABEL_100_34 35
#define LABEL_100_29 37
#define LABEL_100_30 39
#define LABEL_100_32 41
#define LABEL_100_35 43
#define LABEL_100_40 45
#define LABEL_100_36 47
#define LABEL_100_37 49
#define TAG_100_38 23
#define LABEL_100_39 51
#define LABEL_100_43 53
#define LABEL_100_42 55
#define LABEL_100_44 57
#define LABEL_100_46 59
#define LABEL_100_45 61
#define LABEL_100_48 63
#define LABEL_100_47 65
#define LABEL_100_53 67
#define LABEL_100_49 69
#define LABEL_100_50 71
#define LABEL_100_54 73
#define LABEL_100_52 75
#define LABEL_100_55 77
#define LABEL_100_57 79
#define ENVIRONMENT_LABEL_100_3 111
#define DEBUGGING_LABEL_100_2 110
#define OBJECT_100_2 109
#define OBJECT_100_1 108
#define OBJECT_100_0 107
#define EXECUTE_CACHE_100_56 81
#define EXECUTE_CACHE_100_51 83
#define EXECUTE_CACHE_100_41 85
#define EXECUTE_CACHE_100_33 87
#define EXECUTE_CACHE_100_31 89
#define EXECUTE_CACHE_100_25 91
#define EXECUTE_CACHE_100_19 93
#define EXECUTE_CACHE_100_15 95
#define EXECUTE_CACHE_100_12 97
#define EXECUTE_CACHE_100_10 99
#define EXECUTE_CACHE_100_7 101
#define FREE_REFERENCE_100_2 104
#define FREE_REFERENCE_100_1 105
#define FREE_REFERENCE_100_0 106
#define FREE_REFERENCES_LABEL_100_0 80
#define NUMBER_OF_LINKER_SECTIONS_100_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_100 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd21;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd16;
  machine_word Wrd17;
  machine_word Wrd12;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd5;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_100_4);
      goto lambda_53;

    case 1:
      current_block = (Rpc - LABEL_100_5);
      goto lambda_61;

    case 2:
      current_block = (Rpc - LABEL_100_8);
      goto continuation_46;

    case 3:
      current_block = (Rpc - LABEL_100_9);
      goto continuation_45;

    case 4:
      current_block = (Rpc - LABEL_100_11);
      goto continuation_47;

    case 5:
      current_block = (Rpc - LABEL_100_13);
      goto continuation_44;

    case 6:
      current_block = (Rpc - LABEL_100_14);
      goto lambda_42;

    case 7:
      current_block = (Rpc - LABEL_100_16);
      goto continuation_49;

    case 8:
      current_block = (Rpc - LABEL_100_17);
      goto continuation_48;

    case 9:
      current_block = (Rpc - LABEL_100_20);
      goto label_55;

    case 10:
      current_block = (Rpc - LABEL_100_18);
      goto continuation_13;

    case 11:
      current_block = (Rpc - LABEL_100_21);
      goto lambda_28;

    case 12:
      current_block = (Rpc - LABEL_100_23);
      goto continuation_29;

    case 13:
      current_block = (Rpc - LABEL_100_24);
      goto continuation_14;

    case 14:
      current_block = (Rpc - LABEL_100_26);
      goto lambda_64;

    case 15:
      current_block = (Rpc - LABEL_100_28);
      goto continuation_35;

    case 16:
      current_block = (Rpc - LABEL_100_34);
      goto lambda_11;

    case 17:
      current_block = (Rpc - LABEL_100_29);
      goto continuation_20;

    case 18:
      current_block = (Rpc - LABEL_100_30);
      goto continuation_30;

    case 19:
      current_block = (Rpc - LABEL_100_32);
      goto continuation_36;

    case 20:
      current_block = (Rpc - LABEL_100_35);
      goto continuation_0;

    case 21:
      current_block = (Rpc - LABEL_100_40);
      goto label_56;

    case 22:
      current_block = (Rpc - LABEL_100_36);
      goto continuation_21;

    case 23:
      current_block = (Rpc - LABEL_100_37);
      goto lambda_66;

    case 24:
      current_block = (Rpc - LABEL_100_39);
      goto continuation_1;

    case 25:
      current_block = (Rpc - LABEL_100_43);
      goto continuation_24;

    case 26:
      current_block = (Rpc - LABEL_100_42);
      goto continuation_22;

    case 27:
      current_block = (Rpc - LABEL_100_44);
      goto continuation_32;

    case 28:
      current_block = (Rpc - LABEL_100_46);
      goto Z___ks2__8;

    case 29:
      current_block = (Rpc - LABEL_100_45);
      goto continuation_2;

    case 30:
      current_block = (Rpc - LABEL_100_48);
      goto lambda_19;

    case 31:
      current_block = (Rpc - LABEL_100_47);
      goto continuation_4;

    case 32:
      current_block = (Rpc - LABEL_100_53);
      goto label_57;

    case 33:
      current_block = (Rpc - LABEL_100_49);
      goto continuation_16;

    case 34:
      current_block = (Rpc - LABEL_100_50);
      goto continuation_15;

    case 35:
      current_block = (Rpc - LABEL_100_54);
      goto label_58;

    case 36:
      current_block = (Rpc - LABEL_100_52);
      goto continuation_5;

    case 37:
      current_block = (Rpc - LABEL_100_55);
      goto continuation_17;

    case 38:
      current_block = (Rpc - LABEL_100_57);
      goto continuation_6;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_60)
DEFLABEL (lambda_53)
  INTERRUPT_CHECK (26, LABEL_100_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_100_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_100_5])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [1]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_100_7]));

DEFLABEL (lambda_61)
  CLOSURE_HEADER (LABEL_100_5);

DEFLABEL (lambda_52)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100_9]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_100_10]));

DEFLABEL (continuation_45)
  INTERRUPT_CHECK (27, LABEL_100_9);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100_13]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100_14]))));
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_100_15]));

DEFLABEL (continuation_44)
  INTERRUPT_CHECK (27, LABEL_100_13);
  (* (--Rsp)) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_100_0]), 2);

DEFLABEL (continuation_46)
  INTERRUPT_CHECK (27, LABEL_100_8);
  (* (--Rsp)) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_69;
  Rsp = (& (Rsp [4]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (label_69)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100_11]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_100_12]));

DEFLABEL (continuation_47)
  INTERRUPT_CHECK (27, LABEL_100_11);
  (Rsp [0]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100_16]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100_17]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_100_10]));

DEFLABEL (continuation_48)
  INTERRUPT_CHECK (27, LABEL_100_17);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_100_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_72;
  Wrd5 = Wrd9;

DEFLABEL (label_71)
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_100_0]), 2);

DEFLABEL (continuation_49)
  INTERRUPT_CHECK (27, LABEL_100_16);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_70;
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [2]);
  (Rsp [1]) = (Wrd7.Obj);
  (Wrd10.Obj) = (Rsp [0]);
  (Rsp [3]) = (Wrd10.Obj);
  Rsp = (& (Rsp [1]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (label_70)
  Rsp = (& (Rsp [4]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (label_72)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_100_20])), (Wrd6.pObj));

DEFLABEL (label_55)
  (Wrd5.Obj) = Rvl;
  goto label_71;

DEFLABEL (lambda_62)
DEFLABEL (lambda_42)
  INTERRUPT_CHECK (26, LABEL_100_14);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100_18]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_100_19]));

DEFLABEL (continuation_13)
  INTERRUPT_CHECK (27, LABEL_100_18);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd6.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x303, 2);
  (* (Rhp++)) = (dispatch_base + TAG_100_22);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_100_21])));
  Rhp += 1;
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd6.pObj)));
  Wrd7 = Wrd6;
  (Wrd8.Obj) = (Rsp [1]);
  ((Wrd7.pObj) [2]) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100_23]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_100_19]));

DEFLABEL (continuation_29)
  INTERRUPT_CHECK (27, LABEL_100_23);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 7));
  (Wrd6.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_100_27);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_100_26])));
  Rhp += 4;
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd6.pObj)));
  Wrd13 = Wrd6;
  (Wrd14.Obj) = (Rsp [3]);
  ((Wrd13.pObj) [2]) = (Wrd14.Obj);
  (Wrd12.Obj) = (Rsp [2]);
  ((Wrd13.pObj) [3]) = (Wrd12.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  ((Wrd13.pObj) [4]) = (Wrd10.Obj);
  ((Wrd13.pObj) [5]) = Rvl;
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100_28]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd14.Obj);
  goto lambda_11;

DEFLABEL (continuation_35)
  INTERRUPT_CHECK (27, LABEL_100_28);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_73;
  (Wrd13.Obj) = (Rsp [0]);
  (Rsp [4]) = (Wrd13.Obj);
  Rsp = (& (Rsp [4]));
  goto lambda_34;

DEFLABEL (label_73)
  (Wrd7.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100_32]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_100_33]));

DEFLABEL (continuation_36)
  INTERRUPT_CHECK (27, LABEL_100_32);
  (Wrd11.Obj) = (MAKE_OBJECT (0, 1));
  (* (Rhp++)) = (Wrd11.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (10, (Wrd8.pObj)));
  (Rsp [4]) = (Wrd6.Obj);
  (Wrd12.Obj) = (* (Rsp++));
  (Rsp [4]) = (Wrd12.Obj);
  Rsp = (& (Rsp [2]));
  goto lambda_28;

DEFLABEL (lambda_63)
DEFLABEL (lambda_28)
  INTERRUPT_CHECK (26, LABEL_100_21);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100_24]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_100_1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_100_25]));

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_100_24);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_74;
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_74)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100_29]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [2]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_100_19]));

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_100_29);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100_36]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  goto lambda_11;

DEFLABEL (continuation_21)
  INTERRUPT_CHECK (27, LABEL_100_36);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_75;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100_43]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_100_33]));

DEFLABEL (continuation_24)
  INTERRUPT_CHECK (27, LABEL_100_43);
  (Wrd11.Obj) = (MAKE_OBJECT (0, 1));
  (* (Rhp++)) = (Wrd11.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (10, (Wrd8.pObj)));
  (Rsp [0]) = (Wrd6.Obj);
  goto lambda_19;

DEFLABEL (label_75)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100_42]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd18.Obj) = (Rsp [3]);
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [2]);
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_100_31]));

DEFLABEL (continuation_22)
  INTERRUPT_CHECK (27, LABEL_100_42);
  (Wrd10.Obj) = (MAKE_OBJECT (0, 1));
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = ((SCHEME_OBJECT) 0);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (10, (Wrd7.pObj)));
  (Rsp [0]) = (Wrd5.Obj);
  goto lambda_19;

DEFLABEL (lambda_64)
  CLOSURE_HEADER (LABEL_100_26);

DEFLABEL (lambda_34)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100_30]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [5]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_100_31]));

DEFLABEL (continuation_30)
  INTERRUPT_CHECK (27, LABEL_100_30);
  (Wrd10.Obj) = (MAKE_OBJECT (0, 1));
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = ((SCHEME_OBJECT) 0);
  (Wrd6.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (10, (Wrd6.pObj)));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd12.Obj) = (Rsp [1]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [4]);
  (* (--Rsp)) = (Wrd14.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd17.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_100_38);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_100_37])));
  Rhp += 2;
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd17.pObj)));
  Wrd22 = Wrd17;
  (Wrd25.Obj) = ((Wrd13.pObj) [2]);
  ((Wrd22.pObj) [2]) = (Wrd25.Obj);
  (Wrd21.Obj) = ((Wrd13.pObj) [3]);
  ((Wrd22.pObj) [3]) = (Wrd21.Obj);
  (Rsp [2]) = (Wrd16.Obj);
  goto lambda_28;

DEFLABEL (lambda_65)
DEFLABEL (lambda_11)
  INTERRUPT_CHECK (26, LABEL_100_34);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100_35]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_100_19]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_100_35);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100_39]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_100_1]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_78;
  Wrd8 = Wrd12;

DEFLABEL (label_77)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_100_41]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_100_39);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_76;
  Rsp = (& (Rsp [1]));
  goto Z___ks2__8;

DEFLABEL (label_76)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100_45]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_100_31]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_100_45);
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_78)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_100_40])), (Wrd9.pObj));

DEFLABEL (label_56)
  (Wrd8.Obj) = Rvl;
  goto label_77;

DEFLABEL (lambda_66)
  CLOSURE_HEADER (LABEL_100_37);

DEFLABEL (lambda_33)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100_44]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_100_31]));

DEFLABEL (continuation_32)
  INTERRUPT_CHECK (27, LABEL_100_44);
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (Z___ks2__67)
DEFLABEL (Z___ks2__8)
  INTERRUPT_CHECK (26, LABEL_100_46);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100_47]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_100_19]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_100_47);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100_52]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_100_1]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_81;
  Wrd8 = Wrd12;

DEFLABEL (label_80)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_100_41]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_100_52);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_79;
  Rsp = (& (Rsp [1]));
  goto Z___ks2__8;

DEFLABEL (label_79)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100_57]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_100_31]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_100_57);
  Rvl = (current_block [OBJECT_100_2]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_81)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_100_53])), (Wrd9.pObj));

DEFLABEL (label_57)
  (Wrd8.Obj) = Rvl;
  goto label_80;

DEFLABEL (lambda_68)
DEFLABEL (lambda_19)
  INTERRUPT_CHECK (26, LABEL_100_48);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100_49]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100_50]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_100_51]));

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_100_50);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_100_2]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_83;
  Wrd5 = Wrd9;

DEFLABEL (label_82)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100_55]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_100_56]));

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_100_55);
  (Rsp [1]) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_100_0]), 2);

DEFLABEL (label_83)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_100_54])), (Wrd6.pObj));

DEFLABEL (label_58)
  (Wrd5.Obj) = Rvl;
  goto label_82;

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_100_49);
  (Wrd12.Obj) = (MAKE_OBJECT (0, 1));
  (* (Rhp++)) = (Wrd12.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (10, (Wrd8.pObj)));
  Rsp = (& (Rsp [4]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_101_4 3
#define LABEL_101_5 5
#define TAG_101_6 1
#define LABEL_101_8 7
#define TAG_101_9 2
#define LABEL_101_10 9
#define TAG_101_11 3
#define LABEL_101_12 11
#define TAG_101_13 4
#define LABEL_101_15 13
#define LABEL_101_16 15
#define LABEL_101_22 17
#define LABEL_101_18 19
#define TAG_101_19 8
#define LABEL_101_20 21
#define TAG_101_21 9
#define ENVIRONMENT_LABEL_101_3 34
#define DEBUGGING_LABEL_101_2 33
#define OBJECT_101_1 32
#define OBJECT_101_0 31
#define EXECUTE_CACHE_101_17 23
#define EXECUTE_CACHE_101_14 25
#define EXECUTE_CACHE_101_7 27
#define FREE_REFERENCE_101_0 30
#define FREE_REFERENCES_LABEL_101_0 22
#define NUMBER_OF_LINKER_SECTIONS_101_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_101 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd22;
  machine_word Wrd18;
  machine_word Wrd13;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd24;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd19;
  machine_word Wrd20;
  machine_word Wrd14;
  machine_word Wrd15;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_101_4);
      goto lp_product_13;

    case 1:
      current_block = (Rpc - LABEL_101_5);
      goto lambda_18;

    case 2:
      current_block = (Rpc - LABEL_101_8);
      goto lambda_4;

    case 3:
      current_block = (Rpc - LABEL_101_10);
      goto lambda_20;

    case 4:
      current_block = (Rpc - LABEL_101_12);
      goto lambda_21;

    case 5:
      current_block = (Rpc - LABEL_101_15);
      goto continuation_2;

    case 6:
      current_block = (Rpc - LABEL_101_16);
      goto continuation_1;

    case 7:
      current_block = (Rpc - LABEL_101_22);
      goto label_15;

    case 8:
      current_block = (Rpc - LABEL_101_18);
      goto lambda_22;

    case 9:
      current_block = (Rpc - LABEL_101_20);
      goto lambda_23;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lp_product_17)
DEFLABEL (lp_product_13)
  INTERRUPT_CHECK (26, LABEL_101_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_101_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_101_5])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [1]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_101_7]));

DEFLABEL (lambda_18)
  CLOSURE_HEADER (LABEL_101_5);

DEFLABEL (lambda_12)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd6.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_101_9);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_101_8])));
  Rhp += 2;
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd6.pObj)));
  Wrd9 = Wrd6;
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [2]);
  ((Wrd9.pObj) [2]) = (Wrd12.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  ((Wrd9.pObj) [3]) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd15.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_101_11);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_101_10])));
  Rhp += 1;
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd15.pObj)));
  ((Wrd15.pObj) [2]) = (Wrd5.Obj);
  (Rsp [3]) = (Wrd14.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd20.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_101_13);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_101_12])));
  Rhp += 3;
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd20.pObj)));
  Wrd25 = Wrd20;
  (Wrd26.Obj) = (Rsp [4]);
  ((Wrd25.pObj) [2]) = (Wrd26.Obj);
  (Wrd24.Obj) = (Rsp [2]);
  ((Wrd25.pObj) [3]) = (Wrd24.Obj);
  ((Wrd25.pObj) [4]) = (Wrd5.Obj);
  (Rsp [4]) = (Wrd19.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_101_14]));

DEFLABEL (lambda_19)
DEFLABEL (lambda_4)
  INTERRUPT_CHECK (26, LABEL_101_8);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_101_15]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_101_16]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd14.Obj) = (Rsp [2]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [3]);
  (Wrd17.Obj) = (Rsp [4]);
  (* (Rhp++)) = (Wrd16.Obj);
  (* (Rhp++)) = (Wrd17.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_101_17]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_101_16);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_101_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_25;
  Wrd5 = Wrd9;

DEFLABEL (label_24)
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_101_1]), 2);

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_101_15);
  (Wrd9.Obj) = (current_block [OBJECT_101_0]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd11.Obj) = (Rsp [0]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd10.Obj) = ((Wrd12.pObj) [2]);
  (Rsp [0]) = (Wrd10.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (label_25)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_101_22])), (Wrd6.pObj));

DEFLABEL (label_15)
  (Wrd5.Obj) = Rvl;
  goto label_24;

DEFLABEL (lambda_20)
  CLOSURE_HEADER (LABEL_101_10);

DEFLABEL (lambda_7)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_101_19);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_101_18])));
  Rhp += 2;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd10 = Wrd7;
  (Wrd11.Obj) = (Rsp [0]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [2]);
  ((Wrd10.pObj) [2]) = (Wrd13.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  ((Wrd10.pObj) [3]) = (Wrd9.Obj);
  (Rsp [2]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_101_7]));

DEFLABEL (lambda_21)
  CLOSURE_HEADER (LABEL_101_12);

DEFLABEL (lambda_10)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd8.Obj) = (current_block [OBJECT_101_0]);
  (* (Rhp++)) = (Wrd8.Obj);
  (* (Rhp++)) = ((SCHEME_OBJECT) 0);
  (Wrd6.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd6.pObj)));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd15.Obj) = ((Wrd11.pObj) [4]);
  (* (--Rsp)) = (Wrd15.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd18.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_101_21);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_101_20])));
  Rhp += 1;
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd18.pObj)));
  Wrd19 = Wrd18;
  (Wrd22.Obj) = ((Wrd11.pObj) [2]);
  ((Wrd19.pObj) [2]) = (Wrd22.Obj);
  (Rsp [3]) = (Wrd17.Obj);
  goto lambda_4;

DEFLABEL (lambda_22)
  CLOSURE_HEADER (LABEL_101_18);

DEFLABEL (lambda_6)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [3]);
  (Wrd11.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (Rsp [2]) = (Wrd5.Obj);
  (Wrd12.Obj) = ((Wrd9.pObj) [2]);
  (Rsp [0]) = (Wrd12.Obj);
  goto lambda_4;

DEFLABEL (lambda_23)
  CLOSURE_HEADER (LABEL_101_20);

DEFLABEL (lambda_9)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_102_4 3
#define LABEL_102_5 5
#define TAG_102_6 1
#define LABEL_102_10 7
#define LABEL_102_15 9
#define LABEL_102_7 11
#define TAG_102_8 4
#define LABEL_102_11 13
#define TAG_102_12 5
#define LABEL_102_13 15
#define TAG_102_14 6
#define LABEL_102_18 17
#define LABEL_102_16 19
#define TAG_102_17 8
#define LABEL_102_19 21
#define TAG_102_20 9
#define ENVIRONMENT_LABEL_102_3 30
#define DEBUGGING_LABEL_102_2 29
#define OBJECT_102_3 28
#define OBJECT_102_2 27
#define OBJECT_102_1 26
#define OBJECT_102_0 25
#define EXECUTE_CACHE_102_9 23
#define FREE_REFERENCES_LABEL_102_0 22
#define NUMBER_OF_LINKER_SECTIONS_102_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_102 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd30;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd20;
  machine_word Wrd9;
  machine_word Wrd15;
  machine_word Wrd13;
  machine_word Wrd14;
  machine_word Wrd44;
  machine_word Wrd36;
  machine_word Wrd38;
  machine_word Wrd40;
  machine_word Wrd33;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd28;
  machine_word Wrd29;
  machine_word Wrd21;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd10;
  machine_word Wrd16;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd11;
  machine_word Wrd12;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd5;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_102_4);
      goto lp_solidus_14;

    case 1:
      current_block = (Rpc - LABEL_102_5);
      goto lambda_21;

    case 2:
      current_block = (Rpc - LABEL_102_10);
      goto label_16;

    case 3:
      current_block = (Rpc - LABEL_102_15);
      goto label_17;

    case 4:
      current_block = (Rpc - LABEL_102_7);
      goto lambda_22;

    case 5:
      current_block = (Rpc - LABEL_102_11);
      goto lambda_23;

    case 6:
      current_block = (Rpc - LABEL_102_13);
      goto lambda_24;

    case 7:
      current_block = (Rpc - LABEL_102_18);
      goto label_18;

    case 8:
      current_block = (Rpc - LABEL_102_16);
      goto lambda_25;

    case 9:
      current_block = (Rpc - LABEL_102_19);
      goto lambda_26;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lp_solidus_20)
DEFLABEL (lp_solidus_14)
  INTERRUPT_CHECK (26, LABEL_102_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd6.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_102_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_102_5])));
  Rhp += 1;
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd6.pObj)));
  Wrd7 = Wrd6;
  (Wrd8.Obj) = (Rsp [1]);
  ((Wrd7.pObj) [2]) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (Rsp [2]) = (Wrd5.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd12.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_102_8);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_102_7])));
  Rhp += 3;
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd12.pObj)));
  Wrd17 = Wrd12;
  (Wrd18.Obj) = (Rsp [3]);
  ((Wrd17.pObj) [2]) = (Wrd18.Obj);
  (Wrd16.Obj) = (Rsp [1]);
  ((Wrd17.pObj) [3]) = (Wrd16.Obj);
  ((Wrd17.pObj) [4]) = (Wrd5.Obj);
  (Rsp [3]) = (Wrd11.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_102_9]));

DEFLABEL (lambda_21)
  CLOSURE_HEADER (LABEL_102_5);

DEFLABEL (lambda_10)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_28;

DEFLABEL (label_27)
  Rsp = (& (Rsp [3]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (label_28)
  if (! ((Wrd6.uLng) == 1))
    goto label_32;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd8.Obj) = ((Wrd10.pObj) [0]);

DEFLABEL (label_31)
  if (! ((Wrd8.Obj) == (current_block [OBJECT_102_1])))
    goto label_27;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd19.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_102_12);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_102_11])));
  Rhp += 2;
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd19.pObj)));
  Wrd22 = Wrd19;
  (Wrd23.Obj) = (Rsp [0]);
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd25.Obj) = ((Wrd24.pObj) [2]);
  ((Wrd22.pObj) [2]) = (Wrd25.Obj);
  (Wrd21.Obj) = (Rsp [2]);
  ((Wrd22.pObj) [3]) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  (Rsp [3]) = (Wrd18.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd29.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_102_14);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_102_13])));
  Rhp += 3;
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd29.pObj)));
  Wrd34 = Wrd29;
  (Wrd35.Obj) = (Rsp [4]);
  ((Wrd34.pObj) [2]) = (Wrd35.Obj);
  (Wrd33.Obj) = (Rsp [2]);
  ((Wrd34.pObj) [3]) = (Wrd33.Obj);
  ((Wrd34.pObj) [4]) = (Wrd18.Obj);
  (Rsp [4]) = (Wrd28.Obj);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if (! ((Wrd40.uLng) == 1))
    goto label_30;
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd36.Obj) = ((Wrd38.pObj) [1]);

DEFLABEL (label_29)
  (Rsp [2]) = (Wrd36.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_102_9]));

DEFLABEL (label_30)
  (Wrd44.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_102_15]))));
  (* (--Rsp)) = (Wrd44.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_102_2]), 1);

DEFLABEL (label_17)
  (Wrd36.Obj) = Rvl;
  goto label_29;

DEFLABEL (label_32)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_102_10]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_102_0]), 1);

DEFLABEL (label_16)
  (Wrd8.Obj) = Rvl;
  goto label_31;

DEFLABEL (lambda_22)
  CLOSURE_HEADER (LABEL_102_7);

DEFLABEL (lambda_12)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (current_block [OBJECT_102_3]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd8.Obj) = ((Wrd7.pObj) [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = ((Wrd7.pObj) [4]);
  (* (--Rsp)) = (Wrd11.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd14.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_102_17);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_102_16])));
  Rhp += 1;
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd14.pObj)));
  Wrd15 = Wrd14;
  (Wrd18.Obj) = ((Wrd7.pObj) [2]);
  ((Wrd15.pObj) [2]) = (Wrd18.Obj);
  (Rsp [3]) = (Wrd13.Obj);
  goto lambda_10;

DEFLABEL (lambda_23)
  CLOSURE_HEADER (LABEL_102_11);

DEFLABEL (lambda_4)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [3]);
  (Wrd11.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (Rsp [2]) = (Wrd5.Obj);
  (Wrd12.Obj) = ((Wrd9.pObj) [2]);
  (Rsp [0]) = (Wrd12.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (lambda_24)
  CLOSURE_HEADER (LABEL_102_13);

DEFLABEL (lambda_8)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (current_block [OBJECT_102_3]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [3]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd14.uLng) == 1))
    goto label_34;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [1]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_33)
  (Wrd21.Obj) = (Rsp [2]);
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd23.Obj) = ((Wrd22.pObj) [4]);
  (* (--Rsp)) = (Wrd23.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd26.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_102_20);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_102_19])));
  Rhp += 1;
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd26.pObj)));
  Wrd27 = Wrd26;
  (Wrd30.Obj) = ((Wrd22.pObj) [2]);
  ((Wrd27.pObj) [2]) = (Wrd30.Obj);
  (Rsp [3]) = (Wrd25.Obj);
  goto lambda_4;

DEFLABEL (label_34)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_102_18]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd13.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_102_2]), 1);

DEFLABEL (label_18)
  (* (--Rsp)) = Rvl;
  goto label_33;

DEFLABEL (lambda_25)
  CLOSURE_HEADER (LABEL_102_16);

DEFLABEL (lambda_11)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (lambda_26)
  CLOSURE_HEADER (LABEL_102_19);

DEFLABEL (lambda_7)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_103_4 3
#define LABEL_103_5 5
#define TAG_103_6 1
#define LABEL_103_7 7
#define TAG_103_8 2
#define LABEL_103_10 9
#define TAG_103_11 3
#define LABEL_103_12 11
#define TAG_103_13 4
#define LABEL_103_15 13
#define TAG_103_16 5
#define LABEL_103_17 15
#define TAG_103_18 6
#define LABEL_103_20 17
#define TAG_103_21 7
#define LABEL_103_22 19
#define TAG_103_23 8
#define LABEL_103_24 21
#define TAG_103_25 9
#define LABEL_103_26 23
#define TAG_103_27 10
#define LABEL_103_28 25
#define LABEL_103_29 27
#define LABEL_103_31 29
#define ENVIRONMENT_LABEL_103_3 45
#define DEBUGGING_LABEL_103_2 44
#define OBJECT_103_2 43
#define OBJECT_103_1 42
#define OBJECT_103_0 41
#define EXECUTE_CACHE_103_30 31
#define EXECUTE_CACHE_103_19 33
#define EXECUTE_CACHE_103_14 35
#define EXECUTE_CACHE_103_9 37
#define FREE_REFERENCE_103_0 40
#define FREE_REFERENCES_LABEL_103_0 30
#define NUMBER_OF_LINKER_SECTIONS_103_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_103 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd22;
  machine_word Wrd30;
  machine_word Wrd34;
  machine_word Wrd31;
  machine_word Wrd24;
  machine_word Wrd19;
  machine_word Wrd20;
  machine_word Wrd21;
  machine_word Wrd25;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd26;
  machine_word Wrd9;
  machine_word Wrd10;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd16;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd11;
  machine_word Wrd12;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd5;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_103_4);
      goto lp_product_comment_list_21;

    case 1:
      current_block = (Rpc - LABEL_103_5);
      goto lambda_26;

    case 2:
      current_block = (Rpc - LABEL_103_7);
      goto lambda_27;

    case 3:
      current_block = (Rpc - LABEL_103_10);
      goto loop_0_15;

    case 4:
      current_block = (Rpc - LABEL_103_12);
      goto lambda_29;

    case 5:
      current_block = (Rpc - LABEL_103_15);
      goto lambda_30;

    case 6:
      current_block = (Rpc - LABEL_103_17);
      goto lambda_31;

    case 7:
      current_block = (Rpc - LABEL_103_20);
      goto lambda_32;

    case 8:
      current_block = (Rpc - LABEL_103_22);
      goto lambda_33;

    case 9:
      current_block = (Rpc - LABEL_103_24);
      goto lambda_34;

    case 10:
      current_block = (Rpc - LABEL_103_26);
      goto lambda_35;

    case 11:
      current_block = (Rpc - LABEL_103_28);
      goto continuation_10;

    case 12:
      current_block = (Rpc - LABEL_103_29);
      goto continuation_9;

    case 13:
      current_block = (Rpc - LABEL_103_31);
      goto label_23;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lp_product_comment_list_25)
DEFLABEL (lp_product_comment_list_21)
  INTERRUPT_CHECK (26, LABEL_103_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd6.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_103_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_103_5])));
  Rhp += 1;
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd6.pObj)));
  Wrd7 = Wrd6;
  (Wrd8.Obj) = (Rsp [1]);
  ((Wrd7.pObj) [2]) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (Rsp [2]) = (Wrd5.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd12.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_103_8);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_103_7])));
  Rhp += 3;
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd12.pObj)));
  Wrd17 = Wrd12;
  (Wrd18.Obj) = (Rsp [3]);
  ((Wrd17.pObj) [2]) = (Wrd18.Obj);
  (Wrd16.Obj) = (Rsp [1]);
  ((Wrd17.pObj) [3]) = (Wrd16.Obj);
  ((Wrd17.pObj) [4]) = (Wrd5.Obj);
  (Rsp [3]) = (Wrd11.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_103_9]));

DEFLABEL (lambda_26)
  CLOSURE_HEADER (LABEL_103_5);

DEFLABEL (lambda_17)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd16.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_103_11);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_103_10])));
  Rhp += 2;
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd16.pObj)));
  (* (--Rsp)) = (Wrd17.Obj);
  Wrd12 = Wrd16;
  (Wrd13.Obj) = (Rsp [1]);
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [2]);
  ((Wrd12.pObj) [2]) = (Wrd15.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  ((Wrd12.pObj) [3]) = (Wrd10.Obj);
  Rsp = (& (Rsp [1]));
  (Rsp [0]) = (Wrd17.Obj);
  (Wrd7.Obj) = (current_block [OBJECT_103_0]);
  (Rsp [2]) = (Wrd7.Obj);
  goto loop_0_15;

DEFLABEL (lambda_27)
  CLOSURE_HEADER (LABEL_103_7);

DEFLABEL (lambda_19)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [4]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = ((Wrd6.pObj) [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd13.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_103_13);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_103_12])));
  Rhp += 1;
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd13.pObj)));
  Wrd14 = Wrd13;
  (Wrd17.Obj) = ((Wrd6.pObj) [2]);
  ((Wrd14.pObj) [2]) = (Wrd17.Obj);
  (Rsp [2]) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_103_14]));

DEFLABEL (loop_0_28)
DEFLABEL (loop_0_15)
  INTERRUPT_CHECK (26, LABEL_103_10);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd6.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_103_16);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_103_15])));
  Rhp += 2;
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd6.pObj)));
  Wrd9 = Wrd6;
  (Wrd10.Obj) = (Rsp [0]);
  ((Wrd9.pObj) [2]) = (Wrd10.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  ((Wrd9.pObj) [3]) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 9));
  (Wrd13.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_103_18);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_103_17])));
  Rhp += 6;
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd13.pObj)));
  Wrd26 = Wrd13;
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd29.Obj) = ((Wrd28.pObj) [2]);
  ((Wrd26.pObj) [2]) = (Wrd29.Obj);
  (Wrd25.Obj) = ((Wrd28.pObj) [3]);
  ((Wrd26.pObj) [3]) = (Wrd25.Obj);
  (Wrd21.Obj) = (Rsp [4]);
  ((Wrd26.pObj) [4]) = (Wrd21.Obj);
  ((Wrd26.pObj) [5]) = (Wrd8.Obj);
  (Wrd17.Obj) = (Rsp [2]);
  ((Wrd26.pObj) [6]) = (Wrd17.Obj);
  ((Wrd26.pObj) [7]) = (Wrd5.Obj);
  (Rsp [4]) = (Wrd12.Obj);
  (Rsp [3]) = (Wrd5.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_103_19]));

DEFLABEL (lambda_29)
  CLOSURE_HEADER (LABEL_103_12);

DEFLABEL (lambda_18)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (lambda_30)
  CLOSURE_HEADER (LABEL_103_15);

DEFLABEL (lambda_7)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd6.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_103_21);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_103_20])));
  Rhp += 3;
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd6.pObj)));
  Wrd13 = Wrd6;
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [2]);
  ((Wrd13.pObj) [2]) = (Wrd16.Obj);
  (Wrd12.Obj) = ((Wrd15.pObj) [3]);
  ((Wrd13.pObj) [3]) = (Wrd12.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  ((Wrd13.pObj) [4]) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (Rsp [3]) = (Wrd5.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd20.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_103_23);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_103_22])));
  Rhp += 3;
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd20.pObj)));
  Wrd25 = Wrd20;
  (Wrd26.Obj) = (Rsp [4]);
  ((Wrd25.pObj) [2]) = (Wrd26.Obj);
  (Wrd24.Obj) = (Rsp [2]);
  ((Wrd25.pObj) [3]) = (Wrd24.Obj);
  ((Wrd25.pObj) [4]) = (Wrd5.Obj);
  (Rsp [4]) = (Wrd19.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_103_9]));

DEFLABEL (lambda_31)
  CLOSURE_HEADER (LABEL_103_17);

DEFLABEL (lambda_13)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (current_block [OBJECT_103_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd8.Obj) = ((Wrd7.pObj) [6]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = ((Wrd7.pObj) [7]);
  (* (--Rsp)) = (Wrd11.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 8));
  (Wrd14.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_103_25);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_103_24])));
  Rhp += 5;
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd14.pObj)));
  Wrd31 = Wrd14;
  (Wrd34.Obj) = ((Wrd7.pObj) [2]);
  ((Wrd31.pObj) [2]) = (Wrd34.Obj);
  (Wrd30.Obj) = ((Wrd7.pObj) [3]);
  ((Wrd31.pObj) [3]) = (Wrd30.Obj);
  (Wrd26.Obj) = ((Wrd7.pObj) [4]);
  ((Wrd31.pObj) [4]) = (Wrd26.Obj);
  (Wrd22.Obj) = ((Wrd7.pObj) [5]);
  ((Wrd31.pObj) [5]) = (Wrd22.Obj);
  ((Wrd31.pObj) [6]) = (Wrd8.Obj);
  (Rsp [3]) = (Wrd13.Obj);
  goto lambda_7;

DEFLABEL (lambda_32)
  CLOSURE_HEADER (LABEL_103_20);

DEFLABEL (lambda_3)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [4]);
  (Wrd11.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (Wrd17.Obj) = ((Wrd9.pObj) [3]);
  (* (Rhp++)) = (Wrd17.Obj);
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd14.pObj) = (& (Rhp [-2]));
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd14.pObj)));
  (Rsp [2]) = (Wrd12.Obj);
  (Wrd18.Obj) = ((Wrd9.pObj) [2]);
  (Rsp [0]) = (Wrd18.Obj);
  goto loop_0_15;

DEFLABEL (lambda_33)
  CLOSURE_HEADER (LABEL_103_22);

DEFLABEL (lambda_5)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [4]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = ((Wrd6.pObj) [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd13.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_103_27);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_103_26])));
  Rhp += 1;
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd13.pObj)));
  Wrd14 = Wrd13;
  (Wrd17.Obj) = ((Wrd6.pObj) [2]);
  ((Wrd14.pObj) [2]) = (Wrd17.Obj);
  (Rsp [2]) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_103_14]));

DEFLABEL (lambda_34)
  CLOSURE_HEADER (LABEL_103_24);

DEFLABEL (lambda_12)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_103_28]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_103_29]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd14.Obj) = (Rsp [2]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [3]);
  (Wrd19.Obj) = ((Wrd15.pObj) [5]);
  (* (Rhp++)) = (Wrd16.Obj);
  (* (Rhp++)) = (Wrd19.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_103_30]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_103_29);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_103_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_37;
  Wrd5 = Wrd9;

DEFLABEL (label_36)
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_103_2]), 2);

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_103_28);
  (Wrd9.Obj) = (current_block [OBJECT_103_1]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [6]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd15.Obj) = ((Wrd11.pObj) [2]);
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = ((Wrd11.pObj) [4]);
  (Rsp [3]) = (Wrd16.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (label_37)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_103_31])), (Wrd6.pObj));

DEFLABEL (label_23)
  (Wrd5.Obj) = Rvl;
  goto label_36;

DEFLABEL (lambda_35)
  CLOSURE_HEADER (LABEL_103_26);

DEFLABEL (lambda_4)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_104_4 3
#define LABEL_104_6 5
#define LABEL_104_7 7
#define LABEL_104_8 9
#define LABEL_104_5 11
#define LABEL_104_11 13
#define LABEL_104_10 15
#define LABEL_104_12 17
#define LABEL_104_13 19
#define TAG_104_14 8
#define LABEL_104_16 21
#define ENVIRONMENT_LABEL_104_3 38
#define DEBUGGING_LABEL_104_2 37
#define OBJECT_104_3 36
#define OBJECT_104_2 35
#define OBJECT_104_1 34
#define OBJECT_104_0 33
#define EXECUTE_CACHE_104_17 23
#define EXECUTE_CACHE_104_15 25
#define EXECUTE_CACHE_104_9 27
#define FREE_REFERENCE_104_2 30
#define FREE_REFERENCE_104_1 31
#define FREE_REFERENCE_104_0 32
#define FREE_REFERENCES_LABEL_104_0 22
#define NUMBER_OF_LINKER_SECTIONS_104_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_104 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd16;
  machine_word Wrd22;
  machine_word Wrd11;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd20;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd21;
  machine_word Wrd14;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd8;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_104_4);
      goto write_product_comment_list_8;

    case 1:
      current_block = (Rpc - LABEL_104_6);
      goto label_10;

    case 2:
      current_block = (Rpc - LABEL_104_7);
      goto label_11;

    case 3:
      current_block = (Rpc - LABEL_104_8);
      goto label_12;

    case 4:
      current_block = (Rpc - LABEL_104_5);
      goto continuation_0;

    case 5:
      current_block = (Rpc - LABEL_104_11);
      goto label_13;

    case 6:
      current_block = (Rpc - LABEL_104_10);
      goto continuation_3;

    case 7:
      current_block = (Rpc - LABEL_104_12);
      goto label_14;

    case 8:
      current_block = (Rpc - LABEL_104_13);
      goto lambda_17;

    case 9:
      current_block = (Rpc - LABEL_104_16);
      goto continuation_4;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (write_product_comment_list_16)
DEFLABEL (write_product_comment_list_8)
  INTERRUPT_CHECK (26, LABEL_104_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_104_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_104_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_28;
  Wrd8 = Wrd12;

DEFLABEL (label_27)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_104_1]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_26;
  Wrd14 = Wrd18;

DEFLABEL (label_25)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd21.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_104_2]));
  (Wrd24.Obj) = ((Wrd21.pObj) [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd25.uLng) == 50)
    goto label_24;
  Wrd20 = Wrd24;

DEFLABEL (label_23)
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_104_9]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_104_5);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_18;
  Rvl = (current_block [OBJECT_104_1]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_18)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_104_10]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_22;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (* (--Rsp)) = (Wrd15.Obj);

DEFLABEL (label_21)
  (Wrd22.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd22.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_104_10);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_20;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [1]);

DEFLABEL (label_19)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd16.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_104_14);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_104_13])));
  Rhp += 2;
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd16.pObj)));
  Wrd19 = Wrd16;
  (Wrd20.Obj) = (Rsp [2]);
  ((Wrd19.pObj) [2]) = (Wrd20.Obj);
  (Wrd18.Obj) = (Rsp [0]);
  ((Wrd19.pObj) [3]) = (Wrd18.Obj);
  (Rsp [1]) = (Wrd15.Obj);
  (Rsp [2]) = (Wrd5.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_104_15]));

DEFLABEL (label_20)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_104_12]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_104_2]), 1);

DEFLABEL (label_14)
  (Wrd5.Obj) = Rvl;
  goto label_19;

DEFLABEL (label_22)
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_104_11]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_104_0]), 1);

DEFLABEL (label_13)
  (* (--Rsp)) = Rvl;
  goto label_21;

DEFLABEL (label_24)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_104_8])), (Wrd21.pObj));

DEFLABEL (label_12)
  (Wrd20.Obj) = Rvl;
  goto label_23;

DEFLABEL (label_26)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_104_7])), (Wrd15.pObj));

DEFLABEL (label_11)
  (Wrd14.Obj) = Rvl;
  goto label_25;

DEFLABEL (label_28)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_104_6])), (Wrd9.pObj));

DEFLABEL (label_10)
  (Wrd8.Obj) = Rvl;
  goto label_27;

DEFLABEL (lambda_17)
  CLOSURE_HEADER (LABEL_104_13);

DEFLABEL (lambda_5)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_104_16]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_104_3]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_104_17]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_104_16);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = ((Wrd6.pObj) [2]);
  (Wrd11.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd11.Obj);
  (Rsp [2]) = (Wrd8.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_105_4 3
#define LABEL_105_5 5
#define TAG_105_6 1
#define LABEL_105_9 7
#define LABEL_105_7 9
#define LABEL_105_10 11
#define LABEL_105_12 13
#define TAG_105_13 5
#define ENVIRONMENT_LABEL_105_3 30
#define DEBUGGING_LABEL_105_2 29
#define OBJECT_105_3 28
#define OBJECT_105_2 27
#define OBJECT_105_1 26
#define OBJECT_105_0 25
#define EXECUTE_CACHE_105_16 15
#define EXECUTE_CACHE_105_15 17
#define EXECUTE_CACHE_105_14 19
#define EXECUTE_CACHE_105_11 21
#define EXECUTE_CACHE_105_8 23
#define FREE_REFERENCES_LABEL_105_0 14
#define NUMBER_OF_LINKER_SECTIONS_105_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_105 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd51;
  machine_word Wrd35;
  machine_word Wrd17;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd65;
  machine_word Wrd64;
  machine_word Wrd61;
  machine_word Wrd56;
  machine_word Wrd55;
  machine_word Wrd54;
  machine_word Wrd53;
  machine_word Wrd52;
  machine_word Wrd5;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd19;
  machine_word Wrd15;
  machine_word Wrd16;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd8;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_105_4);
      goto string__tokens_15;

    case 1:
      current_block = (Rpc - LABEL_105_5);
      goto lambda_20;

    case 2:
      current_block = (Rpc - LABEL_105_9);
      goto label_17;

    case 3:
      current_block = (Rpc - LABEL_105_7);
      goto continuation_0;

    case 4:
      current_block = (Rpc - LABEL_105_10);
      goto continuation_10;

    case 5:
      current_block = (Rpc - LABEL_105_12);
      goto lambda_21;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (string__tokens_19)
DEFLABEL (string__tokens_15)
  INTERRUPT_CHECK (26, LABEL_105_4);
  (Wrd8.Obj) = (current_block [OBJECT_105_0]);
  (* (Rhp++)) = (Wrd8.Obj);
  (Wrd6.pObj) = (& (Rhp [-1]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd6.pObj)));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (Rhp++)) = (Wrd8.Obj);
  (Wrd10.pObj) = (& (Rhp [-1]));
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (54, (Wrd10.pObj)));
  (* (--Rsp)) = (Wrd11.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd16.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x102, 2);
  (* (Rhp++)) = (dispatch_base + TAG_105_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_105_5])));
  Rhp += 2;
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd16.pObj)));
  Wrd19 = Wrd16;
  ((Wrd19.pObj) [2]) = (Wrd7.Obj);
  ((Wrd19.pObj) [3]) = (Wrd11.Obj);
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_105_7]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd24.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd24.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_105_8]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_105_7);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_105_10]))));
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_105_11]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_105_10);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x102, 2);
  (* (Rhp++)) = (dispatch_base + TAG_105_13);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_105_12])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  ((Wrd7.pObj) [2]) = Rvl;
  Rsp = (& (Rsp [1]));
  (Rsp [2]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_105_14]));

DEFLABEL (lambda_20)
  CLOSURE_HEADER (LABEL_105_5);

DEFLABEL (lambda_8)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  if ((Wrd5.Obj) == (current_block [OBJECT_105_1]))
    goto label_26;
  (Wrd11.Obj) = (current_block [OBJECT_105_0]);
  (* (Rhp++)) = (Wrd5.Obj);
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = (Rsp [1]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [2]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 1)
    goto label_24;
  (Wrd20.Obj) = ((Wrd13.pObj) [3]);
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  ((Wrd21.pObj) [0]) = (Wrd9.Obj);

DEFLABEL (label_23)
  (Wrd23.Obj) = (Rsp [1]);
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd25.Obj) = ((Wrd24.pObj) [2]);
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd27.Obj) = (Rsp [0]);
  ((Wrd26.pObj) [0]) = (Wrd27.Obj);
  Rvl = (current_block [OBJECT_105_3]);

DEFLABEL (label_22)
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_24)
  if (! ((Wrd17.uLng) == 1))
    goto label_25;
  (Wrd35.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  ((Wrd35.pObj) [1]) = (Wrd9.Obj);
  goto label_23;

DEFLABEL (label_25)
  (Wrd51.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_105_9]))));
  (* (--Rsp)) = (Wrd51.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_105_2]), 2);

DEFLABEL (label_17)
  goto label_23;

DEFLABEL (label_26)
  (Wrd52.Obj) = (Rsp [0]);
  (Wrd53.pObj) = (OBJECT_ADDRESS (Wrd52.Obj));
  (Wrd54.Obj) = ((Wrd53.pObj) [3]);
  (Wrd55.pObj) = (OBJECT_ADDRESS (Wrd54.Obj));
  (Wrd56.Obj) = ((Wrd55.pObj) [0]);
  (* (--Rsp)) = (Wrd56.Obj);
  (Wrd61.Obj) = (current_block [OBJECT_105_0]);
  ((Wrd55.pObj) [0]) = (Wrd61.Obj);
  (Wrd64.Obj) = ((Wrd53.pObj) [2]);
  (Wrd65.pObj) = (OBJECT_ADDRESS (Wrd64.Obj));
  ((Wrd65.pObj) [0]) = (Wrd61.Obj);
  Rvl = (Wrd56.Obj);
  goto label_22;

DEFLABEL (lambda_21)
  CLOSURE_HEADER (LABEL_105_12);

DEFLABEL (lambda_13)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  if ((Wrd5.Obj) == (current_block [OBJECT_105_1]))
    goto label_27;
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  (Rsp [1]) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_105_16]));

DEFLABEL (label_27)
  (Wrd12.Obj) = (Rsp [0]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd11.Obj) = ((Wrd13.pObj) [2]);
  (Rsp [1]) = (Wrd11.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_105_15]));

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_106_4 3
#define LABEL_106_5 5
#define LABEL_106_7 7
#define LABEL_106_8 9
#define LABEL_106_9 11
#define LABEL_106_10 13
#define LABEL_106_11 15
#define LABEL_106_12 17
#define LABEL_106_13 19
#define LABEL_106_14 21
#define LABEL_106_17 23
#define TAG_106_18 10
#define LABEL_106_15 25
#define LABEL_106_19 27
#define LABEL_106_22 29
#define LABEL_106_24 31
#define LABEL_106_29 33
#define LABEL_106_30 35
#define LABEL_106_26 37
#define TAG_106_27 17
#define LABEL_106_31 39
#define LABEL_106_32 41
#define ENVIRONMENT_LABEL_106_3 66
#define DEBUGGING_LABEL_106_2 65
#define OBJECT_106_7 64
#define OBJECT_106_6 63
#define OBJECT_106_5 62
#define OBJECT_106_4 61
#define OBJECT_106_3 60
#define OBJECT_106_2 59
#define OBJECT_106_1 58
#define OBJECT_106_0 57
#define EXECUTE_CACHE_106_28 43
#define EXECUTE_CACHE_106_25 45
#define EXECUTE_CACHE_106_23 47
#define EXECUTE_CACHE_106_21 49
#define EXECUTE_CACHE_106_20 51
#define EXECUTE_CACHE_106_16 53
#define EXECUTE_CACHE_106_6 55
#define FREE_REFERENCES_LABEL_106_0 42
#define NUMBER_OF_LINKER_SECTIONS_106_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_106 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd58;
  machine_word Wrd67;
  machine_word Wrd73;
  machine_word Wrd53;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd15;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd24;
  machine_word Wrd48;
  machine_word Wrd41;
  machine_word Wrd22;
  machine_word Wrd23;
  machine_word Wrd34;
  machine_word Wrd30;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd21;
  machine_word Wrd11;
  machine_word Wrd12;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd47;
  machine_word Wrd76;
  machine_word Wrd70;
  machine_word Wrd71;
  machine_word Wrd72;
  machine_word Wrd69;
  machine_word Wrd61;
  machine_word Wrd63;
  machine_word Wrd65;
  machine_word Wrd64;
  machine_word Wrd82;
  machine_word Wrd81;
  machine_word Wrd78;
  machine_word Wrd90;
  machine_word Wrd89;
  machine_word Wrd88;
  machine_word Wrd86;
  machine_word Wrd84;
  machine_word Wrd92;
  machine_word Wrd91;
  machine_word Wrd59;
  machine_word Wrd52;
  machine_word Wrd55;
  machine_word Wrd49;
  machine_word Wrd44;
  machine_word Wrd43;
  machine_word Wrd42;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd33;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd29;
  machine_word Wrd26;
  machine_word Wrd18;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_106_4);
      goto make_state_29;

    case 1:
      current_block = (Rpc - LABEL_106_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_106_7);
      goto continuation_7;

    case 3:
      current_block = (Rpc - LABEL_106_8);
      goto do_loop_20;

    case 4:
      current_block = (Rpc - LABEL_106_9);
      goto label_31;

    case 5:
      current_block = (Rpc - LABEL_106_10);
      goto label_32;

    case 6:
      current_block = (Rpc - LABEL_106_11);
      goto label_33;

    case 7:
      current_block = (Rpc - LABEL_106_12);
      goto label_34;

    case 8:
      current_block = (Rpc - LABEL_106_13);
      goto label_35;

    case 9:
      current_block = (Rpc - LABEL_106_14);
      goto label_36;

    case 10:
      current_block = (Rpc - LABEL_106_17);
      goto lambda_44;

    case 11:
      current_block = (Rpc - LABEL_106_15);
      goto continuation_9;

    case 12:
      current_block = (Rpc - LABEL_106_19);
      goto continuation_22;

    case 13:
      current_block = (Rpc - LABEL_106_22);
      goto continuation_15;

    case 14:
      current_block = (Rpc - LABEL_106_24);
      goto continuation_23;

    case 15:
      current_block = (Rpc - LABEL_106_29);
      goto label_37;

    case 16:
      current_block = (Rpc - LABEL_106_30);
      goto label_38;

    case 17:
      current_block = (Rpc - LABEL_106_26);
      goto lambda_45;

    case 18:
      current_block = (Rpc - LABEL_106_31);
      goto label_39;

    case 19:
      current_block = (Rpc - LABEL_106_32);
      goto label_40;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (make_state_42)
DEFLABEL (make_state_29)
  INTERRUPT_CHECK (26, LABEL_106_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_106_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_106_0]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_106_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_106_5);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd5.Obj);
  goto do_loop_20;

DEFLABEL (do_loop_43)
DEFLABEL (do_loop_20)
  INTERRUPT_CHECK (26, LABEL_106_8);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_46;
  Rsp = (& (Rsp [1]));
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd10.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_106_18);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_106_17])));
  Rhp += 2;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd10.pObj)));
  Wrd13 = Wrd10;
  (Wrd14.Obj) = (Rsp [1]);
  ((Wrd13.pObj) [2]) = (Wrd14.Obj);
  (Wrd12.Obj) = (Rsp [0]);
  ((Wrd13.pObj) [3]) = (Wrd12.Obj);
  Rvl = (Wrd9.Obj);
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_46)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_106_7]))));
  (* (--Rsp)) = (Wrd17.Obj);
  if (! ((Wrd6.uLng) == 1))
    goto label_63;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd18.Obj) = ((Wrd20.pObj) [1]);

DEFLABEL (label_62)
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd29.uLng) == 1))
    goto label_61;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [0]);
  (* (--Rsp)) = (Wrd28.Obj);

DEFLABEL (label_60)
  (Wrd37.Obj) = (Rsp [2]);
  (Wrd38.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if (! ((Wrd38.uLng) == 1))
    goto label_59;
  (Wrd35.pObj) = (OBJECT_ADDRESS (Wrd37.Obj));
  (Wrd36.Obj) = ((Wrd35.pObj) [0]);
  (* (--Rsp)) = (Wrd36.Obj);

DEFLABEL (label_58)
  (Wrd43.Obj) = (Rsp [0]);
  (Wrd44.uLng) = (OBJECT_TYPE (Wrd43.Obj));
  if ((Wrd44.uLng) == 2)
    goto label_48;
  (Wrd47.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_106_15]))));
  (* (--Rsp)) = (Wrd47.Obj);
  (* (--Rsp)) = (Wrd43.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_106_16]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_106_15);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_47;
  (Wrd11.Obj) = (current_block [OBJECT_106_5]);
  (Rsp [1]) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_106_21]));

DEFLABEL (label_47)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_106_22]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_106_23]));

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_106_22);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_106_27);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_106_26])));
  Rhp += 3;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd12 = Wrd7;
  (Wrd13.Obj) = (Rsp [6]);
  ((Wrd12.pObj) [2]) = (Wrd13.Obj);
  (Wrd11.Obj) = (Rsp [4]);
  ((Wrd12.pObj) [3]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [1]);
  ((Wrd12.pObj) [4]) = (Wrd9.Obj);
  (Rsp [0]) = (Wrd6.Obj);
  (Rsp [1]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_106_28]));

DEFLABEL (label_48)
  (Wrd49.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd49.Obj);
  if (! ((Wrd44.uLng) == 2))
    goto label_57;
  (Wrd55.uLng) = (OBJECT_DATUM (Wrd43.Obj));
  (Wrd52.Obj) = (MAKE_OBJECT (26, (Wrd55.uLng)));

DEFLABEL (label_56)
  (Rsp [1]) = (Wrd52.Obj);
  (Wrd91.Obj) = (Rsp [0]);
  (Wrd92.uLng) = (OBJECT_TYPE (Wrd91.Obj));
  if ((Wrd92.uLng) == 10)
    goto label_50;

DEFLABEL (label_49)
  INVOKE_PRIMITIVE ((current_block [OBJECT_106_4]), 3);

DEFLABEL (label_50)
  (Wrd84.uLng) = (OBJECT_TYPE (Wrd52.Obj));
  if (! ((Wrd84.uLng) == 26))
    goto label_49;
  (Wrd86.Lng) = (FIXNUM_TO_LONG (Wrd52.Obj));
  (Wrd88.pObj) = (OBJECT_ADDRESS (Wrd91.Obj));
  (Wrd89.Obj) = ((Wrd88.pObj) [0]);
  (Wrd90.Lng) = (FIXNUM_TO_LONG (Wrd89.Obj));
  if (! (((unsigned long) (Wrd86.Lng)) < ((unsigned long) (Wrd90.Lng))))
    goto label_49;
  (Wrd78.uLng) = (OBJECT_DATUM (Wrd52.Obj));
  (Wrd81.pObj) = (& ((Wrd88.pObj) [(Wrd78.Lng)]));
  (Wrd82.Obj) = (Rsp [2]);
  ((Wrd81.pObj) [1]) = (Wrd82.Obj);
  Rsp = (& (Rsp [4]));

DEFLABEL (label_55)
  (Wrd64.Obj) = (Rsp [0]);
  (Wrd65.uLng) = (OBJECT_TYPE (Wrd64.Obj));
  if (! ((Wrd65.uLng) == 1))
    goto label_54;
  (Wrd63.pObj) = (OBJECT_ADDRESS (Wrd64.Obj));
  (Wrd61.Obj) = ((Wrd63.pObj) [1]);

DEFLABEL (label_53)
  (Wrd72.uLng) = (OBJECT_TYPE (Wrd61.Obj));
  if (! ((Wrd72.uLng) == 1))
    goto label_52;
  (Wrd71.pObj) = (OBJECT_ADDRESS (Wrd61.Obj));
  (Wrd70.Obj) = ((Wrd71.pObj) [1]);

DEFLABEL (label_51)
  (Rsp [0]) = (Wrd70.Obj);
  goto do_loop_20;

DEFLABEL (label_52)
  (Wrd76.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_106_14]))));
  (* (--Rsp)) = (Wrd76.Obj);
  (* (--Rsp)) = (Wrd61.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_106_1]), 1);

DEFLABEL (label_36)
  (Wrd70.Obj) = Rvl;
  goto label_51;

DEFLABEL (label_54)
  (Wrd69.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_106_13]))));
  (* (--Rsp)) = (Wrd69.Obj);
  (* (--Rsp)) = (Wrd64.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_106_1]), 1);

DEFLABEL (label_35)
  (Wrd61.Obj) = Rvl;
  goto label_53;

DEFLABEL (label_57)
  (Wrd59.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_106_12]))));
  (* (--Rsp)) = (Wrd59.Obj);
  (* (--Rsp)) = (Wrd43.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_106_3]), 1);

DEFLABEL (label_34)
  (Wrd52.Obj) = Rvl;
  goto label_56;

DEFLABEL (label_59)
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_106_11]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_106_2]), 1);

DEFLABEL (label_33)
  (* (--Rsp)) = Rvl;
  goto label_58;

DEFLABEL (label_61)
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_106_10]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_106_2]), 1);

DEFLABEL (label_32)
  (* (--Rsp)) = Rvl;
  goto label_60;

DEFLABEL (label_63)
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_106_9]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_106_1]), 1);

DEFLABEL (label_31)
  (Wrd18.Obj) = Rvl;
  goto label_62;

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_106_7);
  goto label_55;

DEFLABEL (lambda_44)
  CLOSURE_HEADER (LABEL_106_17);

DEFLABEL (lambda_27)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_106_19]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_106_20]));

DEFLABEL (continuation_22)
  INTERRUPT_CHECK (27, LABEL_106_19);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_106_24]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_106_25]));

DEFLABEL (continuation_23)
  INTERRUPT_CHECK (27, LABEL_106_24);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_64;
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [2]);
  (Rsp [1]) = (Wrd7.Obj);
  Rsp = (& (Rsp [1]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (label_64)
  (Wrd11.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd13.uLng) == 2))
    goto label_68;
  (Wrd17.uLng) = (OBJECT_DATUM (Wrd11.Obj));
  (Wrd14.Obj) = (MAKE_OBJECT (26, (Wrd17.uLng)));

DEFLABEL (label_67)
  (Wrd37.Obj) = (Rsp [2]);
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd37.Obj));
  (Wrd39.Obj) = ((Wrd38.pObj) [3]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if (! ((Wrd40.uLng) == 10))
    goto label_66;
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if (! ((Wrd29.uLng) == 26))
    goto label_66;
  (Wrd30.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd39.Obj));
  (Wrd35.Obj) = ((Wrd34.pObj) [0]);
  (Wrd36.Lng) = (FIXNUM_TO_LONG (Wrd35.Obj));
  if (! (((unsigned long) (Wrd30.Lng)) < ((unsigned long) (Wrd36.Lng))))
    goto label_66;
  (Wrd23.uLng) = (OBJECT_DATUM (Wrd14.Obj));
  (Wrd28.pObj) = (& ((Wrd34.pObj) [(Wrd23.Lng)]));
  (Wrd22.Obj) = ((Wrd28.pObj) [1]);

DEFLABEL (label_65)
  (Rsp [1]) = (Wrd22.Obj);
  (Wrd48.Obj) = (* (Rsp++));
  (Rsp [1]) = (Wrd48.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 5);
  }

DEFLABEL (label_66)
  (Wrd42.Obj) = (Rsp [2]);
  (Wrd43.pObj) = (OBJECT_ADDRESS (Wrd42.Obj));
  (Wrd41.Obj) = ((Wrd43.pObj) [3]);
  (Wrd47.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_106_30]))));
  (* (--Rsp)) = (Wrd47.Obj);
  (* (--Rsp)) = (Wrd14.Obj);
  (* (--Rsp)) = (Wrd41.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_106_6]), 2);

DEFLABEL (label_38)
  (Wrd22.Obj) = Rvl;
  goto label_65;

DEFLABEL (label_68)
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_106_29]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_106_3]), 1);

DEFLABEL (label_37)
  (Wrd14.Obj) = Rvl;
  goto label_67;

DEFLABEL (lambda_45)
  CLOSURE_HEADER (LABEL_106_26);

DEFLABEL (lambda_14)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd6.uLng) == 2))
    goto label_76;
  (Wrd9.uLng) = (OBJECT_DATUM (Wrd5.Obj));
  (Wrd10.Obj) = (MAKE_OBJECT (26, (Wrd9.uLng)));
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_75)
  (Wrd33.Obj) = (Rsp [1]);
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd35.Obj) = ((Wrd34.pObj) [3]);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if (! ((Wrd36.uLng) == 10))
    goto label_74;
  (Wrd23.Obj) = (Rsp [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if (! ((Wrd24.uLng) == 26))
    goto label_74;
  (Wrd26.Lng) = (FIXNUM_TO_LONG (Wrd23.Obj));
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd31.Obj) = ((Wrd30.pObj) [0]);
  (Wrd32.Lng) = (FIXNUM_TO_LONG (Wrd31.Obj));
  if (! (((unsigned long) (Wrd26.Lng)) < ((unsigned long) (Wrd32.Lng))))
    goto label_74;
  (Wrd17.uLng) = (OBJECT_DATUM (Wrd23.Obj));
  (Wrd22.pObj) = (& ((Wrd30.pObj) [(Wrd17.Lng)]));
  (Wrd15.Obj) = ((Wrd22.pObj) [1]);

DEFLABEL (label_73)
  (Wrd44.Obj) = (Rsp [1]);
  (Wrd45.pObj) = (OBJECT_ADDRESS (Wrd44.Obj));
  (Wrd46.Obj) = ((Wrd45.pObj) [2]);
  if ((Wrd15.Obj) == (Wrd46.Obj))
    goto label_70;

DEFLABEL (label_69)
  Rvl = (current_block [OBJECT_106_7]);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_70)
  (Wrd49.Obj) = ((Wrd45.pObj) [4]);
  (Rsp [2]) = (Wrd49.Obj);
  (Wrd52.Obj) = (Rsp [0]);
  (Wrd53.Obj) = ((Wrd45.pObj) [3]);
  (Rsp [0]) = (Wrd53.Obj);
  (Rsp [1]) = (Wrd52.Obj);
  (Wrd73.uLng) = (OBJECT_TYPE (Wrd53.Obj));
  if ((Wrd73.uLng) == 10)
    goto label_72;

DEFLABEL (label_71)
  INVOKE_PRIMITIVE ((current_block [OBJECT_106_4]), 3);

DEFLABEL (label_72)
  (Wrd65.uLng) = (OBJECT_TYPE (Wrd52.Obj));
  if (! ((Wrd65.uLng) == 26))
    goto label_71;
  (Wrd67.Lng) = (FIXNUM_TO_LONG (Wrd52.Obj));
  (Wrd69.pObj) = (OBJECT_ADDRESS (Wrd53.Obj));
  (Wrd70.Obj) = ((Wrd69.pObj) [0]);
  (Wrd71.Lng) = (FIXNUM_TO_LONG (Wrd70.Obj));
  if (! (((unsigned long) (Wrd67.Lng)) < ((unsigned long) (Wrd71.Lng))))
    goto label_71;
  (Wrd58.uLng) = (OBJECT_DATUM (Wrd52.Obj));
  (Wrd61.pObj) = (& ((Wrd69.pObj) [(Wrd58.Lng)]));
  ((Wrd61.pObj) [1]) = (Wrd49.Obj);
  goto label_69;

DEFLABEL (label_74)
  (Wrd38.Obj) = (Rsp [1]);
  (Wrd39.pObj) = (OBJECT_ADDRESS (Wrd38.Obj));
  (Wrd37.Obj) = ((Wrd39.pObj) [3]);
  (Wrd40.Obj) = (Rsp [0]);
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_106_32]))));
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_106_6]), 2);

DEFLABEL (label_40)
  (Wrd15.Obj) = Rvl;
  goto label_73;

DEFLABEL (label_76)
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_106_31]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_106_3]), 1);

DEFLABEL (label_39)
  (* (--Rsp)) = Rvl;
  goto label_75;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_107_4 3
#define ENVIRONMENT_LABEL_107_3 9
#define DEBUGGING_LABEL_107_2 8
#define OBJECT_107_0 7
#define EXECUTE_CACHE_107_5 5
#define FREE_REFERENCES_LABEL_107_0 4
#define NUMBER_OF_LINKER_SECTIONS_107_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_107 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_107_4);
      goto lws_tokenP_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lws_tokenP_3)
DEFLABEL (lws_tokenP_0)
  INTERRUPT_CHECK (26, LABEL_107_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_107_0]);
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_107_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_108_4 3
#define LABEL_108_5 5
#define ENVIRONMENT_LABEL_108_3 12
#define DEBUGGING_LABEL_108_2 11
#define EXECUTE_CACHE_108_6 7
#define FREE_REFERENCE_108_0 10
#define FREE_REFERENCES_LABEL_108_0 6
#define NUMBER_OF_LINKER_SECTIONS_108_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_108 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd10;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_108_4);
      goto separator_tokenP_1;

    case 1:
      current_block = (Rpc - LABEL_108_5);
      goto label_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (separator_tokenP_5)
DEFLABEL (separator_tokenP_1)
  INTERRUPT_CHECK (26, LABEL_108_4);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 2)
    goto label_6;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_6)
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_108_0]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_8;
  Wrd9 = Wrd13;

DEFLABEL (label_7)
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_108_6]));

DEFLABEL (label_8)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_108_5])), (Wrd10.pObj));

DEFLABEL (label_3)
  (Wrd9.Obj) = Rvl;
  goto label_7;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_109_4 3
#define ENVIRONMENT_LABEL_109_3 5
#define DEBUGGING_LABEL_109_2 4
#define FREE_REFERENCES_LABEL_109_0 4
#define NUMBER_OF_LINKER_SECTIONS_109_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_109 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_109_4);
      goto separator_token__char_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (separator_token__char_3)
DEFLABEL (separator_token__char_0)
  INTERRUPT_CHECK (26, LABEL_109_4);
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_110_4 3
#define ENVIRONMENT_LABEL_110_3 6
#define DEBUGGING_LABEL_110_2 5
#define OBJECT_110_0 4
#define FREE_REFERENCES_LABEL_110_0 4
#define NUMBER_OF_LINKER_SECTIONS_110_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_110 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd7;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_110_4);
      goto token_tokenP_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (token_tokenP_3)
DEFLABEL (token_tokenP_0)
  INTERRUPT_CHECK (26, LABEL_110_4);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.uLng) = (OBJECT_TYPE (Wrd6.Obj));
  if ((Wrd7.uLng) == 30)
    goto label_5;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_4;

DEFLABEL (label_5)
  Rvl = (current_block [OBJECT_110_0]);

DEFLABEL (label_4)
DEFLABEL (label_6)
  Rsp = (& (Rsp [1]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_111_4 3
#define ENVIRONMENT_LABEL_111_3 5
#define DEBUGGING_LABEL_111_2 4
#define FREE_REFERENCES_LABEL_111_0 4
#define NUMBER_OF_LINKER_SECTIONS_111_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_111 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_111_4);
      goto token_token__string_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (token_token__string_3)
DEFLABEL (token_token__string_0)
  INTERRUPT_CHECK (26, LABEL_111_4);
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_112_4 3
#define ENVIRONMENT_LABEL_112_3 6
#define DEBUGGING_LABEL_112_2 5
#define OBJECT_112_0 4
#define FREE_REFERENCES_LABEL_112_0 4
#define NUMBER_OF_LINKER_SECTIONS_112_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_112 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd7;
  machine_word Wrd10;
  machine_word Wrd9;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_112_4);
      goto quoted_string_token__string_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (quoted_string_token__string_3)
DEFLABEL (quoted_string_token__string_0)
  INTERRUPT_CHECK (26, LABEL_112_4);
  (Wrd9.Obj) = (Rsp [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if (! ((Wrd10.uLng) == 1))
    goto label_4;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  Rvl = ((Wrd7.pObj) [1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_112_0]), 1);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_113_4 3
#define ENVIRONMENT_LABEL_113_3 6
#define DEBUGGING_LABEL_113_2 5
#define OBJECT_113_0 4
#define FREE_REFERENCES_LABEL_113_0 4
#define NUMBER_OF_LINKER_SECTIONS_113_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_113 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd7;
  machine_word Wrd10;
  machine_word Wrd9;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_113_4);
      goto comment_token__string_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (comment_token__string_3)
DEFLABEL (comment_token__string_0)
  INTERRUPT_CHECK (26, LABEL_113_4);
  (Wrd9.Obj) = (Rsp [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if (! ((Wrd10.uLng) == 1))
    goto label_4;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  Rvl = ((Wrd7.pObj) [1]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_113_0]), 1);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_114_4 3
#define LABEL_114_6 5
#define LABEL_114_8 7
#define LABEL_114_9 9
#define LABEL_114_10 11
#define LABEL_114_11 13
#define LABEL_114_12 15
#define LABEL_114_13 17
#define LABEL_114_14 19
#define LABEL_114_15 21
#define LABEL_114_16 23
#define LABEL_114_18 25
#define LABEL_114_19 27
#define LABEL_114_20 29
#define LABEL_114_22 31
#define LABEL_114_5 33
#define LABEL_114_24 35
#define LABEL_114_25 37
#define LABEL_114_17 39
#define LABEL_114_27 41
#define LABEL_114_28 43
#define LABEL_114_29 45
#define LABEL_114_26 47
#define LABEL_114_31 49
#define LABEL_114_32 51
#define LABEL_114_36 53
#define LABEL_114_34 55
#define LABEL_114_38 57
#define LABEL_114_39 59
#define LABEL_114_35 61
#define LABEL_114_42 63
#define LABEL_114_37 65
#define LABEL_114_43 67
#define LABEL_114_40 69
#define LABEL_114_47 71
#define LABEL_114_48 73
#define LABEL_114_41 75
#define LABEL_114_49 77
#define LABEL_114_45 79
#define LABEL_114_50 81
#define LABEL_114_51 83
#define LABEL_114_52 85
#define LABEL_114_53 87
#define ENVIRONMENT_LABEL_114_3 133
#define DEBUGGING_LABEL_114_2 132
#define OBJECT_114_26 131
#define OBJECT_114_25 130
#define OBJECT_114_24 129
#define OBJECT_114_23 128
#define OBJECT_114_22 127
#define OBJECT_114_21 126
#define OBJECT_114_20 125
#define OBJECT_114_19 124
#define OBJECT_114_18 123
#define OBJECT_114_17 122
#define OBJECT_114_16 121
#define OBJECT_114_15 120
#define OBJECT_114_14 119
#define OBJECT_114_13 118
#define OBJECT_114_12 117
#define OBJECT_114_11 116
#define OBJECT_114_10 115
#define OBJECT_114_9 114
#define OBJECT_114_8 113
#define OBJECT_114_7 112
#define OBJECT_114_6 111
#define OBJECT_114_5 110
#define OBJECT_114_4 109
#define OBJECT_114_3 108
#define OBJECT_114_2 107
#define OBJECT_114_1 106
#define OBJECT_114_0 105
#define EXECUTE_CACHE_114_54 89
#define EXECUTE_CACHE_114_46 91
#define EXECUTE_CACHE_114_44 93
#define EXECUTE_CACHE_114_33 95
#define EXECUTE_CACHE_114_30 97
#define EXECUTE_CACHE_114_23 99
#define EXECUTE_CACHE_114_21 101
#define EXECUTE_CACHE_114_7 103
#define FREE_REFERENCES_LABEL_114_0 88
#define NUMBER_OF_LINKER_SECTIONS_114_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_114 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd42;
  machine_word Wrd35;
  machine_word Wrd32;
  machine_word Wrd21;
  machine_word Wrd74;
  machine_word Wrd63;
  machine_word Wrd65;
  machine_word Wrd66;
  machine_word Wrd60;
  machine_word Wrd61;
  machine_word Wrd14;
  machine_word Wrd6;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd29;
  machine_word Wrd5;
  machine_word Wrd31;
  machine_word Wrd27;
  machine_word Wrd24;
  machine_word Wrd19;
  machine_word Wrd20;
  machine_word Wrd13;
  machine_word Wrd8;
  machine_word Wrd22;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd23;
  machine_word Wrd53;
  machine_word Wrd45;
  machine_word Wrd47;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd131;
  machine_word Wrd126;
  machine_word Wrd125;
  machine_word Wrd127;
  machine_word Wrd124;
  machine_word Wrd118;
  machine_word Wrd119;
  machine_word Wrd120;
  machine_word Wrd117;
  machine_word Wrd109;
  machine_word Wrd111;
  machine_word Wrd113;
  machine_word Wrd112;
  machine_word Wrd108;
  machine_word Wrd105;
  machine_word Wrd100;
  machine_word Wrd99;
  machine_word Wrd101;
  machine_word Wrd98;
  machine_word Wrd90;
  machine_word Wrd92;
  machine_word Wrd94;
  machine_word Wrd93;
  machine_word Wrd89;
  machine_word Wrd84;
  machine_word Wrd83;
  machine_word Wrd85;
  machine_word Wrd82;
  machine_word Wrd76;
  machine_word Wrd77;
  machine_word Wrd78;
  machine_word Wrd75;
  machine_word Wrd67;
  machine_word Wrd69;
  machine_word Wrd71;
  machine_word Wrd70;
  machine_word Wrd64;
  machine_word Wrd62;
  machine_word Wrd54;
  machine_word Wrd56;
  machine_word Wrd58;
  machine_word Wrd57;
  machine_word Wrd43;
  machine_word Wrd37;
  machine_word Wrd38;
  machine_word Wrd39;
  machine_word Wrd36;
  machine_word Wrd28;
  machine_word Wrd30;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_114_4);
      goto lambda_70;

    case 1:
      current_block = (Rpc - LABEL_114_6);
      goto label_72;

    case 2:
      current_block = (Rpc - LABEL_114_8);
      goto loop_12;

    case 3:
      current_block = (Rpc - LABEL_114_9);
      goto label_75;

    case 4:
      current_block = (Rpc - LABEL_114_10);
      goto label_76;

    case 5:
      current_block = (Rpc - LABEL_114_11);
      goto label_78;

    case 6:
      current_block = (Rpc - LABEL_114_12);
      goto label_79;

    case 7:
      current_block = (Rpc - LABEL_114_13);
      goto label_80;

    case 8:
      current_block = (Rpc - LABEL_114_14);
      goto label_81;

    case 9:
      current_block = (Rpc - LABEL_114_15);
      goto label_82;

    case 10:
      current_block = (Rpc - LABEL_114_16);
      goto label_83;

    case 11:
      current_block = (Rpc - LABEL_114_18);
      goto label_84;

    case 12:
      current_block = (Rpc - LABEL_114_19);
      goto label_85;

    case 13:
      current_block = (Rpc - LABEL_114_20);
      goto label_86;

    case 14:
      current_block = (Rpc - LABEL_114_22);
      goto label_77;

    case 15:
      current_block = (Rpc - LABEL_114_5);
      goto continuation_1;

    case 16:
      current_block = (Rpc - LABEL_114_24);
      goto label_73;

    case 17:
      current_block = (Rpc - LABEL_114_25);
      goto label_74;

    case 18:
      current_block = (Rpc - LABEL_114_17);
      goto continuation_26;

    case 19:
      current_block = (Rpc - LABEL_114_27);
      goto label_87;

    case 20:
      current_block = (Rpc - LABEL_114_28);
      goto label_88;

    case 21:
      current_block = (Rpc - LABEL_114_29);
      goto label_89;

    case 22:
      current_block = (Rpc - LABEL_114_26);
      goto continuation_22;

    case 23:
      current_block = (Rpc - LABEL_114_31);
      goto continuation_34;

    case 24:
      current_block = (Rpc - LABEL_114_32);
      goto lambda_33;

    case 25:
      current_block = (Rpc - LABEL_114_36);
      goto continuation_28;

    case 26:
      current_block = (Rpc - LABEL_114_34);
      goto continuation_29;

    case 27:
      current_block = (Rpc - LABEL_114_38);
      goto compile_rhs_64;

    case 28:
      current_block = (Rpc - LABEL_114_39);
      goto label_90;

    case 29:
      current_block = (Rpc - LABEL_114_35);
      goto continuation_31;

    case 30:
      current_block = (Rpc - LABEL_114_42);
      goto label_91;

    case 31:
      current_block = (Rpc - LABEL_114_37);
      goto continuation_27;

    case 32:
      current_block = (Rpc - LABEL_114_43);
      goto state__name_68;

    case 33:
      current_block = (Rpc - LABEL_114_40);
      goto continuation_60;

    case 34:
      current_block = (Rpc - LABEL_114_47);
      goto continuation_54;

    case 35:
      current_block = (Rpc - LABEL_114_48);
      goto continuation_51;

    case 36:
      current_block = (Rpc - LABEL_114_41);
      goto continuation_48;

    case 37:
      current_block = (Rpc - LABEL_114_49);
      goto label_92;

    case 38:
      current_block = (Rpc - LABEL_114_45);
      goto continuation_42;

    case 39:
      current_block = (Rpc - LABEL_114_50);
      goto continuation_47;

    case 40:
      current_block = (Rpc - LABEL_114_51);
      goto continuation_46;

    case 41:
      current_block = (Rpc - LABEL_114_52);
      goto continuation_41;

    case 42:
      current_block = (Rpc - LABEL_114_53);
      goto compile_action_67;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_94)
DEFLABEL (lambda_70)
  INTERRUPT_CHECK (26, LABEL_114_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd12.uLng) == 1))
    goto label_107;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [1]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_106)
  (Wrd17.Obj) = (current_block [OBJECT_114_1]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_114_7]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_114_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_101;

DEFLABEL (label_100)
  (Wrd23.Obj) = (Rsp [0]);
  (Rsp [1]) = (Wrd23.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_114_23]));

DEFLABEL (label_101)
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_105;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_104)
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_103;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [1]);
  (* (--Rsp)) = (Wrd17.Obj);

DEFLABEL (label_102)
  goto loop_12;

DEFLABEL (label_103)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_25]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_114_0]), 1);

DEFLABEL (label_74)
  (* (--Rsp)) = Rvl;
  goto label_102;

DEFLABEL (label_105)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_24]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_114_0]), 1);

DEFLABEL (label_73)
  (Wrd7.Obj) = Rvl;
  goto label_104;

DEFLABEL (label_107)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_6]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_114_0]), 1);

DEFLABEL (label_72)
  (* (--Rsp)) = Rvl;
  goto label_106;

DEFLABEL (loop_95)
DEFLABEL (loop_12)
  INTERRUPT_CHECK (26, LABEL_114_8);
  (Wrd25.Obj) = (Rsp [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 1)
    goto label_108;
  Rsp = (& (Rsp [1]));
  goto label_100;

DEFLABEL (label_108)
  if (! ((Wrd26.uLng) == 1))
    goto label_144;
  (Wrd30.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd28.Obj) = ((Wrd30.pObj) [0]);

DEFLABEL (label_143)
  (Wrd39.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if (! ((Wrd39.uLng) == 1))
    goto label_142;
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd28.Obj));
  (Wrd37.Obj) = ((Wrd38.pObj) [0]);

DEFLABEL (label_141)
  if ((Wrd37.Obj) == (current_block [OBJECT_114_3]))
    goto label_111;
  (Wrd48.Obj) = (Rsp [0]);
  (Wrd49.uLng) = (OBJECT_TYPE (Wrd48.Obj));
  if (! ((Wrd49.uLng) == 1))
    goto label_110;
  (Wrd47.pObj) = (OBJECT_ADDRESS (Wrd48.Obj));
  (Wrd45.Obj) = ((Wrd47.pObj) [1]);

DEFLABEL (label_109)
  (Rsp [0]) = (Wrd45.Obj);
  goto label_102;

DEFLABEL (label_110)
  (Wrd53.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_22]))));
  (* (--Rsp)) = (Wrd53.Obj);
  (* (--Rsp)) = (Wrd48.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_114_0]), 1);

DEFLABEL (label_77)
  (Wrd45.Obj) = Rvl;
  goto label_109;

DEFLABEL (label_111)
  (Wrd57.Obj) = (Rsp [0]);
  (Wrd58.uLng) = (OBJECT_TYPE (Wrd57.Obj));
  if (! ((Wrd58.uLng) == 1))
    goto label_140;
  (Wrd56.pObj) = (OBJECT_ADDRESS (Wrd57.Obj));
  (Wrd54.Obj) = ((Wrd56.pObj) [1]);

DEFLABEL (label_139)
  if ((Wrd54.Obj) == (current_block [OBJECT_114_4]))
    goto label_113;
  (Wrd64.Obj) = (current_block [OBJECT_114_6]);
  goto label_112;

DEFLABEL (label_113)
  (Wrd64.Obj) = (current_block [OBJECT_114_5]);

DEFLABEL (label_112)
DEFLABEL (label_138)
  Rsp = (& (Rsp [1]));
  if ((Wrd64.Obj) == ((SCHEME_OBJECT) 0))
    goto label_100;
  (Wrd70.Obj) = (Rsp [0]);
  (Wrd71.uLng) = (OBJECT_TYPE (Wrd70.Obj));
  if (! ((Wrd71.uLng) == 1))
    goto label_137;
  (Wrd69.pObj) = (OBJECT_ADDRESS (Wrd70.Obj));
  (Wrd67.Obj) = ((Wrd69.pObj) [1]);

DEFLABEL (label_136)
  (Wrd78.uLng) = (OBJECT_TYPE (Wrd67.Obj));
  if (! ((Wrd78.uLng) == 1))
    goto label_135;
  (Wrd77.pObj) = (OBJECT_ADDRESS (Wrd67.Obj));
  (Wrd76.Obj) = ((Wrd77.pObj) [1]);

DEFLABEL (label_134)
  (Wrd85.uLng) = (OBJECT_TYPE (Wrd76.Obj));
  if (! ((Wrd85.uLng) == 1))
    goto label_133;
  (Wrd83.pObj) = (OBJECT_ADDRESS (Wrd76.Obj));
  (Wrd84.Obj) = ((Wrd83.pObj) [0]);
  (* (--Rsp)) = (Wrd84.Obj);

DEFLABEL (label_132)
  (Wrd93.Obj) = (Rsp [1]);
  (Wrd94.uLng) = (OBJECT_TYPE (Wrd93.Obj));
  if (! ((Wrd94.uLng) == 1))
    goto label_131;
  (Wrd92.pObj) = (OBJECT_ADDRESS (Wrd93.Obj));
  (Wrd90.Obj) = ((Wrd92.pObj) [1]);

DEFLABEL (label_130)
  (Wrd101.uLng) = (OBJECT_TYPE (Wrd90.Obj));
  if (! ((Wrd101.uLng) == 1))
    goto label_129;
  (Wrd99.pObj) = (OBJECT_ADDRESS (Wrd90.Obj));
  (Wrd100.Obj) = ((Wrd99.pObj) [0]);
  (* (--Rsp)) = (Wrd100.Obj);

DEFLABEL (label_128)
  (Wrd108.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_17]))));
  (* (--Rsp)) = (Wrd108.Obj);
  (Wrd112.Obj) = (Rsp [3]);
  (Wrd113.uLng) = (OBJECT_TYPE (Wrd112.Obj));
  if (! ((Wrd113.uLng) == 1))
    goto label_127;
  (Wrd111.pObj) = (OBJECT_ADDRESS (Wrd112.Obj));
  (Wrd109.Obj) = ((Wrd111.pObj) [1]);

DEFLABEL (label_126)
  (Wrd120.uLng) = (OBJECT_TYPE (Wrd109.Obj));
  if (! ((Wrd120.uLng) == 1))
    goto label_125;
  (Wrd119.pObj) = (OBJECT_ADDRESS (Wrd109.Obj));
  (Wrd118.Obj) = ((Wrd119.pObj) [1]);

DEFLABEL (label_124)
  (Wrd127.uLng) = (OBJECT_TYPE (Wrd118.Obj));
  if (! ((Wrd127.uLng) == 1))
    goto label_123;
  (Wrd125.pObj) = (OBJECT_ADDRESS (Wrd118.Obj));
  (Wrd126.Obj) = ((Wrd125.pObj) [1]);
  (* (--Rsp)) = (Wrd126.Obj);

DEFLABEL (label_122)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_114_21]));

DEFLABEL (continuation_26)
  INTERRUPT_CHECK (27, LABEL_114_17);
  (Rsp [3]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_26]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 1))
    goto label_121;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd9.Obj) = ((Wrd11.pObj) [1]);

DEFLABEL (label_120)
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if (! ((Wrd20.uLng) == 1))
    goto label_119;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd18.Obj) = ((Wrd19.pObj) [1]);

DEFLABEL (label_118)
  (Wrd27.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd27.uLng) == 1))
    goto label_117;
  (Wrd25.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd26.Obj) = ((Wrd25.pObj) [1]);
  (* (--Rsp)) = (Wrd26.Obj);

DEFLABEL (label_116)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_114_30]));

DEFLABEL (continuation_22)
  INTERRUPT_CHECK (27, LABEL_114_26);
  (Rsp [2]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_31]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = Rvl;
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_32]))));
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_114_33]));

DEFLABEL (continuation_34)
  INTERRUPT_CHECK (27, LABEL_114_31);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_34]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_114_7]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd9.Obj);
  goto compile_rhs_64;

DEFLABEL (continuation_29)
  INTERRUPT_CHECK (27, LABEL_114_34);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_36]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [3]);
  if ((Wrd13.Obj) == ((SCHEME_OBJECT) 0))
    goto label_115;
  (Wrd15.Obj) = (current_block [OBJECT_114_4]);
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd13.Obj);
  goto compile_rhs_64;

DEFLABEL (continuation_28)
  INTERRUPT_CHECK (27, LABEL_114_36);
  (Wrd18.Obj) = Rvl;

DEFLABEL (label_114)
  (Wrd19.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd18.Obj);
  (* (Rhp++)) = (Wrd19.Obj);
  (Wrd22.pObj) = (& (Rhp [-2]));
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd22.pObj)));
  (Wrd26.Obj) = (current_block [OBJECT_114_8]);
  (* (Rhp++)) = (Wrd26.Obj);
  (* (Rhp++)) = (Wrd20.Obj);
  (Wrd25.pObj) = (& (Rhp [-2]));
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd25.pObj)));
  (Wrd30.Obj) = (current_block [OBJECT_114_4]);
  (* (Rhp++)) = (Wrd23.Obj);
  (* (Rhp++)) = (Wrd30.Obj);
  (Wrd28.pObj) = (& (Rhp [-2]));
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd28.pObj)));
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_37]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd34.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd34.Obj);
  goto state__name_68;

DEFLABEL (continuation_27)
  INTERRUPT_CHECK (27, LABEL_114_37);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  (Wrd14.Obj) = (current_block [OBJECT_114_9]);
  (* (Rhp++)) = (Wrd14.Obj);
  (* (Rhp++)) = (Wrd7.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  Rsp = (& (Rsp [4]));
  goto pop_return;

DEFLABEL (label_115)
  (Wrd18.Obj) = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto label_114;

DEFLABEL (label_117)
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_29]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_114_0]), 1);

DEFLABEL (label_89)
  (* (--Rsp)) = Rvl;
  goto label_116;

DEFLABEL (label_119)
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_28]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_114_0]), 1);

DEFLABEL (label_88)
  (Wrd18.Obj) = Rvl;
  goto label_118;

DEFLABEL (label_121)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_27]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_114_0]), 1);

DEFLABEL (label_87)
  (Wrd9.Obj) = Rvl;
  goto label_120;

DEFLABEL (label_123)
  (Wrd131.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_20]))));
  (* (--Rsp)) = (Wrd131.Obj);
  (* (--Rsp)) = (Wrd118.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_114_0]), 1);

DEFLABEL (label_86)
  (* (--Rsp)) = Rvl;
  goto label_122;

DEFLABEL (label_125)
  (Wrd124.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_19]))));
  (* (--Rsp)) = (Wrd124.Obj);
  (* (--Rsp)) = (Wrd109.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_114_0]), 1);

DEFLABEL (label_85)
  (Wrd118.Obj) = Rvl;
  goto label_124;

DEFLABEL (label_127)
  (Wrd117.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_18]))));
  (* (--Rsp)) = (Wrd117.Obj);
  (* (--Rsp)) = (Wrd112.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_114_0]), 1);

DEFLABEL (label_84)
  (Wrd109.Obj) = Rvl;
  goto label_126;

DEFLABEL (label_129)
  (Wrd105.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_16]))));
  (* (--Rsp)) = (Wrd105.Obj);
  (* (--Rsp)) = (Wrd90.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_114_2]), 1);

DEFLABEL (label_83)
  (* (--Rsp)) = Rvl;
  goto label_128;

DEFLABEL (label_131)
  (Wrd98.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_15]))));
  (* (--Rsp)) = (Wrd98.Obj);
  (* (--Rsp)) = (Wrd93.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_114_0]), 1);

DEFLABEL (label_82)
  (Wrd90.Obj) = Rvl;
  goto label_130;

DEFLABEL (label_133)
  (Wrd89.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_14]))));
  (* (--Rsp)) = (Wrd89.Obj);
  (* (--Rsp)) = (Wrd76.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_114_2]), 1);

DEFLABEL (label_81)
  (* (--Rsp)) = Rvl;
  goto label_132;

DEFLABEL (label_135)
  (Wrd82.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_13]))));
  (* (--Rsp)) = (Wrd82.Obj);
  (* (--Rsp)) = (Wrd67.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_114_0]), 1);

DEFLABEL (label_80)
  (Wrd76.Obj) = Rvl;
  goto label_134;

DEFLABEL (label_137)
  (Wrd75.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_12]))));
  (* (--Rsp)) = (Wrd75.Obj);
  (* (--Rsp)) = (Wrd70.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_114_0]), 1);

DEFLABEL (label_79)
  (Wrd67.Obj) = Rvl;
  goto label_136;

DEFLABEL (label_140)
  (Wrd62.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_11]))));
  (* (--Rsp)) = (Wrd62.Obj);
  (* (--Rsp)) = (Wrd57.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_114_0]), 1);

DEFLABEL (label_78)
  (Wrd54.Obj) = Rvl;
  goto label_139;

DEFLABEL (label_142)
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_10]))));
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_114_2]), 1);

DEFLABEL (label_76)
  (Wrd37.Obj) = Rvl;
  goto label_141;

DEFLABEL (label_144)
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_9]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_114_2]), 1);

DEFLABEL (label_75)
  (Wrd28.Obj) = Rvl;
  goto label_143;

DEFLABEL (lambda_96)
DEFLABEL (lambda_33)
  INTERRUPT_CHECK (26, LABEL_114_32);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_35]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_114_7]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  goto compile_rhs_64;

DEFLABEL (continuation_31)
  INTERRUPT_CHECK (27, LABEL_114_35);
  (Wrd9.Obj) = (current_block [OBJECT_114_4]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd13.Obj) = (Rsp [1]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if (! ((Wrd14.uLng) == 1))
    goto label_146;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd10.Obj) = ((Wrd12.pObj) [0]);

DEFLABEL (label_145)
  (Wrd19.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd19.Obj);
  (Wrd22.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd22.pObj)));
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_146)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_42]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd13.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_114_2]), 1);

DEFLABEL (label_91)
  (Wrd10.Obj) = Rvl;
  goto label_145;

DEFLABEL (compile_rhs_97)
DEFLABEL (compile_rhs_64)
  INTERRUPT_CHECK (26, LABEL_114_38);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_159;
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [1]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_158)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_40]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_41]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd20.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_114_21]));

DEFLABEL (continuation_48)
  INTERRUPT_CHECK (27, LABEL_114_41);
  (* (--Rsp)) = Rvl;
  if (Rvl == (current_block [OBJECT_114_15]))
    goto label_157;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_48]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rsp)) = Rvl;
  (Wrd45.Obj) = (current_block [OBJECT_114_17]);
  (Wrd48.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 29L) < ((unsigned long) (Wrd48.Lng))))
    goto label_156;
  (Wrd12.uLng) = (OBJECT_DATUM (Wrd45.Obj));
  (Wrd14.uLng) = (OBJECT_TYPE (Rvl));
  if ((Wrd12.Obj) == (Wrd14.Obj))
    goto label_155;

DEFLABEL (label_154)
  (Wrd15.Obj) = (current_block [OBJECT_114_19]);
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd25.Lng) = (1 << TYPE_CODE_LENGTH);
  if (((unsigned long) 5L) < ((unsigned long) (Wrd25.Lng)))
    goto label_147;
  INVOKE_PRIMITIVE ((current_block [OBJECT_114_18]), 2);

DEFLABEL (label_147)
  (Wrd19.uLng) = (OBJECT_DATUM (Wrd15.Obj));
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if ((Wrd19.Obj) == (Wrd21.Obj))
    goto label_149;
  (Wrd17.Obj) = (current_block [OBJECT_114_6]);
  goto label_148;

DEFLABEL (label_149)
  (Wrd17.Obj) = (current_block [OBJECT_114_5]);

DEFLABEL (label_148)
DEFLABEL (label_153)
  Rsp = (& (Rsp [3]));
  if ((Wrd17.Obj) == ((SCHEME_OBJECT) 0))
    goto label_152;

DEFLABEL (label_151)
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_47]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (Wrd43.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd43.Obj);
  goto state__name_68;

DEFLABEL (continuation_54)
  INTERRUPT_CHECK (27, LABEL_114_47);
  (Wrd61.Obj) = (current_block [OBJECT_114_12]);
  (Wrd62.Obj) = (current_block [OBJECT_114_4]);
  (* (Rhp++)) = (Wrd61.Obj);
  (* (Rhp++)) = (Wrd62.Obj);
  (Wrd60.pObj) = (& (Rhp [-2]));
  (Wrd58.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd60.pObj)));
  (Wrd66.Obj) = (current_block [OBJECT_114_13]);
  (* (Rhp++)) = (Wrd66.Obj);
  (* (Rhp++)) = (Wrd58.Obj);
  (Wrd65.pObj) = (& (Rhp [-2]));
  (Wrd63.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd65.pObj)));
  (Wrd70.Obj) = (current_block [OBJECT_114_14]);
  (* (Rhp++)) = (Wrd70.Obj);
  (* (Rhp++)) = (Wrd63.Obj);
  (Wrd69.pObj) = (& (Rhp [-2]));
  (Wrd67.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd69.pObj)));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd67.Obj);
  (Wrd74.pObj) = (& (Rhp [-2]));
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd74.pObj)));

DEFLABEL (label_150)
  Rsp = (& (Rsp [1]));
  (Wrd32.Obj) = (current_block [OBJECT_114_4]);
  (* (Rhp++)) = (Wrd28.Obj);
  (* (Rhp++)) = (Wrd32.Obj);
  (Wrd30.pObj) = (& (Rhp [-2]));
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd30.pObj)));
  (* (--Rsp)) = (Wrd31.Obj);
  (Wrd35.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_50]))));
  (* (--Rsp)) = (Wrd35.Obj);
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_51]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (Wrd39.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd39.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_114_30]));

DEFLABEL (continuation_46)
  INTERRUPT_CHECK (27, LABEL_114_51);
  (* (--Rsp)) = Rvl;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_53]))));
  (* (--Rsp)) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_114_54]));

DEFLABEL (continuation_47)
  INTERRUPT_CHECK (27, LABEL_114_50);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_114_46]));

DEFLABEL (continuation_60)
  INTERRUPT_CHECK (27, LABEL_114_40);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_45]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_114_11]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_114_46]));

DEFLABEL (continuation_42)
  INTERRUPT_CHECK (27, LABEL_114_45);
  (Wrd9.Obj) = (current_block [OBJECT_114_20]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (Wrd13.Obj) = (current_block [OBJECT_114_4]);
  (* (Rhp++)) = (Wrd6.Obj);
  (* (Rhp++)) = (Wrd13.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  (Wrd17.Obj) = (current_block [OBJECT_114_21]);
  (* (Rhp++)) = (Wrd17.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd16.pObj) = (& (Rhp [-2]));
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd16.pObj)));
  (Wrd18.Obj) = (* (Rsp++));
  (* (Rhp++)) = (Wrd14.Obj);
  (* (Rhp++)) = (Wrd18.Obj);
  (Wrd20.pObj) = (& (Rhp [-2]));
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd20.pObj)));
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_52]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd25.Obj) = (current_block [OBJECT_114_11]);
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd26.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd26.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_114_46]));

DEFLABEL (continuation_41)
  INTERRUPT_CHECK (27, LABEL_114_52);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  (Wrd14.Obj) = (current_block [OBJECT_114_22]);
  (* (Rhp++)) = (Wrd14.Obj);
  (* (Rhp++)) = (Wrd7.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_152)
  (Wrd28.Obj) = (Rsp [0]);
  goto label_150;

DEFLABEL (label_155)
  Rsp = (& (Rsp [2]));
  goto label_151;

DEFLABEL (label_156)
  (Wrd53.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_49]))));
  (* (--Rsp)) = (Wrd53.Obj);
  (* (--Rsp)) = Rvl;
  (* (--Rsp)) = (Wrd45.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_114_18]), 2);

DEFLABEL (label_92)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_154;
  goto label_155;

DEFLABEL (label_157)
  (Wrd28.Obj) = (current_block [OBJECT_114_16]);
  goto label_150;

DEFLABEL (label_159)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114_39]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_114_0]), 1);

DEFLABEL (label_90)
  (* (--Rsp)) = Rvl;
  goto label_158;

DEFLABEL (continuation_51)
  INTERRUPT_CHECK (27, LABEL_114_48);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_152;
  goto label_151;

DEFLABEL (state__name_98)
DEFLABEL (state__name_68)
  INTERRUPT_CHECK (26, LABEL_114_43);
  (Wrd5.Obj) = (current_block [OBJECT_114_10]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_114_44]));

DEFLABEL (compile_action_99)
DEFLABEL (compile_action_67)
  INTERRUPT_CHECK (26, LABEL_114_53);
  (Wrd5.Obj) = (Rsp [0]);
  if ((Wrd5.Obj) == (current_block [OBJECT_114_23]))
    goto label_163;
  if ((Wrd5.Obj) == (current_block [OBJECT_114_25]))
    goto label_161;
  Rvl = (Wrd5.Obj);
  goto label_160;

DEFLABEL (label_161)
  Rvl = (current_block [OBJECT_114_26]);

DEFLABEL (label_160)
DEFLABEL (label_162)
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_163)
  Rvl = (current_block [OBJECT_114_24]);
  goto label_162;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_115_4 3
#define LABEL_115_5 5
#define LABEL_115_7 7
#define ENVIRONMENT_LABEL_115_3 16
#define DEBUGGING_LABEL_115_2 15
#define OBJECT_115_1 14
#define OBJECT_115_0 13
#define EXECUTE_CACHE_115_6 9
#define FREE_ASSIGNMENT_115_0 12
#define FREE_REFERENCES_LABEL_115_0 8
#define NUMBER_OF_LINKER_SECTIONS_115_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_115 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd6;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_115_4);
      goto lambda_1;

    case 1:
      current_block = (Rpc - LABEL_115_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_115_7);
      goto label_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_5)
DEFLABEL (lambda_1)
  INTERRUPT_CHECK (26, LABEL_115_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_115_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_115_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_115_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_115_5);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_115_0]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_8;

DEFLABEL (label_7)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_6)
  Rvl = (current_block [OBJECT_115_1]);
  goto pop_return;

DEFLABEL (label_8)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_7;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_115_7])), (Wrd6.pObj), Rvl);

DEFLABEL (label_3)
  goto label_6;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_116_4 3
#define LABEL_116_7 5
#define LABEL_116_8 7
#define LABEL_116_5 9
#define LABEL_116_10 11
#define LABEL_116_6 13
#define LABEL_116_11 15
#define ENVIRONMENT_LABEL_116_3 29
#define DEBUGGING_LABEL_116_2 28
#define OBJECT_116_0 27
#define EXECUTE_CACHE_116_12 17
#define EXECUTE_CACHE_116_9 19
#define FREE_REFERENCE_116_2 22
#define FREE_REFERENCE_116_1 23
#define FREE_REFERENCE_116_0 24
#define FREE_ASSIGNMENT_116_0 26
#define FREE_REFERENCES_LABEL_116_0 16
#define NUMBER_OF_LINKER_SECTIONS_116_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_116 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd14;
  machine_word Wrd6;
  machine_word Wrd17;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd18;
  machine_word Wrd11;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd12;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_116_4);
      goto lambda_2;

    case 1:
      current_block = (Rpc - LABEL_116_7);
      goto label_4;

    case 2:
      current_block = (Rpc - LABEL_116_8);
      goto label_5;

    case 3:
      current_block = (Rpc - LABEL_116_5);
      goto continuation_1;

    case 4:
      current_block = (Rpc - LABEL_116_10);
      goto label_6;

    case 5:
      current_block = (Rpc - LABEL_116_6);
      goto continuation_0;

    case 6:
      current_block = (Rpc - LABEL_116_11);
      goto label_7;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_9)
DEFLABEL (lambda_2)
  INTERRUPT_CHECK (26, LABEL_116_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_116_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_116_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_116_0]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_18;
  Wrd11 = Wrd15;

DEFLABEL (label_17)
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd18.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_116_1]));
  (Wrd21.Obj) = ((Wrd18.pObj) [0]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if ((Wrd22.uLng) == 50)
    goto label_16;
  Wrd17 = Wrd21;

DEFLABEL (label_15)
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_116_9]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_116_6);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_116_2]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_14;
  Wrd5 = Wrd9;

DEFLABEL (label_13)
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_116_12]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_116_5);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_116_0]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_12;

DEFLABEL (label_11)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_10)
  Rvl = (current_block [OBJECT_116_0]);
  goto pop_return;

DEFLABEL (label_12)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_11;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_116_10])), (Wrd6.pObj), Rvl);

DEFLABEL (label_6)
  goto label_10;

DEFLABEL (label_14)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_116_11])), (Wrd6.pObj));

DEFLABEL (label_7)
  (Wrd5.Obj) = Rvl;
  goto label_13;

DEFLABEL (label_16)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_116_8])), (Wrd18.pObj));

DEFLABEL (label_5)
  (Wrd17.Obj) = Rvl;
  goto label_15;

DEFLABEL (label_18)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_116_7])), (Wrd12.pObj));

DEFLABEL (label_4)
  (Wrd11.Obj) = Rvl;
  goto label_17;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_117_4 3
#define LABEL_117_6 5
#define LABEL_117_5 7
#define LABEL_117_8 9
#define ENVIRONMENT_LABEL_117_3 19
#define DEBUGGING_LABEL_117_2 18
#define OBJECT_117_0 17
#define EXECUTE_CACHE_117_7 11
#define FREE_REFERENCE_117_0 14
#define FREE_ASSIGNMENT_117_0 16
#define FREE_REFERENCES_LABEL_117_0 10
#define NUMBER_OF_LINKER_SECTIONS_117_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_117 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd6;
  machine_word Wrd8;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_117_4);
      goto lambda_1;

    case 1:
      current_block = (Rpc - LABEL_117_6);
      goto label_3;

    case 2:
      current_block = (Rpc - LABEL_117_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_117_8);
      goto label_4;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_6)
DEFLABEL (lambda_1)
  INTERRUPT_CHECK (26, LABEL_117_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_117_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_117_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_11;
  Wrd8 = Wrd12;

DEFLABEL (label_10)
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_117_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_117_5);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_117_0]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_9;

DEFLABEL (label_8)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_7)
  Rvl = (current_block [OBJECT_117_0]);
  goto pop_return;

DEFLABEL (label_9)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_8;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_117_8])), (Wrd6.pObj), Rvl);

DEFLABEL (label_4)
  goto label_7;

DEFLABEL (label_11)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_117_6])), (Wrd9.pObj));

DEFLABEL (label_3)
  (Wrd8.Obj) = Rvl;
  goto label_10;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_118_4 3
#define LABEL_118_5 5
#define LABEL_118_8 7
#define LABEL_118_6 9
#define LABEL_118_9 11
#define ENVIRONMENT_LABEL_118_3 25
#define DEBUGGING_LABEL_118_2 24
#define OBJECT_118_2 23
#define OBJECT_118_1 22
#define OBJECT_118_0 21
#define EXECUTE_CACHE_118_10 13
#define EXECUTE_CACHE_118_7 15
#define FREE_REFERENCE_118_0 18
#define FREE_ASSIGNMENT_118_0 20
#define FREE_REFERENCES_LABEL_118_0 12
#define NUMBER_OF_LINKER_SECTIONS_118_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_118 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd6;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_118_4);
      goto lambda_2;

    case 1:
      current_block = (Rpc - LABEL_118_5);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_118_8);
      goto label_4;

    case 3:
      current_block = (Rpc - LABEL_118_6);
      goto continuation_0;

    case 4:
      current_block = (Rpc - LABEL_118_9);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_7)
DEFLABEL (lambda_2)
  INTERRUPT_CHECK (26, LABEL_118_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_118_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_118_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_118_0]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_118_1]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_118_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_118_6);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_118_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_12;
  Wrd5 = Wrd9;

DEFLABEL (label_11)
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_118_10]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_118_5);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_118_0]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_10;

DEFLABEL (label_9)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_8)
  Rvl = (current_block [OBJECT_118_2]);
  goto pop_return;

DEFLABEL (label_10)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_9;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_118_8])), (Wrd6.pObj), Rvl);

DEFLABEL (label_4)
  goto label_8;

DEFLABEL (label_12)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_118_9])), (Wrd6.pObj));

DEFLABEL (label_5)
  (Wrd5.Obj) = Rvl;
  goto label_11;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_119_4 3
#define LABEL_119_5 5
#define LABEL_119_8 7
#define LABEL_119_6 9
#define LABEL_119_9 11
#define ENVIRONMENT_LABEL_119_3 24
#define DEBUGGING_LABEL_119_2 23
#define OBJECT_119_1 22
#define OBJECT_119_0 21
#define EXECUTE_CACHE_119_10 13
#define EXECUTE_CACHE_119_7 15
#define FREE_REFERENCE_119_0 18
#define FREE_ASSIGNMENT_119_0 20
#define FREE_REFERENCES_LABEL_119_0 12
#define NUMBER_OF_LINKER_SECTIONS_119_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_119 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd6;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_119_4);
      goto lambda_2;

    case 1:
      current_block = (Rpc - LABEL_119_5);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_119_8);
      goto label_4;

    case 3:
      current_block = (Rpc - LABEL_119_6);
      goto continuation_0;

    case 4:
      current_block = (Rpc - LABEL_119_9);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_7)
DEFLABEL (lambda_2)
  INTERRUPT_CHECK (26, LABEL_119_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_119_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_119_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_119_0]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_119_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_119_6);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_119_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_12;
  Wrd5 = Wrd9;

DEFLABEL (label_11)
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_119_10]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_119_5);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_119_0]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_10;

DEFLABEL (label_9)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_8)
  Rvl = (current_block [OBJECT_119_1]);
  goto pop_return;

DEFLABEL (label_10)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_9;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_119_8])), (Wrd6.pObj), Rvl);

DEFLABEL (label_4)
  goto label_8;

DEFLABEL (label_12)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_119_9])), (Wrd6.pObj));

DEFLABEL (label_5)
  (Wrd5.Obj) = Rvl;
  goto label_11;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_120_4 3
#define LABEL_120_5 5
#define LABEL_120_8 7
#define LABEL_120_6 9
#define LABEL_120_9 11
#define ENVIRONMENT_LABEL_120_3 25
#define DEBUGGING_LABEL_120_2 24
#define OBJECT_120_4 23
#define OBJECT_120_3 22
#define OBJECT_120_2 21
#define OBJECT_120_1 20
#define OBJECT_120_0 19
#define EXECUTE_CACHE_120_10 13
#define EXECUTE_CACHE_120_7 15
#define FREE_ASSIGNMENT_120_0 18
#define FREE_REFERENCES_LABEL_120_0 12
#define NUMBER_OF_LINKER_SECTIONS_120_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_120 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd6;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_120_4);
      goto lambda_3;

    case 1:
      current_block = (Rpc - LABEL_120_5);
      goto continuation_2;

    case 2:
      current_block = (Rpc - LABEL_120_8);
      goto label_5;

    case 3:
      current_block = (Rpc - LABEL_120_6);
      goto continuation_1;

    case 4:
      current_block = (Rpc - LABEL_120_9);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_7)
DEFLABEL (lambda_3)
  INTERRUPT_CHECK (26, LABEL_120_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_120_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_120_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_120_0]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_120_1]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_120_7]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_120_6);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_120_9]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_120_3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_120_4]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_120_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_120_9);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_120_10]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_120_5);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_120_0]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_10;

DEFLABEL (label_9)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_8)
  Rvl = (current_block [OBJECT_120_2]);
  goto pop_return;

DEFLABEL (label_10)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_9;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_120_8])), (Wrd6.pObj), Rvl);

DEFLABEL (label_5)
  goto label_8;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_121_4 3
#define LABEL_121_7 5
#define LABEL_121_12 7
#define LABEL_121_14 9
#define LABEL_121_5 11
#define LABEL_121_18 13
#define LABEL_121_6 15
#define LABEL_121_8 17
#define LABEL_121_9 19
#define LABEL_121_10 21
#define LABEL_121_11 23
#define LABEL_121_13 25
#define LABEL_121_15 27
#define LABEL_121_16 29
#define LABEL_121_19 31
#define LABEL_121_23 33
#define ENVIRONMENT_LABEL_121_3 61
#define DEBUGGING_LABEL_121_2 60
#define OBJECT_121_4 59
#define OBJECT_121_3 58
#define OBJECT_121_2 57
#define OBJECT_121_1 56
#define OBJECT_121_0 55
#define EXECUTE_CACHE_121_26 35
#define EXECUTE_CACHE_121_25 37
#define EXECUTE_CACHE_121_24 39
#define EXECUTE_CACHE_121_22 41
#define EXECUTE_CACHE_121_21 43
#define EXECUTE_CACHE_121_20 45
#define EXECUTE_CACHE_121_17 47
#define FREE_REFERENCE_121_2 50
#define FREE_REFERENCE_121_1 51
#define FREE_REFERENCE_121_0 52
#define FREE_ASSIGNMENT_121_0 54
#define FREE_REFERENCES_LABEL_121_0 34
#define NUMBER_OF_LINKER_SECTIONS_121_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_121 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd44;
  machine_word Wrd42;
  machine_word Wrd35;
  machine_word Wrd40;
  machine_word Wrd39;
  machine_word Wrd36;
  machine_word Wrd34;
  machine_word Wrd27;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd28;
  machine_word Wrd26;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd10;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd11;
  machine_word Wrd9;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_121_4);
      goto lambda_11;

    case 1:
      current_block = (Rpc - LABEL_121_7);
      goto label_13;

    case 2:
      current_block = (Rpc - LABEL_121_12);
      goto label_14;

    case 3:
      current_block = (Rpc - LABEL_121_14);
      goto label_15;

    case 4:
      current_block = (Rpc - LABEL_121_5);
      goto continuation_10;

    case 5:
      current_block = (Rpc - LABEL_121_18);
      goto label_16;

    case 6:
      current_block = (Rpc - LABEL_121_6);
      goto lambda_9;

    case 7:
      current_block = (Rpc - LABEL_121_8);
      goto lambda_7;

    case 8:
      current_block = (Rpc - LABEL_121_9);
      goto lambda_6;

    case 9:
      current_block = (Rpc - LABEL_121_10);
      goto lambda_5;

    case 10:
      current_block = (Rpc - LABEL_121_11);
      goto lambda_4;

    case 11:
      current_block = (Rpc - LABEL_121_13);
      goto lambda_2;

    case 12:
      current_block = (Rpc - LABEL_121_15);
      goto lambda_1;

    case 13:
      current_block = (Rpc - LABEL_121_16);
      goto lambda_0;

    case 14:
      current_block = (Rpc - LABEL_121_19);
      goto continuation_8;

    case 15:
      current_block = (Rpc - LABEL_121_23);
      goto continuation_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_18)
DEFLABEL (lambda_11)
  INTERRUPT_CHECK (26, LABEL_121_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_121_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_121_6]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd11.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_121_0]));
  (Wrd14.Obj) = ((Wrd11.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_35;
  Wrd10 = Wrd14;

DEFLABEL (label_34)
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_121_8]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd18.Obj) = (current_block [OBJECT_121_0]);
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_121_9]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd21.Obj) = (current_block [OBJECT_121_1]);
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_121_10]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd24.Obj) = (current_block [OBJECT_121_2]);
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_121_11]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd28.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_121_1]));
  (Wrd31.Obj) = ((Wrd28.pObj) [0]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if ((Wrd32.uLng) == 50)
    goto label_33;
  Wrd27 = Wrd31;

DEFLABEL (label_32)
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_121_13]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (Wrd36.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_121_2]));
  (Wrd39.Obj) = ((Wrd36.pObj) [0]);
  (Wrd40.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if ((Wrd40.uLng) == 50)
    goto label_31;
  Wrd35 = Wrd39;

DEFLABEL (label_30)
  (* (--Rsp)) = (Wrd35.Obj);
  (Wrd42.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_121_15]))));
  (* (--Rsp)) = (Wrd42.Obj);
  (Wrd44.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_121_16]))));
  (* (--Rsp)) = (Wrd44.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_121_17]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_121_5);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_121_0]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_29;

DEFLABEL (label_28)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_27)
  Rvl = (current_block [OBJECT_121_3]);
  goto pop_return;

DEFLABEL (label_29)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_28;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_121_18])), (Wrd6.pObj), Rvl);

DEFLABEL (label_16)
  goto label_27;

DEFLABEL (label_31)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_121_14])), (Wrd36.pObj));

DEFLABEL (label_15)
  (Wrd35.Obj) = Rvl;
  goto label_30;

DEFLABEL (label_33)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_121_12])), (Wrd28.pObj));

DEFLABEL (label_14)
  (Wrd27.Obj) = Rvl;
  goto label_32;

DEFLABEL (label_35)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_121_7])), (Wrd11.pObj));

DEFLABEL (label_13)
  (Wrd10.Obj) = Rvl;
  goto label_34;

DEFLABEL (lambda_19)
DEFLABEL (lambda_9)
  INTERRUPT_CHECK (26, LABEL_121_6);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_121_19]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd9.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_121_19);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_121_25]));

DEFLABEL (lambda_20)
DEFLABEL (lambda_7)
  INTERRUPT_CHECK (26, LABEL_121_8);
  (Wrd5.Obj) = (current_block [OBJECT_121_4]);
  (Rsp [2]) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [0]);
  (Rsp [3]) = (Wrd6.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_121_20]));

DEFLABEL (lambda_21)
DEFLABEL (lambda_6)
  INTERRUPT_CHECK (26, LABEL_121_9);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_121_21]));

DEFLABEL (lambda_22)
DEFLABEL (lambda_5)
  INTERRUPT_CHECK (26, LABEL_121_10);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_121_22]));

DEFLABEL (lambda_23)
DEFLABEL (lambda_4)
  INTERRUPT_CHECK (26, LABEL_121_11);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_121_23]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd9.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_121_23);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_121_26]));

DEFLABEL (lambda_24)
DEFLABEL (lambda_2)
  INTERRUPT_CHECK (26, LABEL_121_13);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_121_24]));

DEFLABEL (lambda_25)
DEFLABEL (lambda_1)
  INTERRUPT_CHECK (26, LABEL_121_15);
  (Wrd5.Obj) = (current_block [OBJECT_121_4]);
  (Rsp [2]) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [0]);
  (Rsp [3]) = (Wrd6.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_121_20]));

DEFLABEL (lambda_26)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_121_16);
  (Wrd5.Obj) = (Rsp [1]);
  (Rsp [2]) = (Wrd5.Obj);
  Rsp = (& (Rsp [2]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_122_4 3
#define LABEL_122_7 5
#define LABEL_122_5 7
#define LABEL_122_11 9
#define LABEL_122_6 11
#define LABEL_122_8 13
#define LABEL_122_9 15
#define LABEL_122_13 17
#define LABEL_122_15 19
#define ENVIRONMENT_LABEL_122_3 36
#define DEBUGGING_LABEL_122_2 35
#define OBJECT_122_1 34
#define OBJECT_122_0 33
#define EXECUTE_CACHE_122_16 21
#define EXECUTE_CACHE_122_14 23
#define EXECUTE_CACHE_122_12 25
#define EXECUTE_CACHE_122_10 27
#define FREE_REFERENCE_122_0 30
#define FREE_ASSIGNMENT_122_0 32
#define FREE_REFERENCES_LABEL_122_0 20
#define NUMBER_OF_LINKER_SECTIONS_122_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_122 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd19;
  machine_word Wrd17;
  machine_word Wrd10;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd11;
  machine_word Wrd9;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_122_4);
      goto lambda_6;

    case 1:
      current_block = (Rpc - LABEL_122_7);
      goto label_8;

    case 2:
      current_block = (Rpc - LABEL_122_5);
      goto continuation_5;

    case 3:
      current_block = (Rpc - LABEL_122_11);
      goto label_9;

    case 4:
      current_block = (Rpc - LABEL_122_6);
      goto lambda_4;

    case 5:
      current_block = (Rpc - LABEL_122_8);
      goto lambda_3;

    case 6:
      current_block = (Rpc - LABEL_122_9);
      goto lambda_0;

    case 7:
      current_block = (Rpc - LABEL_122_13);
      goto continuation_1;

    case 8:
      current_block = (Rpc - LABEL_122_15);
      goto continuation_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_11)
DEFLABEL (lambda_6)
  INTERRUPT_CHECK (26, LABEL_122_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_122_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_122_6]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd11.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_122_0]));
  (Wrd14.Obj) = ((Wrd11.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_19;
  Wrd10 = Wrd14;

DEFLABEL (label_18)
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_122_8]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_122_9]))));
  (* (--Rsp)) = (Wrd19.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_122_10]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_122_5);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_122_0]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_17;

DEFLABEL (label_16)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_15)
  Rvl = (current_block [OBJECT_122_0]);
  goto pop_return;

DEFLABEL (label_17)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_16;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_122_11])), (Wrd6.pObj), Rvl);

DEFLABEL (label_9)
  goto label_15;

DEFLABEL (label_19)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_122_7])), (Wrd11.pObj));

DEFLABEL (label_8)
  (Wrd10.Obj) = Rvl;
  goto label_18;

DEFLABEL (lambda_12)
DEFLABEL (lambda_4)
  INTERRUPT_CHECK (26, LABEL_122_6);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_122_12]));

DEFLABEL (lambda_13)
DEFLABEL (lambda_3)
  INTERRUPT_CHECK (26, LABEL_122_8);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_122_13]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_122_14]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_122_13);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_122_15]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_122_1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd9.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_122_15);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_122_16]));

DEFLABEL (lambda_14)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_122_9);
  (Wrd5.Obj) = (Rsp [1]);
  (Rsp [2]) = (Wrd5.Obj);
  Rsp = (& (Rsp [2]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_123_4 3
#define LABEL_123_7 5
#define LABEL_123_5 7
#define LABEL_123_11 9
#define LABEL_123_6 11
#define LABEL_123_8 13
#define LABEL_123_9 15
#define LABEL_123_12 17
#define LABEL_123_13 19
#define LABEL_123_14 21
#define LABEL_123_15 23
#define LABEL_123_16 25
#define LABEL_123_18 27
#define ENVIRONMENT_LABEL_123_3 43
#define DEBUGGING_LABEL_123_2 42
#define OBJECT_123_0 41
#define EXECUTE_CACHE_123_20 29
#define EXECUTE_CACHE_123_19 31
#define EXECUTE_CACHE_123_17 33
#define EXECUTE_CACHE_123_10 35
#define FREE_REFERENCE_123_0 38
#define FREE_ASSIGNMENT_123_0 40
#define FREE_REFERENCES_LABEL_123_0 28
#define NUMBER_OF_LINKER_SECTIONS_123_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_123 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd19;
  machine_word Wrd17;
  machine_word Wrd10;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd11;
  machine_word Wrd9;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_123_4);
      goto lambda_10;

    case 1:
      current_block = (Rpc - LABEL_123_7);
      goto label_12;

    case 2:
      current_block = (Rpc - LABEL_123_5);
      goto continuation_9;

    case 3:
      current_block = (Rpc - LABEL_123_11);
      goto label_13;

    case 4:
      current_block = (Rpc - LABEL_123_6);
      goto lambda_8;

    case 5:
      current_block = (Rpc - LABEL_123_8);
      goto lambda_6;

    case 6:
      current_block = (Rpc - LABEL_123_9);
      goto lambda_2;

    case 7:
      current_block = (Rpc - LABEL_123_12);
      goto continuation_7;

    case 8:
      current_block = (Rpc - LABEL_123_13);
      goto continuation_4;

    case 9:
      current_block = (Rpc - LABEL_123_14);
      goto continuation_3;

    case 10:
      current_block = (Rpc - LABEL_123_15);
      goto continuation_1;

    case 11:
      current_block = (Rpc - LABEL_123_16);
      goto continuation_0;

    case 12:
      current_block = (Rpc - LABEL_123_18);
      goto continuation_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_15)
DEFLABEL (lambda_10)
  INTERRUPT_CHECK (26, LABEL_123_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_123_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_123_6]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd11.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_123_0]));
  (Wrd14.Obj) = ((Wrd11.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_23;
  Wrd10 = Wrd14;

DEFLABEL (label_22)
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_123_8]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_123_9]))));
  (* (--Rsp)) = (Wrd19.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_123_10]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_123_5);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_123_0]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_21;

DEFLABEL (label_20)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_19)
  Rvl = (current_block [OBJECT_123_0]);
  goto pop_return;

DEFLABEL (label_21)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_20;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_123_11])), (Wrd6.pObj), Rvl);

DEFLABEL (label_13)
  goto label_19;

DEFLABEL (label_23)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_123_7])), (Wrd11.pObj));

DEFLABEL (label_12)
  (Wrd10.Obj) = Rvl;
  goto label_22;

DEFLABEL (lambda_16)
DEFLABEL (lambda_8)
  INTERRUPT_CHECK (26, LABEL_123_6);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_123_12]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd9.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_123_12);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_123_17]));

DEFLABEL (lambda_17)
DEFLABEL (lambda_6)
  INTERRUPT_CHECK (26, LABEL_123_8);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_123_13]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_123_14]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd11.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_123_14);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd5.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_123_13);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_123_18]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_123_19]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_123_18);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_123_20]));

DEFLABEL (lambda_18)
DEFLABEL (lambda_2)
  INTERRUPT_CHECK (26, LABEL_123_9);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_123_15]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_123_16]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd11.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_123_16);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd5.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_123_15);
  (Wrd5.Obj) = (Rsp [1]);
  (Rsp [2]) = (Wrd5.Obj);
  Rsp = (& (Rsp [2]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_124_4 3
#define LABEL_124_9 5
#define LABEL_124_5 7
#define LABEL_124_13 9
#define LABEL_124_6 11
#define LABEL_124_7 13
#define LABEL_124_8 15
#define LABEL_124_10 17
#define LABEL_124_11 19
#define LABEL_124_14 21
#define LABEL_124_15 23
#define LABEL_124_17 25
#define ENVIRONMENT_LABEL_124_3 50
#define DEBUGGING_LABEL_124_2 49
#define OBJECT_124_5 48
#define OBJECT_124_4 47
#define OBJECT_124_3 46
#define OBJECT_124_2 45
#define OBJECT_124_1 44
#define OBJECT_124_0 43
#define EXECUTE_CACHE_124_21 27
#define EXECUTE_CACHE_124_20 29
#define EXECUTE_CACHE_124_19 31
#define EXECUTE_CACHE_124_18 33
#define EXECUTE_CACHE_124_16 35
#define EXECUTE_CACHE_124_12 37
#define FREE_REFERENCE_124_0 40
#define FREE_ASSIGNMENT_124_0 42
#define FREE_REFERENCES_LABEL_124_0 26
#define NUMBER_OF_LINKER_SECTIONS_124_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_124 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd8;
  machine_word Wrd11;
  machine_word Wrd14;
  machine_word Wrd6;
  machine_word Wrd25;
  machine_word Wrd23;
  machine_word Wrd16;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd17;
  machine_word Wrd15;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_124_4);
      goto lambda_10;

    case 1:
      current_block = (Rpc - LABEL_124_9);
      goto label_12;

    case 2:
      current_block = (Rpc - LABEL_124_5);
      goto continuation_9;

    case 3:
      current_block = (Rpc - LABEL_124_13);
      goto label_13;

    case 4:
      current_block = (Rpc - LABEL_124_6);
      goto lambda_8;

    case 5:
      current_block = (Rpc - LABEL_124_7);
      goto lambda_4;

    case 6:
      current_block = (Rpc - LABEL_124_8);
      goto lambda_3;

    case 7:
      current_block = (Rpc - LABEL_124_10);
      goto lambda_1;

    case 8:
      current_block = (Rpc - LABEL_124_11);
      goto lambda_0;

    case 9:
      current_block = (Rpc - LABEL_124_14);
      goto continuation_7;

    case 10:
      current_block = (Rpc - LABEL_124_15);
      goto continuation_5;

    case 11:
      current_block = (Rpc - LABEL_124_17);
      goto continuation_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_15)
DEFLABEL (lambda_10)
  INTERRUPT_CHECK (26, LABEL_124_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_124_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_124_6]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_124_0]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_124_7]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (current_block [OBJECT_124_1]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_124_8]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd17.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_124_0]));
  (Wrd20.Obj) = ((Wrd17.pObj) [0]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if ((Wrd21.uLng) == 50)
    goto label_25;
  Wrd16 = Wrd20;

DEFLABEL (label_24)
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_124_10]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_124_11]))));
  (* (--Rsp)) = (Wrd25.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_124_12]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_124_5);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_124_0]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_23;

DEFLABEL (label_22)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_21)
  Rvl = (current_block [OBJECT_124_2]);
  goto pop_return;

DEFLABEL (label_23)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_22;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_124_13])), (Wrd6.pObj), Rvl);

DEFLABEL (label_13)
  goto label_21;

DEFLABEL (label_25)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_124_9])), (Wrd17.pObj));

DEFLABEL (label_12)
  (Wrd16.Obj) = Rvl;
  goto label_24;

DEFLABEL (lambda_16)
DEFLABEL (lambda_8)
  INTERRUPT_CHECK (26, LABEL_124_6);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_124_14]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_124_15]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd11.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_124_15);
  (Wrd9.Obj) = (current_block [OBJECT_124_5]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd10.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_124_14);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_124_20]));

DEFLABEL (lambda_17)
DEFLABEL (lambda_4)
  INTERRUPT_CHECK (26, LABEL_124_7);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_124_16]));

DEFLABEL (lambda_18)
DEFLABEL (lambda_3)
  INTERRUPT_CHECK (26, LABEL_124_8);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_124_17]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd9.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_124_17);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_124_21]));

DEFLABEL (lambda_19)
DEFLABEL (lambda_1)
  INTERRUPT_CHECK (26, LABEL_124_10);
  (Wrd5.Obj) = (current_block [OBJECT_124_3]);
  (Rsp [2]) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [0]);
  (Rsp [3]) = (Wrd6.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_124_18]));

DEFLABEL (lambda_20)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_124_11);
  (Wrd5.Obj) = (current_block [OBJECT_124_4]);
  (Rsp [2]) = (Wrd5.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_124_19]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_125_4 3
#define LABEL_125_5 5
#define LABEL_125_9 7
#define LABEL_125_6 9
#define LABEL_125_7 11
#define LABEL_125_10 13
#define ENVIRONMENT_LABEL_125_3 26
#define DEBUGGING_LABEL_125_2 25
#define OBJECT_125_1 24
#define OBJECT_125_0 23
#define EXECUTE_CACHE_125_12 15
#define EXECUTE_CACHE_125_11 17
#define EXECUTE_CACHE_125_8 19
#define FREE_ASSIGNMENT_125_0 22
#define FREE_REFERENCES_LABEL_125_0 14
#define NUMBER_OF_LINKER_SECTIONS_125_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_125 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd8;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd6;
  machine_word Wrd11;
  machine_word Wrd9;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_125_4);
      goto lambda_4;

    case 1:
      current_block = (Rpc - LABEL_125_5);
      goto continuation_3;

    case 2:
      current_block = (Rpc - LABEL_125_9);
      goto label_6;

    case 3:
      current_block = (Rpc - LABEL_125_6);
      goto lambda_2;

    case 4:
      current_block = (Rpc - LABEL_125_7);
      goto lambda_0;

    case 5:
      current_block = (Rpc - LABEL_125_10);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_8)
DEFLABEL (lambda_4)
  INTERRUPT_CHECK (26, LABEL_125_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_125_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_125_6]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_125_7]))));
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_125_8]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_125_5);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_125_0]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_13;

DEFLABEL (label_12)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_11)
  Rvl = (current_block [OBJECT_125_0]);
  goto pop_return;

DEFLABEL (label_13)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_12;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_125_9])), (Wrd6.pObj), Rvl);

DEFLABEL (label_6)
  goto label_11;

DEFLABEL (lambda_9)
DEFLABEL (lambda_2)
  INTERRUPT_CHECK (26, LABEL_125_6);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_125_10]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd9.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_125_10);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_125_12]));

DEFLABEL (lambda_10)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_125_7);
  (Wrd5.Obj) = (current_block [OBJECT_125_1]);
  (Rsp [2]) = (Wrd5.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_125_11]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_126_4 3
#define LABEL_126_5 5
#define LABEL_126_6 7
#define LABEL_126_8 9
#define LABEL_126_15 11
#define LABEL_126_17 13
#define LABEL_126_14 15
#define LABEL_126_12 17
#define LABEL_126_13 19
#define LABEL_126_9 21
#define LABEL_126_22 23
#define LABEL_126_10 25
#define LABEL_126_11 27
#define LABEL_126_7 29
#define LABEL_126_24 31
#define LABEL_126_18 33
#define LABEL_126_21 35
#define LABEL_126_27 37
#define LABEL_126_25 39
#define ENVIRONMENT_LABEL_126_3 63
#define DEBUGGING_LABEL_126_2 62
#define OBJECT_126_6 61
#define OBJECT_126_5 60
#define OBJECT_126_4 59
#define OBJECT_126_3 58
#define OBJECT_126_2 57
#define OBJECT_126_1 56
#define OBJECT_126_0 55
#define EXECUTE_CACHE_126_26 41
#define EXECUTE_CACHE_126_23 43
#define EXECUTE_CACHE_126_28 45
#define EXECUTE_CACHE_126_20 47
#define EXECUTE_CACHE_126_19 49
#define EXECUTE_CACHE_126_16 51
#define FREE_REFERENCE_126_0 54
#define FREE_REFERENCES_LABEL_126_0 40
#define NUMBER_OF_LINKER_SECTIONS_126_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_126 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd14;
  machine_word Wrd11;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd15;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd29;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd23;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd41;
  machine_word Wrd56;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd50;
  machine_word Wrd47;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd54;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_126_4);
      goto tokenizer_state_in_comment_26;

    case 1:
      current_block = (Rpc - LABEL_126_5);
      goto loop_23;

    case 2:
      current_block = (Rpc - LABEL_126_6);
      goto continuation_6;

    case 3:
      current_block = (Rpc - LABEL_126_8);
      goto label_29;

    case 4:
      current_block = (Rpc - LABEL_126_15);
      goto label_28;

    case 5:
      current_block = (Rpc - LABEL_126_17);
      goto lambda_4;

    case 6:
      current_block = (Rpc - LABEL_126_14);
      goto continuation_10;

    case 7:
      current_block = (Rpc - LABEL_126_12);
      goto continuation_13;

    case 8:
      current_block = (Rpc - LABEL_126_13);
      goto continuation_12;

    case 9:
      current_block = (Rpc - LABEL_126_9);
      goto continuation_15;

    case 10:
      current_block = (Rpc - LABEL_126_22);
      goto label_30;

    case 11:
      current_block = (Rpc - LABEL_126_10);
      goto continuation_19;

    case 12:
      current_block = (Rpc - LABEL_126_11);
      goto continuation_17;

    case 13:
      current_block = (Rpc - LABEL_126_7);
      goto continuation_20;

    case 14:
      current_block = (Rpc - LABEL_126_24);
      goto label_31;

    case 15:
      current_block = (Rpc - LABEL_126_18);
      goto continuation_0;

    case 16:
      current_block = (Rpc - LABEL_126_21);
      goto continuation_11;

    case 17:
      current_block = (Rpc - LABEL_126_27);
      goto continuation_2;

    case 18:
      current_block = (Rpc - LABEL_126_25);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (tokenizer_state_in_comment_33)
DEFLABEL (tokenizer_state_in_comment_26)
  INTERRUPT_CHECK (26, LABEL_126_4);
  (Wrd5.Obj) = (current_block [OBJECT_126_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  goto loop_23;

DEFLABEL (loop_34)
DEFLABEL (loop_23)
  INTERRUPT_CHECK (26, LABEL_126_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_126_6]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.pObj) = (& (Rsp [2]));
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd8.pObj)));
  (* (--Rsp)) = (Wrd10.Obj);
  goto lambda_4;

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_126_6);
  (* (--Rsp)) = Rvl;
  if (Rvl == (current_block [OBJECT_126_1]))
    goto label_45;
  if (Rvl == (current_block [OBJECT_126_2]))
    goto label_40;
  if (! (Rvl == (current_block [OBJECT_126_3])))
    goto label_36;
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_126_12]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_126_13]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd27.pObj) = (& (Rsp [4]));
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (59, (Wrd27.pObj)));
  (* (--Rsp)) = (Wrd29.Obj);
  goto lambda_4;

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_126_13);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd5.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_13)
  INTERRUPT_CHECK (27, LABEL_126_12);
  Rsp = (& (Rsp [1]));
  goto loop_23;

DEFLABEL (label_36)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_126_14]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = Rvl;
  (Wrd16.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_126_0]));
  (Wrd19.Obj) = ((Wrd16.pObj) [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if ((Wrd20.uLng) == 50)
    goto label_39;
  Wrd15 = Wrd19;

DEFLABEL (label_38)
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_126_16]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_126_14);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_37;
  (Wrd12.Obj) = (current_block [OBJECT_126_4]);
  (Rsp [3]) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [0]);
  (Rsp [4]) = (Wrd13.Obj);
  Rsp = (& (Rsp [3]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_126_20]));

DEFLABEL (label_37)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_126_21]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd11.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_126_21);
  Rsp = (& (Rsp [1]));
  goto loop_23;

DEFLABEL (label_39)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_126_15])), (Wrd16.pObj));

DEFLABEL (label_28)
  (Wrd15.Obj) = Rvl;
  goto label_38;

DEFLABEL (label_40)
  (Wrd30.Obj) = (Rsp [1]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if (! ((Wrd31.uLng) == 26))
    goto label_44;
  if (! ((Wrd30.Obj) == (current_block [OBJECT_126_0])))
    goto label_42;

DEFLABEL (label_41)
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_126_10]))));
  (* (--Rsp)) = (Wrd41.Obj);
  (Wrd44.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_126_11]))));
  (* (--Rsp)) = (Wrd44.Obj);
  (Wrd45.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd45.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_126_11);
  (Wrd9.Obj) = (current_block [OBJECT_126_5]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd10.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_126_10);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_126_23]));

DEFLABEL (label_42)
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_126_9]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (Wrd37.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd37.Obj);

DEFLABEL (label_43)
  (Wrd56.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd56.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (label_44)
  (Wrd47.Obj) = (current_block [OBJECT_126_0]);
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_126_8]))));
  (* (--Rsp)) = (Wrd50.Obj);
  (* (--Rsp)) = (Wrd47.Obj);
  (* (--Rsp)) = (Wrd30.Obj);
  INVOKE_INTERFACE_0 (36);

DEFLABEL (label_29)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_42;
  goto label_41;

DEFLABEL (label_45)
  (Wrd54.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_126_7]))));
  (* (--Rsp)) = (Wrd54.Obj);
  (* (--Rsp)) = Rvl;
  goto label_43;

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_126_9);
  (Wrd10.Obj) = (Rsp [1]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 26))
    goto label_47;
  (Wrd14.Lng) = (FIXNUM_TO_LONG (Wrd10.Obj));
  (Wrd12.Lng) = ((Wrd14.Lng) - 1L);
  if (! (LONG_TO_FIXNUM_P (Wrd12.Lng)))
    goto label_47;
  (Wrd9.Obj) = (LONG_TO_FIXNUM (Wrd12.Lng));

DEFLABEL (label_46)
  (Rsp [1]) = (Wrd9.Obj);
  Rsp = (& (Rsp [1]));
  goto loop_23;

DEFLABEL (label_47)
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_126_22]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_INTERFACE_0 (34);

DEFLABEL (label_30)
  (Wrd9.Obj) = Rvl;
  goto label_46;

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_126_7);
  (Wrd10.Obj) = (Rsp [1]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 26))
    goto label_49;
  (Wrd14.Lng) = (FIXNUM_TO_LONG (Wrd10.Obj));
  (Wrd12.Lng) = ((Wrd14.Lng) + 1L);
  if (! (LONG_TO_FIXNUM_P (Wrd12.Lng)))
    goto label_49;
  (Wrd9.Obj) = (LONG_TO_FIXNUM (Wrd12.Lng));

DEFLABEL (label_48)
  (Rsp [1]) = (Wrd9.Obj);
  Rsp = (& (Rsp [1]));
  goto loop_23;

DEFLABEL (label_49)
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_126_24]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_INTERFACE_0 (38);

DEFLABEL (label_31)
  (Wrd9.Obj) = Rvl;
  goto label_48;

DEFLABEL (lambda_35)
DEFLABEL (lambda_4)
  INTERRUPT_CHECK (26, LABEL_126_17);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_126_18]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [0]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_126_19]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_126_18);
  (Rsp [0]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_126_25]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_126_26]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_126_25);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_51;

DEFLABEL (label_50)
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_51)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_126_27]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_126_6]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_126_28]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_126_27);
  goto label_50;

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_127_4 3
#define LABEL_127_5 5
#define LABEL_127_7 7
#define LABEL_127_8 9
#define ENVIRONMENT_LABEL_127_3 20
#define DEBUGGING_LABEL_127_2 19
#define EXECUTE_CACHE_127_10 11
#define EXECUTE_CACHE_127_9 13
#define EXECUTE_CACHE_127_6 15
#define FREE_REFERENCE_127_0 18
#define FREE_REFERENCES_LABEL_127_0 10
#define NUMBER_OF_LINKER_SECTIONS_127_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_127 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_127_4);
      goto define_header_2;

    case 1:
      current_block = (Rpc - LABEL_127_5);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_127_7);
      goto label_4;

    case 3:
      current_block = (Rpc - LABEL_127_8);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (define_header_6)
DEFLABEL (define_header_2)
  INTERRUPT_CHECK (26, LABEL_127_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_127_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_127_6]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_127_5);
  (Rsp [3]) = Rvl;
  (Wrd8.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_127_0]));
  (Wrd11.Obj) = ((Wrd8.pObj) [0]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if ((Wrd12.uLng) == 50)
    goto label_8;
  Wrd7 = Wrd11;

DEFLABEL (label_7)
  (Rsp [1]) = (Wrd7.Obj);
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_127_8]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_127_9]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_127_8);
  (Rsp [2]) = Rvl;
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_127_10]));

DEFLABEL (label_8)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_127_7])), (Wrd8.pObj));

DEFLABEL (label_4)
  (Wrd7.Obj) = Rvl;
  goto label_7;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_128_4 3
#define LABEL_128_5 5
#define ENVIRONMENT_LABEL_128_3 12
#define DEBUGGING_LABEL_128_2 11
#define EXECUTE_CACHE_128_6 7
#define FREE_REFERENCE_128_0 10
#define FREE_REFERENCES_LABEL_128_0 6
#define NUMBER_OF_LINKER_SECTIONS_128_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_128 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_128_4);
      goto header_value_defn_0;

    case 1:
      current_block = (Rpc - LABEL_128_5);
      goto label_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (header_value_defn_4)
DEFLABEL (header_value_defn_0)
  INTERRUPT_CHECK (26, LABEL_128_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd7.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_128_0]));
  (Wrd10.Obj) = ((Wrd7.pObj) [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd11.uLng) == 50)
    goto label_6;
  Wrd6 = Wrd10;

DEFLABEL (label_5)
  (* (--Rsp)) = (Wrd6.Obj);
  (Rsp [2]) = ((SCHEME_OBJECT) 0);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_128_6]));

DEFLABEL (label_6)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_128_5])), (Wrd7.pObj));

DEFLABEL (label_2)
  (Wrd6.Obj) = Rvl;
  goto label_5;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_129_4 3
#define LABEL_129_5 5
#define LABEL_129_7 7
#define ENVIRONMENT_LABEL_129_3 15
#define DEBUGGING_LABEL_129_2 14
#define OBJECT_129_0 13
#define EXECUTE_CACHE_129_6 9
#define FREE_ASSIGNMENT_129_0 12
#define FREE_REFERENCES_LABEL_129_0 8
#define NUMBER_OF_LINKER_SECTIONS_129_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_129 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_129_4);
      goto lambda_1;

    case 1:
      current_block = (Rpc - LABEL_129_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_129_7);
      goto label_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_5)
DEFLABEL (lambda_1)
  INTERRUPT_CHECK (26, LABEL_129_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_129_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_129_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_129_5);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_129_0]));
  (Wrd14.Obj) = ((Wrd6.pObj) [0]);
  (Wrd15.uLng) = (OBJECT_TYPE (Wrd14.Obj));
  if ((Wrd15.uLng) == 50)
    goto label_8;

DEFLABEL (label_7)
  ((Wrd6.pObj) [0]) = Rvl;

DEFLABEL (label_6)
  Rvl = (current_block [OBJECT_129_0]);
  goto pop_return;

DEFLABEL (label_8)
  if ((Wrd14.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_7;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_129_7])), (Wrd6.pObj), Rvl);

DEFLABEL (label_3)
  goto label_6;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_130_4 3
#define ENVIRONMENT_LABEL_130_3 5
#define DEBUGGING_LABEL_130_2 4
#define FREE_REFERENCES_LABEL_130_0 4
#define NUMBER_OF_LINKER_SECTIONS_130_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_130 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_130_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_130_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_131_4 3
#define ENVIRONMENT_LABEL_131_3 5
#define DEBUGGING_LABEL_131_2 4
#define FREE_REFERENCES_LABEL_131_0 4
#define NUMBER_OF_LINKER_SECTIONS_131_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_131 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_131_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_131_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_132_4 3
#define ENVIRONMENT_LABEL_132_3 5
#define DEBUGGING_LABEL_132_2 4
#define FREE_REFERENCES_LABEL_132_0 4
#define NUMBER_OF_LINKER_SECTIONS_132_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_132 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_132_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_132_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_133_4 3
#define ENVIRONMENT_LABEL_133_3 5
#define DEBUGGING_LABEL_133_2 4
#define FREE_REFERENCES_LABEL_133_0 4
#define NUMBER_OF_LINKER_SECTIONS_133_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_133 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_133_4);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_3)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_133_4);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_134_4 3
#define ENVIRONMENT_LABEL_134_3 7
#define DEBUGGING_LABEL_134_2 6
#define OBJECT_134_1 5
#define OBJECT_134_0 4
#define FREE_REFERENCES_LABEL_134_0 4
#define NUMBER_OF_LINKER_SECTIONS_134_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_134 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_134_4);
      goto hvdefn_name_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (hvdefn_name_3)
DEFLABEL (hvdefn_name_0)
  INTERRUPT_CHECK (26, LABEL_134_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_134_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_134_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [2]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_135_4 3
#define ENVIRONMENT_LABEL_135_3 7
#define DEBUGGING_LABEL_135_2 6
#define OBJECT_135_1 5
#define OBJECT_135_0 4
#define FREE_REFERENCES_LABEL_135_0 4
#define NUMBER_OF_LINKER_SECTIONS_135_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_135 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_135_4);
      goto hvdefn_parser_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (hvdefn_parser_3)
DEFLABEL (hvdefn_parser_0)
  INTERRUPT_CHECK (26, LABEL_135_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_135_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_135_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [3]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_136_4 3
#define ENVIRONMENT_LABEL_136_3 7
#define DEBUGGING_LABEL_136_2 6
#define OBJECT_136_1 5
#define OBJECT_136_0 4
#define FREE_REFERENCES_LABEL_136_0 4
#define NUMBER_OF_LINKER_SECTIONS_136_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_136 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_136_4);
      goto hvdefn_predicate_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (hvdefn_predicate_3)
DEFLABEL (hvdefn_predicate_0)
  INTERRUPT_CHECK (26, LABEL_136_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_136_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_136_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 3L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [4]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_137_4 3
#define ENVIRONMENT_LABEL_137_3 7
#define DEBUGGING_LABEL_137_2 6
#define OBJECT_137_1 5
#define OBJECT_137_0 4
#define FREE_REFERENCES_LABEL_137_0 4
#define NUMBER_OF_LINKER_SECTIONS_137_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_137 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_137_4);
      goto hvdefn_writer_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (hvdefn_writer_3)
DEFLABEL (hvdefn_writer_0)
  INTERRUPT_CHECK (26, LABEL_137_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_137_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd18.uLng) == 62)
    goto label_5;

DEFLABEL (label_4)
  INVOKE_PRIMITIVE ((current_block [OBJECT_137_1]), 2);

DEFLABEL (label_5)
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd16.Lng))))
    goto label_4;
  Rvl = ((Wrd14.pObj) [5]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_138_4 3
#define LABEL_138_5 5
#define ENVIRONMENT_LABEL_138_3 12
#define DEBUGGING_LABEL_138_2 11
#define OBJECT_138_2 10
#define OBJECT_138_1 9
#define OBJECT_138_0 8
#define FREE_REFERENCE_138_0 7
#define FREE_REFERENCES_LABEL_138_0 6
#define NUMBER_OF_LINKER_SECTIONS_138_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_138 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd12;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd11;
  machine_word Wrd9;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_138_4);
      goto hvdefnP_2;

    case 1:
      current_block = (Rpc - LABEL_138_5);
      goto label_4;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (hvdefnP_6)
DEFLABEL (hvdefnP_2)
  INTERRUPT_CHECK (26, LABEL_138_4);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 62)
    goto label_9;

DEFLABEL (label_8)
  Rvl = ((SCHEME_OBJECT) 0);

DEFLABEL (label_7)
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_9)
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_138_0]));
  (Wrd11.Obj) = ((Wrd9.pObj) [0]);
  (* (--Rsp)) = (Wrd11.Obj);
  if (! ((Wrd6.uLng) == 62))
    goto label_11;
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd19.Obj) = ((Wrd18.pObj) [0]);
  (Wrd20.Lng) = (FIXNUM_TO_LONG (Wrd19.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd20.Lng))))
    goto label_11;
  (Wrd12.Obj) = ((Wrd18.pObj) [1]);

DEFLABEL (label_10)
  (Wrd28.Obj) = (* (Rsp++));
  if (! ((Wrd12.Obj) == (Wrd28.Obj)))
    goto label_8;
  Rvl = (current_block [OBJECT_138_2]);
  goto label_7;

DEFLABEL (label_11)
  (Wrd23.Obj) = (Rsp [1]);
  (Wrd24.Obj) = (current_block [OBJECT_138_0]);
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_138_5]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_138_1]), 2);

DEFLABEL (label_4)
  (Wrd12.Obj) = Rvl;
  goto label_10;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_139_4 3
#define LABEL_139_5 5
#define LABEL_139_6 7
#define LABEL_139_8 9
#define LABEL_139_11 11
#define ENVIRONMENT_LABEL_139_3 24
#define DEBUGGING_LABEL_139_2 23
#define EXECUTE_CACHE_139_13 13
#define EXECUTE_CACHE_139_12 15
#define EXECUTE_CACHE_139_10 17
#define EXECUTE_CACHE_139_9 19
#define EXECUTE_CACHE_139_7 21
#define FREE_REFERENCES_LABEL_139_0 12
#define NUMBER_OF_LINKER_SECTIONS_139_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_139 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_139_4);
      goto define_comma_list_header_4;

    case 1:
      current_block = (Rpc - LABEL_139_5);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_139_6);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_139_8);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_139_11);
      goto continuation_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (define_comma_list_header_7)
DEFLABEL (define_comma_list_header_4)
  INTERRUPT_CHECK (26, LABEL_139_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_139_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_139_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_139_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_139_6);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_139_10]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_139_5);
  (Rsp [1]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_139_8]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_139_9]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_139_8);
  (Rsp [2]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_139_11]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_139_12]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_139_11);
  (Rsp [3]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_139_13]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_140_4 3
#define LABEL_140_5 5
#define LABEL_140_6 7
#define LABEL_140_8 9
#define LABEL_140_11 11
#define ENVIRONMENT_LABEL_140_3 24
#define DEBUGGING_LABEL_140_2 23
#define EXECUTE_CACHE_140_13 13
#define EXECUTE_CACHE_140_12 15
#define EXECUTE_CACHE_140_10 17
#define EXECUTE_CACHE_140_9 19
#define EXECUTE_CACHE_140_7 21
#define FREE_REFERENCES_LABEL_140_0 12
#define NUMBER_OF_LINKER_SECTIONS_140_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_140 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_140_4);
      goto define_comma_list__header_4;

    case 1:
      current_block = (Rpc - LABEL_140_5);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_140_6);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_140_8);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_140_11);
      goto continuation_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (define_comma_list__header_7)
DEFLABEL (define_comma_list__header_4)
  INTERRUPT_CHECK (26, LABEL_140_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_140_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_140_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_140_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_140_6);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_140_10]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_140_5);
  (Rsp [1]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_140_8]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_140_9]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_140_8);
  (Rsp [2]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_140_11]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_140_12]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_140_11);
  (Rsp [3]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_140_13]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_141_4 3
#define LABEL_141_5 5
#define TAG_141_6 1
#define LABEL_141_7 7
#define LABEL_141_9 9
#define TAG_141_10 3
#define LABEL_141_13 11
#define LABEL_141_11 13
#define LABEL_141_14 15
#define LABEL_141_16 17
#define ENVIRONMENT_LABEL_141_3 32
#define DEBUGGING_LABEL_141_2 31
#define OBJECT_141_3 30
#define OBJECT_141_2 29
#define OBJECT_141_1 28
#define OBJECT_141_0 27
#define EXECUTE_CACHE_141_17 19
#define EXECUTE_CACHE_141_15 21
#define EXECUTE_CACHE_141_12 23
#define EXECUTE_CACHE_141_8 25
#define FREE_REFERENCES_LABEL_141_0 18
#define NUMBER_OF_LINKER_SECTIONS_141_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_141 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd21;
  machine_word Wrd18;
  machine_word Wrd5;
  machine_word Wrd11;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_141_4);
      goto tokenized_parser_8;

    case 1:
      current_block = (Rpc - LABEL_141_5);
      goto lambda_13;

    case 2:
      current_block = (Rpc - LABEL_141_7);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_141_9);
      goto lambda_14;

    case 4:
      current_block = (Rpc - LABEL_141_13);
      goto continuation_4;

    case 5:
      current_block = (Rpc - LABEL_141_11);
      goto continuation_2;

    case 6:
      current_block = (Rpc - LABEL_141_14);
      goto label_10;

    case 7:
      current_block = (Rpc - LABEL_141_16);
      goto continuation_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (tokenized_parser_12)
DEFLABEL (tokenized_parser_8)
  INTERRUPT_CHECK (26, LABEL_141_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_141_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_141_5])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  Rvl = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (lambda_13)
  CLOSURE_HEADER (LABEL_141_5);

DEFLABEL (lambda_7)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_141_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_141_8]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_141_7);
  (Rsp [1]) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_141_10);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_141_9])));
  Rhp += 1;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  Wrd9 = Wrd8;
  (Wrd10.Obj) = (Rsp [2]);
  ((Wrd9.pObj) [2]) = (Wrd10.Obj);
  (Rsp [2]) = (Wrd7.Obj);
  (Wrd12.Obj) = (Rsp [0]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd11.Obj) = ((Wrd13.pObj) [2]);
  (Rsp [0]) = (Wrd11.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (lambda_14)
  CLOSURE_HEADER (LABEL_141_9);

DEFLABEL (lambda_6)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  if ((Wrd5.Obj) == (current_block [OBJECT_141_0]))
    goto label_15;
  Rsp = (& (Rsp [3]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (label_15)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_141_11]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_141_12]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_141_11);
  (Wrd6.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd6.uLng) == 26))
    goto label_18;
  if (Rvl == (current_block [OBJECT_141_1]))
    goto label_16;

DEFLABEL (label_17)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_141_13]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_141_2]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_141_15]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_141_13);

DEFLABEL (label_16)
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_141_16]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (current_block [OBJECT_141_3]);
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_141_17]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_141_16);
  (Rsp [3]) = Rvl;
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [2]);
  (Rsp [2]) = (Wrd6.Obj);
  Rsp = (& (Rsp [2]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (label_18)
  (Wrd18.Obj) = (current_block [OBJECT_141_1]);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_141_14]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = Rvl;
  INVOKE_INTERFACE_0 (36);

DEFLABEL (label_10)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_17;
  goto label_16;

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_142_4 3
#define LABEL_142_5 5
#define TAG_142_6 1
#define LABEL_142_9 7
#define LABEL_142_7 9
#define LABEL_142_10 11
#define LABEL_142_11 13
#define ENVIRONMENT_LABEL_142_3 25
#define DEBUGGING_LABEL_142_2 24
#define OBJECT_142_4 23
#define OBJECT_142_3 22
#define OBJECT_142_2 21
#define OBJECT_142_1 20
#define OBJECT_142_0 19
#define EXECUTE_CACHE_142_12 15
#define EXECUTE_CACHE_142_8 17
#define FREE_REFERENCES_LABEL_142_0 14
#define NUMBER_OF_LINKER_SECTIONS_142_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_142 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd38;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd23;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd17;
  machine_word Wrd13;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_142_4);
      goto direct_parser_7;

    case 1:
      current_block = (Rpc - LABEL_142_5);
      goto lambda_13;

    case 2:
      current_block = (Rpc - LABEL_142_9);
      goto continuation_3;

    case 3:
      current_block = (Rpc - LABEL_142_7);
      goto continuation_0;

    case 4:
      current_block = (Rpc - LABEL_142_10);
      goto label_9;

    case 5:
      current_block = (Rpc - LABEL_142_11);
      goto label_10;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (direct_parser_12)
DEFLABEL (direct_parser_7)
  INTERRUPT_CHECK (26, LABEL_142_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_142_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_142_5])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  Rvl = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (lambda_13)
  CLOSURE_HEADER (LABEL_142_5);

DEFLABEL (lambda_6)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_142_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_142_8]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_142_7);
  (* (--Rsp)) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_14;
  Rsp = (& (Rsp [4]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (label_14)
  (Wrd13.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd13.uLng) == 10))
    goto label_19;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd11.Obj) = ((Wrd10.pObj) [0]);
  (Wrd7.Obj) = (MAKE_OBJECT (26, (Wrd11.uLng)));

DEFLABEL (label_18)
  if ((Wrd7.Obj) == (current_block [OBJECT_142_1]))
    goto label_17;
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_142_9]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd22.Obj) = (current_block [OBJECT_142_4]);
  (* (--Rsp)) = (Wrd22.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_142_12]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_142_9);

DEFLABEL (label_17)
  (Wrd32.Obj) = (Rsp [0]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd33.uLng) == 10))
    goto label_16;
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd30.Obj) = ((Wrd29.pObj) [0]);
  (Wrd31.Lng) = (FIXNUM_TO_LONG (Wrd30.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd31.Lng))))
    goto label_16;
  (Wrd23.Obj) = ((Wrd29.pObj) [1]);

DEFLABEL (label_15)
  (Rsp [4]) = (Wrd23.Obj);
  Rsp = (& (Rsp [3]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (label_16)
  (Wrd34.Obj) = (Rsp [0]);
  (Wrd35.Obj) = (current_block [OBJECT_142_2]);
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_142_11]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_142_3]), 2);

DEFLABEL (label_10)
  (Wrd23.Obj) = Rvl;
  goto label_15;

DEFLABEL (label_19)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_142_10]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_142_0]), 1);

DEFLABEL (label_9)
  (Wrd7.Obj) = Rvl;
  goto label_18;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_143_4 3
#define LABEL_143_6 5
#define LABEL_143_7 7
#define LABEL_143_8 9
#define LABEL_143_5 11
#define LABEL_143_11 13
#define LABEL_143_12 15
#define LABEL_143_13 17
#define LABEL_143_10 19
#define LABEL_143_15 21
#define LABEL_143_16 23
#define LABEL_143_18 25
#define LABEL_143_14 27
#define LABEL_143_21 29
#define LABEL_143_22 31
#define LABEL_143_23 33
#define LABEL_143_17 35
#define LABEL_143_20 37
#define LABEL_143_26 39
#define LABEL_143_27 41
#define LABEL_143_28 43
#define LABEL_143_25 45
#define LABEL_143_30 47
#define LABEL_143_31 49
#define LABEL_143_32 51
#define LABEL_143_29 53
#define LABEL_143_34 55
#define LABEL_143_35 57
#define LABEL_143_36 59
#define LABEL_143_33 61
#define LABEL_143_40 63
#define LABEL_143_37 65
#define LABEL_143_38 67
#define LABEL_143_48 69
#define LABEL_143_39 71
#define LABEL_143_50 73
#define LABEL_143_52 75
#define LABEL_143_54 77
#define LABEL_143_42 79
#define LABEL_143_59 81
#define LABEL_143_60 83
#define LABEL_143_43 85
#define LABEL_143_64 87
#define LABEL_143_44 89
#define LABEL_143_65 91
#define LABEL_143_66 93
#define LABEL_143_67 95
#define LABEL_143_45 97
#define LABEL_143_46 99
#define LABEL_143_47 101
#define LABEL_143_74 103
#define LABEL_143_76 105
#define LABEL_143_78 107
#define LABEL_143_51 109
#define LABEL_143_53 111
#define LABEL_143_55 113
#define LABEL_143_82 115
#define LABEL_143_83 117
#define LABEL_143_84 119
#define LABEL_143_56 121
#define LABEL_143_86 123
#define LABEL_143_88 125
#define LABEL_143_89 127
#define LABEL_143_57 129
#define LABEL_143_58 131
#define LABEL_143_62 133
#define LABEL_143_63 135
#define LABEL_143_95 137
#define LABEL_143_96 139
#define LABEL_143_97 141
#define LABEL_143_69 143
#define LABEL_143_70 145
#define TAG_143_71 71
#define LABEL_143_73 147
#define LABEL_143_75 149
#define LABEL_143_77 151
#define LABEL_143_81 153
#define LABEL_143_111 155
#define LABEL_143_112 157
#define LABEL_143_113 159
#define LABEL_143_85 161
#define LABEL_143_87 163
#define LABEL_143_92 165
#define LABEL_143_94 167
#define LABEL_143_101 169
#define TAG_143_102 83
#define LABEL_143_103 171
#define TAG_143_104 84
#define LABEL_143_105 173
#define TAG_143_106 85
#define LABEL_143_110 175
#define LABEL_143_128 177
#define LABEL_143_131 179
#define LABEL_143_114 181
#define LABEL_143_117 183
#define TAG_143_118 90
#define LABEL_143_120 185
#define TAG_143_121 91
#define LABEL_143_122 187
#define TAG_143_123 92
#define LABEL_143_125 189
#define TAG_143_126 93
#define LABEL_143_127 191
#define LABEL_143_142 193
#define LABEL_143_144 195
#define LABEL_143_146 197
#define LABEL_143_129 199
#define LABEL_143_130 201
#define LABEL_143_149 203
#define LABEL_143_133 205
#define TAG_143_134 101
#define LABEL_143_151 207
#define LABEL_143_152 209
#define LABEL_143_135 211
#define LABEL_143_155 213
#define LABEL_143_160 215
#define LABEL_143_136 217
#define LABEL_143_162 219
#define LABEL_143_138 221
#define TAG_143_139 109
#define LABEL_143_141 223
#define LABEL_143_167 225
#define LABEL_143_168 227
#define LABEL_143_170 229
#define LABEL_143_143 231
#define LABEL_143_145 233
#define LABEL_143_148 235
#define LABEL_143_153 237
#define TAG_143_154 117
#define LABEL_143_156 239
#define TAG_143_157 118
#define LABEL_143_178 241
#define LABEL_143_179 243
#define LABEL_143_158 245
#define TAG_143_159 121
#define LABEL_143_183 247
#define LABEL_143_163 249
#define TAG_143_164 123
#define LABEL_143_166 251
#define LABEL_143_193 253
#define LABEL_143_194 255
#define LABEL_143_196 257
#define LABEL_143_169 259
#define LABEL_143_171 261
#define LABEL_143_172 263
#define TAG_143_173 130
#define LABEL_143_175 265
#define TAG_143_176 131
#define LABEL_143_180 267
#define TAG_143_181 132
#define LABEL_143_210 269
#define LABEL_143_213 271
#define LABEL_143_184 273
#define TAG_143_185 135
#define LABEL_143_186 275
#define TAG_143_187 136
#define LABEL_143_188 277
#define TAG_143_189 137
#define LABEL_143_190 279
#define TAG_143_191 138
#define LABEL_143_192 281
#define LABEL_143_224 283
#define LABEL_143_225 285
#define LABEL_143_227 287
#define LABEL_143_195 289
#define LABEL_143_198 291
#define TAG_143_199 144
#define LABEL_143_200 293
#define LABEL_143_201 295
#define LABEL_143_202 297
#define LABEL_143_203 299
#define LABEL_143_233 301
#define LABEL_143_204 303
#define LABEL_143_205 305
#define LABEL_143_206 307
#define TAG_143_207 152
#define LABEL_143_208 309
#define TAG_143_209 153
#define LABEL_143_211 311
#define TAG_143_212 154
#define LABEL_143_214 313
#define LABEL_143_215 315
#define LABEL_143_241 317
#define LABEL_143_216 319
#define LABEL_143_217 321
#define LABEL_143_242 323
#define LABEL_143_218 325
#define TAG_143_219 161
#define LABEL_143_221 327
#define TAG_143_222 162
#define LABEL_143_223 329
#define LABEL_143_246 331
#define LABEL_143_247 333
#define LABEL_143_249 335
#define LABEL_143_226 337
#define LABEL_143_228 339
#define TAG_143_229 168
#define LABEL_143_230 341
#define TAG_143_231 169
#define LABEL_143_234 343
#define LABEL_143_235 345
#define LABEL_143_236 347
#define LABEL_143_257 349
#define LABEL_143_237 351
#define TAG_143_238 174
#define LABEL_143_239 353
#define LABEL_143_240 355
#define LABEL_143_261 357
#define LABEL_143_243 359
#define TAG_143_244 178
#define LABEL_143_245 361
#define LABEL_143_265 363
#define LABEL_143_266 365
#define LABEL_143_267 367
#define LABEL_143_248 369
#define LABEL_143_250 371
#define LABEL_143_251 373
#define LABEL_143_270 375
#define LABEL_143_252 377
#define TAG_143_253 187
#define LABEL_143_255 379
#define LABEL_143_258 381
#define LABEL_143_260 383
#define LABEL_143_263 385
#define LABEL_143_273 387
#define LABEL_143_274 389
#define LABEL_143_276 391
#define LABEL_143_264 393
#define LABEL_143_278 395
#define LABEL_143_279 397
#define LABEL_143_268 399
#define LABEL_143_269 401
#define LABEL_143_280 403
#define LABEL_143_272 405
#define LABEL_143_282 407
#define LABEL_143_283 409
#define LABEL_143_285 411
#define LABEL_143_275 413
#define LABEL_143_277 415
#define LABEL_143_287 417
#define LABEL_143_281 419
#define LABEL_143_290 421
#define LABEL_143_291 423
#define LABEL_143_284 425
#define LABEL_143_286 427
#define LABEL_143_293 429
#define LABEL_143_288 431
#define LABEL_143_295 433
#define LABEL_143_289 435
#define LABEL_143_300 437
#define LABEL_143_301 439
#define LABEL_143_292 441
#define LABEL_143_294 443
#define LABEL_143_305 445
#define LABEL_143_307 447
#define LABEL_143_308 449
#define LABEL_143_296 451
#define LABEL_143_297 453
#define LABEL_143_298 455
#define LABEL_143_299 457
#define LABEL_143_302 459
#define TAG_143_303 228
#define LABEL_143_304 461
#define LABEL_143_318 463
#define LABEL_143_319 465
#define LABEL_143_321 467
#define LABEL_143_306 469
#define LABEL_143_309 471
#define LABEL_143_311 473
#define LABEL_143_313 475
#define LABEL_143_314 477
#define LABEL_143_315 479
#define TAG_143_316 238
#define LABEL_143_317 481
#define LABEL_143_331 483
#define LABEL_143_320 485
#define LABEL_143_322 487
#define LABEL_143_323 489
#define LABEL_143_325 491
#define LABEL_143_326 493
#define TAG_143_327 245
#define LABEL_143_329 495
#define LABEL_143_344 497
#define LABEL_143_345 499
#define LABEL_143_347 501
#define LABEL_143_330 503
#define LABEL_143_349 505
#define LABEL_143_332 507
#define LABEL_143_350 509
#define LABEL_143_334 511
#define TAG_143_335 254
#define LABEL_143_336 513
#define TAG_143_337 255
#define LABEL_143_338 515
#define LABEL_143_340 517
#define TAG_143_341 257
#define LABEL_143_343 519
#define LABEL_143_359 521
#define LABEL_143_360 523
#define LABEL_143_362 525
#define LABEL_143_346 527
#define LABEL_143_348 529
#define LABEL_143_351 531
#define TAG_143_352 264
#define LABEL_143_353 533
#define LABEL_143_370 535
#define LABEL_143_372 537
#define LABEL_143_355 539
#define TAG_143_356 268
#define LABEL_143_358 541
#define LABEL_143_376 543
#define LABEL_143_377 545
#define LABEL_143_379 547
#define LABEL_143_361 549
#define LABEL_143_363 551
#define LABEL_143_364 553
#define LABEL_143_366 555
#define LABEL_143_367 557
#define LABEL_143_382 559
#define LABEL_143_368 561
#define LABEL_143_371 563
#define LABEL_143_373 565
#define LABEL_143_374 567
#define LABEL_143_386 569
#define LABEL_143_375 571
#define LABEL_143_389 573
#define LABEL_143_390 575
#define LABEL_143_391 577
#define LABEL_143_378 579
#define LABEL_143_380 581
#define TAG_143_381 289
#define LABEL_143_384 583
#define TAG_143_385 290
#define LABEL_143_383 585
#define LABEL_143_387 587
#define LABEL_143_398 589
#define LABEL_143_399 591
#define LABEL_143_401 593
#define LABEL_143_388 595
#define LABEL_143_403 597
#define LABEL_143_404 599
#define LABEL_143_392 601
#define TAG_143_393 299
#define LABEL_143_394 603
#define TAG_143_395 300
#define LABEL_143_396 605
#define LABEL_143_397 607
#define LABEL_143_412 609
#define LABEL_143_413 611
#define LABEL_143_414 613
#define LABEL_143_400 615
#define LABEL_143_402 617
#define LABEL_143_405 619
#define TAG_143_406 308
#define LABEL_143_408 621
#define LABEL_143_409 623
#define LABEL_143_410 625
#define LABEL_143_420 627
#define LABEL_143_421 629
#define LABEL_143_422 631
#define LABEL_143_411 633
#define LABEL_143_425 635
#define LABEL_143_415 637
#define LABEL_143_416 639
#define LABEL_143_417 641
#define LABEL_143_418 643
#define LABEL_143_419 645
#define LABEL_143_430 647
#define LABEL_143_431 649
#define LABEL_143_432 651
#define LABEL_143_423 653
#define LABEL_143_424 655
#define LABEL_143_435 657
#define LABEL_143_427 659
#define LABEL_143_428 661
#define LABEL_143_429 663
#define LABEL_143_439 665
#define LABEL_143_440 667
#define LABEL_143_433 669
#define LABEL_143_434 671
#define LABEL_143_436 673
#define LABEL_143_438 675
#define LABEL_143_447 677
#define LABEL_143_448 679
#define LABEL_143_450 681
#define LABEL_143_441 683
#define LABEL_143_442 685
#define TAG_143_443 341
#define LABEL_143_445 687
#define LABEL_143_446 689
#define LABEL_143_458 691
#define LABEL_143_449 693
#define LABEL_143_451 695
#define TAG_143_452 346
#define LABEL_143_453 697
#define TAG_143_454 347
#define LABEL_143_455 699
#define LABEL_143_457 701
#define LABEL_143_459 703
#define LABEL_143_460 705
#define LABEL_143_461 707
#define LABEL_143_462 709
#define LABEL_143_463 711
#define LABEL_143_471 713
#define LABEL_143_464 715
#define LABEL_143_465 717
#define LABEL_143_475 719
#define LABEL_143_476 721
#define LABEL_143_477 723
#define LABEL_143_466 725
#define LABEL_143_467 727
#define LABEL_143_468 729
#define LABEL_143_469 731
#define LABEL_143_470 733
#define LABEL_143_472 735
#define LABEL_143_490 737
#define LABEL_143_473 739
#define LABEL_143_493 741
#define LABEL_143_494 743
#define LABEL_143_474 745
#define LABEL_143_496 747
#define LABEL_143_497 749
#define LABEL_143_498 751
#define LABEL_143_479 753
#define LABEL_143_480 755
#define LABEL_143_482 757
#define LABEL_143_502 759
#define LABEL_143_503 761
#define LABEL_143_484 763
#define LABEL_143_486 765
#define LABEL_143_487 767
#define LABEL_143_488 769
#define LABEL_143_510 771
#define LABEL_143_511 773
#define LABEL_143_489 775
#define LABEL_143_513 777
#define LABEL_143_491 779
#define LABEL_143_492 781
#define LABEL_143_518 783
#define LABEL_143_519 785
#define LABEL_143_495 787
#define LABEL_143_520 789
#define LABEL_143_500 791
#define LABEL_143_506 793
#define LABEL_143_507 795
#define LABEL_143_522 797
#define LABEL_143_523 799
#define LABEL_143_525 801
#define LABEL_143_508 803
#define LABEL_143_527 805
#define LABEL_143_509 807
#define LABEL_143_512 809
#define LABEL_143_515 811
#define LABEL_143_516 813
#define LABEL_143_517 815
#define LABEL_143_532 817
#define LABEL_143_504 819
#define LABEL_143_521 821
#define LABEL_143_524 823
#define LABEL_143_526 825
#define LABEL_143_528 827
#define LABEL_143_529 829
#define LABEL_143_530 831
#define TAG_143_531 414
#define LABEL_143_539 833
#define LABEL_143_546 835
#define LABEL_143_533 837
#define LABEL_143_534 839
#define LABEL_143_535 841
#define LABEL_143_536 843
#define TAG_143_537 420
#define LABEL_143_540 845
#define TAG_143_541 421
#define LABEL_143_542 847
#define TAG_143_543 422
#define LABEL_143_553 849
#define LABEL_143_554 851
#define LABEL_143_544 853
#define TAG_143_545 425
#define LABEL_143_557 855
#define LABEL_143_547 857
#define LABEL_143_548 859
#define TAG_143_549 428
#define LABEL_143_551 861
#define TAG_143_552 429
#define LABEL_143_555 863
#define TAG_143_556 430
#define LABEL_143_558 865
#define TAG_143_559 431
#define LABEL_143_560 867
#define LABEL_143_561 869
#define LABEL_143_562 871
#define LABEL_143_570 873
#define LABEL_143_563 875
#define TAG_143_564 436
#define LABEL_143_565 877
#define TAG_143_566 437
#define LABEL_143_567 879
#define LABEL_143_568 881
#define LABEL_143_575 883
#define LABEL_143_569 885
#define LABEL_143_577 887
#define LABEL_143_571 889
#define LABEL_143_572 891
#define LABEL_143_579 893
#define LABEL_143_573 895
#define TAG_143_574 446
#define LABEL_143_576 897
#define LABEL_143_581 899
#define LABEL_143_580 901
#define LABEL_143_582 903
#define LABEL_143_584 905
#define LABEL_143_583 907
#define LABEL_143_585 909
#define ENVIRONMENT_LABEL_143_3 1177
#define DEBUGGING_LABEL_143_2 1176
#define OBJECT_143_59 1175
#define OBJECT_143_58 1174
#define OBJECT_143_57 1173
#define OBJECT_143_56 1172
#define OBJECT_143_55 1171
#define OBJECT_143_54 1170
#define OBJECT_143_53 1169
#define OBJECT_143_52 1168
#define OBJECT_143_51 1167
#define OBJECT_143_50 1166
#define OBJECT_143_49 1165
#define OBJECT_143_48 1164
#define OBJECT_143_47 1163
#define OBJECT_143_46 1162
#define OBJECT_143_45 1161
#define OBJECT_143_44 1160
#define OBJECT_143_43 1159
#define OBJECT_143_42 1158
#define OBJECT_143_41 1157
#define OBJECT_143_40 1156
#define OBJECT_143_39 1155
#define OBJECT_143_38 1154
#define OBJECT_143_37 1153
#define OBJECT_143_36 1152
#define OBJECT_143_35 1151
#define OBJECT_143_34 1150
#define OBJECT_143_33 1149
#define OBJECT_143_32 1148
#define OBJECT_143_31 1147
#define OBJECT_143_30 1146
#define OBJECT_143_29 1145
#define OBJECT_143_28 1144
#define OBJECT_143_27 1143
#define OBJECT_143_26 1142
#define OBJECT_143_25 1141
#define OBJECT_143_24 1140
#define OBJECT_143_23 1139
#define OBJECT_143_22 1138
#define OBJECT_143_21 1137
#define OBJECT_143_20 1136
#define OBJECT_143_19 1135
#define OBJECT_143_18 1134
#define OBJECT_143_17 1133
#define OBJECT_143_16 1132
#define OBJECT_143_15 1131
#define OBJECT_143_14 1130
#define OBJECT_143_13 1129
#define OBJECT_143_12 1128
#define OBJECT_143_11 1127
#define OBJECT_143_10 1126
#define OBJECT_143_9 1125
#define OBJECT_143_8 1124
#define OBJECT_143_7 1123
#define OBJECT_143_6 1122
#define OBJECT_143_5 1121
#define OBJECT_143_4 1120
#define OBJECT_143_3 1119
#define OBJECT_143_2 1118
#define OBJECT_143_1 1117
#define OBJECT_143_0 1116
#define EXECUTE_CACHE_143_578 911
#define EXECUTE_CACHE_143_550 913
#define EXECUTE_CACHE_143_538 915
#define EXECUTE_CACHE_143_514 917
#define EXECUTE_CACHE_143_505 919
#define EXECUTE_CACHE_143_501 921
#define EXECUTE_CACHE_143_499 923
#define EXECUTE_CACHE_143_485 925
#define EXECUTE_CACHE_143_483 927
#define EXECUTE_CACHE_143_481 929
#define EXECUTE_CACHE_143_444 931
#define EXECUTE_CACHE_143_437 933
#define EXECUTE_CACHE_143_426 935
#define EXECUTE_CACHE_143_407 937
#define EXECUTE_CACHE_143_369 939
#define EXECUTE_CACHE_143_365 941
#define EXECUTE_CACHE_143_357 943
#define EXECUTE_CACHE_143_354 945
#define EXECUTE_CACHE_143_342 947
#define EXECUTE_CACHE_143_339 949
#define EXECUTE_CACHE_143_333 951
#define EXECUTE_CACHE_143_328 953
#define EXECUTE_CACHE_143_324 955
#define EXECUTE_CACHE_143_312 957
#define EXECUTE_CACHE_143_310 959
#define EXECUTE_CACHE_143_271 961
#define EXECUTE_CACHE_143_262 963
#define EXECUTE_CACHE_143_259 965
#define EXECUTE_CACHE_143_256 967
#define EXECUTE_CACHE_143_254 969
#define EXECUTE_CACHE_143_232 971
#define EXECUTE_CACHE_143_220 973
#define EXECUTE_CACHE_143_197 975
#define EXECUTE_CACHE_143_182 977
#define EXECUTE_CACHE_143_177 979
#define EXECUTE_CACHE_143_174 981
#define EXECUTE_CACHE_143_165 983
#define EXECUTE_CACHE_143_161 985
#define EXECUTE_CACHE_143_150 987
#define EXECUTE_CACHE_143_147 989
#define EXECUTE_CACHE_143_140 991
#define EXECUTE_CACHE_143_137 993
#define EXECUTE_CACHE_143_132 995
#define EXECUTE_CACHE_143_124 997
#define EXECUTE_CACHE_143_456 999
#define EXECUTE_CACHE_143_119 1001
#define EXECUTE_CACHE_143_116 1003
#define EXECUTE_CACHE_143_115 1005
#define EXECUTE_CACHE_143_109 1007
#define EXECUTE_CACHE_143_107 1009
#define EXECUTE_CACHE_143_100 1011
#define EXECUTE_CACHE_143_99 1013
#define EXECUTE_CACHE_143_108 1015
#define EXECUTE_CACHE_143_98 1017
#define EXECUTE_CACHE_143_93 1019
#define EXECUTE_CACHE_143_91 1021
#define EXECUTE_CACHE_143_478 1023
#define EXECUTE_CACHE_143_90 1025
#define EXECUTE_CACHE_143_80 1027
#define EXECUTE_CACHE_143_72 1029
#define EXECUTE_CACHE_143_79 1031
#define EXECUTE_CACHE_143_68 1033
#define EXECUTE_CACHE_143_61 1035
#define EXECUTE_CACHE_143_49 1037
#define EXECUTE_CACHE_143_41 1039
#define EXECUTE_CACHE_143_24 1041
#define EXECUTE_CACHE_143_19 1043
#define EXECUTE_CACHE_143_9 1045
#define FREE_REFERENCE_143_67 1048
#define FREE_REFERENCE_143_66 1049
#define FREE_REFERENCE_143_65 1050
#define FREE_REFERENCE_143_64 1051
#define FREE_REFERENCE_143_63 1052
#define FREE_REFERENCE_143_62 1053
#define FREE_REFERENCE_143_61 1054
#define FREE_REFERENCE_143_60 1055
#define FREE_REFERENCE_143_59 1056
#define FREE_REFERENCE_143_58 1057
#define FREE_REFERENCE_143_57 1058
#define FREE_REFERENCE_143_56 1059
#define FREE_REFERENCE_143_55 1060
#define FREE_REFERENCE_143_54 1061
#define FREE_REFERENCE_143_53 1062
#define FREE_REFERENCE_143_52 1063
#define FREE_REFERENCE_143_51 1064
#define FREE_REFERENCE_143_50 1065
#define FREE_REFERENCE_143_49 1066
#define FREE_REFERENCE_143_48 1067
#define FREE_REFERENCE_143_47 1068
#define FREE_REFERENCE_143_46 1069
#define FREE_REFERENCE_143_45 1070
#define FREE_REFERENCE_143_44 1071
#define FREE_REFERENCE_143_43 1072
#define FREE_REFERENCE_143_42 1073
#define FREE_REFERENCE_143_41 1074
#define FREE_REFERENCE_143_40 1075
#define FREE_REFERENCE_143_39 1076
#define FREE_REFERENCE_143_38 1077
#define FREE_REFERENCE_143_37 1078
#define FREE_REFERENCE_143_36 1079
#define FREE_REFERENCE_143_35 1080
#define FREE_REFERENCE_143_34 1081
#define FREE_REFERENCE_143_33 1082
#define FREE_REFERENCE_143_32 1083
#define FREE_REFERENCE_143_31 1084
#define FREE_REFERENCE_143_30 1085
#define FREE_REFERENCE_143_29 1086
#define FREE_REFERENCE_143_28 1087
#define FREE_REFERENCE_143_27 1088
#define FREE_REFERENCE_143_26 1089
#define FREE_REFERENCE_143_25 1090
#define FREE_REFERENCE_143_24 1091
#define FREE_REFERENCE_143_23 1092
#define FREE_REFERENCE_143_22 1093
#define FREE_REFERENCE_143_21 1094
#define FREE_REFERENCE_143_20 1095
#define FREE_REFERENCE_143_19 1096
#define FREE_REFERENCE_143_18 1097
#define FREE_REFERENCE_143_17 1098
#define FREE_REFERENCE_143_16 1099
#define FREE_REFERENCE_143_15 1100
#define FREE_REFERENCE_143_14 1101
#define FREE_REFERENCE_143_13 1102
#define FREE_REFERENCE_143_12 1103
#define FREE_REFERENCE_143_11 1104
#define FREE_REFERENCE_143_10 1105
#define FREE_REFERENCE_143_9 1106
#define FREE_REFERENCE_143_8 1107
#define FREE_REFERENCE_143_7 1108
#define FREE_REFERENCE_143_6 1109
#define FREE_REFERENCE_143_5 1110
#define FREE_REFERENCE_143_4 1111
#define FREE_REFERENCE_143_3 1112
#define FREE_REFERENCE_143_2 1113
#define FREE_REFERENCE_143_1 1114
#define FREE_REFERENCE_143_0 1115
#define FREE_REFERENCES_LABEL_143_0 910
#define NUMBER_OF_LINKER_SECTIONS_143_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_143 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd57;
  machine_word Wrd49;
  machine_word Wrd51;
  machine_word Wrd53;
  machine_word Wrd52;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd44;
  machine_word Wrd45;
  machine_word Wrd41;
  machine_word Wrd39;
  machine_word Wrd46;
  machine_word Wrd38;
  machine_word Wrd40;
  machine_word Wrd42;
  machine_word Wrd37;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd29;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd17;
  machine_word Wrd6;
  machine_word Wrd11;
  machine_word Wrd16;
  machine_word Wrd10;
  machine_word Wrd5;
  machine_word Wrd23;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd22;
  machine_word Wrd26;
  machine_word Wrd20;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd21;
  machine_word Wrd14;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd8;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd9;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_143_4);
      goto lambda_379;

    case 1:
      current_block = (Rpc - LABEL_143_6);
      goto label_381;

    case 2:
      current_block = (Rpc - LABEL_143_7);
      goto label_382;

    case 3:
      current_block = (Rpc - LABEL_143_8);
      goto label_383;

    case 4:
      current_block = (Rpc - LABEL_143_5);
      goto continuation_0;

    case 5:
      current_block = (Rpc - LABEL_143_11);
      goto label_384;

    case 6:
      current_block = (Rpc - LABEL_143_12);
      goto label_385;

    case 7:
      current_block = (Rpc - LABEL_143_13);
      goto label_386;

    case 8:
      current_block = (Rpc - LABEL_143_10);
      goto continuation_1;

    case 9:
      current_block = (Rpc - LABEL_143_15);
      goto label_387;

    case 10:
      current_block = (Rpc - LABEL_143_16);
      goto label_388;

    case 11:
      current_block = (Rpc - LABEL_143_18);
      goto label_389;

    case 12:
      current_block = (Rpc - LABEL_143_14);
      goto continuation_3;

    case 13:
      current_block = (Rpc - LABEL_143_21);
      goto label_390;

    case 14:
      current_block = (Rpc - LABEL_143_22);
      goto label_391;

    case 15:
      current_block = (Rpc - LABEL_143_23);
      goto label_392;

    case 16:
      current_block = (Rpc - LABEL_143_17);
      goto continuation_2;

    case 17:
      current_block = (Rpc - LABEL_143_20);
      goto continuation_4;

    case 18:
      current_block = (Rpc - LABEL_143_26);
      goto label_393;

    case 19:
      current_block = (Rpc - LABEL_143_27);
      goto label_394;

    case 20:
      current_block = (Rpc - LABEL_143_28);
      goto label_395;

    case 21:
      current_block = (Rpc - LABEL_143_25);
      goto continuation_5;

    case 22:
      current_block = (Rpc - LABEL_143_30);
      goto label_396;

    case 23:
      current_block = (Rpc - LABEL_143_31);
      goto label_397;

    case 24:
      current_block = (Rpc - LABEL_143_32);
      goto label_398;

    case 25:
      current_block = (Rpc - LABEL_143_29);
      goto continuation_6;

    case 26:
      current_block = (Rpc - LABEL_143_34);
      goto label_399;

    case 27:
      current_block = (Rpc - LABEL_143_35);
      goto label_400;

    case 28:
      current_block = (Rpc - LABEL_143_36);
      goto label_401;

    case 29:
      current_block = (Rpc - LABEL_143_33);
      goto continuation_7;

    case 30:
      current_block = (Rpc - LABEL_143_40);
      goto label_402;

    case 31:
      current_block = (Rpc - LABEL_143_37);
      goto continuation_48;

    case 32:
      current_block = (Rpc - LABEL_143_38);
      goto continuation_47;

    case 33:
      current_block = (Rpc - LABEL_143_48);
      goto label_403;

    case 34:
      current_block = (Rpc - LABEL_143_39);
      goto continuation_46;

    case 35:
      current_block = (Rpc - LABEL_143_50);
      goto label_404;

    case 36:
      current_block = (Rpc - LABEL_143_52);
      goto label_405;

    case 37:
      current_block = (Rpc - LABEL_143_54);
      goto label_406;

    case 38:
      current_block = (Rpc - LABEL_143_42);
      goto continuation_96;

    case 39:
      current_block = (Rpc - LABEL_143_59);
      goto label_407;

    case 40:
      current_block = (Rpc - LABEL_143_60);
      goto label_408;

    case 41:
      current_block = (Rpc - LABEL_143_43);
      goto continuation_95;

    case 42:
      current_block = (Rpc - LABEL_143_64);
      goto label_409;

    case 43:
      current_block = (Rpc - LABEL_143_44);
      goto continuation_94;

    case 44:
      current_block = (Rpc - LABEL_143_65);
      goto label_410;

    case 45:
      current_block = (Rpc - LABEL_143_66);
      goto label_411;

    case 46:
      current_block = (Rpc - LABEL_143_67);
      goto label_412;

    case 47:
      current_block = (Rpc - LABEL_143_45);
      goto lambda_93;

    case 48:
      current_block = (Rpc - LABEL_143_46);
      goto continuation_43;

    case 49:
      current_block = (Rpc - LABEL_143_47);
      goto continuation_42;

    case 50:
      current_block = (Rpc - LABEL_143_74);
      goto label_413;

    case 51:
      current_block = (Rpc - LABEL_143_76);
      goto label_414;

    case 52:
      current_block = (Rpc - LABEL_143_78);
      goto label_415;

    case 53:
      current_block = (Rpc - LABEL_143_51);
      goto continuation_45;

    case 54:
      current_block = (Rpc - LABEL_143_53);
      goto continuation_44;

    case 55:
      current_block = (Rpc - LABEL_143_55);
      goto continuation_121;

    case 56:
      current_block = (Rpc - LABEL_143_82);
      goto label_416;

    case 57:
      current_block = (Rpc - LABEL_143_83);
      goto label_417;

    case 58:
      current_block = (Rpc - LABEL_143_84);
      goto label_418;

    case 59:
      current_block = (Rpc - LABEL_143_56);
      goto continuation_120;

    case 60:
      current_block = (Rpc - LABEL_143_86);
      goto label_419;

    case 61:
      current_block = (Rpc - LABEL_143_88);
      goto label_420;

    case 62:
      current_block = (Rpc - LABEL_143_89);
      goto label_421;

    case 63:
      current_block = (Rpc - LABEL_143_57);
      goto continuation_119;

    case 64:
      current_block = (Rpc - LABEL_143_58);
      goto lambda_118;

    case 65:
      current_block = (Rpc - LABEL_143_62);
      goto continuation_90;

    case 66:
      current_block = (Rpc - LABEL_143_63);
      goto continuation_89;

    case 67:
      current_block = (Rpc - LABEL_143_95);
      goto label_422;

    case 68:
      current_block = (Rpc - LABEL_143_96);
      goto label_423;

    case 69:
      current_block = (Rpc - LABEL_143_97);
      goto label_424;

    case 70:
      current_block = (Rpc - LABEL_143_69);
      goto continuation_92;

    case 71:
      current_block = (Rpc - LABEL_143_70);
      goto lambda_562;

    case 72:
      current_block = (Rpc - LABEL_143_73);
      goto lambda_39;

    case 73:
      current_block = (Rpc - LABEL_143_75);
      goto continuation_41;

    case 74:
      current_block = (Rpc - LABEL_143_77);
      goto continuation_40;

    case 75:
      current_block = (Rpc - LABEL_143_81);
      goto continuation_122;

    case 76:
      current_block = (Rpc - LABEL_143_111);
      goto label_425;

    case 77:
      current_block = (Rpc - LABEL_143_112);
      goto label_426;

    case 78:
      current_block = (Rpc - LABEL_143_113);
      goto label_427;

    case 79:
      current_block = (Rpc - LABEL_143_85);
      goto continuation_116;

    case 80:
      current_block = (Rpc - LABEL_143_87);
      goto continuation_115;

    case 81:
      current_block = (Rpc - LABEL_143_92);
      goto continuation_117;

    case 82:
      current_block = (Rpc - LABEL_143_94);
      goto lambda_88;

    case 83:
      current_block = (Rpc - LABEL_143_101);
      goto lambda_31;

    case 84:
      current_block = (Rpc - LABEL_143_103);
      goto lambda_566;

    case 85:
      current_block = (Rpc - LABEL_143_105);
      goto lambda_567;

    case 86:
      current_block = (Rpc - LABEL_143_110);
      goto continuation_123;

    case 87:
      current_block = (Rpc - LABEL_143_128);
      goto label_428;

    case 88:
      current_block = (Rpc - LABEL_143_131);
      goto label_429;

    case 89:
      current_block = (Rpc - LABEL_143_114);
      goto lambda_114;

    case 90:
      current_block = (Rpc - LABEL_143_117);
      goto lambda_569;

    case 91:
      current_block = (Rpc - LABEL_143_120);
      goto lambda_570;

    case 92:
      current_block = (Rpc - LABEL_143_122);
      goto lambda_571;

    case 93:
      current_block = (Rpc - LABEL_143_125);
      goto lambda_572;

    case 94:
      current_block = (Rpc - LABEL_143_127);
      goto continuation_126;

    case 95:
      current_block = (Rpc - LABEL_143_142);
      goto label_430;

    case 96:
      current_block = (Rpc - LABEL_143_144);
      goto label_431;

    case 97:
      current_block = (Rpc - LABEL_143_146);
      goto label_432;

    case 98:
      current_block = (Rpc - LABEL_143_129);
      goto continuation_131;

    case 99:
      current_block = (Rpc - LABEL_143_130);
      goto lambda_125;

    case 100:
      current_block = (Rpc - LABEL_143_149);
      goto label_433;

    case 101:
      current_block = (Rpc - LABEL_143_133);
      goto lambda_574;

    case 102:
      current_block = (Rpc - LABEL_143_151);
      goto label_434;

    case 103:
      current_block = (Rpc - LABEL_143_152);
      goto label_435;

    case 104:
      current_block = (Rpc - LABEL_143_135);
      goto continuation_50;

    case 105:
      current_block = (Rpc - LABEL_143_155);
      goto label_436;

    case 106:
      current_block = (Rpc - LABEL_143_160);
      goto label_437;

    case 107:
      current_block = (Rpc - LABEL_143_136);
      goto continuation_49;

    case 108:
      current_block = (Rpc - LABEL_143_162);
      goto label_438;

    case 109:
      current_block = (Rpc - LABEL_143_138);
      goto lambda_575;

    case 110:
      current_block = (Rpc - LABEL_143_141);
      goto continuation_150;

    case 111:
      current_block = (Rpc - LABEL_143_167);
      goto label_439;

    case 112:
      current_block = (Rpc - LABEL_143_168);
      goto label_440;

    case 113:
      current_block = (Rpc - LABEL_143_170);
      goto label_441;

    case 114:
      current_block = (Rpc - LABEL_143_143);
      goto continuation_149;

    case 115:
      current_block = (Rpc - LABEL_143_145);
      goto continuation_148;

    case 116:
      current_block = (Rpc - LABEL_143_148);
      goto lambda_130;

    case 117:
      current_block = (Rpc - LABEL_143_153);
      goto lambda_577;

    case 118:
      current_block = (Rpc - LABEL_143_156);
      goto lambda_578;

    case 119:
      current_block = (Rpc - LABEL_143_178);
      goto label_442;

    case 120:
      current_block = (Rpc - LABEL_143_179);
      goto label_443;

    case 121:
      current_block = (Rpc - LABEL_143_158);
      goto lambda_579;

    case 122:
      current_block = (Rpc - LABEL_143_183);
      goto label_444;

    case 123:
      current_block = (Rpc - LABEL_143_163);
      goto lambda_580;

    case 124:
      current_block = (Rpc - LABEL_143_166);
      goto continuation_152;

    case 125:
      current_block = (Rpc - LABEL_143_193);
      goto label_445;

    case 126:
      current_block = (Rpc - LABEL_143_194);
      goto label_446;

    case 127:
      current_block = (Rpc - LABEL_143_196);
      goto label_447;

    case 128:
      current_block = (Rpc - LABEL_143_169);
      goto continuation_151;

    case 129:
      current_block = (Rpc - LABEL_143_171);
      goto lambda_147;

    case 130:
      current_block = (Rpc - LABEL_143_172);
      goto lambda_582;

    case 131:
      current_block = (Rpc - LABEL_143_175);
      goto lambda_583;

    case 132:
      current_block = (Rpc - LABEL_143_180);
      goto lambda_584;

    case 133:
      current_block = (Rpc - LABEL_143_210);
      goto label_448;

    case 134:
      current_block = (Rpc - LABEL_143_213);
      goto label_449;

    case 135:
      current_block = (Rpc - LABEL_143_184);
      goto lambda_585;

    case 136:
      current_block = (Rpc - LABEL_143_186);
      goto lambda_18;

    case 137:
      current_block = (Rpc - LABEL_143_188);
      goto lambda_587;

    case 138:
      current_block = (Rpc - LABEL_143_190);
      goto lambda_588;

    case 139:
      current_block = (Rpc - LABEL_143_192);
      goto continuation_154;

    case 140:
      current_block = (Rpc - LABEL_143_224);
      goto label_450;

    case 141:
      current_block = (Rpc - LABEL_143_225);
      goto label_451;

    case 142:
      current_block = (Rpc - LABEL_143_227);
      goto label_452;

    case 143:
      current_block = (Rpc - LABEL_143_195);
      goto continuation_153;

    case 144:
      current_block = (Rpc - LABEL_143_198);
      goto loop_0_145;

    case 145:
      current_block = (Rpc - LABEL_143_200);
      goto continuation_128;

    case 146:
      current_block = (Rpc - LABEL_143_201);
      goto continuation_127;

    case 147:
      current_block = (Rpc - LABEL_143_202);
      goto continuation_109;

    case 148:
      current_block = (Rpc - LABEL_143_203);
      goto continuation_108;

    case 149:
      current_block = (Rpc - LABEL_143_233);
      goto label_453;

    case 150:
      current_block = (Rpc - LABEL_143_204);
      goto continuation_105;

    case 151:
      current_block = (Rpc - LABEL_143_205);
      goto continuation_104;

    case 152:
      current_block = (Rpc - LABEL_143_206);
      goto lambda_64;

    case 153:
      current_block = (Rpc - LABEL_143_208);
      goto lambda_592;

    case 154:
      current_block = (Rpc - LABEL_143_211);
      goto lambda_593;

    case 155:
      current_block = (Rpc - LABEL_143_214);
      goto continuation_16;

    case 156:
      current_block = (Rpc - LABEL_143_215);
      goto continuation_15;

    case 157:
      current_block = (Rpc - LABEL_143_241);
      goto label_454;

    case 158:
      current_block = (Rpc - LABEL_143_216);
      goto continuation_10;

    case 159:
      current_block = (Rpc - LABEL_143_217);
      goto continuation_9;

    case 160:
      current_block = (Rpc - LABEL_143_242);
      goto label_455;

    case 161:
      current_block = (Rpc - LABEL_143_218);
      goto lambda_594;

    case 162:
      current_block = (Rpc - LABEL_143_221);
      goto lambda_595;

    case 163:
      current_block = (Rpc - LABEL_143_223);
      goto continuation_156;

    case 164:
      current_block = (Rpc - LABEL_143_246);
      goto label_456;

    case 165:
      current_block = (Rpc - LABEL_143_247);
      goto label_457;

    case 166:
      current_block = (Rpc - LABEL_143_249);
      goto label_458;

    case 167:
      current_block = (Rpc - LABEL_143_226);
      goto continuation_155;

    case 168:
      current_block = (Rpc - LABEL_143_228);
      goto lambda_596;

    case 169:
      current_block = (Rpc - LABEL_143_230);
      goto lambda_597;

    case 170:
      current_block = (Rpc - LABEL_143_234);
      goto lambda_102;

    case 171:
      current_block = (Rpc - LABEL_143_235);
      goto continuation_62;

    case 172:
      current_block = (Rpc - LABEL_143_236);
      goto continuation_61;

    case 173:
      current_block = (Rpc - LABEL_143_257);
      goto label_459;

    case 174:
      current_block = (Rpc - LABEL_143_237);
      goto lambda_598;

    case 175:
      current_block = (Rpc - LABEL_143_239);
      goto continuation_74;

    case 176:
      current_block = (Rpc - LABEL_143_240);
      goto continuation_73;

    case 177:
      current_block = (Rpc - LABEL_143_261);
      goto label_460;

    case 178:
      current_block = (Rpc - LABEL_143_243);
      goto lambda_599;

    case 179:
      current_block = (Rpc - LABEL_143_245);
      goto continuation_158;

    case 180:
      current_block = (Rpc - LABEL_143_265);
      goto label_461;

    case 181:
      current_block = (Rpc - LABEL_143_266);
      goto label_462;

    case 182:
      current_block = (Rpc - LABEL_143_267);
      goto label_463;

    case 183:
      current_block = (Rpc - LABEL_143_248);
      goto continuation_157;

    case 184:
      current_block = (Rpc - LABEL_143_250);
      goto continuation_139;

    case 185:
      current_block = (Rpc - LABEL_143_251);
      goto continuation_138;

    case 186:
      current_block = (Rpc - LABEL_143_270);
      goto label_464;

    case 187:
      current_block = (Rpc - LABEL_143_252);
      goto lambda_600;

    case 188:
      current_block = (Rpc - LABEL_143_255);
      goto continuation_101;

    case 189:
      current_block = (Rpc - LABEL_143_258);
      goto continuation_75;

    case 190:
      current_block = (Rpc - LABEL_143_260);
      goto continuation_72;

    case 191:
      current_block = (Rpc - LABEL_143_263);
      goto continuation_167;

    case 192:
      current_block = (Rpc - LABEL_143_273);
      goto label_465;

    case 193:
      current_block = (Rpc - LABEL_143_274);
      goto label_466;

    case 194:
      current_block = (Rpc - LABEL_143_276);
      goto label_467;

    case 195:
      current_block = (Rpc - LABEL_143_264);
      goto continuation_166;

    case 196:
      current_block = (Rpc - LABEL_143_278);
      goto label_468;

    case 197:
      current_block = (Rpc - LABEL_143_279);
      goto label_469;

    case 198:
      current_block = (Rpc - LABEL_143_268);
      goto continuation_142;

    case 199:
      current_block = (Rpc - LABEL_143_269);
      goto continuation_141;

    case 200:
      current_block = (Rpc - LABEL_143_280);
      goto label_470;

    case 201:
      current_block = (Rpc - LABEL_143_272);
      goto continuation_169;

    case 202:
      current_block = (Rpc - LABEL_143_282);
      goto label_471;

    case 203:
      current_block = (Rpc - LABEL_143_283);
      goto label_472;

    case 204:
      current_block = (Rpc - LABEL_143_285);
      goto label_473;

    case 205:
      current_block = (Rpc - LABEL_143_275);
      goto continuation_168;

    case 206:
      current_block = (Rpc - LABEL_143_277);
      goto continuation_165;

    case 207:
      current_block = (Rpc - LABEL_143_287);
      goto label_474;

    case 208:
      current_block = (Rpc - LABEL_143_281);
      goto continuation_171;

    case 209:
      current_block = (Rpc - LABEL_143_290);
      goto label_475;

    case 210:
      current_block = (Rpc - LABEL_143_291);
      goto label_476;

    case 211:
      current_block = (Rpc - LABEL_143_284);
      goto continuation_170;

    case 212:
      current_block = (Rpc - LABEL_143_286);
      goto continuation_160;

    case 213:
      current_block = (Rpc - LABEL_143_293);
      goto label_477;

    case 214:
      current_block = (Rpc - LABEL_143_288);
      goto continuation_184;

    case 215:
      current_block = (Rpc - LABEL_143_295);
      goto label_478;

    case 216:
      current_block = (Rpc - LABEL_143_289);
      goto continuation_183;

    case 217:
      current_block = (Rpc - LABEL_143_300);
      goto label_479;

    case 218:
      current_block = (Rpc - LABEL_143_301);
      goto label_480;

    case 219:
      current_block = (Rpc - LABEL_143_292);
      goto continuation_159;

    case 220:
      current_block = (Rpc - LABEL_143_294);
      goto continuation_211;

    case 221:
      current_block = (Rpc - LABEL_143_305);
      goto label_481;

    case 222:
      current_block = (Rpc - LABEL_143_307);
      goto label_482;

    case 223:
      current_block = (Rpc - LABEL_143_308);
      goto label_483;

    case 224:
      current_block = (Rpc - LABEL_143_296);
      goto lambda_210;

    case 225:
      current_block = (Rpc - LABEL_143_297);
      goto continuation_207;

    case 226:
      current_block = (Rpc - LABEL_143_298);
      goto lambda_206;

    case 227:
      current_block = (Rpc - LABEL_143_299);
      goto continuation_182;

    case 228:
      current_block = (Rpc - LABEL_143_302);
      goto lambda_602;

    case 229:
      current_block = (Rpc - LABEL_143_304);
      goto continuation_220;

    case 230:
      current_block = (Rpc - LABEL_143_318);
      goto label_484;

    case 231:
      current_block = (Rpc - LABEL_143_319);
      goto label_485;

    case 232:
      current_block = (Rpc - LABEL_143_321);
      goto label_486;

    case 233:
      current_block = (Rpc - LABEL_143_306);
      goto continuation_219;

    case 234:
      current_block = (Rpc - LABEL_143_309);
      goto continuation_208;

    case 235:
      current_block = (Rpc - LABEL_143_311);
      goto continuation_185;

    case 236:
      current_block = (Rpc - LABEL_143_313);
      goto continuation_181;

    case 237:
      current_block = (Rpc - LABEL_143_314);
      goto lambda_180;

    case 238:
      current_block = (Rpc - LABEL_143_315);
      goto lambda_605;

    case 239:
      current_block = (Rpc - LABEL_143_317);
      goto continuation_222;

    case 240:
      current_block = (Rpc - LABEL_143_331);
      goto label_487;

    case 241:
      current_block = (Rpc - LABEL_143_320);
      goto continuation_221;

    case 242:
      current_block = (Rpc - LABEL_143_322);
      goto lambda_218;

    case 243:
      current_block = (Rpc - LABEL_143_323);
      goto continuation_209;

    case 244:
      current_block = (Rpc - LABEL_143_325);
      goto continuation_192;

    case 245:
      current_block = (Rpc - LABEL_143_326);
      goto lambda_607;

    case 246:
      current_block = (Rpc - LABEL_143_329);
      goto continuation_240;

    case 247:
      current_block = (Rpc - LABEL_143_344);
      goto label_488;

    case 248:
      current_block = (Rpc - LABEL_143_345);
      goto label_489;

    case 249:
      current_block = (Rpc - LABEL_143_347);
      goto label_490;

    case 250:
      current_block = (Rpc - LABEL_143_330);
      goto continuation_239;

    case 251:
      current_block = (Rpc - LABEL_143_349);
      goto label_491;

    case 252:
      current_block = (Rpc - LABEL_143_332);
      goto continuation_238;

    case 253:
      current_block = (Rpc - LABEL_143_350);
      goto label_492;

    case 254:
      current_block = (Rpc - LABEL_143_334);
      goto lambda_609;

    case 255:
      current_block = (Rpc - LABEL_143_336);
      goto lambda_610;

    case 256:
      current_block = (Rpc - LABEL_143_338);
      goto continuation_200;

    case 257:
      current_block = (Rpc - LABEL_143_340);
      goto lambda_611;

    case 258:
      current_block = (Rpc - LABEL_143_343);
      goto continuation_242;

    case 259:
      current_block = (Rpc - LABEL_143_359);
      goto label_493;

    case 260:
      current_block = (Rpc - LABEL_143_360);
      goto label_494;

    case 261:
      current_block = (Rpc - LABEL_143_362);
      goto label_495;

    case 262:
      current_block = (Rpc - LABEL_143_346);
      goto continuation_241;

    case 263:
      current_block = (Rpc - LABEL_143_348);
      goto continuation_237;

    case 264:
      current_block = (Rpc - LABEL_143_351);
      goto lambda_612;

    case 265:
      current_block = (Rpc - LABEL_143_353);
      goto continuation_193;

    case 266:
      current_block = (Rpc - LABEL_143_370);
      goto lambda_191;

    case 267:
      current_block = (Rpc - LABEL_143_372);
      goto label_496;

    case 268:
      current_block = (Rpc - LABEL_143_355);
      goto lambda_613;

    case 269:
      current_block = (Rpc - LABEL_143_358);
      goto continuation_244;

    case 270:
      current_block = (Rpc - LABEL_143_376);
      goto label_497;

    case 271:
      current_block = (Rpc - LABEL_143_377);
      goto label_498;

    case 272:
      current_block = (Rpc - LABEL_143_379);
      goto label_499;

    case 273:
      current_block = (Rpc - LABEL_143_361);
      goto continuation_243;

    case 274:
      current_block = (Rpc - LABEL_143_363);
      goto continuation_236;

    case 275:
      current_block = (Rpc - LABEL_143_364);
      goto continuation_223;

    case 276:
      current_block = (Rpc - LABEL_143_366);
      goto continuation_214;

    case 277:
      current_block = (Rpc - LABEL_143_367);
      goto continuation_213;

    case 278:
      current_block = (Rpc - LABEL_143_382);
      goto label_500;

    case 279:
      current_block = (Rpc - LABEL_143_368);
      goto continuation_194;

    case 280:
      current_block = (Rpc - LABEL_143_371);
      goto continuation_188;

    case 281:
      current_block = (Rpc - LABEL_143_373);
      goto continuation_175;

    case 282:
      current_block = (Rpc - LABEL_143_374);
      goto continuation_174;

    case 283:
      current_block = (Rpc - LABEL_143_386);
      goto label_501;

    case 284:
      current_block = (Rpc - LABEL_143_375);
      goto continuation_246;

    case 285:
      current_block = (Rpc - LABEL_143_389);
      goto label_502;

    case 286:
      current_block = (Rpc - LABEL_143_390);
      goto label_503;

    case 287:
      current_block = (Rpc - LABEL_143_391);
      goto label_504;

    case 288:
      current_block = (Rpc - LABEL_143_378);
      goto continuation_245;

    case 289:
      current_block = (Rpc - LABEL_143_380);
      goto lambda_615;

    case 290:
      current_block = (Rpc - LABEL_143_384);
      goto lambda_616;

    case 291:
      current_block = (Rpc - LABEL_143_383);
      goto continuation_195;

    case 292:
      current_block = (Rpc - LABEL_143_387);
      goto continuation_259;

    case 293:
      current_block = (Rpc - LABEL_143_398);
      goto label_505;

    case 294:
      current_block = (Rpc - LABEL_143_399);
      goto label_506;

    case 295:
      current_block = (Rpc - LABEL_143_401);
      goto label_507;

    case 296:
      current_block = (Rpc - LABEL_143_388);
      goto continuation_258;

    case 297:
      current_block = (Rpc - LABEL_143_403);
      goto label_508;

    case 298:
      current_block = (Rpc - LABEL_143_404);
      goto label_509;

    case 299:
      current_block = (Rpc - LABEL_143_392);
      goto lambda_617;

    case 300:
      current_block = (Rpc - LABEL_143_394);
      goto lambda_618;

    case 301:
      current_block = (Rpc - LABEL_143_396);
      goto continuation_196;

    case 302:
      current_block = (Rpc - LABEL_143_397);
      goto continuation_261;

    case 303:
      current_block = (Rpc - LABEL_143_412);
      goto label_510;

    case 304:
      current_block = (Rpc - LABEL_143_413);
      goto label_511;

    case 305:
      current_block = (Rpc - LABEL_143_414);
      goto label_512;

    case 306:
      current_block = (Rpc - LABEL_143_400);
      goto continuation_260;

    case 307:
      current_block = (Rpc - LABEL_143_402);
      goto continuation_257;

    case 308:
      current_block = (Rpc - LABEL_143_405);
      goto lambda_619;

    case 309:
      current_block = (Rpc - LABEL_143_408);
      goto continuation_226;

    case 310:
      current_block = (Rpc - LABEL_143_409);
      goto continuation_225;

    case 311:
      current_block = (Rpc - LABEL_143_410);
      goto continuation_269;

    case 312:
      current_block = (Rpc - LABEL_143_420);
      goto label_513;

    case 313:
      current_block = (Rpc - LABEL_143_421);
      goto label_514;

    case 314:
      current_block = (Rpc - LABEL_143_422);
      goto label_515;

    case 315:
      current_block = (Rpc - LABEL_143_411);
      goto continuation_268;

    case 316:
      current_block = (Rpc - LABEL_143_425);
      goto label_516;

    case 317:
      current_block = (Rpc - LABEL_143_415);
      goto continuation_256;

    case 318:
      current_block = (Rpc - LABEL_143_416);
      goto lambda_255;

    case 319:
      current_block = (Rpc - LABEL_143_417);
      goto continuation_229;

    case 320:
      current_block = (Rpc - LABEL_143_418);
      goto continuation_228;

    case 321:
      current_block = (Rpc - LABEL_143_419);
      goto continuation_270;

    case 322:
      current_block = (Rpc - LABEL_143_430);
      goto label_517;

    case 323:
      current_block = (Rpc - LABEL_143_431);
      goto label_518;

    case 324:
      current_block = (Rpc - LABEL_143_432);
      goto label_519;

    case 325:
      current_block = (Rpc - LABEL_143_423);
      goto continuation_267;

    case 326:
      current_block = (Rpc - LABEL_143_424);
      goto continuation_266;

    case 327:
      current_block = (Rpc - LABEL_143_435);
      goto label_520;

    case 328:
      current_block = (Rpc - LABEL_143_427);
      goto continuation_247;

    case 329:
      current_block = (Rpc - LABEL_143_428);
      goto lambda_227;

    case 330:
      current_block = (Rpc - LABEL_143_429);
      goto continuation_271;

    case 331:
      current_block = (Rpc - LABEL_143_439);
      goto label_521;

    case 332:
      current_block = (Rpc - LABEL_143_440);
      goto label_522;

    case 333:
      current_block = (Rpc - LABEL_143_433);
      goto continuation_265;

    case 334:
      current_block = (Rpc - LABEL_143_434);
      goto lambda_264;

    case 335:
      current_block = (Rpc - LABEL_143_436);
      goto continuation_248;

    case 336:
      current_block = (Rpc - LABEL_143_438);
      goto continuation_276;

    case 337:
      current_block = (Rpc - LABEL_143_447);
      goto label_523;

    case 338:
      current_block = (Rpc - LABEL_143_448);
      goto label_524;

    case 339:
      current_block = (Rpc - LABEL_143_450);
      goto label_525;

    case 340:
      current_block = (Rpc - LABEL_143_441);
      goto lambda_275;

    case 341:
      current_block = (Rpc - LABEL_143_442);
      goto lambda_623;

    case 342:
      current_block = (Rpc - LABEL_143_445);
      goto continuation_249;

    case 343:
      current_block = (Rpc - LABEL_143_446);
      goto continuation_278;

    case 344:
      current_block = (Rpc - LABEL_143_458);
      goto label_526;

    case 345:
      current_block = (Rpc - LABEL_143_449);
      goto continuation_277;

    case 346:
      current_block = (Rpc - LABEL_143_451);
      goto lambda_625;

    case 347:
      current_block = (Rpc - LABEL_143_453);
      goto lambda_626;

    case 348:
      current_block = (Rpc - LABEL_143_455);
      goto continuation_250;

    case 349:
      current_block = (Rpc - LABEL_143_457);
      goto continuation_292;

    case 350:
      current_block = (Rpc - LABEL_143_459);
      goto lambda_291;

    case 351:
      current_block = (Rpc - LABEL_143_460);
      goto continuation_288;

    case 352:
      current_block = (Rpc - LABEL_143_461);
      goto lambda_287;

    case 353:
      current_block = (Rpc - LABEL_143_462);
      goto continuation_273;

    case 354:
      current_block = (Rpc - LABEL_143_463);
      goto continuation_272;

    case 355:
      current_block = (Rpc - LABEL_143_471);
      goto label_527;

    case 356:
      current_block = (Rpc - LABEL_143_464);
      goto continuation_251;

    case 357:
      current_block = (Rpc - LABEL_143_465);
      goto continuation_305;

    case 358:
      current_block = (Rpc - LABEL_143_475);
      goto label_528;

    case 359:
      current_block = (Rpc - LABEL_143_476);
      goto label_529;

    case 360:
      current_block = (Rpc - LABEL_143_477);
      goto label_530;

    case 361:
      current_block = (Rpc - LABEL_143_466);
      goto lambda_304;

    case 362:
      current_block = (Rpc - LABEL_143_467);
      goto lambda_301;

    case 363:
      current_block = (Rpc - LABEL_143_468);
      goto lambda_298;

    case 364:
      current_block = (Rpc - LABEL_143_469);
      goto continuation_289;

    case 365:
      current_block = (Rpc - LABEL_143_470);
      goto continuation_279;

    case 366:
      current_block = (Rpc - LABEL_143_472);
      goto continuation_345;

    case 367:
      current_block = (Rpc - LABEL_143_490);
      goto label_531;

    case 368:
      current_block = (Rpc - LABEL_143_473);
      goto continuation_344;

    case 369:
      current_block = (Rpc - LABEL_143_493);
      goto label_532;

    case 370:
      current_block = (Rpc - LABEL_143_494);
      goto label_533;

    case 371:
      current_block = (Rpc - LABEL_143_474);
      goto continuation_343;

    case 372:
      current_block = (Rpc - LABEL_143_496);
      goto label_534;

    case 373:
      current_block = (Rpc - LABEL_143_497);
      goto label_535;

    case 374:
      current_block = (Rpc - LABEL_143_498);
      goto label_536;

    case 375:
      current_block = (Rpc - LABEL_143_479);
      goto continuation_303;

    case 376:
      current_block = (Rpc - LABEL_143_480);
      goto continuation_302;

    case 377:
      current_block = (Rpc - LABEL_143_482);
      goto continuation_299;

    case 378:
      current_block = (Rpc - LABEL_143_502);
      goto continuation_294;

    case 379:
      current_block = (Rpc - LABEL_143_503);
      goto label_543;

    case 380:
      current_block = (Rpc - LABEL_143_484);
      goto continuation_293;

    case 381:
      current_block = (Rpc - LABEL_143_486);
      goto continuation_290;

    case 382:
      current_block = (Rpc - LABEL_143_487);
      goto continuation_280;

    case 383:
      current_block = (Rpc - LABEL_143_488);
      goto continuation_356;

    case 384:
      current_block = (Rpc - LABEL_143_510);
      goto label_537;

    case 385:
      current_block = (Rpc - LABEL_143_511);
      goto label_538;

    case 386:
      current_block = (Rpc - LABEL_143_489);
      goto continuation_355;

    case 387:
      current_block = (Rpc - LABEL_143_513);
      goto label_539;

    case 388:
      current_block = (Rpc - LABEL_143_491);
      goto continuation_341;

    case 389:
      current_block = (Rpc - LABEL_143_492);
      goto continuation_340;

    case 390:
      current_block = (Rpc - LABEL_143_518);
      goto label_540;

    case 391:
      current_block = (Rpc - LABEL_143_519);
      goto label_541;

    case 392:
      current_block = (Rpc - LABEL_143_495);
      goto continuation_342;

    case 393:
      current_block = (Rpc - LABEL_143_520);
      goto label_542;

    case 394:
      current_block = (Rpc - LABEL_143_500);
      goto continuation_300;

    case 395:
      current_block = (Rpc - LABEL_143_506);
      goto continuation_281;

    case 396:
      current_block = (Rpc - LABEL_143_507);
      goto continuation_377;

    case 397:
      current_block = (Rpc - LABEL_143_522);
      goto label_544;

    case 398:
      current_block = (Rpc - LABEL_143_523);
      goto label_545;

    case 399:
      current_block = (Rpc - LABEL_143_525);
      goto label_546;

    case 400:
      current_block = (Rpc - LABEL_143_508);
      goto continuation_376;

    case 401:
      current_block = (Rpc - LABEL_143_527);
      goto label_547;

    case 402:
      current_block = (Rpc - LABEL_143_509);
      goto lambda_375;

    case 403:
      current_block = (Rpc - LABEL_143_512);
      goto continuation_354;

    case 404:
      current_block = (Rpc - LABEL_143_515);
      goto continuation_338;

    case 405:
      current_block = (Rpc - LABEL_143_516);
      goto lambda_337;

    case 406:
      current_block = (Rpc - LABEL_143_517);
      goto continuation_339;

    case 407:
      current_block = (Rpc - LABEL_143_532);
      goto label_548;

    case 408:
      current_block = (Rpc - LABEL_143_504);
      goto continuation_296;

    case 409:
      current_block = (Rpc - LABEL_143_521);
      goto continuation_282;

    case 410:
      current_block = (Rpc - LABEL_143_524);
      goto continuation_378;

    case 411:
      current_block = (Rpc - LABEL_143_526);
      goto continuation_374;

    case 412:
      current_block = (Rpc - LABEL_143_528);
      goto continuation_353;

    case 413:
      current_block = (Rpc - LABEL_143_529);
      goto lambda_352;

    case 414:
      current_block = (Rpc - LABEL_143_530);
      goto lambda_634;

    case 415:
      current_block = (Rpc - LABEL_143_539);
      goto label_549;

    case 416:
      current_block = (Rpc - LABEL_143_546);
      goto label_550;

    case 417:
      current_block = (Rpc - LABEL_143_533);
      goto continuation_283;

    case 418:
      current_block = (Rpc - LABEL_143_534);
      goto continuation_373;

    case 419:
      current_block = (Rpc - LABEL_143_535);
      goto lambda_372;

    case 420:
      current_block = (Rpc - LABEL_143_536);
      goto lambda_636;

    case 421:
      current_block = (Rpc - LABEL_143_540);
      goto lambda_637;

    case 422:
      current_block = (Rpc - LABEL_143_542);
      goto lambda_638;

    case 423:
      current_block = (Rpc - LABEL_143_553);
      goto label_551;

    case 424:
      current_block = (Rpc - LABEL_143_554);
      goto label_552;

    case 425:
      current_block = (Rpc - LABEL_143_544);
      goto lambda_639;

    case 426:
      current_block = (Rpc - LABEL_143_557);
      goto label_553;

    case 427:
      current_block = (Rpc - LABEL_143_547);
      goto continuation_357;

    case 428:
      current_block = (Rpc - LABEL_143_548);
      goto lambda_641;

    case 429:
      current_block = (Rpc - LABEL_143_551);
      goto lambda_642;

    case 430:
      current_block = (Rpc - LABEL_143_555);
      goto lambda_643;

    case 431:
      current_block = (Rpc - LABEL_143_558);
      goto lambda_644;

    case 432:
      current_block = (Rpc - LABEL_143_560);
      goto continuation_358;

    case 433:
      current_block = (Rpc - LABEL_143_561);
      goto continuation_348;

    case 434:
      current_block = (Rpc - LABEL_143_562);
      goto continuation_347;

    case 435:
      current_block = (Rpc - LABEL_143_570);
      goto label_554;

    case 436:
      current_block = (Rpc - LABEL_143_563);
      goto lambda_645;

    case 437:
      current_block = (Rpc - LABEL_143_565);
      goto lambda_646;

    case 438:
      current_block = (Rpc - LABEL_143_567);
      goto continuation_328;

    case 439:
      current_block = (Rpc - LABEL_143_568);
      goto continuation_327;

    case 440:
      current_block = (Rpc - LABEL_143_575);
      goto label_555;

    case 441:
      current_block = (Rpc - LABEL_143_569);
      goto continuation_359;

    case 442:
      current_block = (Rpc - LABEL_143_577);
      goto label_556;

    case 443:
      current_block = (Rpc - LABEL_143_571);
      goto continuation_313;

    case 444:
      current_block = (Rpc - LABEL_143_572);
      goto continuation_312;

    case 445:
      current_block = (Rpc - LABEL_143_579);
      goto label_557;

    case 446:
      current_block = (Rpc - LABEL_143_573);
      goto lambda_647;

    case 447:
      current_block = (Rpc - LABEL_143_576);
      goto continuation_360;

    case 448:
      current_block = (Rpc - LABEL_143_581);
      goto Z___ks4__368;

    case 449:
      current_block = (Rpc - LABEL_143_580);
      goto continuation_361;

    case 450:
      current_block = (Rpc - LABEL_143_582);
      goto continuation_363;

    case 451:
      current_block = (Rpc - LABEL_143_584);
      goto label_558;

    case 452:
      current_block = (Rpc - LABEL_143_583);
      goto continuation_364;

    case 453:
      current_block = (Rpc - LABEL_143_585);
      goto continuation_365;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_560)
DEFLABEL (lambda_379)
  INTERRUPT_CHECK (26, LABEL_143_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_746;
  Wrd8 = Wrd12;

DEFLABEL (label_745)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_1]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_744;
  Wrd14 = Wrd18;

DEFLABEL (label_743)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd21.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_2]));
  (Wrd24.Obj) = ((Wrd21.pObj) [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd25.uLng) == 50)
    goto label_742;
  Wrd20 = Wrd24;

DEFLABEL (label_741)
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd26.Obj) = (current_block [OBJECT_143_0]);
  (* (--Rsp)) = (Wrd26.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_9]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_143_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_10]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_3]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_740;
  Wrd8 = Wrd12;

DEFLABEL (label_739)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_4]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_738;
  Wrd14 = Wrd18;

DEFLABEL (label_737)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd21.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_5]));
  (Wrd24.Obj) = ((Wrd21.pObj) [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd25.uLng) == 50)
    goto label_736;
  Wrd20 = Wrd24;

DEFLABEL (label_735)
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd26.Obj) = (current_block [OBJECT_143_1]);
  (* (--Rsp)) = (Wrd26.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_9]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_143_10);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_14]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_6]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_734;
  Wrd8 = Wrd12;

DEFLABEL (label_733)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_7]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_732;
  Wrd14 = Wrd18;

DEFLABEL (label_731)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_17]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd24.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_8]));
  (Wrd27.Obj) = ((Wrd24.pObj) [0]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if ((Wrd28.uLng) == 50)
    goto label_730;
  Wrd23 = Wrd27;

DEFLABEL (label_729)
  (* (--Rsp)) = (Wrd23.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_19]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_143_17);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_143_3]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_24]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_143_14);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_20]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_0]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_728;
  Wrd8 = Wrd12;

DEFLABEL (label_727)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_1]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_726;
  Wrd14 = Wrd18;

DEFLABEL (label_725)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd21.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_2]));
  (Wrd24.Obj) = ((Wrd21.pObj) [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd25.uLng) == 50)
    goto label_724;
  Wrd20 = Wrd24;

DEFLABEL (label_723)
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd26.Obj) = (current_block [OBJECT_143_2]);
  (* (--Rsp)) = (Wrd26.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_9]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_143_20);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_25]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_3]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_722;
  Wrd8 = Wrd12;

DEFLABEL (label_721)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_4]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_720;
  Wrd14 = Wrd18;

DEFLABEL (label_719)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd21.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_5]));
  (Wrd24.Obj) = ((Wrd21.pObj) [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd25.uLng) == 50)
    goto label_718;
  Wrd20 = Wrd24;

DEFLABEL (label_717)
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd26.Obj) = (current_block [OBJECT_143_4]);
  (* (--Rsp)) = (Wrd26.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_9]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_143_25);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_29]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_9]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_716;
  Wrd8 = Wrd12;

DEFLABEL (label_715)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_10]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_714;
  Wrd14 = Wrd18;

DEFLABEL (label_713)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd21.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_11]));
  (Wrd24.Obj) = ((Wrd21.pObj) [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd25.uLng) == 50)
    goto label_712;
  Wrd20 = Wrd24;

DEFLABEL (label_711)
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd26.Obj) = (current_block [OBJECT_143_5]);
  (* (--Rsp)) = (Wrd26.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_9]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_143_29);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_33]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_12]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_710;
  Wrd8 = Wrd12;

DEFLABEL (label_709)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_13]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_708;
  Wrd14 = Wrd18;

DEFLABEL (label_707)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd21.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_14]));
  (Wrd24.Obj) = ((Wrd21.pObj) [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd25.uLng) == 50)
    goto label_706;
  Wrd20 = Wrd24;

DEFLABEL (label_705)
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd26.Obj) = (current_block [OBJECT_143_6]);
  (* (--Rsp)) = (Wrd26.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_9]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_143_33);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_37]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_38]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_39]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_15]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_704;
  Wrd14 = Wrd18;

DEFLABEL (label_703)
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_41]));

DEFLABEL (continuation_46)
  INTERRUPT_CHECK (27, LABEL_143_39);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_143_7]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd7.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_17]));
  (Wrd10.Obj) = ((Wrd7.pObj) [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd11.uLng) == 50)
    goto label_702;
  Wrd6 = Wrd10;

DEFLABEL (label_701)
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_143_7]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_51]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd17.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_3]));
  (Wrd20.Obj) = ((Wrd17.pObj) [0]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if ((Wrd21.uLng) == 50)
    goto label_700;
  Wrd16 = Wrd20;

DEFLABEL (label_699)
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd22.Obj) = (current_block [OBJECT_143_8]);
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_53]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd27.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_3]));
  (Wrd30.Obj) = ((Wrd27.pObj) [0]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if ((Wrd31.uLng) == 50)
    goto label_698;
  Wrd26 = Wrd30;

DEFLABEL (label_697)
  (* (--Rsp)) = (Wrd26.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_41]));

DEFLABEL (continuation_44)
  INTERRUPT_CHECK (27, LABEL_143_53);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_80]));

DEFLABEL (continuation_45)
  INTERRUPT_CHECK (27, LABEL_143_51);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_79]));

DEFLABEL (continuation_47)
  INTERRUPT_CHECK (27, LABEL_143_38);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_46]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_47]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_16]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_696;
  Wrd11 = Wrd15;

DEFLABEL (label_695)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_49]));

DEFLABEL (continuation_42)
  INTERRUPT_CHECK (27, LABEL_143_47);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_23]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_694;
  Wrd5 = Wrd9;

DEFLABEL (label_693)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_75]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_4]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_692;
  Wrd14 = Wrd18;

DEFLABEL (label_691)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_77]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd24.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_4]));
  (Wrd27.Obj) = ((Wrd24.pObj) [0]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if ((Wrd28.uLng) == 50)
    goto label_690;
  Wrd23 = Wrd27;

DEFLABEL (label_689)
  (* (--Rsp)) = (Wrd23.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_49]));

DEFLABEL (continuation_40)
  INTERRUPT_CHECK (27, LABEL_143_77);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_109]));

DEFLABEL (continuation_41)
  INTERRUPT_CHECK (27, LABEL_143_75);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_108]));

DEFLABEL (continuation_43)
  INTERRUPT_CHECK (27, LABEL_143_46);
  (* (--Rsp)) = Rvl;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_73]))));
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd7.Obj) = (current_block [OBJECT_143_10]);
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_9]));

DEFLABEL (continuation_48)
  INTERRUPT_CHECK (27, LABEL_143_37);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_42]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_43]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_44]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_45]))));
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_41]));

DEFLABEL (continuation_94)
  INTERRUPT_CHECK (27, LABEL_143_44);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_143_7]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd7.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_21]));
  (Wrd10.Obj) = ((Wrd7.pObj) [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd11.uLng) == 50)
    goto label_688;
  Wrd6 = Wrd10;

DEFLABEL (label_687)
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_143_7]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd14.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_17]));
  (Wrd17.Obj) = ((Wrd14.pObj) [0]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if ((Wrd18.uLng) == 50)
    goto label_686;
  Wrd13 = Wrd17;

DEFLABEL (label_685)
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd19.Obj) = (current_block [OBJECT_143_7]);
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd21.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_22]));
  (Wrd24.Obj) = ((Wrd21.pObj) [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd25.uLng) == 50)
    goto label_684;
  Wrd20 = Wrd24;

DEFLABEL (label_683)
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_68]));

DEFLABEL (continuation_95)
  INTERRUPT_CHECK (27, LABEL_143_43);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_62]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_63]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_20]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_682;
  Wrd11 = Wrd15;

DEFLABEL (label_681)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_49]));

DEFLABEL (continuation_89)
  INTERRUPT_CHECK (27, LABEL_143_63);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_28]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_680;
  Wrd5 = Wrd9;

DEFLABEL (label_679)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_23]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_678;
  Wrd11 = Wrd15;

DEFLABEL (label_677)
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd18.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_29]));
  (Wrd21.Obj) = ((Wrd18.pObj) [0]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if ((Wrd22.uLng) == 50)
    goto label_676;
  Wrd17 = Wrd21;

DEFLABEL (label_675)
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_98]));

DEFLABEL (continuation_90)
  INTERRUPT_CHECK (27, LABEL_143_62);
  (* (--Rsp)) = Rvl;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_94]))));
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd7.Obj) = (current_block [OBJECT_143_12]);
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_9]));

DEFLABEL (continuation_96)
  INTERRUPT_CHECK (27, LABEL_143_42);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_55]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_56]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_143_9]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_57]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_58]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd18.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_18]));
  (Wrd21.Obj) = ((Wrd18.pObj) [0]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if ((Wrd22.uLng) == 50)
    goto label_674;
  Wrd17 = Wrd21;

DEFLABEL (label_673)
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd24.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_19]));
  (Wrd27.Obj) = ((Wrd24.pObj) [0]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if ((Wrd28.uLng) == 50)
    goto label_672;
  Wrd23 = Wrd27;

DEFLABEL (label_671)
  (* (--Rsp)) = (Wrd23.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_61]));

DEFLABEL (continuation_119)
  INTERRUPT_CHECK (27, LABEL_143_57);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_91]));

DEFLABEL (continuation_120)
  INTERRUPT_CHECK (27, LABEL_143_56);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_85]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_27]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_670;
  Wrd8 = Wrd12;

DEFLABEL (label_669)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_87]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd18.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_4]));
  (Wrd21.Obj) = ((Wrd18.pObj) [0]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if ((Wrd22.uLng) == 50)
    goto label_668;
  Wrd17 = Wrd21;

DEFLABEL (label_667)
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd24.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_19]));
  (Wrd27.Obj) = ((Wrd24.pObj) [0]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if ((Wrd28.uLng) == 50)
    goto label_666;
  Wrd23 = Wrd27;

DEFLABEL (label_665)
  (* (--Rsp)) = (Wrd23.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_90]));

DEFLABEL (continuation_115)
  INTERRUPT_CHECK (27, LABEL_143_87);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_109]));

DEFLABEL (continuation_116)
  INTERRUPT_CHECK (27, LABEL_143_85);
  (* (--Rsp)) = Rvl;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_114]))));
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd7.Obj) = (current_block [OBJECT_143_14]);
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_115]));

DEFLABEL (continuation_121)
  INTERRUPT_CHECK (27, LABEL_143_55);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_81]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_24]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_664;
  Wrd8 = Wrd12;

DEFLABEL (label_663)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_25]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_662;
  Wrd14 = Wrd18;

DEFLABEL (label_661)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd21.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_26]));
  (Wrd24.Obj) = ((Wrd21.pObj) [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd25.uLng) == 50)
    goto label_660;
  Wrd20 = Wrd24;

DEFLABEL (label_659)
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd26.Obj) = (current_block [OBJECT_143_11]);
  (* (--Rsp)) = (Wrd26.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_9]));

DEFLABEL (continuation_122)
  INTERRUPT_CHECK (27, LABEL_143_81);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_110]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_24]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_658;
  Wrd8 = Wrd12;

DEFLABEL (label_657)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_25]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_656;
  Wrd14 = Wrd18;

DEFLABEL (label_655)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd21.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_26]));
  (Wrd24.Obj) = ((Wrd21.pObj) [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd25.uLng) == 50)
    goto label_654;
  Wrd20 = Wrd24;

DEFLABEL (label_653)
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd26.Obj) = (current_block [OBJECT_143_13]);
  (* (--Rsp)) = (Wrd26.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_9]));

DEFLABEL (continuation_123)
  INTERRUPT_CHECK (27, LABEL_143_110);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_127]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_24]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_652;
  Wrd8 = Wrd12;

DEFLABEL (label_651)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_129]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_130]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_25]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_650;
  Wrd19 = Wrd23;

DEFLABEL (label_649)
  (* (--Rsp)) = (Wrd19.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_132]));

DEFLABEL (continuation_131)
  INTERRUPT_CHECK (27, LABEL_143_129);
  (* (--Rsp)) = Rvl;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_148]))));
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd7.Obj) = (current_block [OBJECT_143_17]);
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_9]));

DEFLABEL (label_650)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_131])), (Wrd20.pObj));

DEFLABEL (label_429)
  (Wrd19.Obj) = Rvl;
  goto label_649;

DEFLABEL (label_652)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_128])), (Wrd9.pObj));

DEFLABEL (label_428)
  (Wrd8.Obj) = Rvl;
  goto label_651;

DEFLABEL (label_654)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_113])), (Wrd21.pObj));

DEFLABEL (label_427)
  (Wrd20.Obj) = Rvl;
  goto label_653;

DEFLABEL (label_656)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_112])), (Wrd15.pObj));

DEFLABEL (label_426)
  (Wrd14.Obj) = Rvl;
  goto label_655;

DEFLABEL (label_658)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_111])), (Wrd9.pObj));

DEFLABEL (label_425)
  (Wrd8.Obj) = Rvl;
  goto label_657;

DEFLABEL (label_660)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_84])), (Wrd21.pObj));

DEFLABEL (label_418)
  (Wrd20.Obj) = Rvl;
  goto label_659;

DEFLABEL (label_662)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_83])), (Wrd15.pObj));

DEFLABEL (label_417)
  (Wrd14.Obj) = Rvl;
  goto label_661;

DEFLABEL (label_664)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_82])), (Wrd9.pObj));

DEFLABEL (label_416)
  (Wrd8.Obj) = Rvl;
  goto label_663;

DEFLABEL (label_666)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_89])), (Wrd24.pObj));

DEFLABEL (label_421)
  (Wrd23.Obj) = Rvl;
  goto label_665;

DEFLABEL (label_668)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_88])), (Wrd18.pObj));

DEFLABEL (label_420)
  (Wrd17.Obj) = Rvl;
  goto label_667;

DEFLABEL (label_670)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_86])), (Wrd9.pObj));

DEFLABEL (label_419)
  (Wrd8.Obj) = Rvl;
  goto label_669;

DEFLABEL (label_672)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_60])), (Wrd24.pObj));

DEFLABEL (label_408)
  (Wrd23.Obj) = Rvl;
  goto label_671;

DEFLABEL (label_674)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_59])), (Wrd18.pObj));

DEFLABEL (label_407)
  (Wrd17.Obj) = Rvl;
  goto label_673;

DEFLABEL (label_676)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_97])), (Wrd18.pObj));

DEFLABEL (label_424)
  (Wrd17.Obj) = Rvl;
  goto label_675;

DEFLABEL (label_678)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_96])), (Wrd12.pObj));

DEFLABEL (label_423)
  (Wrd11.Obj) = Rvl;
  goto label_677;

DEFLABEL (label_680)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_95])), (Wrd6.pObj));

DEFLABEL (label_422)
  (Wrd5.Obj) = Rvl;
  goto label_679;

DEFLABEL (label_682)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_64])), (Wrd12.pObj));

DEFLABEL (label_409)
  (Wrd11.Obj) = Rvl;
  goto label_681;

DEFLABEL (label_684)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_67])), (Wrd21.pObj));

DEFLABEL (label_412)
  (Wrd20.Obj) = Rvl;
  goto label_683;

DEFLABEL (label_686)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_66])), (Wrd14.pObj));

DEFLABEL (label_411)
  (Wrd13.Obj) = Rvl;
  goto label_685;

DEFLABEL (label_688)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_65])), (Wrd7.pObj));

DEFLABEL (label_410)
  (Wrd6.Obj) = Rvl;
  goto label_687;

DEFLABEL (label_690)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_78])), (Wrd24.pObj));

DEFLABEL (label_415)
  (Wrd23.Obj) = Rvl;
  goto label_689;

DEFLABEL (label_692)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_76])), (Wrd15.pObj));

DEFLABEL (label_414)
  (Wrd14.Obj) = Rvl;
  goto label_691;

DEFLABEL (label_694)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_74])), (Wrd6.pObj));

DEFLABEL (label_413)
  (Wrd5.Obj) = Rvl;
  goto label_693;

DEFLABEL (label_696)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_48])), (Wrd12.pObj));

DEFLABEL (label_403)
  (Wrd11.Obj) = Rvl;
  goto label_695;

DEFLABEL (label_698)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_54])), (Wrd27.pObj));

DEFLABEL (label_406)
  (Wrd26.Obj) = Rvl;
  goto label_697;

DEFLABEL (label_700)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_52])), (Wrd17.pObj));

DEFLABEL (label_405)
  (Wrd16.Obj) = Rvl;
  goto label_699;

DEFLABEL (label_702)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_50])), (Wrd7.pObj));

DEFLABEL (label_404)
  (Wrd6.Obj) = Rvl;
  goto label_701;

DEFLABEL (label_704)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_40])), (Wrd15.pObj));

DEFLABEL (label_402)
  (Wrd14.Obj) = Rvl;
  goto label_703;

DEFLABEL (label_706)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_36])), (Wrd21.pObj));

DEFLABEL (label_401)
  (Wrd20.Obj) = Rvl;
  goto label_705;

DEFLABEL (label_708)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_35])), (Wrd15.pObj));

DEFLABEL (label_400)
  (Wrd14.Obj) = Rvl;
  goto label_707;

DEFLABEL (label_710)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_34])), (Wrd9.pObj));

DEFLABEL (label_399)
  (Wrd8.Obj) = Rvl;
  goto label_709;

DEFLABEL (label_712)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_32])), (Wrd21.pObj));

DEFLABEL (label_398)
  (Wrd20.Obj) = Rvl;
  goto label_711;

DEFLABEL (label_714)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_31])), (Wrd15.pObj));

DEFLABEL (label_397)
  (Wrd14.Obj) = Rvl;
  goto label_713;

DEFLABEL (label_716)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_30])), (Wrd9.pObj));

DEFLABEL (label_396)
  (Wrd8.Obj) = Rvl;
  goto label_715;

DEFLABEL (label_718)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_28])), (Wrd21.pObj));

DEFLABEL (label_395)
  (Wrd20.Obj) = Rvl;
  goto label_717;

DEFLABEL (label_720)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_27])), (Wrd15.pObj));

DEFLABEL (label_394)
  (Wrd14.Obj) = Rvl;
  goto label_719;

DEFLABEL (label_722)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_26])), (Wrd9.pObj));

DEFLABEL (label_393)
  (Wrd8.Obj) = Rvl;
  goto label_721;

DEFLABEL (label_724)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_23])), (Wrd21.pObj));

DEFLABEL (label_392)
  (Wrd20.Obj) = Rvl;
  goto label_723;

DEFLABEL (label_726)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_22])), (Wrd15.pObj));

DEFLABEL (label_391)
  (Wrd14.Obj) = Rvl;
  goto label_725;

DEFLABEL (label_728)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_21])), (Wrd9.pObj));

DEFLABEL (label_390)
  (Wrd8.Obj) = Rvl;
  goto label_727;

DEFLABEL (label_730)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_18])), (Wrd24.pObj));

DEFLABEL (label_389)
  (Wrd23.Obj) = Rvl;
  goto label_729;

DEFLABEL (label_732)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_16])), (Wrd15.pObj));

DEFLABEL (label_388)
  (Wrd14.Obj) = Rvl;
  goto label_731;

DEFLABEL (label_734)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_15])), (Wrd9.pObj));

DEFLABEL (label_387)
  (Wrd8.Obj) = Rvl;
  goto label_733;

DEFLABEL (label_736)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_13])), (Wrd21.pObj));

DEFLABEL (label_386)
  (Wrd20.Obj) = Rvl;
  goto label_735;

DEFLABEL (label_738)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_12])), (Wrd15.pObj));

DEFLABEL (label_385)
  (Wrd14.Obj) = Rvl;
  goto label_737;

DEFLABEL (label_740)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_11])), (Wrd9.pObj));

DEFLABEL (label_384)
  (Wrd8.Obj) = Rvl;
  goto label_739;

DEFLABEL (label_742)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_8])), (Wrd21.pObj));

DEFLABEL (label_383)
  (Wrd20.Obj) = Rvl;
  goto label_741;

DEFLABEL (label_744)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_7])), (Wrd15.pObj));

DEFLABEL (label_382)
  (Wrd14.Obj) = Rvl;
  goto label_743;

DEFLABEL (label_746)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_6])), (Wrd9.pObj));

DEFLABEL (label_381)
  (Wrd8.Obj) = Rvl;
  goto label_745;

DEFLABEL (continuation_126)
  INTERRUPT_CHECK (27, LABEL_143_127);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_141]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_30]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_938;
  Wrd8 = Wrd12;

DEFLABEL (label_937)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_143]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd18.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_31]));
  (Wrd21.Obj) = ((Wrd18.pObj) [0]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if ((Wrd22.uLng) == 50)
    goto label_936;
  Wrd17 = Wrd21;

DEFLABEL (label_935)
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_145]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd27.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_1]));
  (Wrd30.Obj) = ((Wrd27.pObj) [0]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if ((Wrd31.uLng) == 50)
    goto label_934;
  Wrd26 = Wrd30;

DEFLABEL (label_933)
  (* (--Rsp)) = (Wrd26.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_147]));

DEFLABEL (continuation_148)
  INTERRUPT_CHECK (27, LABEL_143_145);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_132]));

DEFLABEL (continuation_149)
  INTERRUPT_CHECK (27, LABEL_143_143);
  (* (--Rsp)) = Rvl;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_171]))));
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd7.Obj) = (current_block [OBJECT_143_21]);
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_9]));

DEFLABEL (continuation_150)
  INTERRUPT_CHECK (27, LABEL_143_141);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_166]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_32]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_932;
  Wrd8 = Wrd12;

DEFLABEL (label_931)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_33]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_930;
  Wrd14 = Wrd18;

DEFLABEL (label_929)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_169]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd24.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_34]));
  (Wrd27.Obj) = ((Wrd24.pObj) [0]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if ((Wrd28.uLng) == 50)
    goto label_928;
  Wrd23 = Wrd27;

DEFLABEL (label_927)
  (* (--Rsp)) = (Wrd23.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_19]));

DEFLABEL (continuation_151)
  INTERRUPT_CHECK (27, LABEL_143_169);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_143_22]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_24]));

DEFLABEL (continuation_152)
  INTERRUPT_CHECK (27, LABEL_143_166);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_192]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_35]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_926;
  Wrd8 = Wrd12;

DEFLABEL (label_925)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_36]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_924;
  Wrd14 = Wrd18;

DEFLABEL (label_923)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_195]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd24.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_37]));
  (Wrd27.Obj) = ((Wrd24.pObj) [0]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if ((Wrd28.uLng) == 50)
    goto label_922;
  Wrd23 = Wrd27;

DEFLABEL (label_921)
  (* (--Rsp)) = (Wrd23.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_197]));

DEFLABEL (continuation_153)
  INTERRUPT_CHECK (27, LABEL_143_195);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_143_24]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_24]));

DEFLABEL (continuation_154)
  INTERRUPT_CHECK (27, LABEL_143_192);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_223]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_6]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_920;
  Wrd8 = Wrd12;

DEFLABEL (label_919)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_7]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_918;
  Wrd14 = Wrd18;

DEFLABEL (label_917)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_226]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd24.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_8]));
  (Wrd27.Obj) = ((Wrd24.pObj) [0]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if ((Wrd28.uLng) == 50)
    goto label_916;
  Wrd23 = Wrd27;

DEFLABEL (label_915)
  (* (--Rsp)) = (Wrd23.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_19]));

DEFLABEL (continuation_155)
  INTERRUPT_CHECK (27, LABEL_143_226);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_143_25]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_24]));

DEFLABEL (continuation_156)
  INTERRUPT_CHECK (27, LABEL_143_223);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_245]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_35]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_914;
  Wrd8 = Wrd12;

DEFLABEL (label_913)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_36]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_912;
  Wrd14 = Wrd18;

DEFLABEL (label_911)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_248]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd24.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_37]));
  (Wrd27.Obj) = ((Wrd24.pObj) [0]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if ((Wrd28.uLng) == 50)
    goto label_910;
  Wrd23 = Wrd27;

DEFLABEL (label_909)
  (* (--Rsp)) = (Wrd23.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_197]));

DEFLABEL (continuation_157)
  INTERRUPT_CHECK (27, LABEL_143_248);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_143_26]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_24]));

DEFLABEL (continuation_158)
  INTERRUPT_CHECK (27, LABEL_143_245);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_263]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_264]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_6]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_908;
  Wrd11 = Wrd15;

DEFLABEL (label_907)
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd18.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_40]));
  (Wrd21.Obj) = ((Wrd18.pObj) [0]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if ((Wrd22.uLng) == 50)
    goto label_906;
  Wrd17 = Wrd21;

DEFLABEL (label_905)
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd24.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_41]));
  (Wrd27.Obj) = ((Wrd24.pObj) [0]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if ((Wrd28.uLng) == 50)
    goto label_904;
  Wrd23 = Wrd27;

DEFLABEL (label_903)
  (* (--Rsp)) = (Wrd23.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_61]));

DEFLABEL (continuation_166)
  INTERRUPT_CHECK (27, LABEL_143_264);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_277]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_7]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_902;
  Wrd8 = Wrd12;

DEFLABEL (label_901)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_41]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_900;
  Wrd14 = Wrd18;

DEFLABEL (label_899)
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_90]));

DEFLABEL (continuation_165)
  INTERRUPT_CHECK (27, LABEL_143_277);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_286]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_8]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_898;
  Wrd8 = Wrd12;

DEFLABEL (label_897)
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_19]));

DEFLABEL (continuation_160)
  INTERRUPT_CHECK (27, LABEL_143_286);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_292]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_48]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_896;
  Wrd8 = Wrd12;

DEFLABEL (label_895)
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_197]));

DEFLABEL (continuation_159)
  INTERRUPT_CHECK (27, LABEL_143_292);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_303);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_302])));
  Rhp += 2;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  Wrd11 = Wrd8;
  (Wrd12.Obj) = (Rsp [1]);
  ((Wrd11.pObj) [2]) = (Wrd12.Obj);
  ((Wrd11.pObj) [3]) = Rvl;
  Rsp = (& (Rsp [2]));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd13.Obj) = (current_block [OBJECT_143_30]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_24]));

DEFLABEL (continuation_167)
  INTERRUPT_CHECK (27, LABEL_143_263);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_272]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_6]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_894;
  Wrd8 = Wrd12;

DEFLABEL (label_893)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_7]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_892;
  Wrd14 = Wrd18;

DEFLABEL (label_891)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_275]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd24.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_8]));
  (Wrd27.Obj) = ((Wrd24.pObj) [0]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if ((Wrd28.uLng) == 50)
    goto label_890;
  Wrd23 = Wrd27;

DEFLABEL (label_889)
  (* (--Rsp)) = (Wrd23.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_19]));

DEFLABEL (continuation_168)
  INTERRUPT_CHECK (27, LABEL_143_275);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_143_27]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_24]));

DEFLABEL (continuation_169)
  INTERRUPT_CHECK (27, LABEL_143_272);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_281]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_43]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_888;
  Wrd8 = Wrd12;

DEFLABEL (label_887)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_44]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_886;
  Wrd14 = Wrd18;

DEFLABEL (label_885)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_284]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd24.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_45]));
  (Wrd27.Obj) = ((Wrd24.pObj) [0]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if ((Wrd28.uLng) == 50)
    goto label_884;
  Wrd23 = Wrd27;

DEFLABEL (label_883)
  (* (--Rsp)) = (Wrd23.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_197]));

DEFLABEL (continuation_170)
  INTERRUPT_CHECK (27, LABEL_143_284);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_143_29]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_24]));

DEFLABEL (continuation_171)
  INTERRUPT_CHECK (27, LABEL_143_281);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_288]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_289]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_46]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_882;
  Wrd11 = Wrd15;

DEFLABEL (label_881)
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd17.Obj) = (current_block [OBJECT_143_28]);
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd19.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_47]));
  (Wrd22.Obj) = ((Wrd19.pObj) [0]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if ((Wrd23.uLng) == 50)
    goto label_880;
  Wrd18 = Wrd22;

DEFLABEL (label_879)
  (* (--Rsp)) = (Wrd18.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_80]));

DEFLABEL (continuation_183)
  INTERRUPT_CHECK (27, LABEL_143_289);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_299]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_50]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_878;
  Wrd8 = Wrd12;

DEFLABEL (label_877)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_51]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_876;
  Wrd14 = Wrd18;

DEFLABEL (label_875)
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_109]));

DEFLABEL (continuation_182)
  INTERRUPT_CHECK (27, LABEL_143_299);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_313]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_314]))));
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_197]));

DEFLABEL (continuation_181)
  INTERRUPT_CHECK (27, LABEL_143_313);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_143_33]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_24]));

DEFLABEL (continuation_184)
  INTERRUPT_CHECK (27, LABEL_143_288);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_294]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_49]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_874;
  Wrd8 = Wrd12;

DEFLABEL (label_873)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_296]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_297]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_298]))));
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_19]));

DEFLABEL (continuation_207)
  INTERRUPT_CHECK (27, LABEL_143_297);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_143_31]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_24]));

DEFLABEL (continuation_211)
  INTERRUPT_CHECK (27, LABEL_143_294);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_304]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_9]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_872;
  Wrd8 = Wrd12;

DEFLABEL (label_871)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_306]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd18.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_27]));
  (Wrd21.Obj) = ((Wrd18.pObj) [0]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if ((Wrd22.uLng) == 50)
    goto label_870;
  Wrd17 = Wrd21;

DEFLABEL (label_869)
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd24.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_4]));
  (Wrd27.Obj) = ((Wrd24.pObj) [0]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if ((Wrd28.uLng) == 50)
    goto label_868;
  Wrd23 = Wrd27;

DEFLABEL (label_867)
  (* (--Rsp)) = (Wrd23.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_109]));

DEFLABEL (continuation_219)
  INTERRUPT_CHECK (27, LABEL_143_306);
  (* (--Rsp)) = Rvl;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_322]))));
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd7.Obj) = (current_block [OBJECT_143_32]);
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_115]));

DEFLABEL (continuation_220)
  INTERRUPT_CHECK (27, LABEL_143_304);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_317]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_52]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_866;
  Wrd8 = Wrd12;

DEFLABEL (label_865)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_53]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_864;
  Wrd14 = Wrd18;

DEFLABEL (label_863)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_320]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd24.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_54]));
  (Wrd27.Obj) = ((Wrd24.pObj) [0]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if ((Wrd28.uLng) == 50)
    goto label_862;
  Wrd23 = Wrd27;

DEFLABEL (label_861)
  (* (--Rsp)) = (Wrd23.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_197]));

DEFLABEL (continuation_221)
  INTERRUPT_CHECK (27, LABEL_143_320);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_143_35]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_24]));

DEFLABEL (continuation_222)
  INTERRUPT_CHECK (27, LABEL_143_317);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_329]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_330]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_55]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_860;
  Wrd11 = Wrd15;

DEFLABEL (label_859)
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_332]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd20.Obj) = (current_block [OBJECT_143_34]);
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_333]));

DEFLABEL (continuation_238)
  INTERRUPT_CHECK (27, LABEL_143_332);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_56]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_858;
  Wrd5 = Wrd9;

DEFLABEL (label_857)
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_61]));

DEFLABEL (continuation_239)
  INTERRUPT_CHECK (27, LABEL_143_330);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_348]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_4]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_856;
  Wrd8 = Wrd12;

DEFLABEL (label_855)
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_147]));

DEFLABEL (continuation_237)
  INTERRUPT_CHECK (27, LABEL_143_348);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_363]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_364]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_143_34]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_365]));

DEFLABEL (continuation_223)
  INTERRUPT_CHECK (27, LABEL_143_364);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_381);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_380])));
  Rhp += 1;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  ((Wrd8.pObj) [2]) = Rvl;
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_197]));

DEFLABEL (continuation_236)
  INTERRUPT_CHECK (27, LABEL_143_363);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_143_41]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_24]));

DEFLABEL (continuation_240)
  INTERRUPT_CHECK (27, LABEL_143_329);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_343]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_43]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_854;
  Wrd8 = Wrd12;

DEFLABEL (label_853)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_44]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_852;
  Wrd14 = Wrd18;

DEFLABEL (label_851)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_346]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd24.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_45]));
  (Wrd27.Obj) = ((Wrd24.pObj) [0]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if ((Wrd28.uLng) == 50)
    goto label_850;
  Wrd23 = Wrd27;

DEFLABEL (label_849)
  (* (--Rsp)) = (Wrd23.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_197]));

DEFLABEL (continuation_241)
  INTERRUPT_CHECK (27, LABEL_143_346);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_143_37]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_24]));

DEFLABEL (continuation_242)
  INTERRUPT_CHECK (27, LABEL_143_343);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_358]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_40]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_848;
  Wrd8 = Wrd12;

DEFLABEL (label_847)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_41]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_846;
  Wrd14 = Wrd18;

DEFLABEL (label_845)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_361]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd24.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_48]));
  (Wrd27.Obj) = ((Wrd24.pObj) [0]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if ((Wrd28.uLng) == 50)
    goto label_844;
  Wrd23 = Wrd27;

DEFLABEL (label_843)
  (* (--Rsp)) = (Wrd23.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_197]));

DEFLABEL (continuation_243)
  INTERRUPT_CHECK (27, LABEL_143_361);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_143_40]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_24]));

DEFLABEL (continuation_244)
  INTERRUPT_CHECK (27, LABEL_143_358);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_375]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_49]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_842;
  Wrd8 = Wrd12;

DEFLABEL (label_841)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_57]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_840;
  Wrd14 = Wrd18;

DEFLABEL (label_839)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_378]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd24.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_58]));
  (Wrd27.Obj) = ((Wrd24.pObj) [0]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if ((Wrd28.uLng) == 50)
    goto label_838;
  Wrd23 = Wrd27;

DEFLABEL (label_837)
  (* (--Rsp)) = (Wrd23.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_19]));

DEFLABEL (continuation_245)
  INTERRUPT_CHECK (27, LABEL_143_378);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_143_42]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_24]));

DEFLABEL (continuation_246)
  INTERRUPT_CHECK (27, LABEL_143_375);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_387]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_388]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_43]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_836;
  Wrd11 = Wrd15;

DEFLABEL (label_835)
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd18.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_6]));
  (Wrd21.Obj) = ((Wrd18.pObj) [0]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if ((Wrd22.uLng) == 50)
    goto label_834;
  Wrd17 = Wrd21;

DEFLABEL (label_833)
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd24.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_7]));
  (Wrd27.Obj) = ((Wrd24.pObj) [0]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if ((Wrd28.uLng) == 50)
    goto label_832;
  Wrd23 = Wrd27;

DEFLABEL (label_831)
  (* (--Rsp)) = (Wrd23.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_61]));

DEFLABEL (continuation_258)
  INTERRUPT_CHECK (27, LABEL_143_388);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_402]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_44]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_830;
  Wrd8 = Wrd12;

DEFLABEL (label_829)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_7]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_828;
  Wrd14 = Wrd18;

DEFLABEL (label_827)
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_90]));

DEFLABEL (continuation_257)
  INTERRUPT_CHECK (27, LABEL_143_402);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_415]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_416]))));
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_19]));

DEFLABEL (continuation_256)
  INTERRUPT_CHECK (27, LABEL_143_415);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_143_45]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_24]));

DEFLABEL (continuation_259)
  INTERRUPT_CHECK (27, LABEL_143_387);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_397]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_52]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_826;
  Wrd8 = Wrd12;

DEFLABEL (label_825)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_53]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_824;
  Wrd14 = Wrd18;

DEFLABEL (label_823)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_400]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd24.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_54]));
  (Wrd27.Obj) = ((Wrd24.pObj) [0]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if ((Wrd28.uLng) == 50)
    goto label_822;
  Wrd23 = Wrd27;

DEFLABEL (label_821)
  (* (--Rsp)) = (Wrd23.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_197]));

DEFLABEL (continuation_260)
  INTERRUPT_CHECK (27, LABEL_143_400);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_143_43]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_24]));

DEFLABEL (continuation_261)
  INTERRUPT_CHECK (27, LABEL_143_397);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_410]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_411]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_55]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_820;
  Wrd11 = Wrd15;

DEFLABEL (label_819)
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd18.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_59]));
  (Wrd21.Obj) = ((Wrd18.pObj) [0]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if ((Wrd22.uLng) == 50)
    goto label_818;
  Wrd17 = Wrd21;

DEFLABEL (label_817)
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd24.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_60]));
  (Wrd27.Obj) = ((Wrd24.pObj) [0]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if ((Wrd28.uLng) == 50)
    goto label_816;
  Wrd23 = Wrd27;

DEFLABEL (label_815)
  (* (--Rsp)) = (Wrd23.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_61]));

DEFLABEL (continuation_268)
  INTERRUPT_CHECK (27, LABEL_143_411);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_423]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_424]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_4]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_814;
  Wrd11 = Wrd15;

DEFLABEL (label_813)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_426]));

DEFLABEL (continuation_266)
  INTERRUPT_CHECK (27, LABEL_143_424);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_60]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_812;
  Wrd5 = Wrd9;

DEFLABEL (label_811)
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_90]));

DEFLABEL (continuation_267)
  INTERRUPT_CHECK (27, LABEL_143_423);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_433]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_434]))));
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_197]));

DEFLABEL (continuation_265)
  INTERRUPT_CHECK (27, LABEL_143_433);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_143_48]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_24]));

DEFLABEL (continuation_269)
  INTERRUPT_CHECK (27, LABEL_143_410);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_419]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_61]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_810;
  Wrd8 = Wrd12;

DEFLABEL (label_809)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_62]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_808;
  Wrd14 = Wrd18;

DEFLABEL (label_807)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd21.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_63]));
  (Wrd24.Obj) = ((Wrd21.pObj) [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd25.uLng) == 50)
    goto label_806;
  Wrd20 = Wrd24;

DEFLABEL (label_805)
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd26.Obj) = (current_block [OBJECT_143_44]);
  (* (--Rsp)) = (Wrd26.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_115]));

DEFLABEL (continuation_270)
  INTERRUPT_CHECK (27, LABEL_143_419);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_429]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_3]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_804;
  Wrd8 = Wrd12;

DEFLABEL (label_803)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_4]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_802;
  Wrd14 = Wrd18;

DEFLABEL (label_801)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd21.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_5]));
  (Wrd24.Obj) = ((Wrd21.pObj) [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd25.uLng) == 50)
    goto label_800;
  Wrd20 = Wrd24;

DEFLABEL (label_799)
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd26.Obj) = (current_block [OBJECT_143_46]);
  (* (--Rsp)) = (Wrd26.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_9]));

DEFLABEL (continuation_271)
  INTERRUPT_CHECK (27, LABEL_143_429);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_438]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_3]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_798;
  Wrd8 = Wrd12;

DEFLABEL (label_797)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_64]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_796;
  Wrd14 = Wrd18;

DEFLABEL (label_795)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_441]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd22.Obj) = (current_block [OBJECT_143_47]);
  (* (--Rsp)) = (Wrd22.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_9]));

DEFLABEL (continuation_276)
  INTERRUPT_CHECK (27, LABEL_143_438);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_446]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_43]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_794;
  Wrd8 = Wrd12;

DEFLABEL (label_793)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_44]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_792;
  Wrd14 = Wrd18;

DEFLABEL (label_791)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_449]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (Wrd24.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_45]));
  (Wrd27.Obj) = ((Wrd24.pObj) [0]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if ((Wrd28.uLng) == 50)
    goto label_790;
  Wrd23 = Wrd27;

DEFLABEL (label_789)
  (* (--Rsp)) = (Wrd23.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_197]));

DEFLABEL (continuation_277)
  INTERRUPT_CHECK (27, LABEL_143_449);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_143_49]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_24]));

DEFLABEL (continuation_278)
  INTERRUPT_CHECK (27, LABEL_143_446);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_457]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_49]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_788;
  Wrd8 = Wrd12;

DEFLABEL (label_787)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_459]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_460]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_461]))));
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_19]));

DEFLABEL (continuation_288)
  INTERRUPT_CHECK (27, LABEL_143_460);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_143_51]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_24]));

DEFLABEL (continuation_292)
  INTERRUPT_CHECK (27, LABEL_143_457);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_465]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_466]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_467]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_468]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_143_50]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_24]));

DEFLABEL (continuation_305)
  INTERRUPT_CHECK (27, LABEL_143_465);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_472]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_473]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_474]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_59]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_786;
  Wrd14 = Wrd18;

DEFLABEL (label_785)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd21.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_43]));
  (Wrd24.Obj) = ((Wrd21.pObj) [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd25.uLng) == 50)
    goto label_784;
  Wrd20 = Wrd24;

DEFLABEL (label_783)
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd27.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_44]));
  (Wrd30.Obj) = ((Wrd27.pObj) [0]);
  (Wrd31.uLng) = (OBJECT_TYPE (Wrd30.Obj));
  if ((Wrd31.uLng) == 50)
    goto label_782;
  Wrd26 = Wrd30;

DEFLABEL (label_781)
  (* (--Rsp)) = (Wrd26.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_478]));

DEFLABEL (continuation_343)
  INTERRUPT_CHECK (27, LABEL_143_474);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_143_8]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_495]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_59]));
  (Wrd13.Obj) = ((Wrd10.pObj) [0]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd14.uLng) == 50)
    goto label_780;
  Wrd9 = Wrd13;

DEFLABEL (label_779)
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd16.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_65]));
  (Wrd19.Obj) = ((Wrd16.pObj) [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if ((Wrd20.uLng) == 50)
    goto label_778;
  Wrd15 = Wrd19;

DEFLABEL (label_777)
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd22.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_66]));
  (Wrd25.Obj) = ((Wrd22.pObj) [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 50)
    goto label_776;
  Wrd21 = Wrd25;

DEFLABEL (label_775)
  (* (--Rsp)) = (Wrd21.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_478]));

DEFLABEL (continuation_342)
  INTERRUPT_CHECK (27, LABEL_143_495);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_143_7]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd7.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_47]));
  (Wrd10.Obj) = ((Wrd7.pObj) [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd11.uLng) == 50)
    goto label_774;
  Wrd6 = Wrd10;

DEFLABEL (label_773)
  (* (--Rsp)) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_79]));

DEFLABEL (continuation_344)
  INTERRUPT_CHECK (27, LABEL_143_473);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_491]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_492]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_60]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_772;
  Wrd11 = Wrd15;

DEFLABEL (label_771)
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd18.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_44]));
  (Wrd21.Obj) = ((Wrd18.pObj) [0]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if ((Wrd22.uLng) == 50)
    goto label_770;
  Wrd17 = Wrd21;

DEFLABEL (label_769)
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_90]));

DEFLABEL (continuation_340)
  INTERRUPT_CHECK (27, LABEL_143_492);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_517]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_60]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_768;
  Wrd8 = Wrd12;

DEFLABEL (label_767)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_66]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_766;
  Wrd14 = Wrd18;

DEFLABEL (label_765)
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_90]));

DEFLABEL (continuation_339)
  INTERRUPT_CHECK (27, LABEL_143_517);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_51]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_764;
  Wrd5 = Wrd9;

DEFLABEL (label_763)
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_108]));

DEFLABEL (continuation_341)
  INTERRUPT_CHECK (27, LABEL_143_491);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_515]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_516]))));
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_197]));

DEFLABEL (continuation_338)
  INTERRUPT_CHECK (27, LABEL_143_515);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_143_55]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_24]));

DEFLABEL (continuation_345)
  INTERRUPT_CHECK (27, LABEL_143_472);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_488]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_489]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_143_52]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_18]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_762;
  Wrd12 = Wrd16;

DEFLABEL (label_761)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_91]));

DEFLABEL (continuation_355)
  INTERRUPT_CHECK (27, LABEL_143_489);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_512]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_19]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_760;
  Wrd8 = Wrd12;

DEFLABEL (label_759)
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_514]));

DEFLABEL (continuation_354)
  INTERRUPT_CHECK (27, LABEL_143_512);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_528]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_529]))));
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_197]));

DEFLABEL (continuation_353)
  INTERRUPT_CHECK (27, LABEL_143_528);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_143_57]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_24]));

DEFLABEL (continuation_356)
  INTERRUPT_CHECK (27, LABEL_143_488);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_507]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_508]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_509]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd14.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_6]));
  (Wrd17.Obj) = ((Wrd14.pObj) [0]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if ((Wrd18.uLng) == 50)
    goto label_758;
  Wrd13 = Wrd17;

DEFLABEL (label_757)
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_7]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_756;
  Wrd19 = Wrd23;

DEFLABEL (label_755)
  (* (--Rsp)) = (Wrd19.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_61]));

DEFLABEL (continuation_376)
  INTERRUPT_CHECK (27, LABEL_143_508);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_526]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_7]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_754;
  Wrd8 = Wrd12;

DEFLABEL (label_753)
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_49]));

DEFLABEL (continuation_374)
  INTERRUPT_CHECK (27, LABEL_143_526);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_534]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_535]))));
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_19]));

DEFLABEL (continuation_373)
  INTERRUPT_CHECK (27, LABEL_143_534);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_143_58]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_24]));

DEFLABEL (continuation_377)
  INTERRUPT_CHECK (27, LABEL_143_507);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_6]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_752;
  Wrd5 = Wrd9;

DEFLABEL (label_751)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_7]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_750;
  Wrd11 = Wrd15;

DEFLABEL (label_749)
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_524]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd21.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_8]));
  (Wrd24.Obj) = ((Wrd21.pObj) [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd25.uLng) == 50)
    goto label_748;
  Wrd20 = Wrd24;

DEFLABEL (label_747)
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_19]));

DEFLABEL (continuation_378)
  INTERRUPT_CHECK (27, LABEL_143_524);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_143_56]);
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_24]));

DEFLABEL (label_748)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_525])), (Wrd21.pObj));

DEFLABEL (label_546)
  (Wrd20.Obj) = Rvl;
  goto label_747;

DEFLABEL (label_750)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_523])), (Wrd12.pObj));

DEFLABEL (label_545)
  (Wrd11.Obj) = Rvl;
  goto label_749;

DEFLABEL (label_752)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_522])), (Wrd6.pObj));

DEFLABEL (label_544)
  (Wrd5.Obj) = Rvl;
  goto label_751;

DEFLABEL (label_754)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_527])), (Wrd9.pObj));

DEFLABEL (label_547)
  (Wrd8.Obj) = Rvl;
  goto label_753;

DEFLABEL (label_756)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_511])), (Wrd20.pObj));

DEFLABEL (label_538)
  (Wrd19.Obj) = Rvl;
  goto label_755;

DEFLABEL (label_758)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_510])), (Wrd14.pObj));

DEFLABEL (label_537)
  (Wrd13.Obj) = Rvl;
  goto label_757;

DEFLABEL (label_760)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_513])), (Wrd9.pObj));

DEFLABEL (label_539)
  (Wrd8.Obj) = Rvl;
  goto label_759;

DEFLABEL (label_762)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_490])), (Wrd13.pObj));

DEFLABEL (label_531)
  (Wrd12.Obj) = Rvl;
  goto label_761;

DEFLABEL (label_764)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_532])), (Wrd6.pObj));

DEFLABEL (label_548)
  (Wrd5.Obj) = Rvl;
  goto label_763;

DEFLABEL (label_766)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_519])), (Wrd15.pObj));

DEFLABEL (label_541)
  (Wrd14.Obj) = Rvl;
  goto label_765;

DEFLABEL (label_768)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_518])), (Wrd9.pObj));

DEFLABEL (label_540)
  (Wrd8.Obj) = Rvl;
  goto label_767;

DEFLABEL (label_770)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_494])), (Wrd18.pObj));

DEFLABEL (label_533)
  (Wrd17.Obj) = Rvl;
  goto label_769;

DEFLABEL (label_772)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_493])), (Wrd12.pObj));

DEFLABEL (label_532)
  (Wrd11.Obj) = Rvl;
  goto label_771;

DEFLABEL (label_774)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_520])), (Wrd7.pObj));

DEFLABEL (label_542)
  (Wrd6.Obj) = Rvl;
  goto label_773;

DEFLABEL (label_776)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_498])), (Wrd22.pObj));

DEFLABEL (label_536)
  (Wrd21.Obj) = Rvl;
  goto label_775;

DEFLABEL (label_778)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_497])), (Wrd16.pObj));

DEFLABEL (label_535)
  (Wrd15.Obj) = Rvl;
  goto label_777;

DEFLABEL (label_780)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_496])), (Wrd10.pObj));

DEFLABEL (label_534)
  (Wrd9.Obj) = Rvl;
  goto label_779;

DEFLABEL (label_782)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_477])), (Wrd27.pObj));

DEFLABEL (label_530)
  (Wrd26.Obj) = Rvl;
  goto label_781;

DEFLABEL (label_784)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_476])), (Wrd21.pObj));

DEFLABEL (label_529)
  (Wrd20.Obj) = Rvl;
  goto label_783;

DEFLABEL (label_786)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_475])), (Wrd15.pObj));

DEFLABEL (label_528)
  (Wrd14.Obj) = Rvl;
  goto label_785;

DEFLABEL (label_788)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_458])), (Wrd9.pObj));

DEFLABEL (label_526)
  (Wrd8.Obj) = Rvl;
  goto label_787;

DEFLABEL (label_790)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_450])), (Wrd24.pObj));

DEFLABEL (label_525)
  (Wrd23.Obj) = Rvl;
  goto label_789;

DEFLABEL (label_792)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_448])), (Wrd15.pObj));

DEFLABEL (label_524)
  (Wrd14.Obj) = Rvl;
  goto label_791;

DEFLABEL (label_794)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_447])), (Wrd9.pObj));

DEFLABEL (label_523)
  (Wrd8.Obj) = Rvl;
  goto label_793;

DEFLABEL (label_796)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_440])), (Wrd15.pObj));

DEFLABEL (label_522)
  (Wrd14.Obj) = Rvl;
  goto label_795;

DEFLABEL (label_798)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_439])), (Wrd9.pObj));

DEFLABEL (label_521)
  (Wrd8.Obj) = Rvl;
  goto label_797;

DEFLABEL (label_800)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_432])), (Wrd21.pObj));

DEFLABEL (label_519)
  (Wrd20.Obj) = Rvl;
  goto label_799;

DEFLABEL (label_802)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_431])), (Wrd15.pObj));

DEFLABEL (label_518)
  (Wrd14.Obj) = Rvl;
  goto label_801;

DEFLABEL (label_804)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_430])), (Wrd9.pObj));

DEFLABEL (label_517)
  (Wrd8.Obj) = Rvl;
  goto label_803;

DEFLABEL (label_806)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_422])), (Wrd21.pObj));

DEFLABEL (label_515)
  (Wrd20.Obj) = Rvl;
  goto label_805;

DEFLABEL (label_808)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_421])), (Wrd15.pObj));

DEFLABEL (label_514)
  (Wrd14.Obj) = Rvl;
  goto label_807;

DEFLABEL (label_810)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_420])), (Wrd9.pObj));

DEFLABEL (label_513)
  (Wrd8.Obj) = Rvl;
  goto label_809;

DEFLABEL (label_812)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_435])), (Wrd6.pObj));

DEFLABEL (label_520)
  (Wrd5.Obj) = Rvl;
  goto label_811;

DEFLABEL (label_814)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_425])), (Wrd12.pObj));

DEFLABEL (label_516)
  (Wrd11.Obj) = Rvl;
  goto label_813;

DEFLABEL (label_816)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_414])), (Wrd24.pObj));

DEFLABEL (label_512)
  (Wrd23.Obj) = Rvl;
  goto label_815;

DEFLABEL (label_818)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_413])), (Wrd18.pObj));

DEFLABEL (label_511)
  (Wrd17.Obj) = Rvl;
  goto label_817;

DEFLABEL (label_820)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_412])), (Wrd12.pObj));

DEFLABEL (label_510)
  (Wrd11.Obj) = Rvl;
  goto label_819;

DEFLABEL (label_822)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_401])), (Wrd24.pObj));

DEFLABEL (label_507)
  (Wrd23.Obj) = Rvl;
  goto label_821;

DEFLABEL (label_824)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_399])), (Wrd15.pObj));

DEFLABEL (label_506)
  (Wrd14.Obj) = Rvl;
  goto label_823;

DEFLABEL (label_826)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_398])), (Wrd9.pObj));

DEFLABEL (label_505)
  (Wrd8.Obj) = Rvl;
  goto label_825;

DEFLABEL (label_828)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_404])), (Wrd15.pObj));

DEFLABEL (label_509)
  (Wrd14.Obj) = Rvl;
  goto label_827;

DEFLABEL (label_830)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_403])), (Wrd9.pObj));

DEFLABEL (label_508)
  (Wrd8.Obj) = Rvl;
  goto label_829;

DEFLABEL (label_832)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_391])), (Wrd24.pObj));

DEFLABEL (label_504)
  (Wrd23.Obj) = Rvl;
  goto label_831;

DEFLABEL (label_834)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_390])), (Wrd18.pObj));

DEFLABEL (label_503)
  (Wrd17.Obj) = Rvl;
  goto label_833;

DEFLABEL (label_836)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_389])), (Wrd12.pObj));

DEFLABEL (label_502)
  (Wrd11.Obj) = Rvl;
  goto label_835;

DEFLABEL (label_838)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_379])), (Wrd24.pObj));

DEFLABEL (label_499)
  (Wrd23.Obj) = Rvl;
  goto label_837;

DEFLABEL (label_840)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_377])), (Wrd15.pObj));

DEFLABEL (label_498)
  (Wrd14.Obj) = Rvl;
  goto label_839;

DEFLABEL (label_842)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_376])), (Wrd9.pObj));

DEFLABEL (label_497)
  (Wrd8.Obj) = Rvl;
  goto label_841;

DEFLABEL (label_844)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_362])), (Wrd24.pObj));

DEFLABEL (label_495)
  (Wrd23.Obj) = Rvl;
  goto label_843;

DEFLABEL (label_846)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_360])), (Wrd15.pObj));

DEFLABEL (label_494)
  (Wrd14.Obj) = Rvl;
  goto label_845;

DEFLABEL (label_848)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_359])), (Wrd9.pObj));

DEFLABEL (label_493)
  (Wrd8.Obj) = Rvl;
  goto label_847;

DEFLABEL (label_850)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_347])), (Wrd24.pObj));

DEFLABEL (label_490)
  (Wrd23.Obj) = Rvl;
  goto label_849;

DEFLABEL (label_852)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_345])), (Wrd15.pObj));

DEFLABEL (label_489)
  (Wrd14.Obj) = Rvl;
  goto label_851;

DEFLABEL (label_854)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_344])), (Wrd9.pObj));

DEFLABEL (label_488)
  (Wrd8.Obj) = Rvl;
  goto label_853;

DEFLABEL (label_856)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_349])), (Wrd9.pObj));

DEFLABEL (label_491)
  (Wrd8.Obj) = Rvl;
  goto label_855;

DEFLABEL (label_858)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_350])), (Wrd6.pObj));

DEFLABEL (label_492)
  (Wrd5.Obj) = Rvl;
  goto label_857;

DEFLABEL (label_860)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_331])), (Wrd12.pObj));

DEFLABEL (label_487)
  (Wrd11.Obj) = Rvl;
  goto label_859;

DEFLABEL (label_862)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_321])), (Wrd24.pObj));

DEFLABEL (label_486)
  (Wrd23.Obj) = Rvl;
  goto label_861;

DEFLABEL (label_864)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_319])), (Wrd15.pObj));

DEFLABEL (label_485)
  (Wrd14.Obj) = Rvl;
  goto label_863;

DEFLABEL (label_866)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_318])), (Wrd9.pObj));

DEFLABEL (label_484)
  (Wrd8.Obj) = Rvl;
  goto label_865;

DEFLABEL (label_868)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_308])), (Wrd24.pObj));

DEFLABEL (label_483)
  (Wrd23.Obj) = Rvl;
  goto label_867;

DEFLABEL (label_870)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_307])), (Wrd18.pObj));

DEFLABEL (label_482)
  (Wrd17.Obj) = Rvl;
  goto label_869;

DEFLABEL (label_872)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_305])), (Wrd9.pObj));

DEFLABEL (label_481)
  (Wrd8.Obj) = Rvl;
  goto label_871;

DEFLABEL (label_874)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_295])), (Wrd9.pObj));

DEFLABEL (label_478)
  (Wrd8.Obj) = Rvl;
  goto label_873;

DEFLABEL (label_876)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_301])), (Wrd15.pObj));

DEFLABEL (label_480)
  (Wrd14.Obj) = Rvl;
  goto label_875;

DEFLABEL (label_878)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_300])), (Wrd9.pObj));

DEFLABEL (label_479)
  (Wrd8.Obj) = Rvl;
  goto label_877;

DEFLABEL (label_880)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_291])), (Wrd19.pObj));

DEFLABEL (label_476)
  (Wrd18.Obj) = Rvl;
  goto label_879;

DEFLABEL (label_882)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_290])), (Wrd12.pObj));

DEFLABEL (label_475)
  (Wrd11.Obj) = Rvl;
  goto label_881;

DEFLABEL (label_884)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_285])), (Wrd24.pObj));

DEFLABEL (label_473)
  (Wrd23.Obj) = Rvl;
  goto label_883;

DEFLABEL (label_886)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_283])), (Wrd15.pObj));

DEFLABEL (label_472)
  (Wrd14.Obj) = Rvl;
  goto label_885;

DEFLABEL (label_888)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_282])), (Wrd9.pObj));

DEFLABEL (label_471)
  (Wrd8.Obj) = Rvl;
  goto label_887;

DEFLABEL (label_890)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_276])), (Wrd24.pObj));

DEFLABEL (label_467)
  (Wrd23.Obj) = Rvl;
  goto label_889;

DEFLABEL (label_892)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_274])), (Wrd15.pObj));

DEFLABEL (label_466)
  (Wrd14.Obj) = Rvl;
  goto label_891;

DEFLABEL (label_894)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_273])), (Wrd9.pObj));

DEFLABEL (label_465)
  (Wrd8.Obj) = Rvl;
  goto label_893;

DEFLABEL (label_896)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_293])), (Wrd9.pObj));

DEFLABEL (label_477)
  (Wrd8.Obj) = Rvl;
  goto label_895;

DEFLABEL (label_898)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_287])), (Wrd9.pObj));

DEFLABEL (label_474)
  (Wrd8.Obj) = Rvl;
  goto label_897;

DEFLABEL (label_900)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_279])), (Wrd15.pObj));

DEFLABEL (label_469)
  (Wrd14.Obj) = Rvl;
  goto label_899;

DEFLABEL (label_902)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_278])), (Wrd9.pObj));

DEFLABEL (label_468)
  (Wrd8.Obj) = Rvl;
  goto label_901;

DEFLABEL (label_904)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_267])), (Wrd24.pObj));

DEFLABEL (label_463)
  (Wrd23.Obj) = Rvl;
  goto label_903;

DEFLABEL (label_906)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_266])), (Wrd18.pObj));

DEFLABEL (label_462)
  (Wrd17.Obj) = Rvl;
  goto label_905;

DEFLABEL (label_908)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_265])), (Wrd12.pObj));

DEFLABEL (label_461)
  (Wrd11.Obj) = Rvl;
  goto label_907;

DEFLABEL (label_910)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_249])), (Wrd24.pObj));

DEFLABEL (label_458)
  (Wrd23.Obj) = Rvl;
  goto label_909;

DEFLABEL (label_912)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_247])), (Wrd15.pObj));

DEFLABEL (label_457)
  (Wrd14.Obj) = Rvl;
  goto label_911;

DEFLABEL (label_914)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_246])), (Wrd9.pObj));

DEFLABEL (label_456)
  (Wrd8.Obj) = Rvl;
  goto label_913;

DEFLABEL (label_916)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_227])), (Wrd24.pObj));

DEFLABEL (label_452)
  (Wrd23.Obj) = Rvl;
  goto label_915;

DEFLABEL (label_918)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_225])), (Wrd15.pObj));

DEFLABEL (label_451)
  (Wrd14.Obj) = Rvl;
  goto label_917;

DEFLABEL (label_920)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_224])), (Wrd9.pObj));

DEFLABEL (label_450)
  (Wrd8.Obj) = Rvl;
  goto label_919;

DEFLABEL (label_922)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_196])), (Wrd24.pObj));

DEFLABEL (label_447)
  (Wrd23.Obj) = Rvl;
  goto label_921;

DEFLABEL (label_924)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_194])), (Wrd15.pObj));

DEFLABEL (label_446)
  (Wrd14.Obj) = Rvl;
  goto label_923;

DEFLABEL (label_926)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_193])), (Wrd9.pObj));

DEFLABEL (label_445)
  (Wrd8.Obj) = Rvl;
  goto label_925;

DEFLABEL (label_928)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_170])), (Wrd24.pObj));

DEFLABEL (label_441)
  (Wrd23.Obj) = Rvl;
  goto label_927;

DEFLABEL (label_930)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_168])), (Wrd15.pObj));

DEFLABEL (label_440)
  (Wrd14.Obj) = Rvl;
  goto label_929;

DEFLABEL (label_932)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_167])), (Wrd9.pObj));

DEFLABEL (label_439)
  (Wrd8.Obj) = Rvl;
  goto label_931;

DEFLABEL (label_934)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_146])), (Wrd27.pObj));

DEFLABEL (label_432)
  (Wrd26.Obj) = Rvl;
  goto label_933;

DEFLABEL (label_936)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_144])), (Wrd18.pObj));

DEFLABEL (label_431)
  (Wrd17.Obj) = Rvl;
  goto label_935;

DEFLABEL (label_938)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_142])), (Wrd9.pObj));

DEFLABEL (label_430)
  (Wrd8.Obj) = Rvl;
  goto label_937;

DEFLABEL (lambda_561)
DEFLABEL (lambda_93)
  INTERRUPT_CHECK (26, LABEL_143_45);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_69]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd9.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_71);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_70])));
  Rhp += 1;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd9.pObj)));
  Wrd10 = Wrd9;
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd10.pObj) [2]) = (Wrd11.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_72]));

DEFLABEL (continuation_92)
  INTERRUPT_CHECK (27, LABEL_143_69);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_99]));

DEFLABEL (lambda_563)
DEFLABEL (lambda_118)
  INTERRUPT_CHECK (26, LABEL_143_58);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_92]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_93]));

DEFLABEL (continuation_117)
  INTERRUPT_CHECK (27, LABEL_143_92);
  (Wrd5.Obj) = (current_block [OBJECT_143_15]);
  (Rsp [0]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_116]));

DEFLABEL (lambda_562)
  CLOSURE_HEADER (LABEL_143_70);

DEFLABEL (lambda_91)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_100]));

DEFLABEL (lambda_564)
DEFLABEL (lambda_39)
  INTERRUPT_CHECK (26, LABEL_143_73);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd6.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_102);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_101])));
  Rhp += 1;
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd6.pObj)));
  Wrd7 = Wrd6;
  (Wrd8.Obj) = (Rsp [1]);
  ((Wrd7.pObj) [2]) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd11.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_104);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_103])));
  Rhp += 1;
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd11.pObj)));
  ((Wrd11.pObj) [2]) = (Wrd5.Obj);
  (Rsp [2]) = (Wrd10.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd16.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_106);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_105])));
  Rhp += 3;
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd16.pObj)));
  Wrd21 = Wrd16;
  (Wrd22.Obj) = (Rsp [3]);
  ((Wrd21.pObj) [2]) = (Wrd22.Obj);
  (Wrd20.Obj) = (Rsp [1]);
  ((Wrd21.pObj) [3]) = (Wrd20.Obj);
  ((Wrd21.pObj) [4]) = (Wrd5.Obj);
  (Rsp [3]) = (Wrd15.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_107]));

DEFLABEL (lambda_568)
DEFLABEL (lambda_88)
  INTERRUPT_CHECK (26, LABEL_143_94);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_118);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_117])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [1]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_119]));

DEFLABEL (lambda_565)
DEFLABEL (lambda_31)
  INTERRUPT_CHECK (26, LABEL_143_101);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_121);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_120])));
  Rhp += 2;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd10 = Wrd7;
  (Wrd11.Obj) = (Rsp [0]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [2]);
  ((Wrd10.pObj) [2]) = (Wrd13.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  ((Wrd10.pObj) [3]) = (Wrd9.Obj);
  (Rsp [2]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_107]));

DEFLABEL (lambda_566)
  CLOSURE_HEADER (LABEL_143_103);

DEFLABEL (lambda_34)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_123);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_122])));
  Rhp += 2;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd10 = Wrd7;
  (Wrd11.Obj) = (Rsp [0]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [2]);
  ((Wrd10.pObj) [2]) = (Wrd13.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  ((Wrd10.pObj) [3]) = (Wrd9.Obj);
  (Rsp [2]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_124]));

DEFLABEL (lambda_567)
  CLOSURE_HEADER (LABEL_143_105);

DEFLABEL (lambda_37)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd8.Obj) = (current_block [OBJECT_143_16]);
  (* (Rhp++)) = (Wrd8.Obj);
  (* (Rhp++)) = ((SCHEME_OBJECT) 0);
  (Wrd6.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd6.pObj)));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd15.Obj) = ((Wrd11.pObj) [4]);
  (* (--Rsp)) = (Wrd15.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd18.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_126);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_125])));
  Rhp += 1;
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd18.pObj)));
  Wrd19 = Wrd18;
  (Wrd22.Obj) = ((Wrd11.pObj) [2]);
  ((Wrd19.pObj) [2]) = (Wrd22.Obj);
  (Rsp [3]) = (Wrd17.Obj);
  goto lambda_31;

DEFLABEL (lambda_573)
DEFLABEL (lambda_114)
  INTERRUPT_CHECK (26, LABEL_143_114);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_134);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_133])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [1]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_107]));

DEFLABEL (lambda_569)
  CLOSURE_HEADER (LABEL_143_117);

DEFLABEL (lambda_87)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_135]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_136]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_137]));

DEFLABEL (continuation_49)
  INTERRUPT_CHECK (27, LABEL_143_136);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_29]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_946;
  Wrd5 = Wrd9;

DEFLABEL (label_945)
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_143_20]), 2);

DEFLABEL (continuation_50)
  INTERRUPT_CHECK (27, LABEL_143_135);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_940;

DEFLABEL (label_939)
  Rsp = (& (Rsp [3]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (label_940)
  (Wrd7.Obj) = (Rsp [1]);
  (Wrd8.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd8.uLng) == 1))
    goto label_939;
  if (! ((Wrd8.uLng) == 1))
    goto label_944;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd10.Obj) = ((Wrd12.pObj) [0]);

DEFLABEL (label_943)
  if (! ((Wrd10.Obj) == (current_block [OBJECT_143_7])))
    goto label_939;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd21.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_157);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_156])));
  Rhp += 2;
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd21.pObj)));
  Wrd24 = Wrd21;
  (Wrd25.Obj) = (Rsp [0]);
  (Wrd26.pObj) = (OBJECT_ADDRESS (Wrd25.Obj));
  (Wrd27.Obj) = ((Wrd26.pObj) [2]);
  ((Wrd24.pObj) [2]) = (Wrd27.Obj);
  (Wrd23.Obj) = (Rsp [2]);
  ((Wrd24.pObj) [3]) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (Rsp [3]) = (Wrd20.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd31.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_159);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_158])));
  Rhp += 3;
  (Wrd30.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd31.pObj)));
  Wrd36 = Wrd31;
  (Wrd37.Obj) = (Rsp [4]);
  ((Wrd36.pObj) [2]) = (Wrd37.Obj);
  (Wrd35.Obj) = (Rsp [2]);
  ((Wrd36.pObj) [3]) = (Wrd35.Obj);
  ((Wrd36.pObj) [4]) = (Wrd20.Obj);
  (Rsp [4]) = (Wrd30.Obj);
  (Wrd42.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if (! ((Wrd42.uLng) == 1))
    goto label_942;
  (Wrd40.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd38.Obj) = ((Wrd40.pObj) [1]);

DEFLABEL (label_941)
  (Rsp [2]) = (Wrd38.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_161]));

DEFLABEL (label_942)
  (Wrd46.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_160]))));
  (* (--Rsp)) = (Wrd46.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_143_19]), 1);

DEFLABEL (label_437)
  (Wrd38.Obj) = Rvl;
  goto label_941;

DEFLABEL (label_944)
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_155]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_143_18]), 1);

DEFLABEL (label_436)
  (Wrd10.Obj) = Rvl;
  goto label_943;

DEFLABEL (label_946)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_162])), (Wrd6.pObj));

DEFLABEL (label_438)
  (Wrd5.Obj) = Rvl;
  goto label_945;

DEFLABEL (lambda_570)
  CLOSURE_HEADER (LABEL_143_120);

DEFLABEL (lambda_30)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_139);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_138])));
  Rhp += 3;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd14 = Wrd7;
  (Wrd15.Obj) = (Rsp [0]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [2]);
  ((Wrd14.pObj) [2]) = (Wrd17.Obj);
  (Wrd13.Obj) = ((Wrd16.pObj) [3]);
  ((Wrd14.pObj) [3]) = (Wrd13.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  ((Wrd14.pObj) [4]) = (Wrd9.Obj);
  (Rsp [2]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_140]));

DEFLABEL (lambda_571)
  CLOSURE_HEADER (LABEL_143_122);

DEFLABEL (lambda_33)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [3]);
  (Wrd11.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (Rsp [2]) = (Wrd5.Obj);
  (Wrd12.Obj) = ((Wrd9.pObj) [2]);
  (Rsp [0]) = (Wrd12.Obj);
  goto lambda_31;

DEFLABEL (lambda_572)
  CLOSURE_HEADER (LABEL_143_125);

DEFLABEL (lambda_36)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (lambda_576)
DEFLABEL (lambda_125)
  INTERRUPT_CHECK (26, LABEL_143_130);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_948;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [0]);

DEFLABEL (label_947)
  (Rsp [0]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_150]));

DEFLABEL (label_948)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_149]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_143_18]), 1);

DEFLABEL (label_433)
  (Wrd5.Obj) = Rvl;
  goto label_947;

DEFLABEL (lambda_574)
  CLOSURE_HEADER (LABEL_143_133);

DEFLABEL (lambda_113)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_950;

DEFLABEL (label_949)
  Rsp = (& (Rsp [3]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (label_950)
  if (! ((Wrd6.uLng) == 1))
    goto label_954;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd8.Obj) = ((Wrd10.pObj) [0]);

DEFLABEL (label_953)
  if (! ((Wrd8.Obj) == (current_block [OBJECT_143_8])))
    goto label_949;
  (Wrd21.Obj) = (Rsp [1]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if (! ((Wrd22.uLng) == 1))
    goto label_952;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd18.Obj) = ((Wrd20.pObj) [1]);

DEFLABEL (label_951)
  (Rsp [1]) = (Wrd18.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd29.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_154);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_153])));
  Rhp += 2;
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd29.pObj)));
  Wrd32 = Wrd29;
  (Wrd33.Obj) = (Rsp [0]);
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd35.Obj) = ((Wrd34.pObj) [2]);
  ((Wrd32.pObj) [2]) = (Wrd35.Obj);
  (Wrd31.Obj) = (Rsp [2]);
  ((Wrd32.pObj) [3]) = (Wrd31.Obj);
  (Rsp [2]) = (Wrd28.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_107]));

DEFLABEL (label_952)
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_152]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_143_19]), 1);

DEFLABEL (label_435)
  (Wrd18.Obj) = Rvl;
  goto label_951;

DEFLABEL (label_954)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_151]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_143_18]), 1);

DEFLABEL (label_434)
  (Wrd8.Obj) = Rvl;
  goto label_953;

DEFLABEL (lambda_575)
  CLOSURE_HEADER (LABEL_143_138);

DEFLABEL (lambda_29)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 7));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_164);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_163])));
  Rhp += 4;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd18 = Wrd7;
  (Wrd19.Obj) = (Rsp [0]);
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd19.Obj));
  (Wrd21.Obj) = ((Wrd20.pObj) [2]);
  ((Wrd18.pObj) [2]) = (Wrd21.Obj);
  (Wrd17.Obj) = ((Wrd20.pObj) [3]);
  ((Wrd18.pObj) [3]) = (Wrd17.Obj);
  (Wrd13.Obj) = ((Wrd20.pObj) [4]);
  ((Wrd18.pObj) [4]) = (Wrd13.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  ((Wrd18.pObj) [5]) = (Wrd9.Obj);
  (Rsp [2]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_165]));

DEFLABEL (lambda_581)
DEFLABEL (lambda_130)
  INTERRUPT_CHECK (26, LABEL_143_148);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_173);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_172])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [1]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_174]));

DEFLABEL (lambda_577)
  CLOSURE_HEADER (LABEL_143_153);

DEFLABEL (lambda_112)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_176);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_175])));
  Rhp += 3;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd14 = Wrd7;
  (Wrd15.Obj) = (Rsp [0]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [2]);
  ((Wrd14.pObj) [2]) = (Wrd17.Obj);
  (Wrd13.Obj) = ((Wrd16.pObj) [3]);
  ((Wrd14.pObj) [3]) = (Wrd13.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  ((Wrd14.pObj) [4]) = (Wrd9.Obj);
  (Rsp [2]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_177]));

DEFLABEL (lambda_578)
  CLOSURE_HEADER (LABEL_143_156);

DEFLABEL (lambda_81)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_956;

DEFLABEL (label_955)
  Rsp = (& (Rsp [3]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (label_956)
  if (! ((Wrd6.uLng) == 1))
    goto label_960;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd8.Obj) = ((Wrd10.pObj) [0]);

DEFLABEL (label_959)
  if (! ((Wrd8.Obj) == (current_block [OBJECT_143_7])))
    goto label_955;
  (Wrd21.Obj) = (Rsp [1]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if (! ((Wrd22.uLng) == 1))
    goto label_958;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd18.Obj) = ((Wrd20.pObj) [1]);

DEFLABEL (label_957)
  (Rsp [1]) = (Wrd18.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd29.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_181);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_180])));
  Rhp += 3;
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd29.pObj)));
  Wrd36 = Wrd29;
  (Wrd37.Obj) = (Rsp [0]);
  (Wrd38.pObj) = (OBJECT_ADDRESS (Wrd37.Obj));
  (Wrd39.Obj) = ((Wrd38.pObj) [2]);
  ((Wrd36.pObj) [2]) = (Wrd39.Obj);
  (Wrd35.Obj) = ((Wrd38.pObj) [3]);
  ((Wrd36.pObj) [3]) = (Wrd35.Obj);
  (Wrd31.Obj) = (Rsp [2]);
  ((Wrd36.pObj) [4]) = (Wrd31.Obj);
  (Rsp [2]) = (Wrd28.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_182]));

DEFLABEL (label_958)
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_179]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_143_19]), 1);

DEFLABEL (label_443)
  (Wrd18.Obj) = Rvl;
  goto label_957;

DEFLABEL (label_960)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_178]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_143_18]), 1);

DEFLABEL (label_442)
  (Wrd8.Obj) = Rvl;
  goto label_959;

DEFLABEL (lambda_579)
  CLOSURE_HEADER (LABEL_143_158);

DEFLABEL (lambda_85)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [4]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd15.Obj) = ((Wrd6.pObj) [3]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 1))
    goto label_962;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [1]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_961)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd25.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_185);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_184])));
  Rhp += 1;
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd25.pObj)));
  Wrd26 = Wrd25;
  (Wrd27.Obj) = (Rsp [2]);
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd29.Obj) = ((Wrd28.pObj) [2]);
  ((Wrd26.pObj) [2]) = (Wrd29.Obj);
  (Rsp [2]) = (Wrd24.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_107]));

DEFLABEL (label_962)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_183]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd15.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_143_19]), 1);

DEFLABEL (label_444)
  (* (--Rsp)) = Rvl;
  goto label_961;

DEFLABEL (lambda_580)
  CLOSURE_HEADER (LABEL_143_163);

DEFLABEL (lambda_28)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 8));
  (Wrd6.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_187);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_186])));
  Rhp += 5;
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd6.pObj)));
  Wrd21 = Wrd6;
  (Wrd22.Obj) = (Rsp [0]);
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd22.Obj));
  (Wrd24.Obj) = ((Wrd23.pObj) [2]);
  ((Wrd21.pObj) [2]) = (Wrd24.Obj);
  (Wrd20.Obj) = ((Wrd23.pObj) [3]);
  ((Wrd21.pObj) [3]) = (Wrd20.Obj);
  (Wrd16.Obj) = ((Wrd23.pObj) [4]);
  ((Wrd21.pObj) [4]) = (Wrd16.Obj);
  (Wrd12.Obj) = ((Wrd23.pObj) [5]);
  ((Wrd21.pObj) [5]) = (Wrd12.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  ((Wrd21.pObj) [6]) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd26.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_189);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_188])));
  Rhp += 1;
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd26.pObj)));
  ((Wrd26.pObj) [2]) = (Wrd5.Obj);
  (* (--Rsp)) = (Wrd25.Obj);
  (Rsp [4]) = (Wrd25.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 7));
  (Wrd32.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_191);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_190])));
  Rhp += 4;
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd32.pObj)));
  Wrd39 = Wrd32;
  (Wrd40.Obj) = (Rsp [5]);
  ((Wrd39.pObj) [2]) = (Wrd40.Obj);
  (Wrd38.Obj) = (Rsp [3]);
  ((Wrd39.pObj) [3]) = (Wrd38.Obj);
  ((Wrd39.pObj) [4]) = (Wrd5.Obj);
  ((Wrd39.pObj) [5]) = (Wrd25.Obj);
  (Rsp [5]) = (Wrd31.Obj);
  Rsp = (& (Rsp [3]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_140]));

DEFLABEL (lambda_589)
DEFLABEL (lambda_147)
  INTERRUPT_CHECK (26, LABEL_143_171);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd11.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_199);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_198])));
  Rhp += 1;
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd11.pObj)));
  (* (--Rsp)) = (Wrd12.Obj);
  Wrd9 = Wrd11;
  (Wrd10.Obj) = (Rsp [2]);
  ((Wrd9.pObj) [2]) = (Wrd10.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd7.Obj) = (current_block [OBJECT_143_23]);
  (Rsp [2]) = (Wrd7.Obj);
  goto loop_0_145;

DEFLABEL (lambda_582)
  CLOSURE_HEADER (LABEL_143_172);

DEFLABEL (lambda_129)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_200]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_201]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_137]));

DEFLABEL (continuation_127)
  INTERRUPT_CHECK (27, LABEL_143_201);
  (* (--Rsp)) = Rvl;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_130]))));
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_143_20]), 2);

DEFLABEL (continuation_128)
  INTERRUPT_CHECK (27, LABEL_143_200);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_963;
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [2]);
  (Rsp [0]) = (Wrd7.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (label_963)
  Rsp = (& (Rsp [3]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (lambda_583)
  CLOSURE_HEADER (LABEL_143_175);

DEFLABEL (lambda_111)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_202]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_203]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_204]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_205]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd20.Obj) = (Rsp [4]);
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd22.Obj) = ((Wrd21.pObj) [3]);
  (Wrd25.Obj) = ((Wrd21.pObj) [4]);
  (* (Rhp++)) = (Wrd22.Obj);
  (* (Rhp++)) = (Wrd25.Obj);
  (Wrd18.pObj) = (& (Rhp [-2]));
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd18.pObj)));
  (* (--Rsp)) = (Wrd19.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_137]));

DEFLABEL (continuation_104)
  INTERRUPT_CHECK (27, LABEL_143_205);
  (* (--Rsp)) = Rvl;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_234]))));
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_143_20]), 2);

DEFLABEL (continuation_105)
  INTERRUPT_CHECK (27, LABEL_143_204);
  (Wrd9.Obj) = (current_block [OBJECT_143_16]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (Wrd13.Obj) = (Rsp [4]);
  (* (Rhp++)) = (Wrd6.Obj);
  (* (Rhp++)) = (Wrd13.Obj);
  (Wrd11.pObj) = (& (Rhp [-2]));
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd11.pObj)));
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_137]));

DEFLABEL (continuation_108)
  INTERRUPT_CHECK (27, LABEL_143_203);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_38]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_965;
  Wrd5 = Wrd9;

DEFLABEL (label_964)
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_143_20]), 2);

DEFLABEL (continuation_109)
  INTERRUPT_CHECK (27, LABEL_143_202);
  (Wrd9.Obj) = (current_block [OBJECT_143_16]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd11.Obj) = (Rsp [0]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd10.Obj) = ((Wrd12.pObj) [2]);
  (Rsp [0]) = (Wrd10.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (label_965)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_233])), (Wrd6.pObj));

DEFLABEL (label_453)
  (Wrd5.Obj) = Rvl;
  goto label_964;

DEFLABEL (lambda_584)
  CLOSURE_HEADER (LABEL_143_180);

DEFLABEL (lambda_80)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 7));
  (Wrd6.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_207);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_206])));
  Rhp += 4;
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd6.pObj)));
  Wrd17 = Wrd6;
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [2]);
  ((Wrd17.pObj) [2]) = (Wrd20.Obj);
  (Wrd16.Obj) = ((Wrd19.pObj) [3]);
  ((Wrd17.pObj) [3]) = (Wrd16.Obj);
  (Wrd12.Obj) = ((Wrd19.pObj) [4]);
  ((Wrd17.pObj) [4]) = (Wrd12.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  ((Wrd17.pObj) [5]) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd22.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_209);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_208])));
  Rhp += 3;
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd22.pObj)));
  Wrd27 = Wrd22;
  (Wrd28.Obj) = (Rsp [4]);
  ((Wrd27.pObj) [2]) = (Wrd28.Obj);
  (Wrd26.Obj) = (Rsp [2]);
  ((Wrd27.pObj) [3]) = (Wrd26.Obj);
  ((Wrd27.pObj) [4]) = (Wrd5.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd30.uLng) = (OBJECT_TYPE (Wrd26.Obj));
  if ((Wrd30.uLng) == 1)
    goto label_967;

DEFLABEL (label_966)
  (Wrd31.Obj) = (Rsp [0]);
  (Rsp [5]) = (Wrd31.Obj);
  Rsp = (& (Rsp [5]));
  goto lambda_67;

DEFLABEL (label_967)
  if (! ((Wrd30.uLng) == 1))
    goto label_971;
  (Wrd35.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd33.Obj) = ((Wrd35.pObj) [0]);

DEFLABEL (label_970)
  if (! ((Wrd33.Obj) == (current_block [OBJECT_143_7])))
    goto label_966;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd45.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_212);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_211])));
  Rhp += 1;
  (Wrd44.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd45.pObj)));
  Wrd46 = Wrd45;
  (Wrd47.Obj) = (Rsp [1]);
  ((Wrd46.pObj) [2]) = (Wrd47.Obj);
  (Rsp [4]) = (Wrd44.Obj);
  (Wrd48.Obj) = (Rsp [0]);
  (Rsp [5]) = (Wrd48.Obj);
  (Wrd52.Obj) = (Rsp [3]);
  (Wrd53.uLng) = (OBJECT_TYPE (Wrd52.Obj));
  if (! ((Wrd53.uLng) == 1))
    goto label_969;
  (Wrd51.pObj) = (OBJECT_ADDRESS (Wrd52.Obj));
  (Wrd49.Obj) = ((Wrd51.pObj) [1]);

DEFLABEL (label_968)
  (Rsp [3]) = (Wrd49.Obj);
  Rsp = (& (Rsp [3]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_182]));

DEFLABEL (label_969)
  (Wrd57.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_213]))));
  (* (--Rsp)) = (Wrd57.Obj);
  (* (--Rsp)) = (Wrd52.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_143_19]), 1);

DEFLABEL (label_449)
  (Wrd49.Obj) = Rvl;
  goto label_968;

DEFLABEL (label_971)
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_210]))));
  (* (--Rsp)) = (Wrd41.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_143_18]), 1);

DEFLABEL (label_448)
  (Wrd33.Obj) = Rvl;
  goto label_970;

DEFLABEL (lambda_585)
  CLOSURE_HEADER (LABEL_143_184);

DEFLABEL (lambda_84)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (lambda_586)
DEFLABEL (lambda_18)
  INTERRUPT_CHECK (26, LABEL_143_186);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_214]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_215]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_216]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_217]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd20.Obj) = (Rsp [4]);
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd22.Obj) = ((Wrd21.pObj) [3]);
  (Wrd25.Obj) = ((Wrd21.pObj) [4]);
  (* (Rhp++)) = (Wrd22.Obj);
  (* (Rhp++)) = (Wrd25.Obj);
  (Wrd18.pObj) = (& (Rhp [-2]));
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd18.pObj)));
  (* (--Rsp)) = (Wrd19.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_137]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_143_217);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_38]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_975;
  Wrd5 = Wrd9;

DEFLABEL (label_974)
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_143_20]), 2);

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_143_216);
  (Wrd9.Obj) = (current_block [OBJECT_143_16]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (Wrd13.Obj) = (Rsp [2]);
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [5]);
  (* (Rhp++)) = (Wrd6.Obj);
  (* (Rhp++)) = (Wrd15.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  (Wrd21.Obj) = ((Wrd14.pObj) [6]);
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd21.Obj);
  (Wrd18.pObj) = (& (Rhp [-2]));
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd18.pObj)));
  (Wrd25.Obj) = (Rsp [4]);
  (* (Rhp++)) = (Wrd16.Obj);
  (* (Rhp++)) = (Wrd25.Obj);
  (Wrd23.pObj) = (& (Rhp [-2]));
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd23.pObj)));
  (* (--Rsp)) = (Wrd24.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_137]));

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_143_215);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_39]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_973;
  Wrd5 = Wrd9;

DEFLABEL (label_972)
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_143_20]), 2);

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_143_214);
  (Wrd9.Obj) = (current_block [OBJECT_143_16]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd11.Obj) = (Rsp [0]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd10.Obj) = ((Wrd12.pObj) [2]);
  (Rsp [0]) = (Wrd10.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (label_973)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_241])), (Wrd6.pObj));

DEFLABEL (label_454)
  (Wrd5.Obj) = Rvl;
  goto label_972;

DEFLABEL (label_975)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_242])), (Wrd6.pObj));

DEFLABEL (label_455)
  (Wrd5.Obj) = Rvl;
  goto label_974;

DEFLABEL (lambda_587)
  CLOSURE_HEADER (LABEL_143_188);

DEFLABEL (lambda_21)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_219);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_218])));
  Rhp += 2;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd10 = Wrd7;
  (Wrd11.Obj) = (Rsp [0]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [2]);
  ((Wrd10.pObj) [2]) = (Wrd13.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  ((Wrd10.pObj) [3]) = (Wrd9.Obj);
  (Rsp [2]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_220]));

DEFLABEL (lambda_588)
  CLOSURE_HEADER (LABEL_143_190);

DEFLABEL (lambda_25)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (current_block [OBJECT_143_23]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd8.Obj) = ((Wrd7.pObj) [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = ((Wrd7.pObj) [5]);
  (* (--Rsp)) = (Wrd11.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd14.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_222);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_221])));
  Rhp += 3;
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd14.pObj)));
  Wrd23 = Wrd14;
  (Wrd26.Obj) = ((Wrd7.pObj) [2]);
  ((Wrd23.pObj) [2]) = (Wrd26.Obj);
  ((Wrd23.pObj) [3]) = (Wrd8.Obj);
  (Wrd18.Obj) = ((Wrd7.pObj) [4]);
  ((Wrd23.pObj) [4]) = (Wrd18.Obj);
  (Rsp [3]) = (Wrd13.Obj);
  goto lambda_21;

DEFLABEL (loop_0_590)
DEFLABEL (loop_0_145)
  INTERRUPT_CHECK (26, LABEL_143_198);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 7));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_229);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_228])));
  Rhp += 4;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd14 = Wrd7;
  (Wrd15.Obj) = (Rsp [0]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [2]);
  ((Wrd14.pObj) [2]) = (Wrd17.Obj);
  (Wrd13.Obj) = (Rsp [3]);
  ((Wrd14.pObj) [3]) = (Wrd13.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  ((Wrd14.pObj) [4]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [1]);
  ((Wrd14.pObj) [5]) = (Wrd9.Obj);
  (Rsp [3]) = (Wrd6.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd20.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_231);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_230])));
  Rhp += 2;
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd20.pObj)));
  Wrd23 = Wrd20;
  ((Wrd23.pObj) [2]) = (Wrd15.Obj);
  ((Wrd23.pObj) [3]) = (Wrd11.Obj);
  (Rsp [2]) = (Wrd19.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_232]));

DEFLABEL (lambda_591)
DEFLABEL (lambda_64)
  INTERRUPT_CHECK (26, LABEL_143_206);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_235]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_236]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd14.Obj) = (Rsp [2]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [3]);
  (Wrd19.Obj) = ((Wrd15.pObj) [4]);
  (* (Rhp++)) = (Wrd16.Obj);
  (* (Rhp++)) = (Wrd19.Obj);
  (Wrd13.pObj) = (& (Rhp [-2]));
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd13.pObj)));
  (Wrd25.Obj) = ((Wrd15.pObj) [5]);
  (* (Rhp++)) = (Wrd11.Obj);
  (* (Rhp++)) = (Wrd25.Obj);
  (Wrd22.pObj) = (& (Rhp [-2]));
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd22.pObj)));
  (Wrd29.Obj) = (Rsp [4]);
  (* (Rhp++)) = (Wrd20.Obj);
  (* (Rhp++)) = (Wrd29.Obj);
  (Wrd27.pObj) = (& (Rhp [-2]));
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd27.pObj)));
  (* (--Rsp)) = (Wrd28.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_137]));

DEFLABEL (continuation_61)
  INTERRUPT_CHECK (27, LABEL_143_236);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_39]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_977;
  Wrd5 = Wrd9;

DEFLABEL (label_976)
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_143_20]), 2);

DEFLABEL (continuation_62)
  INTERRUPT_CHECK (27, LABEL_143_235);
  (Wrd9.Obj) = (current_block [OBJECT_143_16]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd11.Obj) = (Rsp [0]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd10.Obj) = ((Wrd12.pObj) [2]);
  (Rsp [0]) = (Wrd10.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (label_977)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_257])), (Wrd6.pObj));

DEFLABEL (label_459)
  (Wrd5.Obj) = Rvl;
  goto label_976;

DEFLABEL (lambda_592)
  CLOSURE_HEADER (LABEL_143_208);

DEFLABEL (lambda_67)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd8.Obj) = (current_block [OBJECT_143_16]);
  (* (Rhp++)) = (Wrd8.Obj);
  (* (Rhp++)) = ((SCHEME_OBJECT) 0);
  (Wrd6.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd6.pObj)));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd15.Obj) = ((Wrd11.pObj) [4]);
  (* (--Rsp)) = (Wrd15.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd18.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_238);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_237])));
  Rhp += 1;
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd18.pObj)));
  Wrd19 = Wrd18;
  (Wrd22.Obj) = ((Wrd11.pObj) [2]);
  ((Wrd19.pObj) [2]) = (Wrd22.Obj);
  (Rsp [3]) = (Wrd17.Obj);
  goto lambda_64;

DEFLABEL (lambda_593)
  CLOSURE_HEADER (LABEL_143_211);

DEFLABEL (lambda_77)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_239]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_240]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_137]));

DEFLABEL (continuation_73)
  INTERRUPT_CHECK (27, LABEL_143_240);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_260]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_8]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_980;
  Wrd8 = Wrd12;

DEFLABEL (label_979)
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_262]));

DEFLABEL (continuation_72)
  INTERRUPT_CHECK (27, LABEL_143_260);
  (* (--Rsp)) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_143_20]), 2);

DEFLABEL (continuation_74)
  INTERRUPT_CHECK (27, LABEL_143_239);
  (* (--Rsp)) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_978;
  Rsp = (& (Rsp [4]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (label_978)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_258]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_259]));

DEFLABEL (continuation_75)
  INTERRUPT_CHECK (27, LABEL_143_258);
  (Rsp [3]) = Rvl;
  (Wrd7.Obj) = (Rsp [1]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd6.Obj) = ((Wrd8.pObj) [2]);
  (Rsp [1]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  goto lambda_64;

DEFLABEL (label_980)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_261])), (Wrd9.pObj));

DEFLABEL (label_460)
  (Wrd8.Obj) = Rvl;
  goto label_979;

DEFLABEL (lambda_594)
  CLOSURE_HEADER (LABEL_143_218);

DEFLABEL (lambda_20)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [3]);
  (Wrd11.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (Rsp [2]) = (Wrd5.Obj);
  (Wrd12.Obj) = ((Wrd9.pObj) [2]);
  (Rsp [0]) = (Wrd12.Obj);
  goto lambda_18;

DEFLABEL (lambda_595)
  CLOSURE_HEADER (LABEL_143_221);

DEFLABEL (lambda_24)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd8.Obj) = (current_block [OBJECT_143_16]);
  (* (Rhp++)) = (Wrd8.Obj);
  (* (Rhp++)) = ((SCHEME_OBJECT) 0);
  (Wrd6.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd6.pObj)));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd15.Obj) = ((Wrd11.pObj) [4]);
  (* (--Rsp)) = (Wrd15.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd18.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_244);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_243])));
  Rhp += 1;
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd18.pObj)));
  Wrd19 = Wrd18;
  (Wrd22.Obj) = ((Wrd11.pObj) [2]);
  ((Wrd19.pObj) [2]) = (Wrd22.Obj);
  (Rsp [3]) = (Wrd17.Obj);
  goto lambda_18;

DEFLABEL (lambda_596)
  CLOSURE_HEADER (LABEL_143_228);

DEFLABEL (lambda_144)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_250]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_251]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [4]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_137]));

DEFLABEL (continuation_138)
  INTERRUPT_CHECK (27, LABEL_143_251);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_42]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_985;
  Wrd5 = Wrd9;

DEFLABEL (label_984)
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_143_20]), 2);

DEFLABEL (continuation_139)
  INTERRUPT_CHECK (27, LABEL_143_250);
  (Wrd9.Obj) = (current_block [OBJECT_143_16]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_268]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_269]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_137]));

DEFLABEL (continuation_141)
  INTERRUPT_CHECK (27, LABEL_143_269);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_31]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_983;
  Wrd5 = Wrd9;

DEFLABEL (label_982)
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_143_20]), 2);

DEFLABEL (continuation_142)
  INTERRUPT_CHECK (27, LABEL_143_268);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_981;
  (Wrd7.Obj) = (Rsp [1]);
  (Wrd8.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd9.Obj) = ((Wrd8.pObj) [5]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = ((Wrd8.pObj) [2]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = ((Wrd8.pObj) [3]);
  (Rsp [3]) = (Wrd13.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (label_981)
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd16.Obj) = ((Wrd18.pObj) [3]);
  (Rsp [1]) = (Wrd16.Obj);
  Rsp = (& (Rsp [1]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (label_983)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_280])), (Wrd6.pObj));

DEFLABEL (label_470)
  (Wrd5.Obj) = Rvl;
  goto label_982;

DEFLABEL (label_985)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_270])), (Wrd6.pObj));

DEFLABEL (label_464)
  (Wrd5.Obj) = Rvl;
  goto label_984;

DEFLABEL (lambda_597)
  CLOSURE_HEADER (LABEL_143_230);

DEFLABEL (lambda_137)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_253);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_252])));
  Rhp += 3;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd14 = Wrd7;
  (Wrd15.Obj) = (Rsp [0]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [2]);
  ((Wrd14.pObj) [2]) = (Wrd17.Obj);
  (Wrd13.Obj) = ((Wrd16.pObj) [3]);
  ((Wrd14.pObj) [3]) = (Wrd13.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  ((Wrd14.pObj) [4]) = (Wrd9.Obj);
  (Rsp [2]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_254]));

DEFLABEL (lambda_601)
DEFLABEL (lambda_102)
  INTERRUPT_CHECK (26, LABEL_143_234);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_255]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_256]));

DEFLABEL (continuation_101)
  INTERRUPT_CHECK (27, LABEL_143_255);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_986;
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_986)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_271]));

DEFLABEL (lambda_598)
  CLOSURE_HEADER (LABEL_143_237);

DEFLABEL (lambda_66)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (lambda_599)
  CLOSURE_HEADER (LABEL_143_243);

DEFLABEL (lambda_23)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (lambda_600)
  CLOSURE_HEADER (LABEL_143_252);

DEFLABEL (lambda_136)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [4]);
  (Wrd11.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (Wrd17.Obj) = ((Wrd9.pObj) [3]);
  (* (Rhp++)) = (Wrd17.Obj);
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd14.pObj) = (& (Rhp [-2]));
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd14.pObj)));
  (Rsp [2]) = (Wrd12.Obj);
  (Wrd18.Obj) = ((Wrd9.pObj) [2]);
  (Rsp [0]) = (Wrd18.Obj);
  goto loop_0_145;

DEFLABEL (lambda_603)
DEFLABEL (lambda_210)
  INTERRUPT_CHECK (26, LABEL_143_296);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_309]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_310]));

DEFLABEL (continuation_208)
  INTERRUPT_CHECK (27, LABEL_143_309);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_987;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_987)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_323]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_324]));

DEFLABEL (continuation_209)
  INTERRUPT_CHECK (27, LABEL_143_323);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_989;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_988;

DEFLABEL (label_989)
  Rvl = (current_block [OBJECT_143_36]);

DEFLABEL (label_988)
DEFLABEL (label_990)
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (lambda_604)
DEFLABEL (lambda_206)
  INTERRUPT_CHECK (26, LABEL_143_298);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_311]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_312]));

DEFLABEL (continuation_185)
  INTERRUPT_CHECK (27, LABEL_143_311);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_325]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_312]));

DEFLABEL (continuation_192)
  INTERRUPT_CHECK (27, LABEL_143_325);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_337);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_336])));
  Rhp += 3;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd12 = Wrd7;
  (Wrd13.Obj) = (Rsp [2]);
  ((Wrd12.pObj) [2]) = (Wrd13.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd12.pObj) [3]) = (Wrd11.Obj);
  ((Wrd12.pObj) [4]) = Rvl;
  (Rsp [1]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_338]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_339]));

DEFLABEL (continuation_200)
  INTERRUPT_CHECK (27, LABEL_143_338);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_991;
  (Wrd7.Obj) = (Rsp [1]);
  (Rsp [2]) = (Wrd7.Obj);
  (Rsp [1]) = Rvl;
  Rsp = (& (Rsp [1]));
  goto lambda_191;

DEFLABEL (label_991)
  (Wrd10.Obj) = (Rsp [1]);
  (Rsp [2]) = (Wrd10.Obj);
  Rsp = (& (Rsp [2]));
  goto lambda_199;

DEFLABEL (lambda_602)
  CLOSURE_HEADER (LABEL_143_302);

DEFLABEL (lambda_163)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 7));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_316);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_315])));
  Rhp += 4;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd14 = Wrd7;
  (Wrd15.Obj) = (Rsp [0]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [2]);
  ((Wrd14.pObj) [2]) = (Wrd17.Obj);
  (Wrd13.Obj) = (Rsp [3]);
  ((Wrd14.pObj) [3]) = (Wrd13.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  ((Wrd14.pObj) [4]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [1]);
  ((Wrd14.pObj) [5]) = (Wrd9.Obj);
  (Rsp [3]) = (Wrd6.Obj);
  (Wrd18.Obj) = ((Wrd16.pObj) [3]);
  (Rsp [0]) = (Wrd18.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (lambda_606)
DEFLABEL (lambda_180)
  INTERRUPT_CHECK (26, LABEL_143_314);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_327);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_326])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [1]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_328]));

DEFLABEL (lambda_605)
  CLOSURE_HEADER (LABEL_143_315);

DEFLABEL (lambda_162)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [4]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = ((Wrd6.pObj) [5]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = ((Wrd6.pObj) [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = ((Wrd6.pObj) [3]);
  (Rsp [3]) = (Wrd14.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (lambda_608)
DEFLABEL (lambda_218)
  INTERRUPT_CHECK (26, LABEL_143_322);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_335);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_334])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [1]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_107]));

DEFLABEL (lambda_607)
  CLOSURE_HEADER (LABEL_143_326);

DEFLABEL (lambda_179)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_341);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_340])));
  Rhp += 2;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd10 = Wrd7;
  (Wrd11.Obj) = (Rsp [0]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [2]);
  ((Wrd10.pObj) [2]) = (Wrd13.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  ((Wrd10.pObj) [3]) = (Wrd9.Obj);
  (Rsp [2]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_342]));

DEFLABEL (lambda_609)
  CLOSURE_HEADER (LABEL_143_334);

DEFLABEL (lambda_217)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_352);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_351])));
  Rhp += 2;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd10 = Wrd7;
  (Wrd11.Obj) = (Rsp [0]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [2]);
  ((Wrd10.pObj) [2]) = (Wrd13.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  ((Wrd10.pObj) [3]) = (Wrd9.Obj);
  (Rsp [2]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_177]));

DEFLABEL (lambda_610)
  CLOSURE_HEADER (LABEL_143_336);

DEFLABEL (lambda_199)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_353]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [4]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_354]));

DEFLABEL (continuation_193)
  INTERRUPT_CHECK (27, LABEL_143_353);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_368]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_369]));

DEFLABEL (continuation_194)
  INTERRUPT_CHECK (27, LABEL_143_368);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_992;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd9.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_385);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_384])));
  Rhp += 2;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd9.pObj)));
  Wrd14 = Wrd9;
  (Wrd15.Obj) = (Rsp [1]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [2]);
  ((Wrd14.pObj) [2]) = (Wrd17.Obj);
  (Wrd13.Obj) = ((Wrd16.pObj) [3]);
  ((Wrd14.pObj) [3]) = (Wrd13.Obj);
  (Rsp [1]) = (Wrd8.Obj);
  goto lambda_191;

DEFLABEL (label_992)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_383]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd21.Obj) = (Rsp [2]);
  (Wrd22.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd23.Obj) = ((Wrd22.pObj) [3]);
  (* (--Rsp)) = (Wrd23.Obj);
  (Wrd26.Obj) = ((Wrd22.pObj) [2]);
  (* (--Rsp)) = (Wrd26.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_354]));

DEFLABEL (continuation_195)
  INTERRUPT_CHECK (27, LABEL_143_383);
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (lambda_611)
  CLOSURE_HEADER (LABEL_143_340);

DEFLABEL (lambda_178)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_356);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_355])));
  Rhp += 3;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd14 = Wrd7;
  (Wrd15.Obj) = (Rsp [0]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [2]);
  ((Wrd14.pObj) [2]) = (Wrd17.Obj);
  (Wrd13.Obj) = ((Wrd16.pObj) [3]);
  ((Wrd14.pObj) [3]) = (Wrd13.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  ((Wrd14.pObj) [4]) = (Wrd9.Obj);
  (Rsp [2]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_357]));

DEFLABEL (lambda_612)
  CLOSURE_HEADER (LABEL_143_351);

DEFLABEL (lambda_216)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_366]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_367]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd14.Obj) = (Rsp [2]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [3]);
  (Wrd17.Obj) = (Rsp [4]);
  (* (Rhp++)) = (Wrd16.Obj);
  (* (Rhp++)) = (Wrd17.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_137]));

DEFLABEL (continuation_213)
  INTERRUPT_CHECK (27, LABEL_143_367);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_38]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_994;
  Wrd5 = Wrd9;

DEFLABEL (label_993)
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_143_20]), 2);

DEFLABEL (continuation_214)
  INTERRUPT_CHECK (27, LABEL_143_366);
  (Wrd9.Obj) = (current_block [OBJECT_143_16]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd11.Obj) = (Rsp [0]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd10.Obj) = ((Wrd12.pObj) [2]);
  (Rsp [0]) = (Wrd10.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (label_994)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_382])), (Wrd6.pObj));

DEFLABEL (label_500)
  (Wrd5.Obj) = Rvl;
  goto label_993;

DEFLABEL (lambda_614)
DEFLABEL (lambda_191)
  INTERRUPT_CHECK (26, LABEL_143_370);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_371]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd19.uLng) == 10))
    goto label_1000;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [0]);
  (Wrd17.Lng) = (FIXNUM_TO_LONG (Wrd16.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd17.Lng))))
    goto label_1000;
  (Wrd11.Obj) = ((Wrd15.pObj) [1]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_999)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_324]));

DEFLABEL (continuation_188)
  INTERRUPT_CHECK (27, LABEL_143_371);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_996;
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  goto label_995;

DEFLABEL (label_996)
  (Wrd15.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd15.Obj);

DEFLABEL (label_995)
DEFLABEL (label_998)
  (Wrd9.Obj) = (Rsp [0]);
  if ((Wrd9.Obj) == ((SCHEME_OBJECT) 0))
    goto label_997;
  Rvl = (Wrd9.Obj);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_997)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_1000)
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.Obj) = (current_block [OBJECT_143_38]);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_372]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_143_39]), 2);

DEFLABEL (label_496)
  (* (--Rsp)) = Rvl;
  goto label_999;

DEFLABEL (lambda_613)
  CLOSURE_HEADER (LABEL_143_355);

DEFLABEL (lambda_177)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_373]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_374]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd14.Obj) = (Rsp [2]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [3]);
  (Wrd19.Obj) = ((Wrd15.pObj) [4]);
  (* (Rhp++)) = (Wrd16.Obj);
  (* (Rhp++)) = (Wrd19.Obj);
  (Wrd13.pObj) = (& (Rhp [-2]));
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd13.pObj)));
  (Wrd23.Obj) = (Rsp [4]);
  (* (Rhp++)) = (Wrd11.Obj);
  (* (Rhp++)) = (Wrd23.Obj);
  (Wrd21.pObj) = (& (Rhp [-2]));
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd21.pObj)));
  (* (--Rsp)) = (Wrd22.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_137]));

DEFLABEL (continuation_174)
  INTERRUPT_CHECK (27, LABEL_143_374);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_38]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_1002;
  Wrd5 = Wrd9;

DEFLABEL (label_1001)
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_143_20]), 2);

DEFLABEL (continuation_175)
  INTERRUPT_CHECK (27, LABEL_143_373);
  (Wrd9.Obj) = (current_block [OBJECT_143_16]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd11.Obj) = (Rsp [0]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd10.Obj) = ((Wrd12.pObj) [2]);
  (Rsp [0]) = (Wrd10.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (label_1002)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_386])), (Wrd6.pObj));

DEFLABEL (label_501)
  (Wrd5.Obj) = Rvl;
  goto label_1001;

DEFLABEL (lambda_615)
  CLOSURE_HEADER (LABEL_143_380);

DEFLABEL (lambda_234)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_393);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_392])));
  Rhp += 3;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd12 = Wrd7;
  (Wrd13.Obj) = (Rsp [3]);
  ((Wrd12.pObj) [2]) = (Wrd13.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  ((Wrd12.pObj) [3]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [1]);
  ((Wrd12.pObj) [4]) = (Wrd9.Obj);
  (Rsp [3]) = (Wrd6.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd16.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_395);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_394])));
  Rhp += 2;
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd16.pObj)));
  Wrd19 = Wrd16;
  (Wrd20.Obj) = (Rsp [0]);
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd22.Obj) = ((Wrd21.pObj) [2]);
  ((Wrd19.pObj) [2]) = (Wrd22.Obj);
  ((Wrd19.pObj) [3]) = (Wrd11.Obj);
  (Rsp [2]) = (Wrd15.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_107]));

DEFLABEL (lambda_616)
  CLOSURE_HEADER (LABEL_143_384);

DEFLABEL (lambda_197)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_396]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_354]));

DEFLABEL (continuation_196)
  INTERRUPT_CHECK (27, LABEL_143_396);
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (lambda_617)
  CLOSURE_HEADER (LABEL_143_392);

DEFLABEL (lambda_233)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = ((Wrd6.pObj) [4]);
  (* (--Rsp)) = (Wrd10.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd13.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_406);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_405])));
  Rhp += 1;
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd13.pObj)));
  Wrd14 = Wrd13;
  (Wrd17.Obj) = ((Wrd6.pObj) [2]);
  ((Wrd14.pObj) [2]) = (Wrd17.Obj);
  (Rsp [2]) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_407]));

DEFLABEL (lambda_618)
  CLOSURE_HEADER (LABEL_143_394);

DEFLABEL (lambda_231)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_408]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_409]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_137]));

DEFLABEL (continuation_225)
  INTERRUPT_CHECK (27, LABEL_143_409);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [2]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [2]);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_143_20]), 2);

DEFLABEL (continuation_226)
  INTERRUPT_CHECK (27, LABEL_143_408);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_1003;
  Rsp = (& (Rsp [3]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (label_1003)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_417]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_418]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_137]));

DEFLABEL (continuation_228)
  INTERRUPT_CHECK (27, LABEL_143_418);
  (* (--Rsp)) = Rvl;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_428]))));
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_143_20]), 2);

DEFLABEL (continuation_229)
  INTERRUPT_CHECK (27, LABEL_143_417);
  (Wrd9.Obj) = (current_block [OBJECT_143_16]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd11.Obj) = (Rsp [0]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd10.Obj) = ((Wrd12.pObj) [3]);
  (Rsp [0]) = (Wrd10.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (lambda_619)
  CLOSURE_HEADER (LABEL_143_405);

DEFLABEL (lambda_232)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (lambda_620)
DEFLABEL (lambda_255)
  INTERRUPT_CHECK (26, LABEL_143_416);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_427]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_312]));

DEFLABEL (continuation_247)
  INTERRUPT_CHECK (27, LABEL_143_427);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_436]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_437]));

DEFLABEL (continuation_248)
  INTERRUPT_CHECK (27, LABEL_143_436);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_1004;
  Rvl = Rvl;
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_1004)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_445]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_354]));

DEFLABEL (continuation_249)
  INTERRUPT_CHECK (27, LABEL_143_445);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_455]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_456]));

DEFLABEL (continuation_250)
  INTERRUPT_CHECK (27, LABEL_143_455);
  (Rsp [0]) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_1005;
  Rvl = Rvl;
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_1005)
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_464]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_354]));

DEFLABEL (continuation_251)
  INTERRUPT_CHECK (27, LABEL_143_464);
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (lambda_621)
DEFLABEL (lambda_227)
  INTERRUPT_CHECK (26, LABEL_143_428);
  Rvl = (current_block [OBJECT_143_23]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (lambda_622)
DEFLABEL (lambda_264)
  INTERRUPT_CHECK (26, LABEL_143_434);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_443);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_442])));
  Rhp += 3;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd12 = Wrd7;
  (Wrd13.Obj) = (Rsp [2]);
  ((Wrd12.pObj) [2]) = (Wrd13.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd12.pObj) [3]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd12.pObj) [4]) = (Wrd9.Obj);
  (Rsp [2]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_444]));

DEFLABEL (lambda_624)
DEFLABEL (lambda_275)
  INTERRUPT_CHECK (26, LABEL_143_441);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_452);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_451])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [1]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_107]));

DEFLABEL (lambda_623)
  CLOSURE_HEADER (LABEL_143_442);

DEFLABEL (lambda_263)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [3]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = ((Wrd6.pObj) [4]);
  (* (--Rsp)) = (Wrd10.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd13.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_454);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_453])));
  Rhp += 1;
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd13.pObj)));
  Wrd14 = Wrd13;
  (Wrd17.Obj) = ((Wrd6.pObj) [2]);
  ((Wrd14.pObj) [2]) = (Wrd17.Obj);
  (Rsp [2]) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_407]));

DEFLABEL (lambda_625)
  CLOSURE_HEADER (LABEL_143_451);

DEFLABEL (lambda_274)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_462]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_463]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_137]));

DEFLABEL (continuation_272)
  INTERRUPT_CHECK (27, LABEL_143_463);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_64]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_1008;
  Wrd5 = Wrd9;

DEFLABEL (label_1007)
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_143_20]), 2);

DEFLABEL (continuation_273)
  INTERRUPT_CHECK (27, LABEL_143_462);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_1006;
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [2]);
  (Rsp [0]) = (Wrd7.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (label_1006)
  Rsp = (& (Rsp [3]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (label_1008)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_471])), (Wrd6.pObj));

DEFLABEL (label_527)
  (Wrd5.Obj) = Rvl;
  goto label_1007;

DEFLABEL (lambda_626)
  CLOSURE_HEADER (LABEL_143_453);

DEFLABEL (lambda_262)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (lambda_627)
DEFLABEL (lambda_291)
  INTERRUPT_CHECK (26, LABEL_143_459);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_469]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_310]));

DEFLABEL (continuation_289)
  INTERRUPT_CHECK (27, LABEL_143_469);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_1009;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_1009)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_486]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_324]));

DEFLABEL (continuation_290)
  INTERRUPT_CHECK (27, LABEL_143_486);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_1011;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_1010;

DEFLABEL (label_1011)
  Rvl = (current_block [OBJECT_143_36]);

DEFLABEL (label_1010)
DEFLABEL (label_1012)
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (lambda_628)
DEFLABEL (lambda_287)
  INTERRUPT_CHECK (26, LABEL_143_461);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_470]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_312]));

DEFLABEL (continuation_279)
  INTERRUPT_CHECK (27, LABEL_143_470);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_487]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_339]));

DEFLABEL (continuation_280)
  INTERRUPT_CHECK (27, LABEL_143_487);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_1013;
  Rvl = Rvl;
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_1013)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_506]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_354]));

DEFLABEL (continuation_281)
  INTERRUPT_CHECK (27, LABEL_143_506);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_521]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_369]));

DEFLABEL (continuation_282)
  INTERRUPT_CHECK (27, LABEL_143_521);
  (Rsp [0]) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_1014;
  Rvl = Rvl;
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_1014)
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_533]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_354]));

DEFLABEL (continuation_283)
  INTERRUPT_CHECK (27, LABEL_143_533);
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (lambda_629)
DEFLABEL (lambda_304)
  INTERRUPT_CHECK (26, LABEL_143_466);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_479]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_480]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_481]));

DEFLABEL (continuation_302)
  INTERRUPT_CHECK (27, LABEL_143_480);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_499]));

DEFLABEL (continuation_303)
  INTERRUPT_CHECK (27, LABEL_143_479);
  (Rsp [0]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_116]));

DEFLABEL (lambda_630)
DEFLABEL (lambda_301)
  INTERRUPT_CHECK (26, LABEL_143_467);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_482]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_483]));

DEFLABEL (continuation_299)
  INTERRUPT_CHECK (27, LABEL_143_482);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_1015;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_1015)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_500]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_501]));

DEFLABEL (continuation_300)
  INTERRUPT_CHECK (27, LABEL_143_500);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_143_53]);
  (Rsp [1]) = (Wrd5.Obj);
  (Wrd8.uLng) = (OBJECT_TYPE (Rvl));
  if ((Wrd8.uLng) == 26)
    goto label_1016;
  INVOKE_INTERFACE_0 (36);

DEFLABEL (label_1016)
  if (Rvl == (Wrd5.Obj))
    goto label_1018;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_1017;

DEFLABEL (label_1018)
  Rvl = (current_block [OBJECT_143_36]);

DEFLABEL (label_1017)
DEFLABEL (label_1019)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (lambda_631)
DEFLABEL (lambda_298)
  INTERRUPT_CHECK (26, LABEL_143_468);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_484]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_485]));

DEFLABEL (continuation_293)
  INTERRUPT_CHECK (27, LABEL_143_484);
  (* (--Rsp)) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_1021;

DEFLABEL (label_1020)
  Rsp = (& (Rsp [3]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (label_1021)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_502]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_501]));

DEFLABEL (continuation_294)
  INTERRUPT_CHECK (27, LABEL_143_502);
  (Wrd13.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd13.uLng) == 26))
    goto label_1023;
  if (! (Rvl == (current_block [OBJECT_143_53])))
    goto label_1020;

DEFLABEL (label_1022)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_504]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd18.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd18.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_505]));

DEFLABEL (continuation_296)
  INTERRUPT_CHECK (27, LABEL_143_504);
  (Rsp [3]) = Rvl;
  Rsp = (& (Rsp [2]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (label_1023)
  (Wrd20.Obj) = (current_block [OBJECT_143_53]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_503]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = Rvl;
  INVOKE_INTERFACE_0 (36);

DEFLABEL (label_543)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_1020;
  goto label_1022;

DEFLABEL (lambda_632)
DEFLABEL (lambda_375)
  INTERRUPT_CHECK (26, LABEL_143_509);
  (Wrd5.Obj) = (current_block [OBJECT_143_54]);
  (Rsp [0]) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_116]));

DEFLABEL (lambda_633)
DEFLABEL (lambda_337)
  INTERRUPT_CHECK (26, LABEL_143_516);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_531);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_530])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [1]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_328]));

DEFLABEL (lambda_635)
DEFLABEL (lambda_352)
  INTERRUPT_CHECK (26, LABEL_143_529);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_537);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_536])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [1]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_538]));

DEFLABEL (lambda_634)
  CLOSURE_HEADER (LABEL_143_530);

DEFLABEL (lambda_336)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_1025;

DEFLABEL (label_1024)
  Rsp = (& (Rsp [3]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (label_1025)
  if (! ((Wrd6.uLng) == 1))
    goto label_1029;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd8.Obj) = ((Wrd10.pObj) [0]);

DEFLABEL (label_1028)
  if (! ((Wrd8.Obj) == (current_block [OBJECT_143_7])))
    goto label_1024;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd19.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_541);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_540])));
  Rhp += 2;
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd19.pObj)));
  Wrd22 = Wrd19;
  (Wrd23.Obj) = (Rsp [0]);
  (Wrd24.pObj) = (OBJECT_ADDRESS (Wrd23.Obj));
  (Wrd25.Obj) = ((Wrd24.pObj) [2]);
  ((Wrd22.pObj) [2]) = (Wrd25.Obj);
  (Wrd21.Obj) = (Rsp [2]);
  ((Wrd22.pObj) [3]) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd28.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_543);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_542])));
  Rhp += 1;
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd28.pObj)));
  ((Wrd28.pObj) [2]) = (Wrd18.Obj);
  (Rsp [3]) = (Wrd27.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd33.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_545);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_544])));
  Rhp += 3;
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd33.pObj)));
  Wrd38 = Wrd33;
  (Wrd39.Obj) = (Rsp [4]);
  ((Wrd38.pObj) [2]) = (Wrd39.Obj);
  (Wrd37.Obj) = (Rsp [2]);
  ((Wrd38.pObj) [3]) = (Wrd37.Obj);
  ((Wrd38.pObj) [4]) = (Wrd18.Obj);
  (Rsp [4]) = (Wrd32.Obj);
  (Wrd44.uLng) = (OBJECT_TYPE (Wrd37.Obj));
  if (! ((Wrd44.uLng) == 1))
    goto label_1027;
  (Wrd42.pObj) = (OBJECT_ADDRESS (Wrd37.Obj));
  (Wrd40.Obj) = ((Wrd42.pObj) [1]);

DEFLABEL (label_1026)
  (Rsp [2]) = (Wrd40.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_119]));

DEFLABEL (label_1027)
  (Wrd48.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_546]))));
  (* (--Rsp)) = (Wrd48.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_143_19]), 1);

DEFLABEL (label_550)
  (Wrd40.Obj) = Rvl;
  goto label_1026;

DEFLABEL (label_1029)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_539]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_143_18]), 1);

DEFLABEL (label_549)
  (Wrd8.Obj) = Rvl;
  goto label_1028;

DEFLABEL (lambda_640)
DEFLABEL (lambda_372)
  INTERRUPT_CHECK (26, LABEL_143_535);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_547]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_312]));

DEFLABEL (continuation_357)
  INTERRUPT_CHECK (27, LABEL_143_547);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_560]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_437]));

DEFLABEL (continuation_358)
  INTERRUPT_CHECK (27, LABEL_143_560);
  (* (--Rsp)) = Rvl;
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_1030;
  Rvl = Rvl;
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_1030)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_569]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_354]));

DEFLABEL (continuation_359)
  INTERRUPT_CHECK (27, LABEL_143_569);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_576]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_67]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_1033;
  Wrd8 = Wrd12;

DEFLABEL (label_1032)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_578]));

DEFLABEL (continuation_360)
  INTERRUPT_CHECK (27, LABEL_143_576);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_1031;
  Rsp = (& (Rsp [2]));
  goto Z___ks4__368;

DEFLABEL (label_1031)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_580]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_354]));

DEFLABEL (continuation_361)
  INTERRUPT_CHECK (27, LABEL_143_580);
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [3]));
  goto pop_return;

DEFLABEL (label_1033)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_577])), (Wrd9.pObj));

DEFLABEL (label_556)
  (Wrd8.Obj) = Rvl;
  goto label_1032;

DEFLABEL (lambda_636)
  CLOSURE_HEADER (LABEL_143_536);

DEFLABEL (lambda_351)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_549);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_548])));
  Rhp += 2;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd10 = Wrd7;
  (Wrd11.Obj) = (Rsp [0]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [2]);
  ((Wrd10.pObj) [2]) = (Wrd13.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  ((Wrd10.pObj) [3]) = (Wrd9.Obj);
  (Rsp [2]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_550]));

DEFLABEL (lambda_637)
  CLOSURE_HEADER (LABEL_143_540);

DEFLABEL (lambda_320)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_552);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_551])));
  Rhp += 3;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd14 = Wrd7;
  (Wrd15.Obj) = (Rsp [0]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [2]);
  ((Wrd14.pObj) [2]) = (Wrd17.Obj);
  (Wrd13.Obj) = ((Wrd16.pObj) [3]);
  ((Wrd14.pObj) [3]) = (Wrd13.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  ((Wrd14.pObj) [4]) = (Wrd9.Obj);
  (Rsp [2]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_124]));

DEFLABEL (lambda_638)
  CLOSURE_HEADER (LABEL_143_542);

DEFLABEL (lambda_331)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [1]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if ((Wrd6.uLng) == 1)
    goto label_1035;

DEFLABEL (label_1034)
  Rsp = (& (Rsp [3]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (label_1035)
  if (! ((Wrd6.uLng) == 1))
    goto label_1039;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd8.Obj) = ((Wrd10.pObj) [0]);

DEFLABEL (label_1038)
  if (! ((Wrd8.Obj) == (current_block [OBJECT_143_59])))
    goto label_1034;
  (Wrd21.Obj) = (Rsp [1]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if (! ((Wrd22.uLng) == 1))
    goto label_1037;
  (Wrd20.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd18.Obj) = ((Wrd20.pObj) [1]);

DEFLABEL (label_1036)
  (Rsp [1]) = (Wrd18.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd29.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_556);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_555])));
  Rhp += 2;
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd29.pObj)));
  Wrd32 = Wrd29;
  (Wrd33.Obj) = (Rsp [0]);
  (Wrd34.pObj) = (OBJECT_ADDRESS (Wrd33.Obj));
  (Wrd35.Obj) = ((Wrd34.pObj) [2]);
  ((Wrd32.pObj) [2]) = (Wrd35.Obj);
  (Wrd31.Obj) = (Rsp [2]);
  ((Wrd32.pObj) [3]) = (Wrd31.Obj);
  (Rsp [2]) = (Wrd28.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_119]));

DEFLABEL (label_1037)
  (Wrd26.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_554]))));
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_143_19]), 1);

DEFLABEL (label_552)
  (Wrd18.Obj) = Rvl;
  goto label_1036;

DEFLABEL (label_1039)
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_553]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_143_18]), 1);

DEFLABEL (label_551)
  (Wrd8.Obj) = Rvl;
  goto label_1038;

DEFLABEL (lambda_639)
  CLOSURE_HEADER (LABEL_143_544);

DEFLABEL (lambda_334)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [4]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd15.Obj) = ((Wrd6.pObj) [3]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 1))
    goto label_1041;
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [1]);
  (* (--Rsp)) = (Wrd12.Obj);

DEFLABEL (label_1040)
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd25.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_559);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_558])));
  Rhp += 1;
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd25.pObj)));
  Wrd26 = Wrd25;
  (Wrd27.Obj) = (Rsp [2]);
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd29.Obj) = ((Wrd28.pObj) [2]);
  ((Wrd26.pObj) [2]) = (Wrd29.Obj);
  (Rsp [2]) = (Wrd24.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_444]));

DEFLABEL (label_1041)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_557]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd15.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_143_19]), 1);

DEFLABEL (label_553)
  (* (--Rsp)) = Rvl;
  goto label_1040;

DEFLABEL (lambda_641)
  CLOSURE_HEADER (LABEL_143_548);

DEFLABEL (lambda_350)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_561]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_562]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd14.Obj) = (Rsp [2]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [3]);
  (Wrd17.Obj) = (Rsp [4]);
  (* (Rhp++)) = (Wrd16.Obj);
  (* (Rhp++)) = (Wrd17.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_137]));

DEFLABEL (continuation_347)
  INTERRUPT_CHECK (27, LABEL_143_562);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_38]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_1043;
  Wrd5 = Wrd9;

DEFLABEL (label_1042)
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_143_20]), 2);

DEFLABEL (continuation_348)
  INTERRUPT_CHECK (27, LABEL_143_561);
  (Wrd9.Obj) = (current_block [OBJECT_143_16]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd11.Obj) = (Rsp [0]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd10.Obj) = ((Wrd12.pObj) [2]);
  (Rsp [0]) = (Wrd10.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (label_1043)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_570])), (Wrd6.pObj));

DEFLABEL (label_554)
  (Wrd5.Obj) = Rvl;
  goto label_1042;

DEFLABEL (lambda_642)
  CLOSURE_HEADER (LABEL_143_551);

DEFLABEL (lambda_319)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 7));
  (Wrd6.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_564);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_563])));
  Rhp += 4;
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd6.pObj)));
  Wrd17 = Wrd6;
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd20.Obj) = ((Wrd19.pObj) [2]);
  ((Wrd17.pObj) [2]) = (Wrd20.Obj);
  (Wrd16.Obj) = ((Wrd19.pObj) [3]);
  ((Wrd17.pObj) [3]) = (Wrd16.Obj);
  (Wrd12.Obj) = ((Wrd19.pObj) [4]);
  ((Wrd17.pObj) [4]) = (Wrd12.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  ((Wrd17.pObj) [5]) = (Wrd8.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  (Rsp [3]) = (Wrd5.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd24.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_566);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_565])));
  Rhp += 3;
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd24.pObj)));
  Wrd29 = Wrd24;
  (Wrd30.Obj) = (Rsp [4]);
  ((Wrd29.pObj) [2]) = (Wrd30.Obj);
  (Wrd28.Obj) = (Rsp [2]);
  ((Wrd29.pObj) [3]) = (Wrd28.Obj);
  ((Wrd29.pObj) [4]) = (Wrd5.Obj);
  (Rsp [4]) = (Wrd23.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_119]));

DEFLABEL (lambda_643)
  CLOSURE_HEADER (LABEL_143_555);

DEFLABEL (lambda_330)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_567]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_568]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd14.Obj) = (Rsp [2]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [3]);
  (Wrd17.Obj) = (Rsp [4]);
  (* (Rhp++)) = (Wrd16.Obj);
  (* (Rhp++)) = (Wrd17.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_137]));

DEFLABEL (continuation_327)
  INTERRUPT_CHECK (27, LABEL_143_568);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_38]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_1045;
  Wrd5 = Wrd9;

DEFLABEL (label_1044)
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_143_20]), 2);

DEFLABEL (continuation_328)
  INTERRUPT_CHECK (27, LABEL_143_567);
  (Wrd9.Obj) = (current_block [OBJECT_143_16]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd11.Obj) = (Rsp [0]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd10.Obj) = ((Wrd12.pObj) [2]);
  (Rsp [0]) = (Wrd10.Obj);
  goto lambda_320;

DEFLABEL (label_1045)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_575])), (Wrd6.pObj));

DEFLABEL (label_555)
  (Wrd5.Obj) = Rvl;
  goto label_1044;

DEFLABEL (lambda_644)
  CLOSURE_HEADER (LABEL_143_558);

DEFLABEL (lambda_333)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (lambda_645)
  CLOSURE_HEADER (LABEL_143_563);

DEFLABEL (lambda_315)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_571]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_572]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd14.Obj) = (Rsp [2]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [3]);
  (Wrd19.Obj) = ((Wrd15.pObj) [4]);
  (* (Rhp++)) = (Wrd16.Obj);
  (* (Rhp++)) = (Wrd19.Obj);
  (Wrd13.pObj) = (& (Rhp [-2]));
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd13.pObj)));
  (Wrd25.Obj) = ((Wrd15.pObj) [5]);
  (* (Rhp++)) = (Wrd11.Obj);
  (* (Rhp++)) = (Wrd25.Obj);
  (Wrd22.pObj) = (& (Rhp [-2]));
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd22.pObj)));
  (Wrd29.Obj) = (Rsp [4]);
  (* (Rhp++)) = (Wrd20.Obj);
  (* (Rhp++)) = (Wrd29.Obj);
  (Wrd27.pObj) = (& (Rhp [-2]));
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd27.pObj)));
  (* (--Rsp)) = (Wrd28.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_137]));

DEFLABEL (continuation_312)
  INTERRUPT_CHECK (27, LABEL_143_572);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_39]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_1047;
  Wrd5 = Wrd9;

DEFLABEL (label_1046)
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_143_20]), 2);

DEFLABEL (continuation_313)
  INTERRUPT_CHECK (27, LABEL_143_571);
  (Wrd9.Obj) = (current_block [OBJECT_143_16]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd11.Obj) = (Rsp [0]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd10.Obj) = ((Wrd12.pObj) [2]);
  (Rsp [0]) = (Wrd10.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (label_1047)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_579])), (Wrd6.pObj));

DEFLABEL (label_557)
  (Wrd5.Obj) = Rvl;
  goto label_1046;

DEFLABEL (lambda_646)
  CLOSURE_HEADER (LABEL_143_565);

DEFLABEL (lambda_317)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [4]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = ((Wrd6.pObj) [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd13.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_143_574);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_143_573])));
  Rhp += 1;
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd13.pObj)));
  Wrd14 = Wrd13;
  (Wrd17.Obj) = ((Wrd6.pObj) [2]);
  ((Wrd14.pObj) [2]) = (Wrd17.Obj);
  (Rsp [2]) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_444]));

DEFLABEL (lambda_647)
  CLOSURE_HEADER (LABEL_143_573);

DEFLABEL (lambda_316)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (Z___ks4__648)
DEFLABEL (Z___ks4__368)
  INTERRUPT_CHECK (26, LABEL_143_581);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_582]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_312]));

DEFLABEL (continuation_363)
  INTERRUPT_CHECK (27, LABEL_143_582);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_583]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_143_67]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_1050;
  Wrd8 = Wrd12;

DEFLABEL (label_1049)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_578]));

DEFLABEL (continuation_364)
  INTERRUPT_CHECK (27, LABEL_143_583);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_1048;
  Rsp = (& (Rsp [1]));
  goto Z___ks4__368;

DEFLABEL (label_1048)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143_585]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_143_354]));

DEFLABEL (continuation_365)
  INTERRUPT_CHECK (27, LABEL_143_585);
  (Wrd11.Obj) = (MAKE_OBJECT (0, 1));
  (* (Rhp++)) = (Wrd11.Obj);
  (* (Rhp++)) = ((SCHEME_OBJECT) 0);
  (Wrd7.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (10, (Wrd7.pObj)));
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_1050)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_143_584])), (Wrd9.pObj));

DEFLABEL (label_558)
  (Wrd8.Obj) = Rvl;
  goto label_1049;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_144_4 3
#define LABEL_144_5 5
#define LABEL_144_7 7
#define LABEL_144_8 9
#define LABEL_144_10 11
#define TAG_144_11 4
#define LABEL_144_12 13
#define TAG_144_13 5
#define LABEL_144_14 15
#define TAG_144_15 6
#define LABEL_144_17 17
#define LABEL_144_18 19
#define LABEL_144_24 21
#define LABEL_144_20 23
#define TAG_144_21 10
#define ENVIRONMENT_LABEL_144_3 44
#define DEBUGGING_LABEL_144_2 43
#define OBJECT_144_3 42
#define OBJECT_144_2 41
#define OBJECT_144_1 40
#define OBJECT_144_0 39
#define EXECUTE_CACHE_144_23 25
#define EXECUTE_CACHE_144_22 27
#define EXECUTE_CACHE_144_19 29
#define EXECUTE_CACHE_144_16 31
#define EXECUTE_CACHE_144_9 33
#define EXECUTE_CACHE_144_6 35
#define FREE_REFERENCE_144_0 38
#define FREE_REFERENCES_LABEL_144_0 24
#define NUMBER_OF_LINKER_SECTIONS_144_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_144 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd18;
  machine_word Wrd5;
  machine_word Wrd23;
  machine_word Wrd19;
  machine_word Wrd20;
  machine_word Wrd13;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd6;
  machine_word Wrd10;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_144_4);
      goto parse_http_chunk_leader_18;

    case 1:
      current_block = (Rpc - LABEL_144_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_144_7);
      goto lambda_16;

    case 3:
      current_block = (Rpc - LABEL_144_8);
      goto lambda_3;

    case 4:
      current_block = (Rpc - LABEL_144_10);
      goto loop_0_14;

    case 5:
      current_block = (Rpc - LABEL_144_12);
      goto lambda_26;

    case 6:
      current_block = (Rpc - LABEL_144_14);
      goto lambda_27;

    case 7:
      current_block = (Rpc - LABEL_144_17);
      goto continuation_11;

    case 8:
      current_block = (Rpc - LABEL_144_18);
      goto continuation_10;

    case 9:
      current_block = (Rpc - LABEL_144_24);
      goto label_20;

    case 10:
      current_block = (Rpc - LABEL_144_20);
      goto lambda_28;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (parse_http_chunk_leader_22)
DEFLABEL (parse_http_chunk_leader_18)
  INTERRUPT_CHECK (26, LABEL_144_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_144_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_144_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_144_5);
  (Rsp [0]) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_144_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = Rvl;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_144_8]))));
  (Rsp [2]) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_144_9]));

DEFLABEL (lambda_23)
DEFLABEL (lambda_16)
  INTERRUPT_CHECK (26, LABEL_144_7);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd11.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_144_11);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_144_10])));
  Rhp += 1;
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd11.pObj)));
  (* (--Rsp)) = (Wrd12.Obj);
  Wrd9 = Wrd11;
  (Wrd10.Obj) = (Rsp [2]);
  ((Wrd9.pObj) [2]) = (Wrd10.Obj);
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd7.Obj) = (current_block [OBJECT_144_0]);
  (Rsp [2]) = (Wrd7.Obj);
  goto loop_0_14;

DEFLABEL (lambda_25)
DEFLABEL (lambda_3)
  INTERRUPT_CHECK (26, LABEL_144_8);
  Rvl = ((SCHEME_OBJECT) 0);
  goto pop_return;

DEFLABEL (loop_0_24)
DEFLABEL (loop_0_14)
  INTERRUPT_CHECK (26, LABEL_144_10);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 7));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_144_13);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_144_12])));
  Rhp += 4;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd14 = Wrd7;
  (Wrd15.Obj) = (Rsp [0]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [2]);
  ((Wrd14.pObj) [2]) = (Wrd17.Obj);
  (Wrd13.Obj) = (Rsp [3]);
  ((Wrd14.pObj) [3]) = (Wrd13.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  ((Wrd14.pObj) [4]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [1]);
  ((Wrd14.pObj) [5]) = (Wrd9.Obj);
  (Rsp [3]) = (Wrd6.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd20.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_144_15);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_144_14])));
  Rhp += 2;
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd20.pObj)));
  Wrd23 = Wrd20;
  ((Wrd23.pObj) [2]) = (Wrd15.Obj);
  ((Wrd23.pObj) [3]) = (Wrd11.Obj);
  (Rsp [2]) = (Wrd19.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_144_16]));

DEFLABEL (lambda_26)
  CLOSURE_HEADER (LABEL_144_12);

DEFLABEL (lambda_13)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_144_17]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_144_18]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd14.Obj) = (Rsp [2]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [2]);
  (Wrd19.Obj) = ((Wrd15.pObj) [4]);
  (* (Rhp++)) = (Wrd16.Obj);
  (* (Rhp++)) = (Wrd19.Obj);
  (Wrd12.pObj) = (& (Rhp [-2]));
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd12.pObj)));
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_144_19]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_144_18);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_144_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_31;
  Wrd5 = Wrd9;

DEFLABEL (label_30)
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_144_3]), 2);

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_144_17);
  (Wrd9.Obj) = (current_block [OBJECT_144_1]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (Wrd11.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd12.Obj) = ((Wrd11.pObj) [5]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = ((Wrd11.pObj) [3]);
  (Rsp [2]) = (Wrd13.Obj);
  if ((Wrd12.Obj) == (current_block [OBJECT_144_0]))
    goto label_29;
  Rsp = (& (Rsp [2]));
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (label_29)
  (Wrd19.Obj) = (current_block [OBJECT_144_2]);
  (Rsp [2]) = (Wrd19.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_144_23]));

DEFLABEL (label_31)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_144_24])), (Wrd6.pObj));

DEFLABEL (label_20)
  (Wrd5.Obj) = Rvl;
  goto label_30;

DEFLABEL (lambda_27)
  CLOSURE_HEADER (LABEL_144_14);

DEFLABEL (lambda_8)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 6));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_144_21);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_144_20])));
  Rhp += 3;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd14 = Wrd7;
  (Wrd15.Obj) = (Rsp [0]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [2]);
  ((Wrd14.pObj) [2]) = (Wrd17.Obj);
  (Wrd13.Obj) = ((Wrd16.pObj) [3]);
  ((Wrd14.pObj) [3]) = (Wrd13.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  ((Wrd14.pObj) [4]) = (Wrd9.Obj);
  (Rsp [2]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_144_22]));

DEFLABEL (lambda_28)
  CLOSURE_HEADER (LABEL_144_20);

DEFLABEL (lambda_7)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [4]);
  (Wrd11.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (Wrd17.Obj) = ((Wrd9.pObj) [3]);
  (* (Rhp++)) = (Wrd17.Obj);
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd14.pObj) = (& (Rhp [-2]));
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd14.pObj)));
  (Rsp [2]) = (Wrd12.Obj);
  (Wrd18.Obj) = ((Wrd9.pObj) [2]);
  (Rsp [0]) = (Wrd18.Obj);
  goto loop_0_14;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_145_4 3
#define LABEL_145_5 5
#define LABEL_145_8 7
#define LABEL_145_6 9
#define LABEL_145_10 11
#define LABEL_145_11 13
#define LABEL_145_12 15
#define LABEL_145_14 17
#define LABEL_145_15 19
#define LABEL_145_13 21
#define LABEL_145_17 23
#define LABEL_145_18 25
#define ENVIRONMENT_LABEL_145_3 47
#define DEBUGGING_LABEL_145_2 46
#define OBJECT_145_8 45
#define OBJECT_145_7 44
#define OBJECT_145_6 43
#define OBJECT_145_5 42
#define OBJECT_145_4 41
#define OBJECT_145_3 40
#define OBJECT_145_2 39
#define OBJECT_145_1 38
#define OBJECT_145_0 37
#define EXECUTE_CACHE_145_16 27
#define EXECUTE_CACHE_145_9 29
#define EXECUTE_CACHE_145_7 31
#define FREE_REFERENCE_145_0 34
#define FREE_ASSIGNMENT_145_0 36
#define FREE_REFERENCES_LABEL_145_0 26
#define NUMBER_OF_LINKER_SECTIONS_145_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_145 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd14;
  machine_word Wrd12;
  machine_word Wrd39;
  machine_word Wrd36;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd27;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd65;
  machine_word Wrd70;
  machine_word Wrd69;
  machine_word Wrd66;
  machine_word Wrd64;
  machine_word Wrd61;
  machine_word Wrd60;
  machine_word Wrd49;
  machine_word Wrd48;
  machine_word Wrd47;
  machine_word Wrd44;
  machine_word Wrd57;
  machine_word Wrd56;
  machine_word Wrd55;
  machine_word Wrd53;
  machine_word Wrd51;
  machine_word Wrd50;
  machine_word Wrd59;
  machine_word Wrd58;
  machine_word Wrd41;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd26;
  machine_word Wrd22;
  machine_word Wrd24;
  machine_word Wrd25;
  machine_word Wrd18;
  machine_word Wrd20;
  machine_word Wrd21;
  machine_word Wrd17;
  machine_word Wrd13;
  machine_word Wrd74;
  machine_word Wrd72;
  machine_word Wrd6;
  machine_word Wrd5;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_145_4);
      goto lambda_17;

    case 1:
      current_block = (Rpc - LABEL_145_5);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_145_8);
      goto label_19;

    case 3:
      current_block = (Rpc - LABEL_145_6);
      goto continuation_0;

    case 4:
      current_block = (Rpc - LABEL_145_10);
      goto do_loop_11;

    case 5:
      current_block = (Rpc - LABEL_145_11);
      goto label_20;

    case 6:
      current_block = (Rpc - LABEL_145_12);
      goto label_21;

    case 7:
      current_block = (Rpc - LABEL_145_14);
      goto label_22;

    case 8:
      current_block = (Rpc - LABEL_145_15);
      goto label_23;

    case 9:
      current_block = (Rpc - LABEL_145_13);
      goto continuation_8;

    case 10:
      current_block = (Rpc - LABEL_145_17);
      goto label_25;

    case 11:
      current_block = (Rpc - LABEL_145_18);
      goto label_24;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_27)
DEFLABEL (lambda_17)
  INTERRUPT_CHECK (26, LABEL_145_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_145_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_145_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_145_0]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_145_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_145_6);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_145_9]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_145_5);
  (* (--Rsp)) = Rvl;
  (Wrd11.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd11.uLng) == 30))
    goto label_30;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd8.Obj) = ((Wrd7.pObj) [1]);
  (Wrd9.Obj) = (MAKE_OBJECT (26, (Wrd8.uLng)));
  (* (--Rsp)) = (Wrd9.Obj);

DEFLABEL (label_29)
  (Wrd16.Obj) = (current_block [OBJECT_145_2]);
  (* (--Rsp)) = (Wrd16.Obj);
  goto do_loop_11;

DEFLABEL (label_30)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_145_8]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_145_1]), 1);

DEFLABEL (label_19)
  (* (--Rsp)) = Rvl;
  goto label_29;

DEFLABEL (do_loop_28)
DEFLABEL (do_loop_11)
  INTERRUPT_CHECK (26, LABEL_145_10);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd6.uLng) == 26))
    goto label_45;
  (Wrd7.Obj) = (Rsp [1]);
  (Wrd8.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd8.uLng) == 26))
    goto label_45;
  (Wrd72.Lng) = (FIXNUM_TO_LONG (Wrd5.Obj));
  (Wrd74.Lng) = (FIXNUM_TO_LONG (Wrd7.Obj));
  if ((Wrd72.Lng) < (Wrd74.Lng))
    goto label_35;

DEFLABEL (label_34)
  Rsp = (& (Rsp [2]));
  (Wrd17.Obj) = (Rsp [0]);
  Rsp = (& (Rsp [1]));
  (Wrd21.Obj) = (current_block [OBJECT_145_3]);
  (* (Rhp++)) = (Wrd21.Obj);
  (* (Rhp++)) = (Wrd17.Obj);
  (Wrd20.pObj) = (& (Rhp [-2]));
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd20.pObj)));
  (Wrd25.Obj) = (current_block [OBJECT_145_4]);
  (* (Rhp++)) = (Wrd18.Obj);
  (* (Rhp++)) = (Wrd25.Obj);
  (Wrd24.pObj) = (& (Rhp [-2]));
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd24.pObj)));
  (Wrd26.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_145_0]));
  (Wrd34.Obj) = ((Wrd26.pObj) [0]);
  (Wrd35.uLng) = (OBJECT_TYPE (Wrd34.Obj));
  if ((Wrd35.uLng) == 50)
    goto label_33;

DEFLABEL (label_32)
  ((Wrd26.pObj) [0]) = (Wrd22.Obj);

DEFLABEL (label_31)
  Rvl = (current_block [OBJECT_145_5]);
  goto pop_return;

DEFLABEL (label_33)
  if ((Wrd34.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_32;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_145_12])), (Wrd26.pObj), (Wrd22.Obj));

DEFLABEL (label_21)
  goto label_31;

DEFLABEL (label_35)
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_145_13]))));
  (* (--Rsp)) = (Wrd41.Obj);
  (Wrd58.Obj) = (Rsp [3]);
  (Wrd59.uLng) = (OBJECT_TYPE (Wrd58.Obj));
  if (! ((Wrd59.uLng) == 30))
    goto label_44;
  (Wrd50.Obj) = (Rsp [1]);
  (Wrd51.uLng) = (OBJECT_TYPE (Wrd50.Obj));
  if (! ((Wrd51.uLng) == 26))
    goto label_44;
  (Wrd53.Lng) = (FIXNUM_TO_LONG (Wrd50.Obj));
  (Wrd55.pObj) = (OBJECT_ADDRESS (Wrd58.Obj));
  (Wrd56.Obj) = ((Wrd55.pObj) [1]);
  (Wrd57.Lng) = (FIXNUM_TO_LONG (Wrd56.Obj));
  if (! (((unsigned long) (Wrd53.Lng)) < ((unsigned long) (Wrd57.Lng))))
    goto label_44;
  (Wrd44.uLng) = (OBJECT_DATUM (Wrd50.Obj));
  (Wrd47.pChr) = (& ((Wrd55.pChr) [(Wrd44.Lng)]));
  (Wrd48.uLng) = ((unsigned long) (((unsigned char *) (Wrd47.pChr)) [(ADDRESS_UNITS_PER_OBJECT * 2)]));
  (Wrd49.Obj) = (MAKE_OBJECT (2, (Wrd48.uLng)));
  (* (--Rsp)) = (Wrd49.Obj);

DEFLABEL (label_43)
  (Wrd66.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_145_0]));
  (Wrd69.Obj) = ((Wrd66.pObj) [0]);
  (Wrd70.uLng) = (OBJECT_TYPE (Wrd69.Obj));
  if ((Wrd70.uLng) == 50)
    goto label_42;
  Wrd65 = Wrd69;

DEFLABEL (label_41)
  (* (--Rsp)) = (Wrd65.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_145_16]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_145_13);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_39;

DEFLABEL (label_38)
  (Wrd12.Obj) = (Rsp [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if (! ((Wrd13.uLng) == 26))
    goto label_37;
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd12.Obj));
  (Wrd14.Lng) = ((Wrd16.Lng) + 1L);
  if (! (LONG_TO_FIXNUM_P (Wrd14.Lng)))
    goto label_37;
  (Wrd11.Obj) = (LONG_TO_FIXNUM (Wrd14.Lng));

DEFLABEL (label_36)
  (Rsp [0]) = (Wrd11.Obj);
  goto do_loop_11;

DEFLABEL (label_37)
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_145_18]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_INTERFACE_0 (38);

DEFLABEL (label_24)
  (Wrd11.Obj) = Rvl;
  goto label_36;

DEFLABEL (label_39)
  (Wrd32.Obj) = (Rsp [2]);
  (Wrd33.uLng) = (OBJECT_TYPE (Wrd32.Obj));
  if (! ((Wrd33.uLng) == 30))
    goto label_40;
  (Wrd24.Obj) = (Rsp [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if (! ((Wrd25.uLng) == 26))
    goto label_40;
  (Wrd27.Lng) = (FIXNUM_TO_LONG (Wrd24.Obj));
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd32.Obj));
  (Wrd30.Obj) = ((Wrd29.pObj) [1]);
  (Wrd31.Lng) = (FIXNUM_TO_LONG (Wrd30.Obj));
  if (! (((unsigned long) (Wrd27.Lng)) < ((unsigned long) (Wrd31.Lng))))
    goto label_40;
  (Wrd18.uLng) = (OBJECT_DATUM (Wrd24.Obj));
  (Wrd21.pChr) = (& ((Wrd29.pChr) [(Wrd18.Lng)]));
  (Wrd22.Obj) = (current_block [OBJECT_145_7]);
  ((Wrd21.pChr) [(ADDRESS_UNITS_PER_OBJECT * 2)]) = ((char) (CHAR_TO_ASCII (Wrd22.Obj)));
  goto label_38;

DEFLABEL (label_40)
  (Wrd34.Obj) = (Rsp [2]);
  (Wrd35.Obj) = (Rsp [0]);
  (Wrd36.Obj) = (current_block [OBJECT_145_7]);
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_145_17]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  (* (--Rsp)) = (Wrd34.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_145_8]), 3);

DEFLABEL (label_25)
  goto label_38;

DEFLABEL (label_42)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_145_15])), (Wrd66.pObj));

DEFLABEL (label_23)
  (Wrd65.Obj) = Rvl;
  goto label_41;

DEFLABEL (label_44)
  (Wrd60.Obj) = (Rsp [3]);
  (Wrd61.Obj) = (Rsp [1]);
  (Wrd64.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_145_14]))));
  (* (--Rsp)) = (Wrd64.Obj);
  (* (--Rsp)) = (Wrd61.Obj);
  (* (--Rsp)) = (Wrd60.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_145_6]), 2);

DEFLABEL (label_22)
  (* (--Rsp)) = Rvl;
  goto label_43;

DEFLABEL (label_45)
  (Wrd9.Obj) = (Rsp [0]);
  (Wrd10.Obj) = (Rsp [1]);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_145_11]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = (Wrd9.Obj);
  INVOKE_INTERFACE_0 (39);

DEFLABEL (label_20)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_34;
  goto label_35;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_146_4 3
#define LABEL_146_5 5
#define LABEL_146_6 7
#define ENVIRONMENT_LABEL_146_3 15
#define DEBUGGING_LABEL_146_2 14
#define OBJECT_146_0 13
#define EXECUTE_CACHE_146_7 9
#define FREE_REFERENCE_146_0 12
#define FREE_REFERENCES_LABEL_146_0 8
#define NUMBER_OF_LINKER_SECTIONS_146_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_146 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd5;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd6;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_146_4);
      goto vector__values_1;

    case 1:
      current_block = (Rpc - LABEL_146_5);
      goto label_3;

    case 2:
      current_block = (Rpc - LABEL_146_6);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (vector__values_5)
DEFLABEL (vector__values_1)
  INTERRUPT_CHECK (26, LABEL_146_4);
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_146_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_7;
  Wrd5 = Wrd9;

DEFLABEL (label_6)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_146_6]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_146_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_146_6);
  (Rsp [1]) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_146_0]), 2);

DEFLABEL (label_7)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_146_5])), (Wrd6.pObj));

DEFLABEL (label_3)
  (Wrd5.Obj) = Rvl;
  goto label_6;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_147_4 3
#define LABEL_147_5 5
#define TAG_147_6 1
#define LABEL_147_7 7
#define LABEL_147_9 9
#define ENVIRONMENT_LABEL_147_3 17
#define DEBUGGING_LABEL_147_2 16
#define OBJECT_147_2 15
#define OBJECT_147_1 14
#define OBJECT_147_0 13
#define EXECUTE_CACHE_147_8 11
#define FREE_REFERENCES_LABEL_147_0 10
#define NUMBER_OF_LINKER_SECTIONS_147_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_147 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd26;
  machine_word Wrd28;
  machine_word Wrd23;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd18;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_147_4);
      goto Z__parser_transform_4;

    case 1:
      current_block = (Rpc - LABEL_147_5);
      goto lambda_9;

    case 2:
      current_block = (Rpc - LABEL_147_7);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_147_9);
      goto label_6;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (Z__parser_transform_8)
DEFLABEL (Z__parser_transform_4)
  INTERRUPT_CHECK (26, LABEL_147_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_147_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_147_5])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  Rvl = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (lambda_9)
  CLOSURE_HEADER (LABEL_147_5);

DEFLABEL (lambda_3)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_147_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_147_8]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_147_7);
  (Rsp [1]) = Rvl;
  Rsp = (& (Rsp [1]));
  (Wrd6.Obj) = (Rsp [0]);
  if ((Wrd6.Obj) == ((SCHEME_OBJECT) 0))
    goto label_13;
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd6.Obj));
  if (! ((Wrd18.uLng) == 10))
    goto label_12;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd16.Lng))))
    goto label_12;
  (Wrd8.Obj) = ((Wrd14.pObj) [1]);

DEFLABEL (label_11)
  (Wrd28.Obj) = (current_block [OBJECT_147_2]);
  (* (Rhp++)) = (Wrd8.Obj);
  (* (Rhp++)) = (Wrd28.Obj);
  (Wrd26.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd26.pObj)));

DEFLABEL (label_10)
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_12)
  (Wrd19.Obj) = (Rsp [0]);
  (Wrd20.Obj) = (current_block [OBJECT_147_0]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_147_9]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_147_1]), 2);

DEFLABEL (label_6)
  (Wrd8.Obj) = Rvl;
  goto label_11;

DEFLABEL (label_13)
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_10;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_148_4 3
#define LABEL_148_5 5
#define TAG_148_6 1
#define LABEL_148_8 7
#define LABEL_148_10 9
#define LABEL_148_11 11
#define ENVIRONMENT_LABEL_148_3 25
#define DEBUGGING_LABEL_148_2 24
#define OBJECT_148_0 23
#define EXECUTE_CACHE_148_14 13
#define EXECUTE_CACHE_148_13 15
#define EXECUTE_CACHE_148_12 17
#define EXECUTE_CACHE_148_9 19
#define EXECUTE_CACHE_148_7 21
#define FREE_REFERENCES_LABEL_148_0 12
#define NUMBER_OF_LINKER_SECTIONS_148_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_148 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_148_4);
      goto encode_base64_octets_5;

    case 1:
      current_block = (Rpc - LABEL_148_5);
      goto lambda_9;

    case 2:
      current_block = (Rpc - LABEL_148_8);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_148_10);
      goto continuation_2;

    case 4:
      current_block = (Rpc - LABEL_148_11);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (encode_base64_octets_8)
DEFLABEL (encode_base64_octets_5)
  INTERRUPT_CHECK (26, LABEL_148_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_148_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_148_5])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  (Rsp [0]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_148_7]));

DEFLABEL (lambda_9)
  CLOSURE_HEADER (LABEL_148_5);

DEFLABEL (lambda_4)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_148_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_148_9]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_148_8);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_148_10]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_148_11]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd11.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_148_12]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_148_11);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_148_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [4]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd8.Obj) = ((Wrd7.pObj) [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_148_14]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_148_10);
  (Wrd5.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd5.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_148_13]));

INVOKE_INTERFACE_TARGET_0
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_149_4 3
#define LABEL_149_5 5
#define TAG_149_6 1
#define LABEL_149_8 7
#define LABEL_149_9 9
#define TAG_149_10 3
#define LABEL_149_11 11
#define TAG_149_12 4
#define LABEL_149_14 13
#define TAG_149_15 5
#define LABEL_149_17 15
#define LABEL_149_19 17
#define LABEL_149_21 19
#define LABEL_149_24 21
#define LABEL_149_23 23
#define ENVIRONMENT_LABEL_149_3 48
#define DEBUGGING_LABEL_149_2 47
#define OBJECT_149_3 46
#define OBJECT_149_2 45
#define OBJECT_149_1 44
#define OBJECT_149_0 43
#define EXECUTE_CACHE_149_26 25
#define EXECUTE_CACHE_149_25 27
#define EXECUTE_CACHE_149_22 29
#define EXECUTE_CACHE_149_20 31
#define EXECUTE_CACHE_149_18 33
#define EXECUTE_CACHE_149_16 35
#define EXECUTE_CACHE_149_13 37
#define EXECUTE_CACHE_149_7 39
#define FREE_REFERENCE_149_0 42
#define FREE_REFERENCES_LABEL_149_0 24
#define NUMBER_OF_LINKER_SECTIONS_149_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
http_syntax_so_code_149 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd29;
  machine_word Wrd28;
  machine_word Wrd12;
  machine_word Wrd16;
  machine_word Wrd5;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd24;
  machine_word Wrd25;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd17;
  machine_word Wrd18;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd15;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd6;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_149_4);
      goto decode_base64_octets_11;

    case 1:
      current_block = (Rpc - LABEL_149_5);
      goto lambda_17;

    case 2:
      current_block = (Rpc - LABEL_149_8);
      goto label_13;

    case 3:
      current_block = (Rpc - LABEL_149_9);
      goto lambda_18;

    case 4:
      current_block = (Rpc - LABEL_149_11);
      goto lambda_19;

    case 5:
      current_block = (Rpc - LABEL_149_14);
      goto lambda_20;

    case 6:
      current_block = (Rpc - LABEL_149_17);
      goto continuation_2;

    case 7:
      current_block = (Rpc - LABEL_149_19);
      goto continuation_3;

    case 8:
      current_block = (Rpc - LABEL_149_21);
      goto continuation_4;

    case 9:
      current_block = (Rpc - LABEL_149_24);
      goto label_14;

    case 10:
      current_block = (Rpc - LABEL_149_23);
      goto continuation_6;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (decode_base64_octets_16)
DEFLABEL (decode_base64_octets_11)
  INTERRUPT_CHECK (26, LABEL_149_4);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_149_6);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_149_5])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [0]);
  ((Wrd8.pObj) [2]) = (Wrd9.Obj);
  (Rsp [0]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_149_7]));

DEFLABEL (lambda_17)
  CLOSURE_HEADER (LABEL_149_5);

DEFLABEL (lambda_10)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_149_0]));
  (Wrd10.Obj) = ((Wrd7.pObj) [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd11.uLng) == 50)
    goto label_22;
  Wrd6 = Wrd10;

DEFLABEL (label_21)
  (Wrd15.Obj) = (current_block [OBJECT_149_0]);
  (* (Rhp++)) = (Wrd6.Obj);
  (* (Rhp++)) = (Wrd15.Obj);
  (Wrd13.pObj) = (& (Rhp [-2]));
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd13.pObj)));
  (* (--Rsp)) = (Wrd14.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd18.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_149_10);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_149_9])));
  Rhp += 1;
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd18.pObj)));
  Wrd19 = Wrd18;
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd22.Obj) = ((Wrd21.pObj) [2]);
  ((Wrd19.pObj) [2]) = (Wrd22.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd25.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_149_12);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_149_11])));
  Rhp += 1;
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd25.pObj)));
  Wrd26 = Wrd25;
  (Wrd27.Obj) = (Rsp [2]);
  ((Wrd26.pObj) [2]) = (Wrd27.Obj);
  (Rsp [1]) = (Wrd24.Obj);
  (Rsp [2]) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_149_13]));

DEFLABEL (label_22)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_149_8])), (Wrd7.pObj));

DEFLABEL (label_13)
  (Wrd6.Obj) = Rvl;
  goto label_21;

DEFLABEL (lambda_18)
  CLOSURE_HEADER (LABEL_149_9);

DEFLABEL (lambda_9)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x202, 2);
  (* (Rhp++)) = (dispatch_base + TAG_149_15);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_149_14])));
  Rhp += 1;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd8 = Wrd7;
  (Wrd9.Obj) = (Rsp [0]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [2]);
  ((Wrd8.pObj) [2]) = (Wrd11.Obj);
  (Rsp [0]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_149_16]));

DEFLABEL (lambda_19)
  CLOSURE_HEADER (LABEL_149_11);

DEFLABEL (lambda_1)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  (Rsp [1]) = ((SCHEME_OBJECT) 0);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

DEFLABEL (lambda_20)
  CLOSURE_HEADER (LABEL_149_14);

DEFLABEL (lambda_8)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_149_17]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_149_1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_149_18]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_149_17);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_149_19]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_149_1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_149_20]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_149_19);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_149_21]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_149_22]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_149_21);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_149_23]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd15.Obj) = (Rsp [2]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [2]);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd18.uLng) == 30))
    goto label_24;
  (Wrd12.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd13.Obj) = ((Wrd12.pObj) [1]);
  (Wrd14.Obj) = (MAKE_OBJECT (26, (Wrd13.uLng)));
  (* (--Rsp)) = (Wrd14.Obj);

DEFLABEL (label_23)
  (Wrd25.Obj) = (current_block [OBJECT_149_3]);
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd26.Obj) = (Rsp [4]);
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd26.Obj));
  (Wrd28.Obj) = ((Wrd27.pObj) [2]);
  (* (--Rsp)) = (Wrd28.Obj);
  (Wrd29.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd29.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_149_25]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_149_23);
  (Wrd5.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd5.Obj);
  Rsp = (& (Rsp [2]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_149_26]));

DEFLABEL (label_24)
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_149_24]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_149_2]), 1);

DEFLABEL (label_14)
  (* (--Rsp)) = Rvl;
  goto label_23;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_4 3
#define LABEL_5 5
#define LABEL_6 7
#define LABEL_7 9
#define LABEL_8 11
#define LABEL_9 13
#define LABEL_10 15
#define LABEL_11 17
#define LABEL_12 19
#define LABEL_13 21
#define LABEL_14 23
#define LABEL_15 25
#define LABEL_16 27
#define LABEL_17 29
#define LABEL_18 31
#define LABEL_19 33
#define LABEL_20 35
#define LABEL_21 37
#define LABEL_22 39
#define LABEL_23 41
#define LABEL_24 43
#define LABEL_25 45
#define LABEL_26 47
#define LABEL_27 49
#define LABEL_28 51
#define LABEL_29 53
#define LABEL_30 55
#define LABEL_31 57
#define LABEL_32 59
#define LABEL_33 61
#define LABEL_35 63
#define LABEL_36 65
#define LABEL_37 67
#define LABEL_38 69
#define LABEL_39 71
#define LABEL_40 73
#define LABEL_41 75
#define LABEL_42 77
#define LABEL_43 79
#define LABEL_48 81
#define LABEL_44 83
#define LABEL_46 85
#define LABEL_52 87
#define LABEL_47 89
#define LABEL_50 91
#define LABEL_56 93
#define LABEL_51 95
#define LABEL_54 97
#define LABEL_60 99
#define LABEL_55 101
#define LABEL_58 103
#define LABEL_63 105
#define LABEL_59 107
#define LABEL_61 109
#define LABEL_62 111
#define LABEL_64 113
#define LABEL_65 115
#define LABEL_66 117
#define LABEL_67 119
#define LABEL_70 121
#define LABEL_69 123
#define LABEL_72 125
#define LABEL_73 127
#define LABEL_74 129
#define LABEL_75 131
#define LABEL_76 133
#define LABEL_77 135
#define LABEL_78 137
#define LABEL_79 139
#define LABEL_80 141
#define LABEL_81 143
#define LABEL_82 145
#define LABEL_83 147
#define LABEL_84 149
#define LABEL_85 151
#define LABEL_86 153
#define LABEL_87 155
#define LABEL_88 157
#define LABEL_89 159
#define LABEL_92 161
#define LABEL_93 163
#define LABEL_94 165
#define LABEL_90 167
#define LABEL_91 169
#define LABEL_96 171
#define LABEL_97 173
#define LABEL_98 175
#define LABEL_99 177
#define LABEL_100 179
#define LABEL_101 181
#define LABEL_106 183
#define LABEL_102 185
#define LABEL_108 187
#define LABEL_110 189
#define LABEL_103 191
#define LABEL_105 193
#define LABEL_109 195
#define LABEL_112 197
#define LABEL_119 199
#define LABEL_114 201
#define LABEL_115 203
#define LABEL_116 205
#define LABEL_124 207
#define LABEL_118 209
#define LABEL_121 211
#define LABEL_128 213
#define TAG_129 105
#define LABEL_132 215
#define LABEL_126 217
#define LABEL_130 219
#define LABEL_136 221
#define LABEL_131 223
#define LABEL_133 225
#define LABEL_141 227
#define LABEL_134 229
#define LABEL_144 231
#define LABEL_135 233
#define LABEL_138 235
#define TAG_139 116
#define LABEL_140 237
#define LABEL_142 239
#define LABEL_143 241
#define LABEL_146 243
#define LABEL_147 245
#define LABEL_148 247
#define LABEL_150 249
#define LABEL_152 251
#define LABEL_151 253
#define LABEL_153 255
#define LABEL_158 257
#define LABEL_154 259
#define LABEL_155 261
#define TAG_156 129
#define LABEL_157 263
#define LABEL_159 265
#define LABEL_160 267
#define LABEL_161 269
#define LABEL_162 271
#define LABEL_164 273
#define LABEL_166 275
#define LABEL_167 277
#define LABEL_170 279
#define LABEL_169 281
#define LABEL_174 283
#define LABEL_175 285
#define LABEL_171 287
#define LABEL_178 289
#define LABEL_172 291
#define LABEL_173 293
#define LABEL_177 295
#define LABEL_179 297
#define LABEL_180 299
#define LABEL_181 301
#define LABEL_183 303
#define LABEL_182 305
#define LABEL_188 307
#define LABEL_184 309
#define LABEL_191 311
#define LABEL_185 313
#define LABEL_195 315
#define LABEL_186 317
#define LABEL_187 319
#define LABEL_197 321
#define LABEL_190 323
#define LABEL_192 325
#define LABEL_193 327
#define LABEL_194 329
#define LABEL_200 331
#define LABEL_198 333
#define LABEL_199 335
#define LABEL_205 337
#define LABEL_202 339
#define LABEL_203 341
#define LABEL_210 343
#define LABEL_204 345
#define LABEL_208 347
#define LABEL_209 349
#define LABEL_212 351
#define LABEL_213 353
#define LABEL_214 355
#define LABEL_217 357
#define LABEL_215 359
#define LABEL_221 361
#define LABEL_216 363
#define LABEL_219 365
#define LABEL_220 367
#define LABEL_223 369
#define LABEL_224 371
#define LABEL_227 373
#define LABEL_225 375
#define LABEL_230 377
#define LABEL_226 379
#define LABEL_228 381
#define LABEL_229 383
#define LABEL_231 385
#define LABEL_232 387
#define LABEL_233 389
#define LABEL_236 391
#define LABEL_237 393
#define LABEL_234 395
#define LABEL_240 397
#define LABEL_241 399
#define LABEL_235 401
#define LABEL_238 403
#define LABEL_239 405
#define LABEL_242 407
#define LABEL_243 409
#define LABEL_244 411
#define LABEL_246 413
#define LABEL_247 415
#define LABEL_248 417
#define LABEL_249 419
#define LABEL_250 421
#define LABEL_251 423
#define LABEL_252 425
#define LABEL_253 427
#define LABEL_254 429
#define LABEL_255 431
#define LABEL_259 433
#define LABEL_256 435
#define LABEL_263 437
#define LABEL_257 439
#define LABEL_258 441
#define LABEL_264 443
#define LABEL_260 445
#define LABEL_261 447
#define LABEL_262 449
#define LABEL_266 451
#define LABEL_265 453
#define LABEL_269 455
#define LABEL_270 457
#define LABEL_267 459
#define LABEL_274 461
#define LABEL_275 463
#define LABEL_276 465
#define LABEL_268 467
#define LABEL_272 469
#define LABEL_273 471
#define LABEL_277 473
#define LABEL_280 475
#define LABEL_281 477
#define LABEL_278 479
#define LABEL_279 481
#define LABEL_282 483
#define LABEL_285 485
#define LABEL_286 487
#define LABEL_283 489
#define LABEL_289 491
#define LABEL_284 493
#define LABEL_287 495
#define LABEL_292 497
#define LABEL_288 499
#define LABEL_290 501
#define LABEL_296 503
#define LABEL_291 505
#define LABEL_293 507
#define LABEL_303 509
#define LABEL_294 511
#define LABEL_295 513
#define LABEL_304 515
#define LABEL_298 517
#define TAG_299 257
#define LABEL_300 519
#define LABEL_301 521
#define LABEL_302 523
#define LABEL_309 525
#define LABEL_310 527
#define LABEL_305 529
#define TAG_306 263
#define LABEL_308 531
#define LABEL_311 533
#define TAG_312 265
#define LABEL_313 535
#define LABEL_314 537
#define LABEL_315 539
#define LABEL_321 541
#define LABEL_316 543
#define LABEL_317 545
#define LABEL_318 547
#define LABEL_319 549
#define LABEL_320 551
#define LABEL_326 553
#define LABEL_322 555
#define LABEL_329 557
#define LABEL_323 559
#define LABEL_325 561
#define LABEL_327 563
#define LABEL_333 565
#define LABEL_334 567
#define LABEL_328 569
#define LABEL_330 571
#define LABEL_331 573
#define LABEL_332 575
#define LABEL_335 577
#define LABEL_336 579
#define LABEL_340 581
#define LABEL_337 583
#define LABEL_344 585
#define LABEL_338 587
#define LABEL_339 589
#define LABEL_345 591
#define LABEL_341 593
#define LABEL_342 595
#define LABEL_343 597
#define LABEL_347 599
#define LABEL_346 601
#define LABEL_351 603
#define LABEL_352 605
#define LABEL_348 607
#define LABEL_349 609
#define LABEL_350 611
#define LABEL_353 613
#define LABEL_354 615
#define LABEL_355 617
#define LABEL_356 619
#define LABEL_357 621
#define LABEL_358 623
#define LABEL_359 625
#define LABEL_360 627
#define LABEL_363 629
#define LABEL_361 631
#define LABEL_362 633
#define LABEL_364 635
#define LABEL_365 637
#define LABEL_368 639
#define LABEL_366 641
#define LABEL_367 643
#define LABEL_369 645
#define LABEL_370 647
#define LABEL_371 649
#define LABEL_372 651
#define LABEL_373 653
#define LABEL_375 655
#define LABEL_376 657
#define LABEL_377 659
#define LABEL_378 661
#define LABEL_379 663
#define LABEL_380 665
#define LABEL_381 667
#define LABEL_382 669
#define LABEL_383 671
#define LABEL_384 673
#define LABEL_385 675
#define LABEL_386 677
#define LABEL_387 679
#define LABEL_388 681
#define LABEL_389 683
#define LABEL_390 685
#define LABEL_391 687
#define LABEL_392 689
#define LABEL_393 691
#define LABEL_394 693
#define LABEL_395 695
#define LABEL_396 697
#define LABEL_397 699
#define LABEL_398 701
#define LABEL_399 703
#define LABEL_400 705
#define LABEL_401 707
#define LABEL_402 709
#define LABEL_407 711
#define LABEL_403 713
#define LABEL_405 715
#define LABEL_406 717
#define LABEL_409 719
#define LABEL_410 721
#define TAG_411 359
#define LABEL_412 723
#define LABEL_413 725
#define LABEL_414 727
#define LABEL_417 729
#define LABEL_415 731
#define LABEL_416 733
#define LABEL_418 735
#define LABEL_419 737
#define LABEL_420 739
#define LABEL_421 741
#define LABEL_422 743
#define LABEL_423 745
#define LABEL_424 747
#define LABEL_425 749
#define LABEL_426 751
#define LABEL_427 753
#define LABEL_428 755
#define LABEL_429 757
#define LABEL_430 759
#define LABEL_431 761
#define LABEL_432 763
#define ENVIRONMENT_LABEL_3 1250
#define DEBUGGING_LABEL_2 1249
#define PURIFICATION_ROOT 1248
#define OBJECT_366 1247
#define OBJECT_365 1246
#define OBJECT_364 1245
#define OBJECT_363 1244
#define OBJECT_362 1243
#define OBJECT_361 1242
#define OBJECT_360 1241
#define OBJECT_359 1240
#define OBJECT_358 1239
#define OBJECT_357 1238
#define OBJECT_356 1237
#define OBJECT_355 1236
#define OBJECT_354 1235
#define OBJECT_353 1234
#define OBJECT_352 1233
#define OBJECT_351 1232
#define OBJECT_350 1231
#define OBJECT_349 1230
#define OBJECT_348 1229
#define OBJECT_347 1228
#define OBJECT_346 1227
#define OBJECT_345 1226
#define OBJECT_344 1225
#define OBJECT_343 1224
#define OBJECT_342 1223
#define OBJECT_341 1222
#define OBJECT_340 1221
#define OBJECT_339 1220
#define OBJECT_338 1219
#define OBJECT_337 1218
#define OBJECT_336 1217
#define OBJECT_335 1216
#define OBJECT_334 1215
#define OBJECT_333 1214
#define OBJECT_332 1213
#define OBJECT_331 1212
#define OBJECT_330 1211
#define OBJECT_329 1210
#define OBJECT_328 1209
#define OBJECT_327 1208
#define OBJECT_326 1207
#define OBJECT_325 1206
#define OBJECT_324 1205
#define OBJECT_323 1204
#define OBJECT_322 1203
#define OBJECT_321 1202
#define OBJECT_320 1201
#define OBJECT_319 1200
#define OBJECT_318 1199
#define OBJECT_317 1198
#define OBJECT_316 1197
#define OBJECT_315 1196
#define OBJECT_314 1195
#define OBJECT_313 1194
#define OBJECT_312 1193
#define OBJECT_311 1192
#define OBJECT_310 1191
#define OBJECT_309 1190
#define OBJECT_308 1189
#define OBJECT_307 1188
#define OBJECT_306 1187
#define OBJECT_305 1186
#define OBJECT_304 1185
#define OBJECT_303 1184
#define OBJECT_302 1183
#define OBJECT_301 1182
#define OBJECT_300 1181
#define OBJECT_299 1180
#define OBJECT_298 1179
#define OBJECT_297 1178
#define OBJECT_296 1177
#define OBJECT_295 1176
#define OBJECT_294 1175
#define OBJECT_293 1174
#define OBJECT_292 1173
#define OBJECT_291 1172
#define OBJECT_290 1171
#define OBJECT_289 1170
#define OBJECT_288 1169
#define OBJECT_287 1168
#define OBJECT_286 1167
#define OBJECT_285 1166
#define OBJECT_284 1165
#define OBJECT_283 1164
#define OBJECT_282 1163
#define OBJECT_281 1162
#define OBJECT_280 1161
#define OBJECT_279 1160
#define OBJECT_278 1159
#define OBJECT_277 1158
#define OBJECT_276 1157
#define OBJECT_275 1156
#define OBJECT_274 1155
#define OBJECT_273 1154
#define OBJECT_272 1153
#define OBJECT_271 1152
#define OBJECT_270 1151
#define OBJECT_269 1150
#define OBJECT_268 1149
#define OBJECT_267 1148
#define OBJECT_266 1147
#define OBJECT_265 1146
#define OBJECT_264 1145
#define OBJECT_263 1144
#define OBJECT_262 1143
#define OBJECT_261 1142
#define OBJECT_260 1141
#define OBJECT_259 1140
#define OBJECT_258 1139
#define OBJECT_257 1138
#define OBJECT_256 1137
#define OBJECT_255 1136
#define OBJECT_254 1135
#define OBJECT_253 1134
#define OBJECT_252 1133
#define OBJECT_251 1132
#define OBJECT_250 1131
#define OBJECT_249 1130
#define OBJECT_248 1129
#define OBJECT_247 1128
#define OBJECT_246 1127
#define OBJECT_245 1126
#define OBJECT_244 1125
#define OBJECT_243 1124
#define OBJECT_242 1123
#define OBJECT_241 1122
#define OBJECT_240 1121
#define OBJECT_239 1120
#define OBJECT_238 1119
#define OBJECT_237 1118
#define OBJECT_236 1117
#define OBJECT_235 1116
#define OBJECT_234 1115
#define OBJECT_233 1114
#define OBJECT_232 1113
#define OBJECT_231 1112
#define OBJECT_230 1111
#define OBJECT_229 1110
#define OBJECT_228 1109
#define OBJECT_227 1108
#define OBJECT_226 1107
#define OBJECT_225 1106
#define OBJECT_224 1105
#define OBJECT_223 1104
#define OBJECT_222 1103
#define OBJECT_221 1102
#define OBJECT_220 1101
#define OBJECT_219 1100
#define OBJECT_218 1099
#define OBJECT_217 1098
#define OBJECT_216 1097
#define OBJECT_215 1096
#define OBJECT_214 1095
#define OBJECT_213 1094
#define OBJECT_212 1093
#define OBJECT_211 1092
#define OBJECT_210 1091
#define OBJECT_209 1090
#define OBJECT_208 1089
#define OBJECT_207 1088
#define OBJECT_206 1087
#define OBJECT_205 1086
#define OBJECT_204 1085
#define OBJECT_203 1084
#define OBJECT_202 1083
#define OBJECT_201 1082
#define OBJECT_200 1081
#define OBJECT_199 1080
#define OBJECT_198 1079
#define OBJECT_197 1078
#define OBJECT_196 1077
#define OBJECT_195 1076
#define OBJECT_194 1075
#define OBJECT_193 1074
#define OBJECT_192 1073
#define OBJECT_191 1072
#define OBJECT_190 1071
#define OBJECT_189 1070
#define OBJECT_188 1069
#define OBJECT_187 1068
#define OBJECT_186 1067
#define OBJECT_185 1066
#define OBJECT_184 1065
#define OBJECT_183 1064
#define OBJECT_182 1063
#define OBJECT_181 1062
#define OBJECT_180 1061
#define OBJECT_179 1060
#define OBJECT_178 1059
#define OBJECT_177 1058
#define OBJECT_176 1057
#define OBJECT_175 1056
#define OBJECT_174 1055
#define OBJECT_173 1054
#define OBJECT_172 1053
#define OBJECT_171 1052
#define OBJECT_170 1051
#define OBJECT_169 1050
#define OBJECT_168 1049
#define OBJECT_167 1048
#define OBJECT_166 1047
#define OBJECT_165 1046
#define OBJECT_164 1045
#define OBJECT_163 1044
#define OBJECT_162 1043
#define OBJECT_161 1042
#define OBJECT_160 1041
#define OBJECT_159 1040
#define OBJECT_158 1039
#define OBJECT_157 1038
#define OBJECT_156 1037
#define OBJECT_155 1036
#define OBJECT_154 1035
#define OBJECT_153 1034
#define OBJECT_152 1033
#define OBJECT_151 1032
#define OBJECT_150 1031
#define OBJECT_149 1030
#define OBJECT_148 1029
#define OBJECT_147 1028
#define OBJECT_146 1027
#define OBJECT_145 1026
#define OBJECT_144 1025
#define OBJECT_143 1024
#define OBJECT_142 1023
#define OBJECT_141 1022
#define OBJECT_140 1021
#define OBJECT_139 1020
#define OBJECT_138 1019
#define OBJECT_137 1018
#define OBJECT_136 1017
#define OBJECT_135 1016
#define OBJECT_134 1015
#define OBJECT_133 1014
#define OBJECT_132 1013
#define OBJECT_131 1012
#define OBJECT_130 1011
#define OBJECT_129 1010
#define OBJECT_128 1009
#define OBJECT_127 1008
#define OBJECT_126 1007
#define OBJECT_125 1006
#define OBJECT_124 1005
#define OBJECT_123 1004
#define OBJECT_122 1003
#define OBJECT_121 1002
#define OBJECT_120 1001
#define OBJECT_119 1000
#define OBJECT_118 999
#define OBJECT_117 998
#define OBJECT_116 997
#define OBJECT_115 996
#define OBJECT_114 995
#define OBJECT_113 994
#define OBJECT_112 993
#define OBJECT_111 992
#define OBJECT_110 991
#define OBJECT_109 990
#define OBJECT_108 989
#define OBJECT_107 988
#define OBJECT_106 987
#define OBJECT_105 986
#define OBJECT_104 985
#define OBJECT_103 984
#define OBJECT_102 983
#define OBJECT_101 982
#define OBJECT_100 981
#define OBJECT_99 980
#define OBJECT_98 979
#define OBJECT_97 978
#define OBJECT_96 977
#define OBJECT_95 976
#define OBJECT_94 975
#define OBJECT_93 974
#define OBJECT_92 973
#define OBJECT_91 972
#define OBJECT_90 971
#define OBJECT_89 970
#define OBJECT_88 969
#define OBJECT_87 968
#define OBJECT_86 967
#define OBJECT_85 966
#define OBJECT_84 965
#define OBJECT_83 964
#define OBJECT_82 963
#define OBJECT_81 962
#define OBJECT_80 961
#define OBJECT_79 960
#define OBJECT_78 959
#define OBJECT_77 958
#define OBJECT_76 957
#define OBJECT_75 956
#define OBJECT_74 955
#define OBJECT_73 954
#define OBJECT_72 953
#define OBJECT_71 952
#define OBJECT_70 951
#define OBJECT_69 950
#define OBJECT_68 949
#define OBJECT_67 948
#define OBJECT_66 947
#define OBJECT_65 946
#define OBJECT_64 945
#define OBJECT_63 944
#define OBJECT_62 943
#define OBJECT_61 942
#define OBJECT_60 941
#define OBJECT_59 940
#define OBJECT_58 939
#define OBJECT_57 938
#define OBJECT_56 937
#define OBJECT_55 936
#define OBJECT_54 935
#define OBJECT_53 934
#define OBJECT_52 933
#define OBJECT_51 932
#define OBJECT_50 931
#define OBJECT_49 930
#define OBJECT_48 929
#define OBJECT_47 928
#define OBJECT_46 927
#define OBJECT_45 926
#define OBJECT_44 925
#define OBJECT_43 924
#define OBJECT_42 923
#define OBJECT_41 922
#define OBJECT_40 921
#define OBJECT_39 920
#define OBJECT_38 919
#define OBJECT_37 918
#define OBJECT_36 917
#define OBJECT_35 916
#define OBJECT_34 915
#define OBJECT_33 914
#define OBJECT_32 913
#define OBJECT_31 912
#define OBJECT_30 911
#define OBJECT_29 910
#define OBJECT_28 909
#define OBJECT_27 908
#define OBJECT_26 907
#define OBJECT_25 906
#define OBJECT_24 905
#define OBJECT_23 904
#define OBJECT_22 903
#define OBJECT_21 902
#define OBJECT_20 901
#define OBJECT_19 900
#define OBJECT_18 899
#define OBJECT_17 898
#define OBJECT_16 897
#define OBJECT_15 896
#define OBJECT_14 895
#define OBJECT_13 894
#define OBJECT_12 893
#define OBJECT_11 892
#define OBJECT_10 891
#define OBJECT_9 890
#define OBJECT_8 889
#define OBJECT_7 888
#define OBJECT_6 887
#define OBJECT_5 886
#define OBJECT_4 885
#define OBJECT_3 884
#define OBJECT_2 883
#define OBJECT_1 882
#define OBJECT_0 881
#define EXECUTE_CACHE_324 765
#define EXECUTE_CACHE_307 767
#define EXECUTE_CACHE_297 769
#define EXECUTE_CACHE_271 771
#define EXECUTE_CACHE_245 773
#define EXECUTE_CACHE_222 775
#define EXECUTE_CACHE_218 777
#define EXECUTE_CACHE_211 779
#define EXECUTE_CACHE_207 781
#define EXECUTE_CACHE_206 783
#define EXECUTE_CACHE_201 785
#define EXECUTE_CACHE_196 787
#define EXECUTE_CACHE_189 789
#define EXECUTE_CACHE_176 791
#define EXECUTE_CACHE_168 793
#define EXECUTE_CACHE_165 795
#define EXECUTE_CACHE_163 797
#define EXECUTE_CACHE_149 799
#define EXECUTE_CACHE_145 801
#define EXECUTE_CACHE_137 803
#define EXECUTE_CACHE_127 805
#define EXECUTE_CACHE_125 807
#define EXECUTE_CACHE_123 809
#define EXECUTE_CACHE_122 811
#define EXECUTE_CACHE_120 813
#define EXECUTE_CACHE_117 815
#define EXECUTE_CACHE_113 817
#define EXECUTE_CACHE_111 819
#define EXECUTE_CACHE_107 821
#define EXECUTE_CACHE_104 823
#define EXECUTE_CACHE_95 825
#define EXECUTE_CACHE_71 827
#define EXECUTE_CACHE_68 829
#define EXECUTE_CACHE_57 831
#define EXECUTE_CACHE_53 833
#define EXECUTE_CACHE_49 835
#define EXECUTE_CACHE_45 837
#define EXECUTE_CACHE_34 839
#define FREE_REFERENCE_31 842
#define FREE_REFERENCE_30 843
#define FREE_REFERENCE_29 844
#define FREE_REFERENCE_28 845
#define FREE_REFERENCE_27 846
#define FREE_REFERENCE_26 847
#define FREE_REFERENCE_25 848
#define FREE_REFERENCE_24 849
#define FREE_REFERENCE_23 850
#define FREE_REFERENCE_22 851
#define FREE_REFERENCE_21 852
#define FREE_REFERENCE_20 853
#define FREE_REFERENCE_19 854
#define FREE_REFERENCE_18 855
#define FREE_REFERENCE_17 856
#define FREE_REFERENCE_16 857
#define FREE_REFERENCE_15 858
#define FREE_REFERENCE_14 859
#define FREE_REFERENCE_13 860
#define FREE_REFERENCE_12 861
#define FREE_REFERENCE_11 862
#define FREE_REFERENCE_10 863
#define FREE_REFERENCE_9 864
#define FREE_REFERENCE_8 865
#define FREE_REFERENCE_7 866
#define FREE_REFERENCE_6 867
#define FREE_REFERENCE_5 868
#define FREE_REFERENCE_4 869
#define FREE_REFERENCE_3 870
#define FREE_REFERENCE_2 871
#define FREE_REFERENCE_1 872
#define FREE_REFERENCE_0 873
#define GLOBAL_EXECUTE_CACHE_408 875
#define GLOBAL_EXECUTE_CACHE_404 877
#define GLOBAL_EXECUTE_CACHE_374 879
#define FREE_REFERENCES_LABEL_0 764
#define NUMBER_OF_LINKER_SECTIONS_1 3

#ifndef WANT_ONLY_DATA

SCHEME_OBJECT *
http_syntax_so_a55ad10acee7df26 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd26;
  machine_word Wrd20;
  machine_word Wrd41;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd25;
  machine_word Wrd19;
  machine_word Wrd14;
  machine_word Wrd46;
  machine_word Wrd45;
  machine_word Wrd44;
  machine_word Wrd23;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd24;
  machine_word Wrd22;
  machine_word Wrd21;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd6;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd7;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_4);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_5);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_6);
      goto continuation_2;

    case 3:
      current_block = (Rpc - LABEL_7);
      goto continuation_3;

    case 4:
      current_block = (Rpc - LABEL_8);
      goto continuation_4;

    case 5:
      current_block = (Rpc - LABEL_9);
      goto continuation_5;

    case 6:
      current_block = (Rpc - LABEL_10);
      goto continuation_6;

    case 7:
      current_block = (Rpc - LABEL_11);
      goto continuation_7;

    case 8:
      current_block = (Rpc - LABEL_12);
      goto continuation_8;

    case 9:
      current_block = (Rpc - LABEL_13);
      goto continuation_9;

    case 10:
      current_block = (Rpc - LABEL_14);
      goto continuation_10;

    case 11:
      current_block = (Rpc - LABEL_15);
      goto continuation_11;

    case 12:
      current_block = (Rpc - LABEL_16);
      goto continuation_12;

    case 13:
      current_block = (Rpc - LABEL_17);
      goto continuation_13;

    case 14:
      current_block = (Rpc - LABEL_18);
      goto continuation_14;

    case 15:
      current_block = (Rpc - LABEL_19);
      goto continuation_15;

    case 16:
      current_block = (Rpc - LABEL_20);
      goto continuation_16;

    case 17:
      current_block = (Rpc - LABEL_21);
      goto continuation_17;

    case 18:
      current_block = (Rpc - LABEL_22);
      goto continuation_18;

    case 19:
      current_block = (Rpc - LABEL_23);
      goto continuation_19;

    case 20:
      current_block = (Rpc - LABEL_24);
      goto continuation_20;

    case 21:
      current_block = (Rpc - LABEL_25);
      goto continuation_21;

    case 22:
      current_block = (Rpc - LABEL_26);
      goto continuation_22;

    case 23:
      current_block = (Rpc - LABEL_27);
      goto continuation_23;

    case 24:
      current_block = (Rpc - LABEL_28);
      goto continuation_24;

    case 25:
      current_block = (Rpc - LABEL_29);
      goto continuation_25;

    case 26:
      current_block = (Rpc - LABEL_30);
      goto continuation_26;

    case 27:
      current_block = (Rpc - LABEL_31);
      goto continuation_27;

    case 28:
      current_block = (Rpc - LABEL_32);
      goto continuation_28;

    case 29:
      current_block = (Rpc - LABEL_33);
      goto continuation_29;

    case 30:
      current_block = (Rpc - LABEL_35);
      goto continuation_30;

    case 31:
      current_block = (Rpc - LABEL_36);
      goto continuation_31;

    case 32:
      current_block = (Rpc - LABEL_37);
      goto continuation_32;

    case 33:
      current_block = (Rpc - LABEL_38);
      goto continuation_33;

    case 34:
      current_block = (Rpc - LABEL_39);
      goto continuation_34;

    case 35:
      current_block = (Rpc - LABEL_40);
      goto continuation_35;

    case 36:
      current_block = (Rpc - LABEL_41);
      goto continuation_36;

    case 37:
      current_block = (Rpc - LABEL_42);
      goto continuation_37;

    case 38:
      current_block = (Rpc - LABEL_43);
      goto continuation_39;

    case 39:
      current_block = (Rpc - LABEL_48);
      goto label_345;

    case 40:
      current_block = (Rpc - LABEL_44);
      goto continuation_38;

    case 41:
      current_block = (Rpc - LABEL_46);
      goto continuation_41;

    case 42:
      current_block = (Rpc - LABEL_52);
      goto label_346;

    case 43:
      current_block = (Rpc - LABEL_47);
      goto continuation_40;

    case 44:
      current_block = (Rpc - LABEL_50);
      goto continuation_43;

    case 45:
      current_block = (Rpc - LABEL_56);
      goto label_347;

    case 46:
      current_block = (Rpc - LABEL_51);
      goto continuation_42;

    case 47:
      current_block = (Rpc - LABEL_54);
      goto continuation_45;

    case 48:
      current_block = (Rpc - LABEL_60);
      goto label_348;

    case 49:
      current_block = (Rpc - LABEL_55);
      goto continuation_44;

    case 50:
      current_block = (Rpc - LABEL_58);
      goto continuation_47;

    case 51:
      current_block = (Rpc - LABEL_63);
      goto label_349;

    case 52:
      current_block = (Rpc - LABEL_59);
      goto continuation_46;

    case 53:
      current_block = (Rpc - LABEL_61);
      goto continuation_49;

    case 54:
      current_block = (Rpc - LABEL_62);
      goto continuation_48;

    case 55:
      current_block = (Rpc - LABEL_64);
      goto continuation_50;

    case 56:
      current_block = (Rpc - LABEL_65);
      goto continuation_51;

    case 57:
      current_block = (Rpc - LABEL_66);
      goto continuation_53;

    case 58:
      current_block = (Rpc - LABEL_67);
      goto continuation_52;

    case 59:
      current_block = (Rpc - LABEL_70);
      goto label_350;

    case 60:
      current_block = (Rpc - LABEL_69);
      goto continuation_54;

    case 61:
      current_block = (Rpc - LABEL_72);
      goto continuation_55;

    case 62:
      current_block = (Rpc - LABEL_73);
      goto continuation_56;

    case 63:
      current_block = (Rpc - LABEL_74);
      goto continuation_57;

    case 64:
      current_block = (Rpc - LABEL_75);
      goto continuation_58;

    case 65:
      current_block = (Rpc - LABEL_76);
      goto continuation_59;

    case 66:
      current_block = (Rpc - LABEL_77);
      goto continuation_60;

    case 67:
      current_block = (Rpc - LABEL_78);
      goto continuation_61;

    case 68:
      current_block = (Rpc - LABEL_79);
      goto continuation_62;

    case 69:
      current_block = (Rpc - LABEL_80);
      goto continuation_63;

    case 70:
      current_block = (Rpc - LABEL_81);
      goto continuation_64;

    case 71:
      current_block = (Rpc - LABEL_82);
      goto continuation_65;

    case 72:
      current_block = (Rpc - LABEL_83);
      goto continuation_66;

    case 73:
      current_block = (Rpc - LABEL_84);
      goto continuation_67;

    case 74:
      current_block = (Rpc - LABEL_85);
      goto continuation_68;

    case 75:
      current_block = (Rpc - LABEL_86);
      goto continuation_69;

    case 76:
      current_block = (Rpc - LABEL_87);
      goto continuation_70;

    case 77:
      current_block = (Rpc - LABEL_88);
      goto continuation_71;

    case 78:
      current_block = (Rpc - LABEL_89);
      goto continuation_72;

    case 79:
      current_block = (Rpc - LABEL_92);
      goto label_351;

    case 80:
      current_block = (Rpc - LABEL_93);
      goto label_352;

    case 81:
      current_block = (Rpc - LABEL_94);
      goto label_353;

    case 82:
      current_block = (Rpc - LABEL_90);
      goto continuation_74;

    case 83:
      current_block = (Rpc - LABEL_91);
      goto continuation_73;

    case 84:
      current_block = (Rpc - LABEL_96);
      goto continuation_75;

    case 85:
      current_block = (Rpc - LABEL_97);
      goto continuation_76;

    case 86:
      current_block = (Rpc - LABEL_98);
      goto continuation_77;

    case 87:
      current_block = (Rpc - LABEL_99);
      goto continuation_137;

    case 88:
      current_block = (Rpc - LABEL_100);
      goto lambda_135;

    case 89:
      current_block = (Rpc - LABEL_101);
      goto continuation_138;

    case 90:
      current_block = (Rpc - LABEL_106);
      goto continuation_125;

    case 91:
      current_block = (Rpc - LABEL_102);
      goto continuation_124;

    case 92:
      current_block = (Rpc - LABEL_108);
      goto label_354;

    case 93:
      current_block = (Rpc - LABEL_110);
      goto label_355;

    case 94:
      current_block = (Rpc - LABEL_103);
      goto lambda_122;

    case 95:
      current_block = (Rpc - LABEL_105);
      goto continuation_139;

    case 96:
      current_block = (Rpc - LABEL_109);
      goto continuation_127;

    case 97:
      current_block = (Rpc - LABEL_112);
      goto continuation_78;

    case 98:
      current_block = (Rpc - LABEL_119);
      goto label_356;

    case 99:
      current_block = (Rpc - LABEL_114);
      goto continuation_140;

    case 100:
      current_block = (Rpc - LABEL_115);
      goto continuation_130;

    case 101:
      current_block = (Rpc - LABEL_116);
      goto continuation_129;

    case 102:
      current_block = (Rpc - LABEL_124);
      goto label_357;

    case 103:
      current_block = (Rpc - LABEL_118);
      goto continuation_79;

    case 104:
      current_block = (Rpc - LABEL_121);
      goto continuation_141;

    case 105:
      current_block = (Rpc - LABEL_128);
      goto lambda_418;

    case 106:
      current_block = (Rpc - LABEL_132);
      goto Z___ks15__119;

    case 107:
      current_block = (Rpc - LABEL_126);
      goto continuation_80;

    case 108:
      current_block = (Rpc - LABEL_130);
      goto continuation_142;

    case 109:
      current_block = (Rpc - LABEL_136);
      goto label_358;

    case 110:
      current_block = (Rpc - LABEL_131);
      goto continuation_81;

    case 111:
      current_block = (Rpc - LABEL_133);
      goto continuation_84;

    case 112:
      current_block = (Rpc - LABEL_141);
      goto label_359;

    case 113:
      current_block = (Rpc - LABEL_134);
      goto continuation_144;

    case 114:
      current_block = (Rpc - LABEL_144);
      goto label_360;

    case 115:
      current_block = (Rpc - LABEL_135);
      goto continuation_143;

    case 116:
      current_block = (Rpc - LABEL_138);
      goto lambda_420;

    case 117:
      current_block = (Rpc - LABEL_140);
      goto continuation_116;

    case 118:
      current_block = (Rpc - LABEL_142);
      goto continuation_146;

    case 119:
      current_block = (Rpc - LABEL_143);
      goto continuation_145;

    case 120:
      current_block = (Rpc - LABEL_146);
      goto continuation_85;

    case 121:
      current_block = (Rpc - LABEL_147);
      goto continuation_147;

    case 122:
      current_block = (Rpc - LABEL_148);
      goto continuation_86;

    case 123:
      current_block = (Rpc - LABEL_150);
      goto continuation_148;

    case 124:
      current_block = (Rpc - LABEL_152);
      goto Z___ks12__112;

    case 125:
      current_block = (Rpc - LABEL_151);
      goto continuation_149;

    case 126:
      current_block = (Rpc - LABEL_153);
      goto continuation_89;

    case 127:
      current_block = (Rpc - LABEL_158);
      goto label_361;

    case 128:
      current_block = (Rpc - LABEL_154);
      goto continuation_150;

    case 129:
      current_block = (Rpc - LABEL_155);
      goto lambda_422;

    case 130:
      current_block = (Rpc - LABEL_157);
      goto continuation_109;

    case 131:
      current_block = (Rpc - LABEL_159);
      goto continuation_151;

    case 132:
      current_block = (Rpc - LABEL_160);
      goto continuation_90;

    case 133:
      current_block = (Rpc - LABEL_161);
      goto continuation_153;

    case 134:
      current_block = (Rpc - LABEL_162);
      goto continuation_152;

    case 135:
      current_block = (Rpc - LABEL_164);
      goto continuation_91;

    case 136:
      current_block = (Rpc - LABEL_166);
      goto continuation_155;

    case 137:
      current_block = (Rpc - LABEL_167);
      goto continuation_154;

    case 138:
      current_block = (Rpc - LABEL_170);
      goto Z___ks7__106;

    case 139:
      current_block = (Rpc - LABEL_169);
      goto continuation_156;

    case 140:
      current_block = (Rpc - LABEL_174);
      goto label_362;

    case 141:
      current_block = (Rpc - LABEL_175);
      goto label_363;

    case 142:
      current_block = (Rpc - LABEL_171);
      goto continuation_93;

    case 143:
      current_block = (Rpc - LABEL_178);
      goto label_364;

    case 144:
      current_block = (Rpc - LABEL_172);
      goto continuation_158;

    case 145:
      current_block = (Rpc - LABEL_173);
      goto continuation_157;

    case 146:
      current_block = (Rpc - LABEL_177);
      goto continuation_94;

    case 147:
      current_block = (Rpc - LABEL_179);
      goto continuation_159;

    case 148:
      current_block = (Rpc - LABEL_180);
      goto continuation_95;

    case 149:
      current_block = (Rpc - LABEL_181);
      goto continuation_160;

    case 150:
      current_block = (Rpc - LABEL_183);
      goto Z___ks4__103;

    case 151:
      current_block = (Rpc - LABEL_182);
      goto continuation_161;

    case 152:
      current_block = (Rpc - LABEL_188);
      goto label_365;

    case 153:
      current_block = (Rpc - LABEL_184);
      goto continuation_97;

    case 154:
      current_block = (Rpc - LABEL_191);
      goto label_366;

    case 155:
      current_block = (Rpc - LABEL_185);
      goto continuation_164;

    case 156:
      current_block = (Rpc - LABEL_195);
      goto label_367;

    case 157:
      current_block = (Rpc - LABEL_186);
      goto continuation_163;

    case 158:
      current_block = (Rpc - LABEL_187);
      goto continuation_162;

    case 159:
      current_block = (Rpc - LABEL_197);
      goto label_368;

    case 160:
      current_block = (Rpc - LABEL_190);
      goto continuation_98;

    case 161:
      current_block = (Rpc - LABEL_192);
      goto continuation_167;

    case 162:
      current_block = (Rpc - LABEL_193);
      goto continuation_166;

    case 163:
      current_block = (Rpc - LABEL_194);
      goto continuation_165;

    case 164:
      current_block = (Rpc - LABEL_200);
      goto label_369;

    case 165:
      current_block = (Rpc - LABEL_198);
      goto continuation_99;

    case 166:
      current_block = (Rpc - LABEL_199);
      goto continuation_168;

    case 167:
      current_block = (Rpc - LABEL_205);
      goto label_370;

    case 168:
      current_block = (Rpc - LABEL_202);
      goto continuation_100;

    case 169:
      current_block = (Rpc - LABEL_203);
      goto continuation_170;

    case 170:
      current_block = (Rpc - LABEL_210);
      goto label_371;

    case 171:
      current_block = (Rpc - LABEL_204);
      goto continuation_169;

    case 172:
      current_block = (Rpc - LABEL_208);
      goto continuation_172;

    case 173:
      current_block = (Rpc - LABEL_209);
      goto continuation_171;

    case 174:
      current_block = (Rpc - LABEL_212);
      goto continuation_173;

    case 175:
      current_block = (Rpc - LABEL_213);
      goto continuation_174;

    case 176:
      current_block = (Rpc - LABEL_214);
      goto continuation_175;

    case 177:
      current_block = (Rpc - LABEL_217);
      goto label_372;

    case 178:
      current_block = (Rpc - LABEL_215);
      goto continuation_177;

    case 179:
      current_block = (Rpc - LABEL_221);
      goto label_373;

    case 180:
      current_block = (Rpc - LABEL_216);
      goto continuation_176;

    case 181:
      current_block = (Rpc - LABEL_219);
      goto continuation_179;

    case 182:
      current_block = (Rpc - LABEL_220);
      goto continuation_178;

    case 183:
      current_block = (Rpc - LABEL_223);
      goto continuation_180;

    case 184:
      current_block = (Rpc - LABEL_224);
      goto continuation_181;

    case 185:
      current_block = (Rpc - LABEL_227);
      goto label_374;

    case 186:
      current_block = (Rpc - LABEL_225);
      goto continuation_183;

    case 187:
      current_block = (Rpc - LABEL_230);
      goto label_375;

    case 188:
      current_block = (Rpc - LABEL_226);
      goto continuation_182;

    case 189:
      current_block = (Rpc - LABEL_228);
      goto continuation_185;

    case 190:
      current_block = (Rpc - LABEL_229);
      goto continuation_184;

    case 191:
      current_block = (Rpc - LABEL_231);
      goto continuation_186;

    case 192:
      current_block = (Rpc - LABEL_232);
      goto continuation_187;

    case 193:
      current_block = (Rpc - LABEL_233);
      goto continuation_188;

    case 194:
      current_block = (Rpc - LABEL_236);
      goto label_376;

    case 195:
      current_block = (Rpc - LABEL_237);
      goto label_377;

    case 196:
      current_block = (Rpc - LABEL_234);
      goto continuation_190;

    case 197:
      current_block = (Rpc - LABEL_240);
      goto label_378;

    case 198:
      current_block = (Rpc - LABEL_241);
      goto label_379;

    case 199:
      current_block = (Rpc - LABEL_235);
      goto continuation_189;

    case 200:
      current_block = (Rpc - LABEL_238);
      goto continuation_192;

    case 201:
      current_block = (Rpc - LABEL_239);
      goto continuation_191;

    case 202:
      current_block = (Rpc - LABEL_242);
      goto continuation_193;

    case 203:
      current_block = (Rpc - LABEL_243);
      goto continuation_195;

    case 204:
      current_block = (Rpc - LABEL_244);
      goto continuation_194;

    case 205:
      current_block = (Rpc - LABEL_246);
      goto continuation_197;

    case 206:
      current_block = (Rpc - LABEL_247);
      goto continuation_196;

    case 207:
      current_block = (Rpc - LABEL_248);
      goto continuation_198;

    case 208:
      current_block = (Rpc - LABEL_249);
      goto continuation_199;

    case 209:
      current_block = (Rpc - LABEL_250);
      goto continuation_200;

    case 210:
      current_block = (Rpc - LABEL_251);
      goto continuation_201;

    case 211:
      current_block = (Rpc - LABEL_252);
      goto continuation_202;

    case 212:
      current_block = (Rpc - LABEL_253);
      goto continuation_203;

    case 213:
      current_block = (Rpc - LABEL_254);
      goto continuation_204;

    case 214:
      current_block = (Rpc - LABEL_255);
      goto continuation_205;

    case 215:
      current_block = (Rpc - LABEL_259);
      goto label_380;

    case 216:
      current_block = (Rpc - LABEL_256);
      goto continuation_208;

    case 217:
      current_block = (Rpc - LABEL_263);
      goto label_381;

    case 218:
      current_block = (Rpc - LABEL_257);
      goto continuation_207;

    case 219:
      current_block = (Rpc - LABEL_258);
      goto continuation_206;

    case 220:
      current_block = (Rpc - LABEL_264);
      goto label_382;

    case 221:
      current_block = (Rpc - LABEL_260);
      goto continuation_211;

    case 222:
      current_block = (Rpc - LABEL_261);
      goto continuation_210;

    case 223:
      current_block = (Rpc - LABEL_262);
      goto continuation_209;

    case 224:
      current_block = (Rpc - LABEL_266);
      goto label_383;

    case 225:
      current_block = (Rpc - LABEL_265);
      goto continuation_212;

    case 226:
      current_block = (Rpc - LABEL_269);
      goto label_384;

    case 227:
      current_block = (Rpc - LABEL_270);
      goto label_385;

    case 228:
      current_block = (Rpc - LABEL_267);
      goto continuation_214;

    case 229:
      current_block = (Rpc - LABEL_274);
      goto label_386;

    case 230:
      current_block = (Rpc - LABEL_275);
      goto label_387;

    case 231:
      current_block = (Rpc - LABEL_276);
      goto label_388;

    case 232:
      current_block = (Rpc - LABEL_268);
      goto continuation_213;

    case 233:
      current_block = (Rpc - LABEL_272);
      goto continuation_216;

    case 234:
      current_block = (Rpc - LABEL_273);
      goto continuation_215;

    case 235:
      current_block = (Rpc - LABEL_277);
      goto continuation_217;

    case 236:
      current_block = (Rpc - LABEL_280);
      goto label_389;

    case 237:
      current_block = (Rpc - LABEL_281);
      goto label_390;

    case 238:
      current_block = (Rpc - LABEL_278);
      goto continuation_219;

    case 239:
      current_block = (Rpc - LABEL_279);
      goto continuation_218;

    case 240:
      current_block = (Rpc - LABEL_282);
      goto continuation_220;

    case 241:
      current_block = (Rpc - LABEL_285);
      goto label_391;

    case 242:
      current_block = (Rpc - LABEL_286);
      goto label_392;

    case 243:
      current_block = (Rpc - LABEL_283);
      goto continuation_222;

    case 244:
      current_block = (Rpc - LABEL_289);
      goto label_393;

    case 245:
      current_block = (Rpc - LABEL_284);
      goto continuation_221;

    case 246:
      current_block = (Rpc - LABEL_287);
      goto continuation_224;

    case 247:
      current_block = (Rpc - LABEL_292);
      goto label_394;

    case 248:
      current_block = (Rpc - LABEL_288);
      goto continuation_223;

    case 249:
      current_block = (Rpc - LABEL_290);
      goto continuation_231;

    case 250:
      current_block = (Rpc - LABEL_296);
      goto label_395;

    case 251:
      current_block = (Rpc - LABEL_291);
      goto continuation_225;

    case 252:
      current_block = (Rpc - LABEL_293);
      goto continuation_234;

    case 253:
      current_block = (Rpc - LABEL_303);
      goto label_396;

    case 254:
      current_block = (Rpc - LABEL_294);
      goto continuation_233;

    case 255:
      current_block = (Rpc - LABEL_295);
      goto continuation_232;

    case 256:
      current_block = (Rpc - LABEL_304);
      goto label_397;

    case 257:
      current_block = (Rpc - LABEL_298);
      goto lambda_425;

    case 258:
      current_block = (Rpc - LABEL_300);
      goto continuation_237;

    case 259:
      current_block = (Rpc - LABEL_301);
      goto continuation_236;

    case 260:
      current_block = (Rpc - LABEL_302);
      goto continuation_235;

    case 261:
      current_block = (Rpc - LABEL_309);
      goto label_398;

    case 262:
      current_block = (Rpc - LABEL_310);
      goto label_399;

    case 263:
      current_block = (Rpc - LABEL_305);
      goto lambda_426;

    case 264:
      current_block = (Rpc - LABEL_308);
      goto continuation_238;

    case 265:
      current_block = (Rpc - LABEL_311);
      goto lambda_427;

    case 266:
      current_block = (Rpc - LABEL_313);
      goto continuation_240;

    case 267:
      current_block = (Rpc - LABEL_314);
      goto continuation_239;

    case 268:
      current_block = (Rpc - LABEL_315);
      goto continuation_242;

    case 269:
      current_block = (Rpc - LABEL_321);
      goto label_400;

    case 270:
      current_block = (Rpc - LABEL_316);
      goto continuation_241;

    case 271:
      current_block = (Rpc - LABEL_317);
      goto continuation_247;

    case 272:
      current_block = (Rpc - LABEL_318);
      goto continuation_246;

    case 273:
      current_block = (Rpc - LABEL_319);
      goto continuation_245;

    case 274:
      current_block = (Rpc - LABEL_320);
      goto continuation_244;

    case 275:
      current_block = (Rpc - LABEL_326);
      goto label_401;

    case 276:
      current_block = (Rpc - LABEL_322);
      goto continuation_249;

    case 277:
      current_block = (Rpc - LABEL_329);
      goto label_402;

    case 278:
      current_block = (Rpc - LABEL_323);
      goto continuation_248;

    case 279:
      current_block = (Rpc - LABEL_325);
      goto continuation_243;

    case 280:
      current_block = (Rpc - LABEL_327);
      goto continuation_251;

    case 281:
      current_block = (Rpc - LABEL_333);
      goto label_403;

    case 282:
      current_block = (Rpc - LABEL_334);
      goto label_404;

    case 283:
      current_block = (Rpc - LABEL_328);
      goto continuation_250;

    case 284:
      current_block = (Rpc - LABEL_330);
      goto continuation_254;

    case 285:
      current_block = (Rpc - LABEL_331);
      goto continuation_253;

    case 286:
      current_block = (Rpc - LABEL_332);
      goto continuation_252;

    case 287:
      current_block = (Rpc - LABEL_335);
      goto continuation_255;

    case 288:
      current_block = (Rpc - LABEL_336);
      goto continuation_256;

    case 289:
      current_block = (Rpc - LABEL_340);
      goto label_405;

    case 290:
      current_block = (Rpc - LABEL_337);
      goto continuation_259;

    case 291:
      current_block = (Rpc - LABEL_344);
      goto label_406;

    case 292:
      current_block = (Rpc - LABEL_338);
      goto continuation_258;

    case 293:
      current_block = (Rpc - LABEL_339);
      goto continuation_257;

    case 294:
      current_block = (Rpc - LABEL_345);
      goto label_407;

    case 295:
      current_block = (Rpc - LABEL_341);
      goto continuation_262;

    case 296:
      current_block = (Rpc - LABEL_342);
      goto continuation_261;

    case 297:
      current_block = (Rpc - LABEL_343);
      goto continuation_260;

    case 298:
      current_block = (Rpc - LABEL_347);
      goto label_408;

    case 299:
      current_block = (Rpc - LABEL_346);
      goto continuation_263;

    case 300:
      current_block = (Rpc - LABEL_351);
      goto label_409;

    case 301:
      current_block = (Rpc - LABEL_352);
      goto label_410;

    case 302:
      current_block = (Rpc - LABEL_348);
      goto continuation_266;

    case 303:
      current_block = (Rpc - LABEL_349);
      goto continuation_265;

    case 304:
      current_block = (Rpc - LABEL_350);
      goto continuation_264;

    case 305:
      current_block = (Rpc - LABEL_353);
      goto continuation_267;

    case 306:
      current_block = (Rpc - LABEL_354);
      goto continuation_268;

    case 307:
      current_block = (Rpc - LABEL_355);
      goto continuation_269;

    case 308:
      current_block = (Rpc - LABEL_356);
      goto continuation_270;

    case 309:
      current_block = (Rpc - LABEL_357);
      goto continuation_271;

    case 310:
      current_block = (Rpc - LABEL_358);
      goto continuation_272;

    case 311:
      current_block = (Rpc - LABEL_359);
      goto continuation_273;

    case 312:
      current_block = (Rpc - LABEL_360);
      goto continuation_274;

    case 313:
      current_block = (Rpc - LABEL_363);
      goto label_411;

    case 314:
      current_block = (Rpc - LABEL_361);
      goto continuation_277;

    case 315:
      current_block = (Rpc - LABEL_362);
      goto continuation_276;

    case 316:
      current_block = (Rpc - LABEL_364);
      goto continuation_275;

    case 317:
      current_block = (Rpc - LABEL_365);
      goto continuation_278;

    case 318:
      current_block = (Rpc - LABEL_368);
      goto label_412;

    case 319:
      current_block = (Rpc - LABEL_366);
      goto continuation_281;

    case 320:
      current_block = (Rpc - LABEL_367);
      goto continuation_280;

    case 321:
      current_block = (Rpc - LABEL_369);
      goto continuation_279;

    case 322:
      current_block = (Rpc - LABEL_370);
      goto continuation_282;

    case 323:
      current_block = (Rpc - LABEL_371);
      goto continuation_286;

    case 324:
      current_block = (Rpc - LABEL_372);
      goto continuation_285;

    case 325:
      current_block = (Rpc - LABEL_373);
      goto continuation_283;

    case 326:
      current_block = (Rpc - LABEL_375);
      goto continuation_287;

    case 327:
      current_block = (Rpc - LABEL_376);
      goto continuation_288;

    case 328:
      current_block = (Rpc - LABEL_377);
      goto continuation_289;

    case 329:
      current_block = (Rpc - LABEL_378);
      goto continuation_290;

    case 330:
      current_block = (Rpc - LABEL_379);
      goto continuation_291;

    case 331:
      current_block = (Rpc - LABEL_380);
      goto continuation_292;

    case 332:
      current_block = (Rpc - LABEL_381);
      goto continuation_293;

    case 333:
      current_block = (Rpc - LABEL_382);
      goto continuation_294;

    case 334:
      current_block = (Rpc - LABEL_383);
      goto continuation_295;

    case 335:
      current_block = (Rpc - LABEL_384);
      goto continuation_296;

    case 336:
      current_block = (Rpc - LABEL_385);
      goto continuation_297;

    case 337:
      current_block = (Rpc - LABEL_386);
      goto continuation_298;

    case 338:
      current_block = (Rpc - LABEL_387);
      goto continuation_299;

    case 339:
      current_block = (Rpc - LABEL_388);
      goto continuation_300;

    case 340:
      current_block = (Rpc - LABEL_389);
      goto continuation_301;

    case 341:
      current_block = (Rpc - LABEL_390);
      goto continuation_302;

    case 342:
      current_block = (Rpc - LABEL_391);
      goto continuation_303;

    case 343:
      current_block = (Rpc - LABEL_392);
      goto continuation_304;

    case 344:
      current_block = (Rpc - LABEL_393);
      goto continuation_305;

    case 345:
      current_block = (Rpc - LABEL_394);
      goto continuation_306;

    case 346:
      current_block = (Rpc - LABEL_395);
      goto continuation_307;

    case 347:
      current_block = (Rpc - LABEL_396);
      goto continuation_308;

    case 348:
      current_block = (Rpc - LABEL_397);
      goto continuation_309;

    case 349:
      current_block = (Rpc - LABEL_398);
      goto continuation_310;

    case 350:
      current_block = (Rpc - LABEL_399);
      goto continuation_311;

    case 351:
      current_block = (Rpc - LABEL_400);
      goto continuation_312;

    case 352:
      current_block = (Rpc - LABEL_401);
      goto continuation_313;

    case 353:
      current_block = (Rpc - LABEL_402);
      goto continuation_319;

    case 354:
      current_block = (Rpc - LABEL_407);
      goto label_413;

    case 355:
      current_block = (Rpc - LABEL_403);
      goto continuation_318;

    case 356:
      current_block = (Rpc - LABEL_405);
      goto continuation_324;

    case 357:
      current_block = (Rpc - LABEL_406);
      goto continuation_320;

    case 358:
      current_block = (Rpc - LABEL_409);
      goto continuation_325;

    case 359:
      current_block = (Rpc - LABEL_410);
      goto make_hvdefn_428;

    case 360:
      current_block = (Rpc - LABEL_412);
      goto continuation_326;

    case 361:
      current_block = (Rpc - LABEL_413);
      goto continuation_327;

    case 362:
      current_block = (Rpc - LABEL_414);
      goto continuation_328;

    case 363:
      current_block = (Rpc - LABEL_417);
      goto label_414;

    case 364:
      current_block = (Rpc - LABEL_415);
      goto continuation_330;

    case 365:
      current_block = (Rpc - LABEL_416);
      goto continuation_329;

    case 366:
      current_block = (Rpc - LABEL_418);
      goto continuation_331;

    case 367:
      current_block = (Rpc - LABEL_419);
      goto continuation_332;

    case 368:
      current_block = (Rpc - LABEL_420);
      goto continuation_333;

    case 369:
      current_block = (Rpc - LABEL_421);
      goto continuation_334;

    case 370:
      current_block = (Rpc - LABEL_422);
      goto continuation_335;

    case 371:
      current_block = (Rpc - LABEL_423);
      goto continuation_336;

    case 372:
      current_block = (Rpc - LABEL_424);
      goto continuation_337;

    case 373:
      current_block = (Rpc - LABEL_425);
      goto continuation_338;

    case 374:
      current_block = (Rpc - LABEL_426);
      goto continuation_339;

    case 375:
      current_block = (Rpc - LABEL_427);
      goto continuation_340;

    case 376:
      current_block = (Rpc - LABEL_428);
      goto continuation_341;

    case 377:
      current_block = (Rpc - LABEL_429);
      goto continuation_342;

    case 378:
      current_block = (Rpc - LABEL_430);
      goto label_430;

    case 379:
      current_block = (Rpc - LABEL_431);
      goto label_431;

    case 380:
      current_block = (Rpc - LABEL_432);
      goto expression_344;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (expression_344)
  (current_block [ENVIRONMENT_LABEL_3]) = (Rrb [REGBLOCK_ENV]);
  INVOKE_INTERFACE_4 (23, (& (current_block [LABEL_431])), current_block, (& (current_block [FREE_REFERENCES_LABEL_0])), NUMBER_OF_LINKER_SECTIONS_1);

DEFLABEL (label_431)
  (* (--Rsp)) = (ULONG_TO_FIXNUM (1UL));

DEFLABEL (label_430)
  {
    static const short sections [] =
      {
	0,
	2,
	1,
	1,
	2,
	3,
	2,
	2,
	1,
	1,
	1,
	1,
	1,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	0,
	2,
	2,
	2,
	2,
	2,
	3,
	3,
	3,
	3,
	2,
	3,
	3,
	3,
	3,
	2,
	1,
	0,
	0,
	0,
	0,
	0,
	2,
	1,
	1,
	1,
	2,
	2,
	1,
	2,
	2,
	0,
	2,
	1,
	2,
	2,
	1,
	2,
	2,
	1,
	1,
	3,
	2,
	1,
	1,
	0,
	2,
	2,
	1,
	2,
	1,
	2,
	2,
	2,
	1,
	1,
	2,
	2,
	2,
	2,
	1,
	2,
	2,
	1,
	2,
	2,
	1,
	1,
	1,
	1,
	2,
	1,
	1,
	2,
	1,
	1,
	0,
	2,
	2,
	2,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	1,
	2,
	1,
	1,
	1,
	1,
	1,
	1,
	2,
	1,
	1,
	1,
	1,
	2,
	2,
	1,
	2,
	0,
	0,
	0,
	0,
	0,
	1,
	1,
	1,
	1,
	0,
	0,
	0,
	1,
	1,
	1,
	1,
	1,
	1,
	0,
	1,
	1,
	1,
	0,
	1,
	2,
	2
      };
    unsigned long counter = (OBJECT_DATUM (* Rsp));
    SCHEME_OBJECT blocks;
    SCHEME_OBJECT * sub_block;
    short section;
    if (counter > 149)
      goto label_429;
    blocks = (current_block [OBJECT_366]);
    sub_block = (OBJECT_ADDRESS (MEMORY_REF (blocks, counter)));
    (sub_block [(OBJECT_DATUM (sub_block [0]))]) = (Rrb [REGBLOCK_ENV]);
    section = (sections [counter]);
    (* Rsp) = (ULONG_TO_FIXNUM (counter + 1));
    INVOKE_INTERFACE_4 (23, (& (current_block [LABEL_430])), sub_block, (sub_block + (2 + (OBJECT_DATUM (sub_block [1])))), section);
  }

DEFLABEL (label_429)
  Rsp += 1;
  (Wrd5.Obj) = (Rrb [3]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_1]);
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_4]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_5]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_6]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_6);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_7]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_8]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_7);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_9]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_10]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_8);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_11]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_12]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_9);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_13]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_14]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_10);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_15]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_16]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_11);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_17]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_18]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_12);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_19]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_20]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_13);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_21]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_22]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_14);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_23]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_24]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_15);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_16]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_25]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_26]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_16);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_27]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_28]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_13)
  INTERRUPT_CHECK (27, LABEL_17);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_29]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_30]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_18);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_31]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_32]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_19);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_33]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_34]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_20);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_35]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_36]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_21);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_37]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_38]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_18)
  INTERRUPT_CHECK (27, LABEL_22);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_39]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_40]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_23);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_41]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_42]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_43]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_44]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_21)
  INTERRUPT_CHECK (27, LABEL_25);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_45]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_46]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_22)
  INTERRUPT_CHECK (27, LABEL_26);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_47]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_48]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_23)
  INTERRUPT_CHECK (27, LABEL_27);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_28]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_49]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_50]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_24)
  INTERRUPT_CHECK (27, LABEL_28);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_29]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_51]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_52]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_25)
  INTERRUPT_CHECK (27, LABEL_29);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_53]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_54]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_26)
  INTERRUPT_CHECK (27, LABEL_30);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_55]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_56]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_27)
  INTERRUPT_CHECK (27, LABEL_31);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_32]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_OBJECT (50, 0));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_57]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_28)
  INTERRUPT_CHECK (27, LABEL_32);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_58]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34]));

DEFLABEL (continuation_29)
  INTERRUPT_CHECK (27, LABEL_33);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_OBJECT (50, 0));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_59]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_30)
  INTERRUPT_CHECK (27, LABEL_35);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_60]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34]));

DEFLABEL (continuation_31)
  INTERRUPT_CHECK (27, LABEL_36);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_61]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_62]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_32)
  INTERRUPT_CHECK (27, LABEL_37);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_63]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_64]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_33)
  INTERRUPT_CHECK (27, LABEL_38);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_39]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_65]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_66]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_34)
  INTERRUPT_CHECK (27, LABEL_39);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_67]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_68]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_35)
  INTERRUPT_CHECK (27, LABEL_40);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_69]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_70]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_36)
  INTERRUPT_CHECK (27, LABEL_41);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_71]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_72]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_37)
  INTERRUPT_CHECK (27, LABEL_42);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_44]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_73]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_74]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_45]));

DEFLABEL (continuation_38)
  INTERRUPT_CHECK (27, LABEL_44);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_74]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_39)
  INTERRUPT_CHECK (27, LABEL_43);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_73]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_0]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_555;
  Wrd12 = Wrd16;

DEFLABEL (label_554)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_49]));

DEFLABEL (continuation_40)
  INTERRUPT_CHECK (27, LABEL_47);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_75]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_41)
  INTERRUPT_CHECK (27, LABEL_46);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_50]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_51]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_0]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_553;
  Wrd11 = Wrd15;

DEFLABEL (label_552)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_53]));

DEFLABEL (continuation_42)
  INTERRUPT_CHECK (27, LABEL_51);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_77]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_43)
  INTERRUPT_CHECK (27, LABEL_50);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_54]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_55]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_76]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_0]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_551;
  Wrd12 = Wrd16;

DEFLABEL (label_550)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_57]));

DEFLABEL (continuation_44)
  INTERRUPT_CHECK (27, LABEL_55);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_79]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_45)
  INTERRUPT_CHECK (27, LABEL_54);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_58]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_59]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_78]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_0]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_549;
  Wrd12 = Wrd16;

DEFLABEL (label_548)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_57]));

DEFLABEL (continuation_46)
  INTERRUPT_CHECK (27, LABEL_59);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_81]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_47)
  INTERRUPT_CHECK (27, LABEL_58);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_61]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_62]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_80]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_0]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_547;
  Wrd12 = Wrd16;

DEFLABEL (label_546)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_57]));

DEFLABEL (continuation_48)
  INTERRUPT_CHECK (27, LABEL_62);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_84]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_49)
  INTERRUPT_CHECK (27, LABEL_61);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_64]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_82]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_83]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_50)
  INTERRUPT_CHECK (27, LABEL_64);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_65]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_85]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_86]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_51)
  INTERRUPT_CHECK (27, LABEL_65);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_66]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_67]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_87]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_88]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_68]));

DEFLABEL (continuation_52)
  INTERRUPT_CHECK (27, LABEL_67);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_545;
  Wrd5 = Wrd9;

DEFLABEL (label_544)
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_71]));

DEFLABEL (continuation_53)
  INTERRUPT_CHECK (27, LABEL_66);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_69]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_89]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_90]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_54)
  INTERRUPT_CHECK (27, LABEL_69);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_72]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_91]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_92]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_55)
  INTERRUPT_CHECK (27, LABEL_72);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_73]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_93]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_94]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_56)
  INTERRUPT_CHECK (27, LABEL_73);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_74]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_95]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_88]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_57)
  INTERRUPT_CHECK (27, LABEL_74);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_75]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_96]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_97]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_58)
  INTERRUPT_CHECK (27, LABEL_75);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_76]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_98]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_99]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_59)
  INTERRUPT_CHECK (27, LABEL_76);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_77]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_100]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_101]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_60)
  INTERRUPT_CHECK (27, LABEL_77);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_78]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_102]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_103]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_61)
  INTERRUPT_CHECK (27, LABEL_78);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_79]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_104]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_105]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_62)
  INTERRUPT_CHECK (27, LABEL_79);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_80]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_106]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_107]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_63)
  INTERRUPT_CHECK (27, LABEL_80);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_81]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_108]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_109]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_64)
  INTERRUPT_CHECK (27, LABEL_81);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_82]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_110]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_111]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_65)
  INTERRUPT_CHECK (27, LABEL_82);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_83]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_112]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_113]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_66)
  INTERRUPT_CHECK (27, LABEL_83);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_84]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_114]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_115]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_67)
  INTERRUPT_CHECK (27, LABEL_84);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_85]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_116]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_117]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_68)
  INTERRUPT_CHECK (27, LABEL_85);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_86]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_118]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_119]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_69)
  INTERRUPT_CHECK (27, LABEL_86);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_87]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_120]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_121]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_70)
  INTERRUPT_CHECK (27, LABEL_87);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_88]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_122]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_123]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_71)
  INTERRUPT_CHECK (27, LABEL_88);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_89]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_124]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_125]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_72)
  INTERRUPT_CHECK (27, LABEL_89);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_90]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_91]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_543;
  Wrd11 = Wrd15;

DEFLABEL (label_542)
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd18.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2]));
  (Wrd21.Obj) = ((Wrd18.pObj) [0]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if ((Wrd22.uLng) == 50)
    goto label_541;
  Wrd17 = Wrd21;

DEFLABEL (label_540)
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd24.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_3]));
  (Wrd27.Obj) = ((Wrd24.pObj) [0]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if ((Wrd28.uLng) == 50)
    goto label_539;
  Wrd23 = Wrd27;

DEFLABEL (label_538)
  (* (--Rsp)) = (Wrd23.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_95]));

DEFLABEL (continuation_73)
  INTERRUPT_CHECK (27, LABEL_91);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_128]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_74)
  INTERRUPT_CHECK (27, LABEL_90);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_96]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_126]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_127]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_75)
  INTERRUPT_CHECK (27, LABEL_96);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_97]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_129]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_130]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_76)
  INTERRUPT_CHECK (27, LABEL_97);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_98]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_131]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_132]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_77)
  INTERRUPT_CHECK (27, LABEL_98);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_99]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_100]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_133]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_137)
  INTERRUPT_CHECK (27, LABEL_99);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_101]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_134]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_135]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_138)
  INTERRUPT_CHECK (27, LABEL_101);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_105]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_136]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_137]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_139)
  INTERRUPT_CHECK (27, LABEL_105);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_114]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_142]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_143]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_140)
  INTERRUPT_CHECK (27, LABEL_114);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_121]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_144]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_145]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_141)
  INTERRUPT_CHECK (27, LABEL_121);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_130]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_148]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_149]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_142)
  INTERRUPT_CHECK (27, LABEL_130);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_134]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_135]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_5]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_537;
  Wrd11 = Wrd15;

DEFLABEL (label_536)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_137]));

DEFLABEL (continuation_143)
  INTERRUPT_CHECK (27, LABEL_135);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_150]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_144)
  INTERRUPT_CHECK (27, LABEL_134);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_142]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_143]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_6]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_535;
  Wrd11 = Wrd15;

DEFLABEL (label_534)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_145]));

DEFLABEL (continuation_145)
  INTERRUPT_CHECK (27, LABEL_143);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_153]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_146)
  INTERRUPT_CHECK (27, LABEL_142);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_147]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_151]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_152]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_147)
  INTERRUPT_CHECK (27, LABEL_147);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_150]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_154]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_155]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_148)
  INTERRUPT_CHECK (27, LABEL_150);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_151]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_156]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_157]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_149)
  INTERRUPT_CHECK (27, LABEL_151);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_154]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_158]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_159]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_150)
  INTERRUPT_CHECK (27, LABEL_154);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_159]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_160]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_161]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_151)
  INTERRUPT_CHECK (27, LABEL_159);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_161]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_162]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_162]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_163]));

DEFLABEL (continuation_152)
  INTERRUPT_CHECK (27, LABEL_162);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_164]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_153)
  INTERRUPT_CHECK (27, LABEL_161);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_166]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_167]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_162]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_168]));

DEFLABEL (continuation_154)
  INTERRUPT_CHECK (27, LABEL_167);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_167]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_155)
  INTERRUPT_CHECK (27, LABEL_166);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_169]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_165]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_166]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_156)
  INTERRUPT_CHECK (27, LABEL_169);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_172]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_173]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_8]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_533;
  Wrd11 = Wrd15;

DEFLABEL (label_532)
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd18.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_9]));
  (Wrd21.Obj) = ((Wrd18.pObj) [0]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if ((Wrd22.uLng) == 50)
    goto label_531;
  Wrd17 = Wrd21;

DEFLABEL (label_530)
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_176]));

DEFLABEL (continuation_157)
  INTERRUPT_CHECK (27, LABEL_173);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_170]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_158)
  INTERRUPT_CHECK (27, LABEL_172);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_179]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_168]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_169]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_159)
  INTERRUPT_CHECK (27, LABEL_179);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_181]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_171]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_172]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_160)
  INTERRUPT_CHECK (27, LABEL_181);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_182]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_173]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_174]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_161)
  INTERRUPT_CHECK (27, LABEL_182);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_185]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_186]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_187]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_8]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_529;
  Wrd14 = Wrd18;

DEFLABEL (label_528)
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_189]));

DEFLABEL (continuation_162)
  INTERRUPT_CHECK (27, LABEL_187);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_9]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_527;
  Wrd5 = Wrd9;

DEFLABEL (label_526)
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_176]));

DEFLABEL (continuation_163)
  INTERRUPT_CHECK (27, LABEL_186);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_175]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_164)
  INTERRUPT_CHECK (27, LABEL_185);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_192]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_193]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_194]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_11]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_525;
  Wrd14 = Wrd18;

DEFLABEL (label_524)
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_196]));

DEFLABEL (continuation_165)
  INTERRUPT_CHECK (27, LABEL_194);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_179]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd7.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_6]));
  (Wrd10.Obj) = ((Wrd7.pObj) [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd11.uLng) == 50)
    goto label_523;
  Wrd6 = Wrd10;

DEFLABEL (label_522)
  (* (--Rsp)) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_201]));

DEFLABEL (continuation_166)
  INTERRUPT_CHECK (27, LABEL_193);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_178]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_167)
  INTERRUPT_CHECK (27, LABEL_192);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_199]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_176]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_177]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_168)
  INTERRUPT_CHECK (27, LABEL_199);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_203]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_204]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_12]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_521;
  Wrd11 = Wrd15;

DEFLABEL (label_520)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_206]));

DEFLABEL (continuation_169)
  INTERRUPT_CHECK (27, LABEL_204);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_181]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_170)
  INTERRUPT_CHECK (27, LABEL_203);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_208]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_209]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_13]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_519;
  Wrd11 = Wrd15;

DEFLABEL (label_518)
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd17.Obj) = (current_block [OBJECT_180]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_211]));

DEFLABEL (continuation_171)
  INTERRUPT_CHECK (27, LABEL_209);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_184]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_172)
  INTERRUPT_CHECK (27, LABEL_208);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_212]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_182]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_183]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_173)
  INTERRUPT_CHECK (27, LABEL_212);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_213]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_185]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_186]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_174)
  INTERRUPT_CHECK (27, LABEL_213);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_214]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_187]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_188]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_175)
  INTERRUPT_CHECK (27, LABEL_214);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_215]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_216]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_9]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_517;
  Wrd11 = Wrd15;

DEFLABEL (label_516)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_218]));

DEFLABEL (continuation_176)
  INTERRUPT_CHECK (27, LABEL_216);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_190]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_177)
  INTERRUPT_CHECK (27, LABEL_215);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_219]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_220]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_189]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_6]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_515;
  Wrd12 = Wrd16;

DEFLABEL (label_514)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_222]));

DEFLABEL (continuation_178)
  INTERRUPT_CHECK (27, LABEL_220);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_193]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_179)
  INTERRUPT_CHECK (27, LABEL_219);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_223]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_191]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_192]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_180)
  INTERRUPT_CHECK (27, LABEL_223);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_224]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_194]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_195]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_181)
  INTERRUPT_CHECK (27, LABEL_224);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_225]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_226]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_196]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_9]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_513;
  Wrd12 = Wrd16;

DEFLABEL (label_512)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_176]));

DEFLABEL (continuation_182)
  INTERRUPT_CHECK (27, LABEL_226);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_197]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_183)
  INTERRUPT_CHECK (27, LABEL_225);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_228]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_229]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_189]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd13.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_6]));
  (Wrd16.Obj) = ((Wrd13.pObj) [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd17.uLng) == 50)
    goto label_511;
  Wrd12 = Wrd16;

DEFLABEL (label_510)
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_222]));

DEFLABEL (continuation_184)
  INTERRUPT_CHECK (27, LABEL_229);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_200]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_185)
  INTERRUPT_CHECK (27, LABEL_228);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_231]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_198]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_199]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_186)
  INTERRUPT_CHECK (27, LABEL_231);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_232]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_201]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_202]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_187)
  INTERRUPT_CHECK (27, LABEL_232);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_233]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_203]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_204]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_188)
  INTERRUPT_CHECK (27, LABEL_233);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_234]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_235]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_14]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_509;
  Wrd11 = Wrd15;

DEFLABEL (label_508)
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd18.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_14]));
  (Wrd21.Obj) = ((Wrd18.pObj) [0]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if ((Wrd22.uLng) == 50)
    goto label_507;
  Wrd17 = Wrd21;

DEFLABEL (label_506)
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_176]));

DEFLABEL (continuation_189)
  INTERRUPT_CHECK (27, LABEL_235);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_206]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_190)
  INTERRUPT_CHECK (27, LABEL_234);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_238]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_239]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_15]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_505;
  Wrd11 = Wrd15;

DEFLABEL (label_504)
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd17.Obj) = (current_block [OBJECT_205]);
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd19.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_15]));
  (Wrd22.Obj) = ((Wrd19.pObj) [0]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if ((Wrd23.uLng) == 50)
    goto label_503;
  Wrd18 = Wrd22;

DEFLABEL (label_502)
  (* (--Rsp)) = (Wrd18.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_201]));

DEFLABEL (continuation_191)
  INTERRUPT_CHECK (27, LABEL_239);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_209]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_192)
  INTERRUPT_CHECK (27, LABEL_238);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_242]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_207]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_208]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_193)
  INTERRUPT_CHECK (27, LABEL_242);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_243]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_244]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_210]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_245]));

DEFLABEL (continuation_194)
  INTERRUPT_CHECK (27, LABEL_244);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_212]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_195)
  INTERRUPT_CHECK (27, LABEL_243);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_246]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_247]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_211]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_245]));

DEFLABEL (continuation_196)
  INTERRUPT_CHECK (27, LABEL_247);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_215]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_197)
  INTERRUPT_CHECK (27, LABEL_246);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_248]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_213]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_214]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_198)
  INTERRUPT_CHECK (27, LABEL_248);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_249]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_216]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_217]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_199)
  INTERRUPT_CHECK (27, LABEL_249);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_250]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_OBJECT (50, 0));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_218]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_200)
  INTERRUPT_CHECK (27, LABEL_250);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_251]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_219]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34]));

DEFLABEL (continuation_201)
  INTERRUPT_CHECK (27, LABEL_251);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_252]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_220]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_221]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_202)
  INTERRUPT_CHECK (27, LABEL_252);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_253]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_222]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_223]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_203)
  INTERRUPT_CHECK (27, LABEL_253);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_254]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_224]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_225]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_204)
  INTERRUPT_CHECK (27, LABEL_254);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_255]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_226]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_227]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_205)
  INTERRUPT_CHECK (27, LABEL_255);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_256]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_257]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_258]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_14]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_501;
  Wrd14 = Wrd18;

DEFLABEL (label_500)
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_189]));

DEFLABEL (continuation_206)
  INTERRUPT_CHECK (27, LABEL_258);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_16]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_499;
  Wrd5 = Wrd9;

DEFLABEL (label_498)
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_176]));

DEFLABEL (continuation_207)
  INTERRUPT_CHECK (27, LABEL_257);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_228]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_208)
  INTERRUPT_CHECK (27, LABEL_256);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_260]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_261]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_262]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_15]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_497;
  Wrd14 = Wrd18;

DEFLABEL (label_496)
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_196]));

DEFLABEL (continuation_209)
  INTERRUPT_CHECK (27, LABEL_262);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_163]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd7.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2]));
  (Wrd10.Obj) = ((Wrd7.pObj) [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd11.uLng) == 50)
    goto label_495;
  Wrd6 = Wrd10;

DEFLABEL (label_494)
  (* (--Rsp)) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_201]));

DEFLABEL (continuation_210)
  INTERRUPT_CHECK (27, LABEL_261);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_231]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_211)
  INTERRUPT_CHECK (27, LABEL_260);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_265]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_229]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_230]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_212)
  INTERRUPT_CHECK (27, LABEL_265);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_267]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_268]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_9]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_493;
  Wrd11 = Wrd15;

DEFLABEL (label_492)
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd18.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_17]));
  (Wrd21.Obj) = ((Wrd18.pObj) [0]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if ((Wrd22.uLng) == 50)
    goto label_491;
  Wrd17 = Wrd21;

DEFLABEL (label_490)
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_271]));

DEFLABEL (continuation_213)
  INTERRUPT_CHECK (27, LABEL_268);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_232]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_214)
  INTERRUPT_CHECK (27, LABEL_267);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_272]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_273]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_6]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_489;
  Wrd11 = Wrd15;

DEFLABEL (label_488)
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd18.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_18]));
  (Wrd21.Obj) = ((Wrd18.pObj) [0]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if ((Wrd22.uLng) == 50)
    goto label_487;
  Wrd17 = Wrd21;

DEFLABEL (label_486)
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd24.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_17]));
  (Wrd27.Obj) = ((Wrd24.pObj) [0]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if ((Wrd28.uLng) == 50)
    goto label_485;
  Wrd23 = Wrd27;

DEFLABEL (label_484)
  (* (--Rsp)) = (Wrd23.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_95]));

DEFLABEL (continuation_215)
  INTERRUPT_CHECK (27, LABEL_273);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_235]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_216)
  INTERRUPT_CHECK (27, LABEL_272);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_277]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_233]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_234]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_217)
  INTERRUPT_CHECK (27, LABEL_277);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_278]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_279]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_19]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_483;
  Wrd11 = Wrd15;

DEFLABEL (label_482)
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd18.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_20]));
  (Wrd21.Obj) = ((Wrd18.pObj) [0]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if ((Wrd22.uLng) == 50)
    goto label_481;
  Wrd17 = Wrd21;

DEFLABEL (label_480)
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_271]));

DEFLABEL (continuation_218)
  INTERRUPT_CHECK (27, LABEL_279);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_238]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_219)
  INTERRUPT_CHECK (27, LABEL_278);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_282]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_236]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_237]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_220)
  INTERRUPT_CHECK (27, LABEL_282);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_283]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_284]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_8]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_479;
  Wrd11 = Wrd15;

DEFLABEL (label_478)
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd18.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_21]));
  (Wrd21.Obj) = ((Wrd18.pObj) [0]);
  (Wrd22.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if ((Wrd22.uLng) == 50)
    goto label_477;
  Wrd17 = Wrd21;

DEFLABEL (label_476)
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_176]));

DEFLABEL (continuation_221)
  INTERRUPT_CHECK (27, LABEL_284);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_240]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_222)
  INTERRUPT_CHECK (27, LABEL_283);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_287]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_288]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_475;
  Wrd11 = Wrd15;

DEFLABEL (label_474)
  (* (--Rsp)) = (Wrd11.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd18.Obj) = (current_block [OBJECT_239]);
  (* (--Rsp)) = (Wrd18.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_201]));

DEFLABEL (continuation_223)
  INTERRUPT_CHECK (27, LABEL_288);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_241]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_224)
  INTERRUPT_CHECK (27, LABEL_287);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_290]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_291]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_22]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_473;
  Wrd11 = Wrd15;

DEFLABEL (label_472)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_137]));

DEFLABEL (continuation_225)
  INTERRUPT_CHECK (27, LABEL_291);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x404, 2);
  (* (Rhp++)) = (dispatch_base + TAG_299);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_298])));
  Rhp += 1;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  ((Wrd8.pObj) [2]) = Rvl;
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_242]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_231)
  INTERRUPT_CHECK (27, LABEL_290);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_293]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_294]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_295]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_23]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_471;
  Wrd14 = Wrd18;

DEFLABEL (label_470)
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_297]));

DEFLABEL (continuation_232)
  INTERRUPT_CHECK (27, LABEL_295);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_20]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_469;
  Wrd5 = Wrd9;

DEFLABEL (label_468)
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_271]));

DEFLABEL (continuation_233)
  INTERRUPT_CHECK (27, LABEL_294);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_243]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_234)
  INTERRUPT_CHECK (27, LABEL_293);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_300]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_301]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_302]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_24]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_467;
  Wrd14 = Wrd18;

DEFLABEL (label_466)
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_145]));

DEFLABEL (continuation_235)
  INTERRUPT_CHECK (27, LABEL_302);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_25]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_465;
  Wrd5 = Wrd9;

DEFLABEL (label_464)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_20]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_463;
  Wrd11 = Wrd15;

DEFLABEL (label_462)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_95]));

DEFLABEL (continuation_236)
  INTERRUPT_CHECK (27, LABEL_301);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_246]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_237)
  INTERRUPT_CHECK (27, LABEL_300);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_308]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_244]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_245]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_238)
  INTERRUPT_CHECK (27, LABEL_308);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_313]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_314]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_247]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_163]));

DEFLABEL (continuation_239)
  INTERRUPT_CHECK (27, LABEL_314);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_248]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_240)
  INTERRUPT_CHECK (27, LABEL_313);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_315]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_316]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_247]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_168]));

DEFLABEL (continuation_241)
  INTERRUPT_CHECK (27, LABEL_316);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_250]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_242)
  INTERRUPT_CHECK (27, LABEL_315);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_317]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_318]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_249]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd14.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_319]))));
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_320]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd19.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_14]));
  (Wrd22.Obj) = ((Wrd19.pObj) [0]);
  (Wrd23.uLng) = (OBJECT_TYPE (Wrd22.Obj));
  if ((Wrd23.uLng) == 50)
    goto label_461;
  Wrd18 = Wrd22;

DEFLABEL (label_460)
  (* (--Rsp)) = (Wrd18.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_189]));

DEFLABEL (continuation_244)
  INTERRUPT_CHECK (27, LABEL_320);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_325]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_14]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_459;
  Wrd8 = Wrd12;

DEFLABEL (label_458)
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_189]));

DEFLABEL (continuation_243)
  INTERRUPT_CHECK (27, LABEL_325);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_176]));

DEFLABEL (continuation_245)
  INTERRUPT_CHECK (27, LABEL_319);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_324]));

DEFLABEL (continuation_246)
  INTERRUPT_CHECK (27, LABEL_318);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_252]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_247)
  INTERRUPT_CHECK (27, LABEL_317);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_322]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_323]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_251]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_137]));

DEFLABEL (continuation_248)
  INTERRUPT_CHECK (27, LABEL_323);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_253]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_249)
  INTERRUPT_CHECK (27, LABEL_322);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_327]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_328]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_26]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_457;
  Wrd11 = Wrd15;

DEFLABEL (label_456)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_297]));

DEFLABEL (continuation_250)
  INTERRUPT_CHECK (27, LABEL_328);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_254]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_251)
  INTERRUPT_CHECK (27, LABEL_327);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_330]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_331]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_332]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_27]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_455;
  Wrd14 = Wrd18;

DEFLABEL (label_454)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd20.Obj) = (current_block [OBJECT_205]);
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd22.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_27]));
  (Wrd25.Obj) = ((Wrd22.pObj) [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 50)
    goto label_453;
  Wrd21 = Wrd25;

DEFLABEL (label_452)
  (* (--Rsp)) = (Wrd21.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_201]));

DEFLABEL (continuation_252)
  INTERRUPT_CHECK (27, LABEL_332);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_145]));

DEFLABEL (continuation_253)
  INTERRUPT_CHECK (27, LABEL_331);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_257]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_254)
  INTERRUPT_CHECK (27, LABEL_330);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_335]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_255]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_256]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_255)
  INTERRUPT_CHECK (27, LABEL_335);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_336]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_258]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_259]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_256)
  INTERRUPT_CHECK (27, LABEL_336);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_337]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_338]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_339]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_28]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_451;
  Wrd14 = Wrd18;

DEFLABEL (label_450)
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_189]));

DEFLABEL (continuation_257)
  INTERRUPT_CHECK (27, LABEL_339);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_28]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_449;
  Wrd5 = Wrd9;

DEFLABEL (label_448)
  (* (--Rsp)) = (Wrd5.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_176]));

DEFLABEL (continuation_258)
  INTERRUPT_CHECK (27, LABEL_338);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_260]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_259)
  INTERRUPT_CHECK (27, LABEL_337);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_341]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_342]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_343]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_447;
  Wrd14 = Wrd18;

DEFLABEL (label_446)
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_196]));

DEFLABEL (continuation_260)
  INTERRUPT_CHECK (27, LABEL_343);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_264]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd7.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_2]));
  (Wrd10.Obj) = ((Wrd7.pObj) [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if ((Wrd11.uLng) == 50)
    goto label_445;
  Wrd6 = Wrd10;

DEFLABEL (label_444)
  (* (--Rsp)) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_201]));

DEFLABEL (continuation_261)
  INTERRUPT_CHECK (27, LABEL_342);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_263]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_262)
  INTERRUPT_CHECK (27, LABEL_341);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_346]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_261]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_262]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_263)
  INTERRUPT_CHECK (27, LABEL_346);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_348]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_349]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_350]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_29]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_443;
  Wrd14 = Wrd18;

DEFLABEL (label_442)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd21.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_30]));
  (Wrd24.Obj) = ((Wrd21.pObj) [0]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if ((Wrd25.uLng) == 50)
    goto label_441;
  Wrd20 = Wrd24;

DEFLABEL (label_440)
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_271]));

DEFLABEL (continuation_264)
  INTERRUPT_CHECK (27, LABEL_350);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_206]));

DEFLABEL (continuation_265)
  INTERRUPT_CHECK (27, LABEL_349);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_267]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_266)
  INTERRUPT_CHECK (27, LABEL_348);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_353]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_265]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_266]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_267)
  INTERRUPT_CHECK (27, LABEL_353);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_354]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_268]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_269]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_268)
  INTERRUPT_CHECK (27, LABEL_354);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_355]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_270]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_271]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_269)
  INTERRUPT_CHECK (27, LABEL_355);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_356]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_272]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_273]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_270)
  INTERRUPT_CHECK (27, LABEL_356);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_357]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_274]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_275]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_271)
  INTERRUPT_CHECK (27, LABEL_357);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_358]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_276]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_277]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_272)
  INTERRUPT_CHECK (27, LABEL_358);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_359]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_278]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_279]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_273)
  INTERRUPT_CHECK (27, LABEL_359);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_360]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_280]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_281]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_274)
  INTERRUPT_CHECK (27, LABEL_360);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_361]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_362]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_16]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_439;
  Wrd11 = Wrd15;

DEFLABEL (label_438)
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_364]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd20.Obj) = (current_block [OBJECT_282]);
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_163]));

DEFLABEL (continuation_275)
  INTERRUPT_CHECK (27, LABEL_364);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_176]));

DEFLABEL (continuation_276)
  INTERRUPT_CHECK (27, LABEL_362);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_285]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_277)
  INTERRUPT_CHECK (27, LABEL_361);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_365]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_283]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_284]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_278)
  INTERRUPT_CHECK (27, LABEL_365);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_366]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_367]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_16]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_437;
  Wrd11 = Wrd15;

DEFLABEL (label_436)
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd19.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_369]))));
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd20.Obj) = (current_block [OBJECT_286]);
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_163]));

DEFLABEL (continuation_279)
  INTERRUPT_CHECK (27, LABEL_369);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_176]));

DEFLABEL (continuation_280)
  INTERRUPT_CHECK (27, LABEL_367);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_289]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_281)
  INTERRUPT_CHECK (27, LABEL_366);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_370]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_287]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_288]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_282)
  INTERRUPT_CHECK (27, LABEL_370);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_371]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_372]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_373]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (current_block [OBJECT_290]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_374]));

DEFLABEL (continuation_283)
  INTERRUPT_CHECK (27, LABEL_373);
  (Wrd9.Obj) = (current_block [OBJECT_293]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_294]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_295]), 2);

DEFLABEL (continuation_285)
  INTERRUPT_CHECK (27, LABEL_372);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_292]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_286)
  INTERRUPT_CHECK (27, LABEL_371);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_375]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_OBJECT (50, 0));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_291]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_287)
  INTERRUPT_CHECK (27, LABEL_375);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_376]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_296]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34]));

DEFLABEL (continuation_288)
  INTERRUPT_CHECK (27, LABEL_376);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_377]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_OBJECT (50, 0));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_297]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_289)
  INTERRUPT_CHECK (27, LABEL_377);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_378]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_298]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34]));

DEFLABEL (continuation_290)
  INTERRUPT_CHECK (27, LABEL_378);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_379]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_OBJECT (50, 0));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_299]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_291)
  INTERRUPT_CHECK (27, LABEL_379);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_380]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_300]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34]));

DEFLABEL (continuation_292)
  INTERRUPT_CHECK (27, LABEL_380);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_381]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_OBJECT (50, 0));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_301]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_293)
  INTERRUPT_CHECK (27, LABEL_381);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_382]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_302]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34]));

DEFLABEL (continuation_294)
  INTERRUPT_CHECK (27, LABEL_382);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_383]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_OBJECT (50, 0));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_303]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_295)
  INTERRUPT_CHECK (27, LABEL_383);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_384]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_304]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34]));

DEFLABEL (continuation_296)
  INTERRUPT_CHECK (27, LABEL_384);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_385]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_OBJECT (50, 0));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_305]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_297)
  INTERRUPT_CHECK (27, LABEL_385);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_386]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_306]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34]));

DEFLABEL (continuation_298)
  INTERRUPT_CHECK (27, LABEL_386);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_387]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_OBJECT (50, 0));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_307]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_299)
  INTERRUPT_CHECK (27, LABEL_387);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_388]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_308]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34]));

DEFLABEL (continuation_300)
  INTERRUPT_CHECK (27, LABEL_388);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_389]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_OBJECT (50, 0));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_309]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_301)
  INTERRUPT_CHECK (27, LABEL_389);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_390]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_310]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34]));

DEFLABEL (continuation_302)
  INTERRUPT_CHECK (27, LABEL_390);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_391]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_OBJECT (50, 0));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_311]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_303)
  INTERRUPT_CHECK (27, LABEL_391);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_392]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_312]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34]));

DEFLABEL (continuation_304)
  INTERRUPT_CHECK (27, LABEL_392);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_393]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_OBJECT (50, 0));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_313]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_305)
  INTERRUPT_CHECK (27, LABEL_393);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_394]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_314]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34]));

DEFLABEL (continuation_306)
  INTERRUPT_CHECK (27, LABEL_394);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_395]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_OBJECT (50, 0));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_315]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_307)
  INTERRUPT_CHECK (27, LABEL_395);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_396]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_316]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34]));

DEFLABEL (continuation_308)
  INTERRUPT_CHECK (27, LABEL_396);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_397]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_317]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_318]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_309)
  INTERRUPT_CHECK (27, LABEL_397);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_398]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_319]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_320]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_310)
  INTERRUPT_CHECK (27, LABEL_398);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_399]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_321]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_322]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_311)
  INTERRUPT_CHECK (27, LABEL_399);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_400]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_OBJECT (50, 0));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_323]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_312)
  INTERRUPT_CHECK (27, LABEL_400);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_401]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_324]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34]));

DEFLABEL (continuation_313)
  INTERRUPT_CHECK (27, LABEL_401);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_402]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_403]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = ((SCHEME_OBJECT) 0);
  (Wrd15.Obj) = (current_block [OBJECT_325]);
  (Wrd16.Obj) = (current_block [OBJECT_326]);
  (* (Rhp++)) = (Wrd15.Obj);
  (* (Rhp++)) = (Wrd16.Obj);
  (Wrd14.pObj) = (& (Rhp [-2]));
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd14.pObj)));
  (Wrd20.Obj) = (current_block [OBJECT_327]);
  (* (Rhp++)) = (Wrd20.Obj);
  (* (Rhp++)) = (Wrd12.Obj);
  (Wrd19.pObj) = (& (Rhp [-2]));
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd19.pObj)));
  (Wrd24.Obj) = (current_block [OBJECT_328]);
  (* (Rhp++)) = (Wrd24.Obj);
  (* (Rhp++)) = (Wrd17.Obj);
  (Wrd23.pObj) = (& (Rhp [-2]));
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd23.pObj)));
  (Wrd28.Obj) = (current_block [OBJECT_329]);
  (* (Rhp++)) = (Wrd28.Obj);
  (* (Rhp++)) = (Wrd21.Obj);
  (Wrd26.pObj) = (& (Rhp [-2]));
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd26.pObj)));
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd29.Obj) = (current_block [OBJECT_330]);
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd30.Obj) = (current_block [OBJECT_331]);
  (* (--Rsp)) = (Wrd30.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_404]));

DEFLABEL (continuation_318)
  INTERRUPT_CHECK (27, LABEL_403);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_332]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_319)
  INTERRUPT_CHECK (27, LABEL_402);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_405]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_406]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_31]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_435;
  Wrd11 = Wrd15;

DEFLABEL (label_434)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_408]));

DEFLABEL (continuation_320)
  INTERRUPT_CHECK (27, LABEL_406);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x505, 2);
  (* (Rhp++)) = (dispatch_base + TAG_411);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_410])));
  Rhp += 1;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  ((Wrd8.pObj) [2]) = Rvl;
  Rsp = (& (Rsp [1]));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_335]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_324)
  INTERRUPT_CHECK (27, LABEL_405);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_409]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_333]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_334]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_325)
  INTERRUPT_CHECK (27, LABEL_409);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_412]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_336]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_337]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_326)
  INTERRUPT_CHECK (27, LABEL_412);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_413]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_338]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_339]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_327)
  INTERRUPT_CHECK (27, LABEL_413);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_414]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_340]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_341]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_328)
  INTERRUPT_CHECK (27, LABEL_414);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_415]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_416]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd12.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_31]));
  (Wrd15.Obj) = ((Wrd12.pObj) [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd16.uLng) == 50)
    goto label_433;
  Wrd11 = Wrd15;

DEFLABEL (label_432)
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_408]));

DEFLABEL (continuation_329)
  INTERRUPT_CHECK (27, LABEL_416);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_344]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_330)
  INTERRUPT_CHECK (27, LABEL_415);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_418]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_342]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_343]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_331)
  INTERRUPT_CHECK (27, LABEL_418);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_419]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_345]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_346]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_332)
  INTERRUPT_CHECK (27, LABEL_419);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_420]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_347]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_348]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_333)
  INTERRUPT_CHECK (27, LABEL_420);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_421]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_349]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_350]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_334)
  INTERRUPT_CHECK (27, LABEL_421);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_422]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_351]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_352]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_335)
  INTERRUPT_CHECK (27, LABEL_422);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_423]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_353]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34]));

DEFLABEL (continuation_336)
  INTERRUPT_CHECK (27, LABEL_423);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_424]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_354]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_355]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_337)
  INTERRUPT_CHECK (27, LABEL_424);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_425]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_OBJECT (50, 0));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_356]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_338)
  INTERRUPT_CHECK (27, LABEL_425);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_426]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_357]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34]));

DEFLABEL (continuation_339)
  INTERRUPT_CHECK (27, LABEL_426);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_427]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_358]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_359]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_340)
  INTERRUPT_CHECK (27, LABEL_427);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_428]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_360]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_361]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_341)
  INTERRUPT_CHECK (27, LABEL_428);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_429]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_362]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_363]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_342)
  INTERRUPT_CHECK (27, LABEL_429);
  (Wrd5.Obj) = (current_block [OBJECT_364]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd7.Obj) = (current_block [OBJECT_365]);
  (Rsp [2]) = (Wrd7.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (label_433)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_417])), (Wrd12.pObj));

DEFLABEL (label_414)
  (Wrd11.Obj) = Rvl;
  goto label_432;

DEFLABEL (label_435)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_407])), (Wrd12.pObj));

DEFLABEL (label_413)
  (Wrd11.Obj) = Rvl;
  goto label_434;

DEFLABEL (label_437)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_368])), (Wrd12.pObj));

DEFLABEL (label_412)
  (Wrd11.Obj) = Rvl;
  goto label_436;

DEFLABEL (label_439)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_363])), (Wrd12.pObj));

DEFLABEL (label_411)
  (Wrd11.Obj) = Rvl;
  goto label_438;

DEFLABEL (label_441)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_352])), (Wrd21.pObj));

DEFLABEL (label_410)
  (Wrd20.Obj) = Rvl;
  goto label_440;

DEFLABEL (label_443)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_351])), (Wrd15.pObj));

DEFLABEL (label_409)
  (Wrd14.Obj) = Rvl;
  goto label_442;

DEFLABEL (label_445)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_347])), (Wrd7.pObj));

DEFLABEL (label_408)
  (Wrd6.Obj) = Rvl;
  goto label_444;

DEFLABEL (label_447)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_344])), (Wrd15.pObj));

DEFLABEL (label_406)
  (Wrd14.Obj) = Rvl;
  goto label_446;

DEFLABEL (label_449)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_345])), (Wrd6.pObj));

DEFLABEL (label_407)
  (Wrd5.Obj) = Rvl;
  goto label_448;

DEFLABEL (label_451)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_340])), (Wrd15.pObj));

DEFLABEL (label_405)
  (Wrd14.Obj) = Rvl;
  goto label_450;

DEFLABEL (label_453)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_334])), (Wrd22.pObj));

DEFLABEL (label_404)
  (Wrd21.Obj) = Rvl;
  goto label_452;

DEFLABEL (label_455)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_333])), (Wrd15.pObj));

DEFLABEL (label_403)
  (Wrd14.Obj) = Rvl;
  goto label_454;

DEFLABEL (label_457)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_329])), (Wrd12.pObj));

DEFLABEL (label_402)
  (Wrd11.Obj) = Rvl;
  goto label_456;

DEFLABEL (label_459)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_326])), (Wrd9.pObj));

DEFLABEL (label_401)
  (Wrd8.Obj) = Rvl;
  goto label_458;

DEFLABEL (label_461)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_321])), (Wrd19.pObj));

DEFLABEL (label_400)
  (Wrd18.Obj) = Rvl;
  goto label_460;

DEFLABEL (label_463)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_310])), (Wrd12.pObj));

DEFLABEL (label_399)
  (Wrd11.Obj) = Rvl;
  goto label_462;

DEFLABEL (label_465)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_309])), (Wrd6.pObj));

DEFLABEL (label_398)
  (Wrd5.Obj) = Rvl;
  goto label_464;

DEFLABEL (label_467)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_303])), (Wrd15.pObj));

DEFLABEL (label_396)
  (Wrd14.Obj) = Rvl;
  goto label_466;

DEFLABEL (label_469)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_304])), (Wrd6.pObj));

DEFLABEL (label_397)
  (Wrd5.Obj) = Rvl;
  goto label_468;

DEFLABEL (label_471)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_296])), (Wrd15.pObj));

DEFLABEL (label_395)
  (Wrd14.Obj) = Rvl;
  goto label_470;

DEFLABEL (label_473)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_292])), (Wrd12.pObj));

DEFLABEL (label_394)
  (Wrd11.Obj) = Rvl;
  goto label_472;

DEFLABEL (label_475)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_289])), (Wrd12.pObj));

DEFLABEL (label_393)
  (Wrd11.Obj) = Rvl;
  goto label_474;

DEFLABEL (label_477)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_286])), (Wrd18.pObj));

DEFLABEL (label_392)
  (Wrd17.Obj) = Rvl;
  goto label_476;

DEFLABEL (label_479)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_285])), (Wrd12.pObj));

DEFLABEL (label_391)
  (Wrd11.Obj) = Rvl;
  goto label_478;

DEFLABEL (label_481)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_281])), (Wrd18.pObj));

DEFLABEL (label_390)
  (Wrd17.Obj) = Rvl;
  goto label_480;

DEFLABEL (label_483)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_280])), (Wrd12.pObj));

DEFLABEL (label_389)
  (Wrd11.Obj) = Rvl;
  goto label_482;

DEFLABEL (label_485)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_276])), (Wrd24.pObj));

DEFLABEL (label_388)
  (Wrd23.Obj) = Rvl;
  goto label_484;

DEFLABEL (label_487)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_275])), (Wrd18.pObj));

DEFLABEL (label_387)
  (Wrd17.Obj) = Rvl;
  goto label_486;

DEFLABEL (label_489)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_274])), (Wrd12.pObj));

DEFLABEL (label_386)
  (Wrd11.Obj) = Rvl;
  goto label_488;

DEFLABEL (label_491)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_270])), (Wrd18.pObj));

DEFLABEL (label_385)
  (Wrd17.Obj) = Rvl;
  goto label_490;

DEFLABEL (label_493)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_269])), (Wrd12.pObj));

DEFLABEL (label_384)
  (Wrd11.Obj) = Rvl;
  goto label_492;

DEFLABEL (label_495)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_266])), (Wrd7.pObj));

DEFLABEL (label_383)
  (Wrd6.Obj) = Rvl;
  goto label_494;

DEFLABEL (label_497)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_263])), (Wrd15.pObj));

DEFLABEL (label_381)
  (Wrd14.Obj) = Rvl;
  goto label_496;

DEFLABEL (label_499)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_264])), (Wrd6.pObj));

DEFLABEL (label_382)
  (Wrd5.Obj) = Rvl;
  goto label_498;

DEFLABEL (label_501)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_259])), (Wrd15.pObj));

DEFLABEL (label_380)
  (Wrd14.Obj) = Rvl;
  goto label_500;

DEFLABEL (label_503)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_241])), (Wrd19.pObj));

DEFLABEL (label_379)
  (Wrd18.Obj) = Rvl;
  goto label_502;

DEFLABEL (label_505)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_240])), (Wrd12.pObj));

DEFLABEL (label_378)
  (Wrd11.Obj) = Rvl;
  goto label_504;

DEFLABEL (label_507)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_237])), (Wrd18.pObj));

DEFLABEL (label_377)
  (Wrd17.Obj) = Rvl;
  goto label_506;

DEFLABEL (label_509)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_236])), (Wrd12.pObj));

DEFLABEL (label_376)
  (Wrd11.Obj) = Rvl;
  goto label_508;

DEFLABEL (label_511)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_230])), (Wrd13.pObj));

DEFLABEL (label_375)
  (Wrd12.Obj) = Rvl;
  goto label_510;

DEFLABEL (label_513)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_227])), (Wrd13.pObj));

DEFLABEL (label_374)
  (Wrd12.Obj) = Rvl;
  goto label_512;

DEFLABEL (label_515)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_221])), (Wrd13.pObj));

DEFLABEL (label_373)
  (Wrd12.Obj) = Rvl;
  goto label_514;

DEFLABEL (label_517)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_217])), (Wrd12.pObj));

DEFLABEL (label_372)
  (Wrd11.Obj) = Rvl;
  goto label_516;

DEFLABEL (label_519)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_210])), (Wrd12.pObj));

DEFLABEL (label_371)
  (Wrd11.Obj) = Rvl;
  goto label_518;

DEFLABEL (label_521)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_205])), (Wrd12.pObj));

DEFLABEL (label_370)
  (Wrd11.Obj) = Rvl;
  goto label_520;

DEFLABEL (label_523)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_200])), (Wrd7.pObj));

DEFLABEL (label_369)
  (Wrd6.Obj) = Rvl;
  goto label_522;

DEFLABEL (label_525)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_195])), (Wrd15.pObj));

DEFLABEL (label_367)
  (Wrd14.Obj) = Rvl;
  goto label_524;

DEFLABEL (label_527)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_197])), (Wrd6.pObj));

DEFLABEL (label_368)
  (Wrd5.Obj) = Rvl;
  goto label_526;

DEFLABEL (label_529)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_188])), (Wrd15.pObj));

DEFLABEL (label_365)
  (Wrd14.Obj) = Rvl;
  goto label_528;

DEFLABEL (label_531)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_175])), (Wrd18.pObj));

DEFLABEL (label_363)
  (Wrd17.Obj) = Rvl;
  goto label_530;

DEFLABEL (label_533)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_174])), (Wrd12.pObj));

DEFLABEL (label_362)
  (Wrd11.Obj) = Rvl;
  goto label_532;

DEFLABEL (label_535)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_144])), (Wrd12.pObj));

DEFLABEL (label_360)
  (Wrd11.Obj) = Rvl;
  goto label_534;

DEFLABEL (label_537)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_136])), (Wrd12.pObj));

DEFLABEL (label_358)
  (Wrd11.Obj) = Rvl;
  goto label_536;

DEFLABEL (label_539)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_94])), (Wrd24.pObj));

DEFLABEL (label_353)
  (Wrd23.Obj) = Rvl;
  goto label_538;

DEFLABEL (label_541)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_93])), (Wrd18.pObj));

DEFLABEL (label_352)
  (Wrd17.Obj) = Rvl;
  goto label_540;

DEFLABEL (label_543)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_92])), (Wrd12.pObj));

DEFLABEL (label_351)
  (Wrd11.Obj) = Rvl;
  goto label_542;

DEFLABEL (label_545)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_70])), (Wrd6.pObj));

DEFLABEL (label_350)
  (Wrd5.Obj) = Rvl;
  goto label_544;

DEFLABEL (label_547)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_63])), (Wrd13.pObj));

DEFLABEL (label_349)
  (Wrd12.Obj) = Rvl;
  goto label_546;

DEFLABEL (label_549)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_60])), (Wrd13.pObj));

DEFLABEL (label_348)
  (Wrd12.Obj) = Rvl;
  goto label_548;

DEFLABEL (label_551)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_56])), (Wrd13.pObj));

DEFLABEL (label_347)
  (Wrd12.Obj) = Rvl;
  goto label_550;

DEFLABEL (label_553)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_52])), (Wrd12.pObj));

DEFLABEL (label_346)
  (Wrd11.Obj) = Rvl;
  goto label_552;

DEFLABEL (label_555)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_48])), (Wrd13.pObj));

DEFLABEL (label_345)
  (Wrd12.Obj) = Rvl;
  goto label_554;

DEFLABEL (lambda_416)
DEFLABEL (lambda_135)
  INTERRUPT_CHECK (26, LABEL_100);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_102]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_103]))));
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_104]));

DEFLABEL (continuation_124)
  INTERRUPT_CHECK (27, LABEL_102);
  (* (--Rsp)) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_563;
  (Wrd44.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_106]))));
  (* (--Rsp)) = (Wrd44.Obj);
  (Wrd45.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd45.Obj);
  (Wrd46.Obj) = (current_block [OBJECT_138]);
  (* (--Rsp)) = (Wrd46.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_107]));

DEFLABEL (continuation_125)
  INTERRUPT_CHECK (27, LABEL_106);

DEFLABEL (label_563)
  (Wrd16.Obj) = (Rsp [0]);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if (! ((Wrd17.uLng) == 10))
    goto label_562;
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd16.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [0]);
  (Wrd15.Lng) = (FIXNUM_TO_LONG (Wrd14.Obj));
  if (! (((unsigned long) 1L) < ((unsigned long) (Wrd15.Lng))))
    goto label_562;
  (Wrd7.Obj) = ((Wrd13.pObj) [2]);

DEFLABEL (label_561)
  (Rsp [1]) = (Wrd7.Obj);
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_109]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd35.Obj) = (Rsp [1]);
  (Wrd36.uLng) = (OBJECT_TYPE (Wrd35.Obj));
  if (! ((Wrd36.uLng) == 10))
    goto label_560;
  (Wrd32.pObj) = (OBJECT_ADDRESS (Wrd35.Obj));
  (Wrd33.Obj) = ((Wrd32.pObj) [0]);
  (Wrd34.Lng) = (FIXNUM_TO_LONG (Wrd33.Obj));
  if (! (((unsigned long) 0L) < ((unsigned long) (Wrd34.Lng))))
    goto label_560;
  (Wrd28.Obj) = ((Wrd32.pObj) [1]);
  (* (--Rsp)) = (Wrd28.Obj);

DEFLABEL (label_559)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_111]));

DEFLABEL (continuation_127)
  INTERRUPT_CHECK (27, LABEL_109);
  (Rsp [0]) = Rvl;
  (* (--Rsp)) = Rvl;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_115]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_116]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_117]));

DEFLABEL (continuation_129)
  INTERRUPT_CHECK (27, LABEL_116);
  (* (--Rsp)) = Rvl;
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_556;
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_123]));

DEFLABEL (label_556)
  (Wrd7.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd18.uLng) == 62))
    goto label_558;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (Wrd16.Lng) = (FIXNUM_TO_LONG (Wrd15.Obj));
  if (! (((unsigned long) 2L) < ((unsigned long) (Wrd16.Lng))))
    goto label_558;
  (Wrd10.Obj) = ((Wrd14.pObj) [3]);
  (* (--Rsp)) = (Wrd10.Obj);

DEFLABEL (label_557)
  (Rsp [2]) = ((SCHEME_OBJECT) 0);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_125]));

DEFLABEL (label_558)
  (Wrd19.Obj) = (Rsp [1]);
  (Wrd20.Obj) = (current_block [OBJECT_146]);
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_124]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_147]), 2);

DEFLABEL (label_357)
  (* (--Rsp)) = Rvl;
  goto label_557;

DEFLABEL (label_560)
  (Wrd37.Obj) = (Rsp [1]);
  (Wrd38.Obj) = (current_block [OBJECT_141]);
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_110]))));
  (* (--Rsp)) = (Wrd41.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_140]), 2);

DEFLABEL (label_355)
  (* (--Rsp)) = Rvl;
  goto label_559;

DEFLABEL (label_562)
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.Obj) = (current_block [OBJECT_139]);
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_108]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_140]), 2);

DEFLABEL (label_354)
  (Wrd7.Obj) = Rvl;
  goto label_561;

DEFLABEL (continuation_130)
  INTERRUPT_CHECK (27, LABEL_115);
  (Wrd5.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd5.Obj);
  (Rsp [2]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_122]));

DEFLABEL (lambda_417)
DEFLABEL (lambda_122)
  INTERRUPT_CHECK (26, LABEL_103);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_112]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113]));

DEFLABEL (continuation_78)
  INTERRUPT_CHECK (27, LABEL_112);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_118]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_4]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_566;
  Wrd8 = Wrd12;

DEFLABEL (label_565)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_120]));

DEFLABEL (continuation_79)
  INTERRUPT_CHECK (27, LABEL_118);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_564;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 5));
  (Wrd8.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_129);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_128])));
  Rhp += 2;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd8.pObj)));
  Wrd11 = Wrd8;
  (Wrd12.Obj) = (Rsp [1]);
  ((Wrd11.pObj) [2]) = (Wrd12.Obj);
  (Wrd10.Obj) = (Rsp [0]);
  ((Wrd11.pObj) [3]) = (Wrd10.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  goto Z___ks15__119;

DEFLABEL (label_564)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_126]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (Wrd16.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_127]));

DEFLABEL (continuation_80)
  INTERRUPT_CHECK (27, LABEL_126);
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_566)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_119])), (Wrd9.pObj));

DEFLABEL (label_356)
  (Wrd8.Obj) = Rvl;
  goto label_565;

DEFLABEL (lambda_418)
  CLOSURE_HEADER (LABEL_128);

DEFLABEL (lambda_82)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_131]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_127]));

DEFLABEL (continuation_81)
  INTERRUPT_CHECK (27, LABEL_131);
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (Z___ks15__419)
DEFLABEL (Z___ks15__119)
  INTERRUPT_CHECK (26, LABEL_132);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_133]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113]));

DEFLABEL (continuation_84)
  INTERRUPT_CHECK (27, LABEL_133);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 7));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_139);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_138])));
  Rhp += 4;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd14 = Wrd7;
  (Wrd15.Obj) = (Rsp [3]);
  ((Wrd14.pObj) [2]) = (Wrd15.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  ((Wrd14.pObj) [3]) = (Wrd13.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd14.pObj) [4]) = (Wrd11.Obj);
  ((Wrd14.pObj) [5]) = Rvl;
  (Rsp [1]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  (Wrd18.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_140]))));
  (* (--Rsp)) = (Wrd18.Obj);
  (Wrd20.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_4]));
  (Wrd23.Obj) = ((Wrd20.pObj) [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd24.uLng) == 50)
    goto label_569;
  Wrd19 = Wrd23;

DEFLABEL (label_568)
  (* (--Rsp)) = (Wrd19.Obj);
  (Wrd25.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd25.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_120]));

DEFLABEL (continuation_116)
  INTERRUPT_CHECK (27, LABEL_140);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_567;
  goto Z___ks15__119;

DEFLABEL (label_567)
  (Wrd7.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd7.Obj);
  Rsp = (& (Rsp [2]));
  goto lambda_115;

DEFLABEL (label_569)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_141])), (Wrd20.pObj));

DEFLABEL (label_359)
  (Wrd19.Obj) = Rvl;
  goto label_568;

DEFLABEL (lambda_420)
  CLOSURE_HEADER (LABEL_138);

DEFLABEL (lambda_115)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_146]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [5]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_127]));

DEFLABEL (continuation_85)
  INTERRUPT_CHECK (27, LABEL_146);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_148]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_149]));

DEFLABEL (continuation_86)
  INTERRUPT_CHECK (27, LABEL_148);
  (Wrd11.Obj) = (MAKE_OBJECT (0, 1));
  (* (Rhp++)) = (Wrd11.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (10, (Wrd7.pObj)));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd12.Obj) = (Rsp [1]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [4]);
  (* (--Rsp)) = (Wrd14.Obj);
  goto Z___ks12__112;

DEFLABEL (Z___ks12__421)
DEFLABEL (Z___ks12__112)
  INTERRUPT_CHECK (26, LABEL_152);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_153]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113]));

DEFLABEL (continuation_89)
  INTERRUPT_CHECK (27, LABEL_153);
  (* (--Rsp)) = Rvl;
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 7));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_156);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_155])));
  Rhp += 4;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd14 = Wrd7;
  (Wrd15.Obj) = (Rsp [3]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [2]);
  ((Wrd14.pObj) [2]) = (Wrd17.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  ((Wrd14.pObj) [3]) = (Wrd13.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  ((Wrd14.pObj) [4]) = (Wrd11.Obj);
  ((Wrd14.pObj) [5]) = Rvl;
  (Rsp [1]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_157]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (Wrd22.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_7]));
  (Wrd25.Obj) = ((Wrd22.pObj) [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 50)
    goto label_572;
  Wrd21 = Wrd25;

DEFLABEL (label_571)
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd27.Obj) = (Rsp [4]);
  (Wrd28.pObj) = (OBJECT_ADDRESS (Wrd27.Obj));
  (Wrd29.Obj) = ((Wrd28.pObj) [2]);
  (* (--Rsp)) = (Wrd29.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_120]));

DEFLABEL (continuation_109)
  INTERRUPT_CHECK (27, LABEL_157);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_570;
  goto Z___ks12__112;

DEFLABEL (label_570)
  (Wrd7.Obj) = (Rsp [0]);
  (Rsp [2]) = (Wrd7.Obj);
  Rsp = (& (Rsp [2]));
  goto lambda_108;

DEFLABEL (label_572)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_158])), (Wrd22.pObj));

DEFLABEL (label_361)
  (Wrd21.Obj) = Rvl;
  goto label_571;

DEFLABEL (lambda_422)
  CLOSURE_HEADER (LABEL_155);

DEFLABEL (lambda_108)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_160]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [5]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_127]));

DEFLABEL (continuation_90)
  INTERRUPT_CHECK (27, LABEL_160);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_164]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_163]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_165]));

DEFLABEL (continuation_91)
  INTERRUPT_CHECK (27, LABEL_164);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_573;
  goto Z___ks7__106;

DEFLABEL (label_573)
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [4]);
  (Rsp [0]) = (Wrd7.Obj);
  goto pop_return;

DEFLABEL (Z___ks7__423)
DEFLABEL (Z___ks7__106)
  INTERRUPT_CHECK (26, LABEL_170);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_171]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113]));

DEFLABEL (continuation_93)
  INTERRUPT_CHECK (27, LABEL_171);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_177]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_7]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_576;
  Wrd8 = Wrd12;

DEFLABEL (label_575)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [2]);
  (* (--Rsp)) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_120]));

DEFLABEL (continuation_94)
  INTERRUPT_CHECK (27, LABEL_177);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_574;
  Rsp = (& (Rsp [1]));
  goto Z___ks7__106;

DEFLABEL (label_574)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_180]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [2]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_127]));

DEFLABEL (continuation_95)
  INTERRUPT_CHECK (27, LABEL_180);
  goto Z___ks4__103;

DEFLABEL (label_576)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_178])), (Wrd9.pObj));

DEFLABEL (label_364)
  (Wrd8.Obj) = Rvl;
  goto label_575;

DEFLABEL (Z___ks4__424)
DEFLABEL (Z___ks4__103)
  INTERRUPT_CHECK (26, LABEL_183);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_184]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd10.Obj) = ((Wrd9.pObj) [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_113]));

DEFLABEL (continuation_97)
  INTERRUPT_CHECK (27, LABEL_184);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_190]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd9.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_10]));
  (Wrd12.Obj) = ((Wrd9.pObj) [0]);
  (Wrd13.uLng) = (OBJECT_TYPE (Wrd12.Obj));
  if ((Wrd13.uLng) == 50)
    goto label_579;
  Wrd8 = Wrd12;

DEFLABEL (label_578)
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd14.Obj) = (Rsp [4]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [2]);
  (* (--Rsp)) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_120]));

DEFLABEL (continuation_98)
  INTERRUPT_CHECK (27, LABEL_190);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_577;
  Rsp = (& (Rsp [1]));
  goto Z___ks4__103;

DEFLABEL (label_577)
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_198]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [4]);
  (Wrd13.pObj) = (OBJECT_ADDRESS (Wrd12.Obj));
  (Wrd14.Obj) = ((Wrd13.pObj) [2]);
  (* (--Rsp)) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_127]));

DEFLABEL (continuation_99)
  INTERRUPT_CHECK (27, LABEL_198);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_202]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [4]);
  (Wrd10.pObj) = (OBJECT_ADDRESS (Wrd9.Obj));
  (Wrd11.Obj) = ((Wrd10.pObj) [2]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_149]));

DEFLABEL (continuation_100)
  INTERRUPT_CHECK (27, LABEL_202);
  (Wrd11.Obj) = (MAKE_OBJECT (0, 1));
  (* (Rhp++)) = (Wrd11.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (10, (Wrd8.pObj)));
  (Wrd13.Obj) = (Rsp [2]);
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd13.Obj));
  (Wrd12.Obj) = ((Wrd14.pObj) [3]);
  (Rsp [1]) = (Wrd12.Obj);
  (Rsp [2]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_207]));

DEFLABEL (label_579)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_191])), (Wrd9.pObj));

DEFLABEL (label_366)
  (Wrd8.Obj) = Rvl;
  goto label_578;

DEFLABEL (lambda_425)
  CLOSURE_HEADER (LABEL_298);

DEFLABEL (lambda_229)
  CLOSURE_INTERRUPT_CHECK (24);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 7));
  (Wrd7.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_306);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_305])));
  Rhp += 4;
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd7.pObj)));
  Wrd14 = Wrd7;
  (Wrd15.Obj) = (Rsp [0]);
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [2]);
  ((Wrd14.pObj) [2]) = (Wrd17.Obj);
  (Wrd13.Obj) = (Rsp [3]);
  ((Wrd14.pObj) [3]) = (Wrd13.Obj);
  (Wrd11.Obj) = (Rsp [2]);
  ((Wrd14.pObj) [4]) = (Wrd11.Obj);
  (Wrd9.Obj) = (Rsp [1]);
  ((Wrd14.pObj) [5]) = (Wrd9.Obj);
  (Rsp [3]) = (Wrd6.Obj);
  Rsp = (& (Rsp [1]));
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_307]));

DEFLABEL (lambda_426)
  CLOSURE_HEADER (LABEL_305);

DEFLABEL (lambda_228)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd5.Obj) = (Rsp [0]);
  (Wrd6.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd6.pObj) [4]);
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = ((Wrd6.pObj) [5]);
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = ((Wrd6.pObj) [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  (* (Rhp++)) = (MAKE_OBJECT (TC_MANIFEST_CLOSURE, 4));
  (Wrd16.pObj) = (Rhp + 1);
  Rhp += 1;
  WRITE_LABEL_DESCRIPTOR (Rhp, 0x101, 2);
  (* (Rhp++)) = (dispatch_base + TAG_312);
  (* (Rhp++)) = ((SCHEME_OBJECT) (& (current_block [LABEL_311])));
  Rhp += 1;
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (Wrd16.pObj)));
  Wrd17 = Wrd16;
  (Wrd20.Obj) = ((Wrd6.pObj) [3]);
  ((Wrd17.pObj) [2]) = (Wrd20.Obj);
  (Rsp [3]) = (Wrd15.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

DEFLABEL (lambda_427)
  CLOSURE_HEADER (LABEL_311);

DEFLABEL (lambda_227)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd6.Obj) = (Rsp [0]);
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [2]);
  (Rsp [0]) = (Wrd5.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 1);
  }

DEFLABEL (make_hvdefn_428)
  CLOSURE_HEADER (LABEL_410);

DEFLABEL (make_hvdefn_322)
  CLOSURE_INTERRUPT_CHECK (24);
  (Wrd13.Obj) = (MAKE_OBJECT (0, 5));
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd14.Obj));
  (Wrd16.Obj) = ((Wrd15.pObj) [2]);
  (Wrd17.Obj) = (Rsp [1]);
  (Wrd18.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd13.Obj);
  (* (Rhp++)) = (Wrd16.Obj);
  (* (Rhp++)) = (Wrd17.Obj);
  (* (Rhp++)) = (Wrd18.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (Wrd10.Obj) = (Rsp [4]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd7.pObj) = (& (Rhp [-6]));
  Rvl = (MAKE_POINTER_OBJECT (62, (Wrd7.pObj)));
  Rsp = (& (Rsp [5]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

static const struct liarc_code_S arr_decl_http_syntax_so_a55ad10acee7df26 [149] =
  {
    { "http_syntax_so_code_1", 28, http_syntax_so_code_1 },
    { "http_syntax_so_code_2", 7, http_syntax_so_code_2 },
    { "http_syntax_so_code_3", 3, http_syntax_so_code_3 },
    { "http_syntax_so_code_4", 5, http_syntax_so_code_4 },
    { "http_syntax_so_code_5", 2, http_syntax_so_code_5 },
    { "http_syntax_so_code_6", 2, http_syntax_so_code_6 },
    { "http_syntax_so_code_7", 11, http_syntax_so_code_7 },
    { "http_syntax_so_code_8", 2, http_syntax_so_code_8 },
    { "http_syntax_so_code_9", 3, http_syntax_so_code_9 },
    { "http_syntax_so_code_10", 3, http_syntax_so_code_10 },
    { "http_syntax_so_code_11", 7, http_syntax_so_code_11 },
    { "http_syntax_so_code_12", 1, http_syntax_so_code_12 },
    { "http_syntax_so_code_13", 15, http_syntax_so_code_13 },
    { "http_syntax_so_code_14", 36, http_syntax_so_code_14 },
    { "http_syntax_so_code_15", 1, http_syntax_so_code_15 },
    { "http_syntax_so_code_16", 2, http_syntax_so_code_16 },
    { "http_syntax_so_code_17", 3, http_syntax_so_code_17 },
    { "http_syntax_so_code_18", 2, http_syntax_so_code_18 },
    { "http_syntax_so_code_19", 4, http_syntax_so_code_19 },
    { "http_syntax_so_code_20", 2, http_syntax_so_code_20 },
    { "http_syntax_so_code_21", 1, http_syntax_so_code_21 },
    { "http_syntax_so_code_22", 1, http_syntax_so_code_22 },
    { "http_syntax_so_code_23", 1, http_syntax_so_code_23 },
    { "http_syntax_so_code_24", 1, http_syntax_so_code_24 },
    { "http_syntax_so_code_25", 6, http_syntax_so_code_25 },
    { "http_syntax_so_code_26", 9, http_syntax_so_code_26 },
    { "http_syntax_so_code_27", 35, http_syntax_so_code_27 },
    { "http_syntax_so_code_28", 6, http_syntax_so_code_28 },
    { "http_syntax_so_code_29", 3, http_syntax_so_code_29 },
    { "http_syntax_so_code_30", 3, http_syntax_so_code_30 },
    { "http_syntax_so_code_31", 2, http_syntax_so_code_31 },
    { "http_syntax_so_code_32", 2, http_syntax_so_code_32 },
    { "http_syntax_so_code_33", 1, http_syntax_so_code_33 },
    { "http_syntax_so_code_34", 1, http_syntax_so_code_34 },
    { "http_syntax_so_code_35", 11, http_syntax_so_code_35 },
    { "http_syntax_so_code_36", 3, http_syntax_so_code_36 },
    { "http_syntax_so_code_37", 2, http_syntax_so_code_37 },
    { "http_syntax_so_code_38", 1, http_syntax_so_code_38 },
    { "http_syntax_so_code_39", 2, http_syntax_so_code_39 },
    { "http_syntax_so_code_40", 13, http_syntax_so_code_40 },
    { "http_syntax_so_code_41", 19, http_syntax_so_code_41 },
    { "http_syntax_so_code_42", 2, http_syntax_so_code_42 },
    { "http_syntax_so_code_43", 5, http_syntax_so_code_43 },
    { "http_syntax_so_code_44", 3, http_syntax_so_code_44 },
    { "http_syntax_so_code_45", 2, http_syntax_so_code_45 },
    { "http_syntax_so_code_46", 1, http_syntax_so_code_46 },
    { "http_syntax_so_code_47", 2, http_syntax_so_code_47 },
    { "http_syntax_so_code_48", 1, http_syntax_so_code_48 },
    { "http_syntax_so_code_49", 2, http_syntax_so_code_49 },
    { "http_syntax_so_code_50", 1, http_syntax_so_code_50 },
    { "http_syntax_so_code_51", 2, http_syntax_so_code_51 },
    { "http_syntax_so_code_52", 6, http_syntax_so_code_52 },
    { "http_syntax_so_code_53", 10, http_syntax_so_code_53 },
    { "http_syntax_so_code_54", 1, http_syntax_so_code_54 },
    { "http_syntax_so_code_55", 2, http_syntax_so_code_55 },
    { "http_syntax_so_code_56", 1, http_syntax_so_code_56 },
    { "http_syntax_so_code_57", 4, http_syntax_so_code_57 },
    { "http_syntax_so_code_58", 7, http_syntax_so_code_58 },
    { "http_syntax_so_code_59", 7, http_syntax_so_code_59 },
    { "http_syntax_so_code_60", 4, http_syntax_so_code_60 },
    { "http_syntax_so_code_61", 4, http_syntax_so_code_61 },
    { "http_syntax_so_code_62", 4, http_syntax_so_code_62 },
    { "http_syntax_so_code_63", 1, http_syntax_so_code_63 },
    { "http_syntax_so_code_64", 11, http_syntax_so_code_64 },
    { "http_syntax_so_code_65", 4, http_syntax_so_code_65 },
    { "http_syntax_so_code_66", 7, http_syntax_so_code_66 },
    { "http_syntax_so_code_67", 3, http_syntax_so_code_67 },
    { "http_syntax_so_code_68", 7, http_syntax_so_code_68 },
    { "http_syntax_so_code_69", 7, http_syntax_so_code_69 },
    { "http_syntax_so_code_70", 4, http_syntax_so_code_70 },
    { "http_syntax_so_code_71", 5, http_syntax_so_code_71 },
    { "http_syntax_so_code_72", 8, http_syntax_so_code_72 },
    { "http_syntax_so_code_73", 7, http_syntax_so_code_73 },
    { "http_syntax_so_code_74", 10, http_syntax_so_code_74 },
    { "http_syntax_so_code_75", 10, http_syntax_so_code_75 },
    { "http_syntax_so_code_76", 10, http_syntax_so_code_76 },
    { "http_syntax_so_code_77", 2, http_syntax_so_code_77 },
    { "http_syntax_so_code_78", 4, http_syntax_so_code_78 },
    { "http_syntax_so_code_79", 6, http_syntax_so_code_79 },
    { "http_syntax_so_code_80", 3, http_syntax_so_code_80 },
    { "http_syntax_so_code_81", 13, http_syntax_so_code_81 },
    { "http_syntax_so_code_82", 4, http_syntax_so_code_82 },
    { "http_syntax_so_code_83", 23, http_syntax_so_code_83 },
    { "http_syntax_so_code_84", 10, http_syntax_so_code_84 },
    { "http_syntax_so_code_85", 4, http_syntax_so_code_85 },
    { "http_syntax_so_code_86", 8, http_syntax_so_code_86 },
    { "http_syntax_so_code_87", 1, http_syntax_so_code_87 },
    { "http_syntax_so_code_88", 8, http_syntax_so_code_88 },
    { "http_syntax_so_code_89", 14, http_syntax_so_code_89 },
    { "http_syntax_so_code_90", 3, http_syntax_so_code_90 },
    { "http_syntax_so_code_91", 1, http_syntax_so_code_91 },
    { "http_syntax_so_code_92", 16, http_syntax_so_code_92 },
    { "http_syntax_so_code_93", 7, http_syntax_so_code_93 },
    { "http_syntax_so_code_94", 3, http_syntax_so_code_94 },
    { "http_syntax_so_code_95", 24, http_syntax_so_code_95 },
    { "http_syntax_so_code_96", 16, http_syntax_so_code_96 },
    { "http_syntax_so_code_97", 1, http_syntax_so_code_97 },
    { "http_syntax_so_code_98", 5, http_syntax_so_code_98 },
    { "http_syntax_so_code_99", 8, http_syntax_so_code_99 },
    { "http_syntax_so_code_100", 39, http_syntax_so_code_100 },
    { "http_syntax_so_code_101", 10, http_syntax_so_code_101 },
    { "http_syntax_so_code_102", 10, http_syntax_so_code_102 },
    { "http_syntax_so_code_103", 14, http_syntax_so_code_103 },
    { "http_syntax_so_code_104", 10, http_syntax_so_code_104 },
    { "http_syntax_so_code_105", 6, http_syntax_so_code_105 },
    { "http_syntax_so_code_106", 20, http_syntax_so_code_106 },
    { "http_syntax_so_code_107", 1, http_syntax_so_code_107 },
    { "http_syntax_so_code_108", 2, http_syntax_so_code_108 },
    { "http_syntax_so_code_109", 1, http_syntax_so_code_109 },
    { "http_syntax_so_code_110", 1, http_syntax_so_code_110 },
    { "http_syntax_so_code_111", 1, http_syntax_so_code_111 },
    { "http_syntax_so_code_112", 1, http_syntax_so_code_112 },
    { "http_syntax_so_code_113", 1, http_syntax_so_code_113 },
    { "http_syntax_so_code_114", 43, http_syntax_so_code_114 },
    { "http_syntax_so_code_115", 3, http_syntax_so_code_115 },
    { "http_syntax_so_code_116", 7, http_syntax_so_code_116 },
    { "http_syntax_so_code_117", 4, http_syntax_so_code_117 },
    { "http_syntax_so_code_118", 5, http_syntax_so_code_118 },
    { "http_syntax_so_code_119", 5, http_syntax_so_code_119 },
    { "http_syntax_so_code_120", 5, http_syntax_so_code_120 },
    { "http_syntax_so_code_121", 16, http_syntax_so_code_121 },
    { "http_syntax_so_code_122", 9, http_syntax_so_code_122 },
    { "http_syntax_so_code_123", 13, http_syntax_so_code_123 },
    { "http_syntax_so_code_124", 12, http_syntax_so_code_124 },
    { "http_syntax_so_code_125", 6, http_syntax_so_code_125 },
    { "http_syntax_so_code_126", 19, http_syntax_so_code_126 },
    { "http_syntax_so_code_127", 4, http_syntax_so_code_127 },
    { "http_syntax_so_code_128", 2, http_syntax_so_code_128 },
    { "http_syntax_so_code_129", 3, http_syntax_so_code_129 },
    { "http_syntax_so_code_130", 1, http_syntax_so_code_130 },
    { "http_syntax_so_code_131", 1, http_syntax_so_code_131 },
    { "http_syntax_so_code_132", 1, http_syntax_so_code_132 },
    { "http_syntax_so_code_133", 1, http_syntax_so_code_133 },
    { "http_syntax_so_code_134", 1, http_syntax_so_code_134 },
    { "http_syntax_so_code_135", 1, http_syntax_so_code_135 },
    { "http_syntax_so_code_136", 1, http_syntax_so_code_136 },
    { "http_syntax_so_code_137", 1, http_syntax_so_code_137 },
    { "http_syntax_so_code_138", 2, http_syntax_so_code_138 },
    { "http_syntax_so_code_139", 5, http_syntax_so_code_139 },
    { "http_syntax_so_code_140", 5, http_syntax_so_code_140 },
    { "http_syntax_so_code_141", 8, http_syntax_so_code_141 },
    { "http_syntax_so_code_142", 6, http_syntax_so_code_142 },
    { "http_syntax_so_code_143", 454, http_syntax_so_code_143 },
    { "http_syntax_so_code_144", 11, http_syntax_so_code_144 },
    { "http_syntax_so_code_145", 12, http_syntax_so_code_145 },
    { "http_syntax_so_code_146", 3, http_syntax_so_code_146 },
    { "http_syntax_so_code_147", 4, http_syntax_so_code_147 },
    { "http_syntax_so_code_148", 5, http_syntax_so_code_148 },
    { "http_syntax_so_code_149", 11, http_syntax_so_code_149 }
  };

int
decl_http_syntax_so_a55ad10acee7df26 (void)
{
  DECLARE_SUBCODE_MULTIPLE (arr_decl_http_syntax_so_a55ad10acee7df26);
  return (0);
}

DECLARE_COMPILED_CODE ("http-syntax.so", 381, decl_http_syntax_so_a55ad10acee7df26, http_syntax_so_a55ad10acee7df26)

#endif /* !WANT_ONLY_DATA */

#ifndef WANT_ONLY_CODE

static const unsigned char prog_http_syntax_so_data_a55ad10acee7df26 [28459] =
  "\xab\x0a\xc7\x02\xe3\x38\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\xc1\xb9"
  "\x0f\xc1\xba\xc2\xbb\x0d\xbc\x08\x0d\xbd\x24\x28\x0d\xbe\x28\x0d"
  "\xbf\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x82\x88\xb3\x0d\x24\x28\x0d\x1c\x28\xb6\x23\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x83"
  "\x88\x07\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x84\x88\xb1\xb2\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x85\x88\x28\x0d\x1c\x23\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x86\x88\x28\x1b\x23\x22\x29\x22\x29\x21"
  "\x17\x2b\x1c\x1d\xb0\x02\x88\xb1\x07\xb2\xc2\x1c\x80\xc1\x1c\x28"
  "\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x07\x22\x29\x22\x29\x21\x9f\x2b\x1c\x1d\xb0\x02\x88\x28\x1b\x23"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x0d"
  "\x1c\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\xb1\x1d\xb2\x28\x0d\x1c\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x0c\x28\x0d\x1c\x23\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1d"
  "\xb2\x08\xb1\x28\x0d\x1c\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1d"
  "\x81\x1b\x80\x0c\x06\x07\x08\xb2\xb1\x28\x1b\x28\x0d\x28\x0d\x1c"
  "\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x0d\x1c\x22\x29\x21\x9d\x2b\x1c\x1d\xb0\x02\x88\x07"
  "\x1b\xb2\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x0d\x1c\x23"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xb1\xb2\x28\x0d"
  "\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\x1d\x28\x0d\x1c\x28\x0d\x1c\x23\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x06\x1d\x0c\x28\x0d\x1c\x23\x22\x29\x21"
  "\x17\x2b\x1c\x1d\xb0\x02\x88\x22\x29\x21\x9c\x2b\x1c\x1d\xb0\x02"
  "\x88\xb2\x22\x29\x21\x9d\x2b\x1c\x1d\xb0\x02\x88\xb1\x22\x29\x21"
  "\x9d\x2b\x1c\x1d\xb0\x02\x88\x07\xb1\xb2\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x07\xb1"
  "\xb2\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xb3\x0f\x0c\x0d\x1c"
  "\x0d\x1c\x0d\x1c\x24\x28\x0d\x1c\x28\x0d\x28\x0d\x1c\x28\x0d\x1c"
  "\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x23"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xb1\x0c"
  "\xb2\x0c\x28\x0d\x1c\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1d\x81\x80"
  "\x0d\x1c\x25\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x1d\x81\x0d\x1c\x25\x28\x1b\x23\x22\x29\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x07\x02\x28\x1b\x23\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1d\x28\x0d\x1c\x28"
  "\x0d\x1c\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x06"
  "\x1d\x0c\x28\x1b\x23\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x02"
  "\x28\x0d\x23\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x1b\x24"
  "\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x83\x0f\x28\x0d\x28\x1b\x28"
  "\x0d\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x1d\x28\x0d\x1c\x28\x0d\x1c\x23\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x06\x1d\x0c\x28\x1b\x23\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x08\x28\x0d\x1c\x23\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x82\x07\x84\xc2\x1c\x83\x0d\x1c\x28\x0d\x1c"
  "\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x28"
  "\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x08\xb2\xb1\x28\x0d\x28\x0d\x1c\x28\x1b\x28"
  "\x1b\x28\x0d\x1c\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x0c\x1b\x24\x28\x0d\x23\x22\x29\x22\x29\x21"
  "\x17\x2b\x1c\x1d\xb0\x02\x88\x07\x0d\x1c\x28\x0d\x28\x0d\x28\x1b"
  "\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x28\x0d\x28\x0d\x1c\x28\x0d\x1c\x23\x22\x29\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1d\x28\x1b\x28\x0d\x1c"
  "\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x06\x1d\x0c"
  "\x28\x1b\x23\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x1b\x28"
  "\x1b\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x1b"
  "\x23\x22\x29\x21\x9f\x2b\x1c\x1d\xb0\x02\x88\x1d\x28\x0d\x1c\x28"
  "\x0d\x1c\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x06"
  "\x1d\x0c\x28\x1b\x23\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0d"
  "\x1c\x24\x28\x0d\x1c\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\x0d\x1c\x24\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x23"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x07\x0d\x1c\x24\x28\x1b\x28\x1b\x28\x1b\x23\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x07\x22\x29\x21\x9d"
  "\x2b\x1c\x1d\xb0\x02\x88\x1d\x28\x0d\x1c\x28\x0d\x1c\x23\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x06\x1d\x0c\x28\x1b\x23"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0f\x0d\x1c\x24\x28\x0d"
  "\x1c\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x0f\x07\xc2\x1c\x80\xc1\x1c\x28\x0d\x1c\x28"
  "\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x07\x0f\x0f\x80\x28\x0d\x1c\x28"
  "\x0d\x1c\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0f\x0f\x0d\x1c"
  "\x24\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x08\x28\x0d\x28\x0d\x28\x0d\x1c\x23\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0c"
  "\x28\x0d\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21"
  "\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x0d\x23\x22\x29\x21\x9f\x2b\x1c"
  "\x1d\xb0\x02\x88\x1b\x81\x0c\x0d\x1c\x28\x0d\x1c\x28\x1b\x28\x0d"
  "\x28\x1b\x28\x1b\x28\x1b\x28\x0d\x1c\x28\x1b\x23\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x24\x28\x0d\x1c\x28"
  "\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\xb1\xb4\xb2\x0d\x1c\x24\x28\x1b\x28\x0d\x1c\x23\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x28\x1b\x28\x0d\x1c\x23\x22\x29\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xb1\xb4\xb2\x0d\x1c\x24\x28"
  "\x1b\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xb1\xb4\xb2\x0d\x1c"
  "\x24\x28\x1b\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xb2\x0f\x08"
  "\xb1\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\xb3\x0d\x1c\x24\x28\x0d\x1c\x28\xb6\x23\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\xb3\xb4\x08\xb5\x24\x28\x0d\x1c\x28\xb6\x28\x0d\x1c\x23\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21"
  "\x17\x2b\x1c\x1d\xb0\x02\x88\xb3\xb4\x0d\x1c\x24\x28\x1b\x28\x0d"
  "\x1c\x28\x0d\x1c\x28\xb6\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xb3\xb4\x1b"
  "\x24\x28\x1b\x28\x1b\x28\xb6\x28\x1b\x23\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x08\xb1\x0f\xb2\x28\xb7\x23\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x08\xb1\x0f\xb2\x28\xb7\x23"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0d\x1c\x24\x28"
  "\x0d\x1c\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0d"
  "\x1c\x24\x28\x1b\x28\x0d\x1c\x28\x1b\x23\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xb3\xb4\x1b\x24\x28\x1b"
  "\x28\x0d\x1c\x28\xb6\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x07\x0d\xb2\x28\x0d\x1c"
  "\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xb3"
  "\xb4\x08\xb5\x0d\x1c\x24\x28\x1b\x28\x1b\x28\xb6\x28\x1b\x23\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\xb1\xb2\x07\x08\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xb3\xb4\x08\xb5\x1b\x24\x28\x1b"
  "\x28\x1b\x28\xb6\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xb1\x07"
  "\xb2\x0d\x1c\x24\x28\x0d\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x07\x08\xb1\xb2\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x08\xb3\x28"
  "\x1b\x28\xb6\x28\x0d\x1c\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x1d\x28\x1b\x23\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xb3"
  "\xb4\xb1\x0f\xb2\x0d\x1c\x24\x28\x1b\x28\xb6\x23\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x1d\x80\x0d\x1c\x25\x0d\x24\x28\x0d\x28\x1b\x28"
  "\x0d\x28\x1b\x28\x1b\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x80\x28\x0d\x1c"
  "\x28\x0d\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x28\x0d\x23\x22\x29\x21\x9f\x2b\x1c\x1d\xb0\x02\x88"
  "\x08\x1b\x80\x0c\xb3\xb4\xb1\x0f\xb2\x0d\x1c\x24\x28\x1b\x28\xb6"
  "\x28\x1b\x28\x0d\x1c\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\xb3\x1b\x24\x28\x1b\x28\x0d\x28\x1b\x28\x1b\x23\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\x28\x0d\x1c\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x07\x81\x02\x0f\x0d\x1c\x24\x28\x1b\x28"
  "\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x0c\x07\xb3\xb1\x0f\xb2\xb4\x1b\x24\x28\x1b\x28"
  "\x1b\x28\xb6\x28\x1b\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x0c\x1d\x28\x1b\x23\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xb3"
  "\x0d\x1c\x24\x28\x1b\x28\xb6\x23\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x07\xb1\xb2\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x07\x0f\xb3\x0d\x1c\x1b\x1b\x24\x28\x1b\x28"
  "\xb6\x28\x1b\x28\x0d\x1c\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x1b"
  "\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xb3\xb4\x1b\x24\x28"
  "\x1b\x28\x0d\x1c\x28\xb6\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x08\xb1\x0f\xb2\x28\xb7\x23\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\xb3\xb4\x08\xb5\x24\x28\x0d\x1c\x28\x0d"
  "\x1c\x28\xb7\x28\xb6\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0f\xb1\x1d\xb2\x0d\x1c"
  "\x0d\x1c\x0d\x1c\x24\x28\x0d\x1c\x28\x1b\x28\x1b\x23\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1d\xc2\x1d\x08\x28\x1b\x28"
  "\x0d\x28\x0d\x1c\x28\x0d\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1d\x1b\x0c"
  "\xc3\xc1\xb2\xb1\x02\x28\x0d\x28\x0d\x28\x1b\x28\x1b\x28\x0d\x28"
  "\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x0f\x28\x1b\x23\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\x0d\x1c\x24\x28\x1b\x23\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x22\x29\x21\x9c\x2b\x1c\x1d\xb0\x02\x88\x07\x22"
  "\x29\x21\x9d\x2b\x1c\x1d\xb0\x02\x88\x22\x29\x21\x9c\x2b\x1c\x1d"
  "\xb0\x02\x88\xb1\x22\x29\x21\x9d\x2b\x1c\x1d\xb0\x02\x88\xb1\x22"
  "\x29\x21\x9d\x2b\x1c\x1d\xb0\x02\x88\x0d\x1c\x0d\x1c\x0d\x1c\x08"
  "\x8a\x1b\x0d\x1c\x1b\x08\x89\x0d\x0d\x0d\x0d\x85\xc2\x02\x0d\x1c"
  "\x08\x88\x0d\x1b\x1b\x1b\x1b\x1b\x1b\x08\x8a\x0d\x0d\x0d\x1c\x1b"
  "\x08\x88\x06\x07\x08\x0d\xb2\x0d\x1c\x0d\x0d\x08\x89\x0d\x1c\x0d"
  "\x1c\x08\x8a\x1b\x0d\x1b\x1b\x08\x8a\x08\x8b\xb1\x28\x0d\x28\x0d"
  "\x28\x0d\x28\x0d\x28\x0d\x28\x1b\x28\x0d\x28\x1b\x23\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1d\x0c\x1b\x25\x28"
  "\x0d\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x1d\x1b\x25\x1b\x0d\x1c\x0d\x24\x28\x0d\x1c\x28\x0d\x1c\x23\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x1d\x1b\x25\x1b\x24\x28\x0d\x23\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1d\x0f\x0f"
  "\x0d\x1c\x25\x1b\x24\x28\x0d\x1c\x28\x1b\x23\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1d\x0f\x1b"
  "\x25\x1b\x24\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x02\x02\x1d\x02\x02\x1b"
  "\x25\x28\x0d\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0c\x1d\x0f\x0f\x0f\x1b\x25\x1b"
  "\x1b\x0d\x1c\x24\x28\x1b\x28\x1b\x28\x0d\x1c\x28\x0d\x1c\x28\x0d"
  "\x1c\x28\x1b\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0f"
  "\x1d\x1b\x25\x1b\x24\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1d\x1b\x25\x1b\x24\x28\x1b\x28"
  "\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0d\x1c\x0c\x0c\x1d\x0f\x0f\x1b"
  "\x25\x1b\x24\x28\x1b\x28\x0d\x1c\x28\x1b\x28\x1b\x28\x1b\x28\x1b"
  "\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x0c\x1d\x1b\x25\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x0c\x0d\x1c\x0c\x0f\x0f\x0f\x81\x1b\x24\x28\x1b\x28\x1b\x28\x1b"
  "\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x0d\x1c\x24\x28\x0d\x1c\x28\x1b\x28\x0d\x23"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x1b\x24\x28\x0d\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x1d\x1b\x25\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\x22\x29\x21\x9c\x2b\x1c\x1d\xb0\x02\x88\x22"
  "\x29\x21\x9c\x2b\x1c\x1d\xb0\x02\x88\x22\x29\x21\x9c\x2b\x1c\x1d"
  "\xb0\x02\x88\x22\x29\x21\x9c\x2b\x1c\x1d\xb0\x02\x88\x1b\x81\x22"
  "\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\x1b\x82\x22\x29\x21\x9e\x2b"
  "\x1c\x1d\xb0\x02\x88\x1b\x83\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02"
  "\x88\x1b\x84\x22\x29\x21\x9e\x2b\x1c\x1d\xb0\x02\x88\x07\x1b\x80"
  "\x0e\x1c\x24\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x28"
  "\x1b\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x23\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x28\x0d\x1c\x28\x0d\x1c\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x80"
  "\x0c\x81\x08\x28\x0d\x1c\x28\x0d\x28\x1b\x28\x0d\x1c\x23\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x02\x88\x0c\x1b\x80\x81\x1b\x28\x1b\x28\x1b\x23"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x0f\x0c\x0c\x0c\x0c\x0c\x02\x0c\x0c\x0c\x0c\x0c"
  "\x0c\x0c\x0c\x0c\x0c\x0c\x0c\x0c\x1b\x80\x0c\x07\x0c\x0d\x0c\x0c"
  "\x0c\x0c\x0c\x0f\x0c\x0c\x0c\x0c\x08\x0c\x0c\xb3\xb1\xb2\x0c\xb4"
  "\x0c\x0c\x0c\x0c\x0c\x0c\x0c\x0f\x0f\x0c\x0c\x0c\x0c\x0c\x0c\x0c"
  "\x1b\x1b\x1b\x1b\x1b\x1b\x0d\xba\x0d\xb9\x1b\x0d\x1c\x0d\x1c\x0d"
  "\x1c\x1b\x1b\x1b\x1b\x0d\x1c\x0d\x1c\x0d\x0d\x1b\x0d\x1c\x0d\x1c"
  "\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x1b\x1b\x0d\x1c\x0d\x1c"
  "\x0d\x1c\x0d\x1c\x1b\x0d\x1c\x0d\x1c\x0d\x1c\x1b\x0d\x0d\x1c\x0d"
  "\x1c\xb5\x1b\x1b\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x0d\x1c\x1b"
  "\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x1c\x0d\x0d\x0d\x1c\x0d\x1c\x1b\x1b"
  "\x1b\x1b\x0d\x1c\x0d\x1c\x0d\x1c\x1b\x24\x28\x0d\x1c\x28\x0d\x1c"
  "\x28\x1b\x28\x1b\x28\x0d\x1c\x28\x1b\x28\x0d\x1c\x28\x1b\x28\x1b"
  "\x28\x1b\x28\x0d\x1c\x28\x1b\x28\x0d\x1c\x28\x1b\x28\x0d\x1c\x28"
  "\x1b\x28\x1b\x28\xb2\x28\x1b\x28\x1b\x28\x0d\x1c\x28\x1b\x28\x1b"
  "\x28\x1b\x28\x1b\x28\x0d\x1c\x28\xb6\x28\xb7\x28\x1b\x28\x0d\x1c"
  "\x28\x1b\x28\x0d\x1c\x28\x1b\x28\x0d\x1c\x28\x1b\x28\x1b\x28\x1b"
  "\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x0d\x28\x1b"
  "\x28\x0d\x28\x0d\x1c\x28\x0d\x1c\x28\x1b\x28\x1b\x28\x1b\x28\x0d"
  "\x1c\x28\x0d\x1c\x28\x0d\x28\x0d\x1c\x28\x1b\x28\x1b\x28\x0d\x1c"
  "\x28\x0d\x1c\x28\x0d\x28\x0d\x1c\x28\x0d\x28\x0d\x1c\x28\x0d\x28"
  "\x0d\x1c\x28\x0d\x1c\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xb3\x80"
  "\xb4\x08\xb5\x24\x28\x1b\x28\x0d\xbd\x28\x1b\x28\xb6\x28\x1b\x28"
  "\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\xc3\x0f\x1b\x1d\x08\x0c\x80\x1b\x0c\x0d\x1c\x25\x1b\x24\x28\x0d"
  "\x28\x0d\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
  "\x1c\x1d\xb0\x02\x88\xb3\x0d\x24\x28\x1b\x23\x22\x29\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x08\x1b\x80\x28\x1b\x23\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\xbe\x1d\xb0\x02\x88\x80"
  "\x28\x1b\x28\x0d\x28\x1b\x28\x0d\x28\x0d\x23\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x80\x1b\x0d"
  "\x08\x0d\x24\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28"
  "\x0d\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x17\x1c"
  "\x88\x1b\x1b\x2a\x1b\x1b\x1b\x2a\x1b\xb6\x2a\x0d\x1b\x2a\x1b\x2a"
  "\x1b\x0d\x1b\x2a\x1b\x2a\x1b\x1b\x2a\x1b\x1b\x2a\x1b\x1b\x2a\x1b"
  "\x1b\x2a\x1b\x0d\x1b\x2a\x0d\x1b\x2a\x0d\x1b\x2a\x0d\x1b\x2a\x1b"
  "\x0d\x1b\x2a\x0d\x1c\x0c\x0d\x1c\x0d\x0d\x0d\x08\x8b\x1b\x2a\x1b"
  "\x2a\x1b\x2a\x08\x1b\x2a\x1b\x2a\x1b\x1b\x1b\x2a\x1b\x1b\x2a\x1b"
  "\x1b\x2a\x1b\x2a\x1b\x1b\x2a\x1b\x1b\x2a\x1b\x1b\x2a\x1b\x1b\x2a"
  "\x1b\x1b\x2a\x1b\x1b\x2a\x1b\x1b\x2a\x1b\x1b\x2a\x1b\x1b\x2a\x1b"
  "\x1b\x2a\xc2\x02\x02\x0d\x1b\x1b\x2a\x1b\x1b\x1b\x2a\x1b\x1b\x1b"
  "\x1b\x2a\x1b\x1b\x1b\x2a\x1b\x1b\x2a\x0d\x1b\x2a\x0d\x1b\x2a\x0d"
  "\x1b\x2a\x1b\x1b\x2a\x1b\x1b\x2a\x1b\x1b\x1b\x2a\x0f\x1b\x1b\x1b"
  "\x2a\x1b\x1b\x1b\x2a\x1b\x1b\x1b\x2a\x1b\x1b\x1b\x1b\x2a\x1b\x1b"
  "\x2a\x1b\x0d\x1b\x1b\x1b\x2a\x1b\x1b\x1b\x1b\x1b\x2a\x1b\x1b\x1b"
  "\x2a\x1b\x1b\x1b\x2a\x1b\x1b\x1b\x1b\x2a\x1b\x1b\x1b\x2a\x1b\x1b"
  "\x2a\xb2\x1b\x2a\xb1\x1b\x2a\x1b\x2a\x1b\x1b\x1b\x2a\xb5\x0d\x1c"
  "\x1b\x2a\x1b\x02\x02\x1b\x0d\x1c\x1b\x2a\x1b\x0f\x1b\x1b\x2a\x1b"
  "\x1b\x2a\x1b\x1b\x1b\x2a\x1b\x1b\x2a\x1b\x1b\x2a\x1b\x1b\x1b\x2a"
  "\x1b\x0c\x1b\x1b\x2a\x1b\x1b\x2a\x1b\x1b\x1b\x2a\x1b\x0c\x0f\x1b"
  "\x1b\x1b\x2a\x1b\x1b\x1b\x2a\x1b\x1b\x2a\x1b\x1b\x1b\x2a\x1b\x1b"
  "\x1b\x2a\x1b\x0f\x0d\x1b\x1b\x2a\xb7\x1b\x2a\x1b\x1b\x2a\x1b\x1b"
  "\x2a\x1b\x1b\x1b\x2a\x1b\x1b\x1b\x2a\x1b\x82\x1b\x1b\x2a\x1b\x1b"
  "\x2a\x80\x1b\x81\x0c\x1b\x1b\x2a\x1b\x1b\x2a\x1b\x0d\x1b\x2a\x1b"
  "\x1b\x2a\x0d\x1c\x1b\x1b\x2a\x1b\x1b\x2a\x1b\x1b\x2a\x1b\x1b\x2a"
  "\x1b\x1b\x2a\x1b\x1b\x2a\x1b\x1b\x2a\x0d\x1b\x2a\x1b\x1b\x2a\x1b"
  "\x1b\x2a\x0d\x1b\x2a\x1b\x1b\x2a\x1b\x1b\x2a\x1b\x1b\x2a\x1b\x1b"
  "\x2a\x1b\x1b\x2a\x1b\x2a\x1b\x1b\x2a\x0d\x1b\x2a\x1b\x1b\x2a\x1b"
  "\x1b\x2a\x1b\x1b\x2a\x0d\x0d\x1b\x2a\x1b\x0d\x1c\x1b\x0d\x1c\x1b"
  "\x1b\x1b\x0d\x1c\x1b\x1b\x1b\x08\x8a\x1b\x1b\x2a\x0d\x1b\x2a\x0d"
  "\x1b\x2a\x1b\x1b\x2a\x0d\x1b\x2a\x1b\x1b\x2a\x1b\x2a\x1b\x1b\x2a"
  "\x1b\x0d\x1b\x2a\x0d\x1b\x2a\x0d\x1b\x2a\x0d\x1b\x2a\x0d\x1b\x2a"
  "\x0d\x1b\x2a\x1b\x1b\x2a\x1b\x1b\x2a\x0d\x1b\x2a\x1b\x1b\x2a\x1b"
  "\x1b\x2a\x1b\x1b\x2a\x1b\x1b\x2a\x1b\x1b\x2a\x1b\x1b\x2a\x1b\x1b"
  "\x2a\x1b\x1b\x2a\x1b\x1b\x2a\x1b\x1b\x2a\x1b\x1b\x2a\x1b\x1b\x2a"
  "\x1b\x1b\x2a\x1b\x1b\x2a\x1b\x1b\x2a\x1b\x1b\x2a\x1b\x1b\x2a\x1b"
  "\x1b\x2a\xc3\x1b\x1b\x2a\x28\x0d\x28\x0d\x1c\x28\x0d\x26\x1b\x1b"
  "\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x0d\x1b"
  "\x1b\x1b\x1b\x0d\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x1b\x24\x28"
  "\x0d\x28\x1b\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x0d\x28\x1b\x28"
  "\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28"
  "\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28"
  "\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28"
  "\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x02\x58\x2f\x55\x73\x65\x72\x73"
  "\x2f\x63\x70\x68\x2f\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x73\x63"
  "\x68\x65\x6d\x65\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31"
  "\x2e\x31\x2f\x6d\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d"
  "\x39\x2e\x31\x2e\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74\x69\x6d"
  "\x65\x2f\x68\x74\x74\x70\x2d\x73\x79\x6e\x74\x61\x78\x2e\x69\x6e"
  "\x66\x15\x23\x5b\x70\x75\x72\x69\x66\x69\x63\x61\x74\x69\x6f\x6e"
  "\x2d\x72\x6f\x6f\x74\x5d\x02\x04\x63\x64\x72\x01\x2d\x04\x63\x61"
  "\x72\x06\x61\x70\x70\x6c\x79\x2c\x23\x5b\x28\x72\x75\x6e\x74\x69"
  "\x6d\x65\x20\x6f\x62\x6a\x65\x63\x74\x2d\x70\x61\x72\x73\x65\x72"
  "\x29\x73\x69\x6e\x67\x6c\x65\x2d\x76\x61\x6c\x2d\x6d\x61\x72\x6b"
  "\x65\x72\x5d\x05\x6c\x69\x73\x74\x02\x03\x1e\x73\x74\x72\x75\x63"
  "\x74\x75\x72\x65\x2d\x70\x61\x72\x73\x65\x72\x2d\x76\x61\x6c\x75"
  "\x65\x73\x2d\x3e\x6c\x69\x73\x74\x05\x07\x6c\x70\x3a\x6c\x77\x73"
  "\x03\x99\x03\x3a\x81\x89\x02\x98\x03\x38\x81\x83\x02\x97\x03\x36"
  "\x81\x89\x02\x96\x03\x34\x81\x85\x02\x95\x03\x32\x81\x83\x02\x94"
  "\x03\x30\x81\x89\x02\x93\x03\x2e\x81\x83\x02\x92\x03\x2c\x81\x83"
  "\x02\x91\x03\x2a\x81\x8d\x02\x90\x03\x28\x81\x8b\x02\x8f\x03\x26"
  "\x81\x89\x02\x8e\x03\x24\x81\x83\x02\x8d\x03\x22\x81\x89\x02\x8c"
  "\x03\x20\x81\x83\x02\x8b\x03\x1e\x81\x89\x02\x8a\x03\x1c\x81\x8d"
  "\x02\x89\x03\x1a\x81\x8d\x02\x88\x03\x18\x81\x89\x02\x87\x03\x16"
  "\x81\x83\x02\x86\x03\x14\x81\x89\x02\x85\x03\x12\x81\x8d\x02\x84"
  "\x03\x10\x81\x8b\x02\x83\x03\x0e\x81\x89\x02\x82\x03\x0c\x81\x87"
  "\x02\x81\x03\x0a\x81\x83\x02\x80\x03\x08\x81\x89\x02\xff\x02\x06"
  "\x81\x89\x02\xfe\x02\x04\x83\x04\x39\x49\x09\x02\x06\x70\x61\x69"
  "\x72\x3f\x02\x03\x0e\x6c\x70\x3a\x63\x6f\x6d\x6d\x61\x2d\x6c\x69"
  "\x73\x74\x0a\x03\x03\xa0\x03\x10\x81\x8d\x02\x9f\x03\x0e\x81\x8b"
  "\x02\x9e\x03\x0c\x81\x89\x02\x9d\x03\x0a\x81\x89\x02\x9c\x03\x08"
  "\x81\x89\x02\x9b\x03\x06\x81\x83\x02\x9a\x03\x04\x83\x04\x0f\x1a"
  "\x0b\x02\x04\x04\x61\x6e\x79\x0c\x02\xa3\x03\x08\x81\x85\x02\xa2"
  "\x03\x06\x81\x85\x02\xa1\x03\x04\xff\x03\x07\x0e\x0d\x02\xa8\x03"
  "\x0c\x81\x85\x02\xa7\x03\x0a\x81\x85\x02\xa6\x03\x08\x81\x87\x02"
  "\xa5\x03\x06\x81\x85\x02\xa4\x03\x04\x84\x06\x0b\x10\x0e\x02\x04"
  "\x0e\x6c\x69\x73\x74\x2d\x6f\x66\x2d\x74\x79\x70\x65\x3f\x0f\x02"
  "\xaa\x03\x06\x81\x85\x02\xa9\x03\x04\x83\x04\x05\x0b\x10\x02\x04"
  "\x0f\x02\xac\x03\x06\x81\x85\x02\xab\x03\x04\x83\x04\x05\x0b\x0f"
  "\x02\x08\x0b\x76\x65\x63\x74\x6f\x72\x2d\x72\x65\x66\x11\x0e\x76"
  "\x65\x63\x74\x6f\x72\x2d\x6c\x65\x6e\x67\x74\x68\x12\x03\x07\x6c"
  "\x65\x6e\x67\x74\x68\x02\xb7\x03\x18\x81\x89\x02\xb6\x03\x16\x81"
  "\x89\x02\xb5\x03\x14\x81\x89\x02\xb4\x03\x12\x81\x8d\x02\xb3\x03"
  "\x10\x81\x8b\x02\xb2\x03\x0e\x81\x89\x02\xb1\x03\x0c\x81\x85\x02"
  "\xb0\x03\x0a\x81\x85\x02\xaf\x03\x08\x81\x85\x02\xae\x03\x06\x81"
  "\x83\x02\xad\x03\x04\xff\x03\x17\x23\x13\x02\x09\xb9\x03\x06\x81"
  "\x85\x02\xb8\x03\x04\x83\x04\x05\x14\x02\x0a\x04\x0c\x02\xbc\x03"
  "\x08\x81\x85\x02\xbb\x03\x06\x81\x85\x02\xba\x03\x04\xff\x03\x07"
  "\x0d\x0c\x02\x0b\x04\x06\x65\x76\x65\x72\x79\x15\x02\xbf\x03\x08"
  "\x81\x85\x02\xbe\x03\x06\x81\x85\x02\xbd\x03\x04\xff\x03\x07\x0d"
  "\x16\x02\x0c\x02\x04\x09\x66\x6f\x72\x2d\x65\x61\x63\x68\x17\x04"
  "\x08\x64\x69\x73\x70\x6c\x61\x79\x18\x03\xc6\x03\x10\x81\x85\x02"
  "\xc5\x03\x0e\x81\x85\x02\xc4\x03\x0c\x81\x87\x02\xc3\x03\x0a\x81"
  "\x87\x02\xc2\x03\x08\x81\x8b\x02\xc1\x03\x06\x81\x87\x02\xc0\x03"
  "\x04\x84\x06\x0f\x1a\x19\x02\x0d\x03\x2c\x20\x04\x10\x73\x65\x70"
  "\x2d\x6c\x69\x73\x74\x2d\x77\x72\x69\x74\x65\x72\x1a\x02\xc7\x03"
  "\x04\x83\x04\x03\x0a\x1b\x02\x0e\x02\x03\x0c\x6f\x70\x74\x2d\x77"
  "\x72\x69\x74\x65\x72\x3f\x1c\x04\x18\x03\xd6\x03\x20\x81\x8f\x02"
  "\xd5\x03\x1e\x81\x8b\x02\xd4\x03\x1c\x81\x89\x02\xd3\x03\x1a\x81"
  "\x8b\x02\xd2\x03\x18\x81\x8b\x02\xd1\x03\x16\x81\x8b\x02\xd0\x03"
  "\x14\x81\x8b\x02\xcf\x03\x12\x81\x8b\x02\xce\x03\x10\x81\x87\x02"
  "\xcd\x03\x0e\x81\x89\x02\xcc\x03\x0c\x81\x89\x02\xcb\x03\x0a\x81"
  "\x89\x02\xca\x03\x08\x81\x89\x02\xc9\x03\x06\x81\x87\x02\xc8\x03"
  "\x04\x85\x08\x1f\x2b\x1d\x02\x0f\x02\x11\x1f\x49\x6c\x6c\x2d\x66"
  "\x6f\x72\x6d\x65\x64\x20\x56\x45\x43\x54\x4f\x52\x2d\x57\x52\x49"
  "\x54\x45\x52\x20\x61\x72\x67\x73\x3a\x03\x1c\x03\x0b\x70\x72\x6f"
  "\x63\x65\x64\x75\x72\x65\x3f\x04\x06\x65\x72\x72\x6f\x72\x1e\x04"
  "\x18\x05\xfa\x03\x4a\x81\x93\x02\xf9\x03\x48\x81\x8f\x02\xf8\x03"
  "\x46\x81\x8f\x02\xf7\x03\x44\x81\x8f\x02\xf6\x03\x42\x81\x8d\x02"
  "\xf5\x03\x40\x81\x8b\x02\xf4\x03\x3e\x81\x8d\x02\xf3\x03\x3c\x81"
  "\x8d\x02\xf2\x03\x3a\x81\x8d\x02\xf1\x03\x38\x81\x8d\x02\xf0\x03"
  "\x36\x81\x8d\x02\xef\x03\x34\x81\x8d\x02\xee\x03\x32\x81\x8d\x02"
  "\xed\x03\x30\x81\x8f\x02\xec\x03\x2e\x81\x8f\x02\xeb\x03\x2c\x81"
  "\x8f\x02\xea\x03\x2a\x81\x8f\x02\xe9\x03\x28\x81\x8b\x02\xe8\x03"
  "\x26\x81\x87\x02\xe7\x03\x24\x81\x8b\x02\xe6\x03\x22\x81\x87\x02"
  "\xe5\x03\x20\x81\x89\x02\xe4\x03\x1e\x81\x89\x02\xe3\x03\x1c\x81"
  "\x87\x02\xe2\x03\x1a\x81\x87\x02\xe1\x03\x18\x81\x87\x02\xe0\x03"
  "\x16\x81\x87\x02\xdf\x03\x14\x81\x87\x02\xde\x03\x12\x81\x85\x02"
  "\xdd\x03\x10\x81\x87\x02\xdc\x03\x0e\x81\x87\x02\xdb\x03\x0c\x81"
  "\x89\x02\xda\x03\x0a\x81\x89\x02\xd9\x03\x08\x81\x87\x02\xd8\x03"
  "\x06\x81\x87\x02\xd7\x03\x04\xfe\x05\x49\x5f\x18\x02\x10\x0b\x6f"
  "\x70\x74\x2d\x77\x72\x69\x74\x65\x72\x1f\xfb\x03\x04\x83\x04\x03"
  "\x20\x02\x11\x1f\xfd\x03\x06\x81\x83\x02\xfc\x03\x04\x83\x04\x05"
  "\x0b\x21\x02\x12\x80\x04\x08\x81\x87\x02\xff\x03\x06\x81\x87\x02"
  "\xfe\x03\x04\x85\x08\x07\x0a\x22\x02\x13\x04\x11\x77\x72\x69\x74"
  "\x65\x2d\x68\x74\x74\x70\x2d\x74\x6f\x6b\x65\x6e\x23\x02\x82\x04"
  "\x06\x81\x87\x02\x81\x04\x04\x83\x04\x05\x0b\x24\x02\x14\x03\x1b"
  "\x65\x78\x61\x63\x74\x2d\x6e\x6f\x6e\x6e\x65\x67\x61\x74\x69\x76"
  "\x65\x2d\x69\x6e\x74\x65\x67\x65\x72\x3f\x25\x02\x86\x04\x0a\x81"
  "\x83\x02\x85\x04\x08\x81\x83\x02\x84\x04\x06\x81\x85\x02\x83\x04"
  "\x04\x83\x04\x09\x11\x26\x02\x15\x02\x03\x0e\x68\x74\x74\x70\x2d"
  "\x76\x65\x72\x73\x69\x6f\x6e\x3f\x27\x04\x17\x65\x72\x72\x6f\x72"
  "\x3a\x6e\x6f\x74\x2d\x68\x74\x74\x70\x2d\x76\x65\x72\x73\x69\x6f"
  "\x6e\x28\x03\x88\x04\x06\x81\x85\x02\x87\x04\x04\x84\x04\x05\x0e"
  "\x29\x02\x16\x08\x0d\x48\x54\x54\x50\x20\x76\x65\x72\x73\x69\x6f"
  "\x6e\x05\x1a\x65\x72\x72\x6f\x72\x3a\x77\x72\x6f\x6e\x67\x2d\x74"
  "\x79\x70\x65\x2d\x61\x72\x67\x75\x6d\x65\x6e\x74\x2a\x02\x89\x04"
  "\x04\x84\x04\x03\x0c\x2b\x02\x17\x8a\x04\x04\x84\x06\x03\x2c\x02"
  "\x18\x8b\x04\x04\x83\x04\x03\x2d\x02\x19\x8c\x04\x04\x83\x04\x03"
  "\x2e\x02\x1a\x92\x04\x0e\x81\x85\x02\x91\x04\x0c\x81\x85\x02\x90"
  "\x04\x0a\x81\x85\x02\x8f\x04\x08\x81\x87\x02\x8e\x04\x06\x81\x85"
  "\x02\x8d\x04\x04\x84\x06\x0d\x13\x2f\x02\x1b\x9b\x04\x14\x81\x85"
  "\x02\x9a\x04\x12\x81\x85\x02\x99\x04\x10\x81\x85\x02\x98\x04\x0e"
  "\x81\x87\x02\x97\x04\x0c\x81\x85\x02\x96\x04\x0a\x81\x85\x02\x95"
  "\x04\x08\x81\x87\x02\x94\x04\x06\x81\x85\x02\x93\x04\x04\x84\x06"
  "\x13\x19\x30\x02\x1c\x01\x2f\x06\x48\x54\x54\x50\x2f\x11\x63\x68"
  "\x61\x72\x2d\x73\x65\x74\x3a\x6e\x75\x6d\x65\x72\x69\x63\x31\x0f"
  "\x73\x74\x72\x69\x6e\x67\x2d\x3e\x6e\x75\x6d\x62\x65\x72\x32\x12"
  "\x6d\x61\x6b\x65\x2d\x68\x74\x74\x70\x2d\x76\x65\x72\x73\x69\x6f"
  "\x6e\x33\x04\x03\x1a\x67\x65\x74\x2d\x70\x61\x72\x73\x65\x72\x2d"
  "\x62\x75\x66\x66\x65\x72\x2d\x70\x6f\x69\x6e\x74\x65\x72\x34\x04"
  "\x1b\x6d\x61\x74\x63\x68\x2d\x70\x61\x72\x73\x65\x72\x2d\x62\x75"
  "\x66\x66\x65\x72\x2d\x73\x74\x72\x69\x6e\x67\x04\x1b\x73\x65\x74"
  "\x2d\x70\x61\x72\x73\x65\x72\x2d\x62\x75\x66\x66\x65\x72\x2d\x70"
  "\x6f\x69\x6e\x74\x65\x72\x21\x35\x04\x20\x6d\x61\x74\x63\x68\x2d"
  "\x70\x61\x72\x73\x65\x72\x2d\x62\x75\x66\x66\x65\x72\x2d\x63\x68"
  "\x61\x72\x2d\x69\x6e\x2d\x73\x65\x74\x36\x04\x17\x67\x65\x74\x2d"
  "\x70\x61\x72\x73\x65\x72\x2d\x62\x75\x66\x66\x65\x72\x2d\x74\x61"
  "\x69\x6c\x37\x04\x0b\x76\x65\x63\x74\x6f\x72\x2d\x6d\x61\x70\x38"
  "\x04\x19\x6d\x61\x74\x63\x68\x2d\x70\x61\x72\x73\x65\x72\x2d\x62"
  "\x75\x66\x66\x65\x72\x2d\x63\x68\x61\x72\x39\x03\x0d\x76\x65\x63"
  "\x74\x6f\x72\x2d\x3e\x6c\x69\x73\x74\x3a\x04\x0e\x76\x65\x63\x74"
  "\x6f\x72\x2d\x61\x70\x70\x65\x6e\x64\x3b\x0a\xbe\x04\x48\x81\x85"
  "\x02\xbd\x04\x46\x81\x83\x02\xbc\x04\x44\x81\x89\x02\xbb\x04\x42"
  "\x81\x83\x02\xba\x04\x40\x81\x87\x02\xb9\x04\x3e\x81\x8d\x02\xb8"
  "\x04\x3c\x81\x89\x02\xb7\x04\x3a\x81\x89\x02\xb6\x04\x38\x81\x89"
  "\x02\xb5\x04\x36\x81\x8b\x02\xb4\x04\x34\x81\x87\x02\xb3\x04\x32"
  "\x81\x87\x02\xb2\x04\x30\x81\x87\x02\xb1\x04\x2e\x81\x89\x02\xb0"
  "\x04\x2c\x81\x85\x02\xaf\x04\x2a\x81\x85\x02\xae\x04\x28\x81\x85"
  "\x02\xad\x04\x26\x81\x89\x02\xac\x04\x24\x81\x83\x02\xab\x04\x22"
  "\x81\x83\x02\xaa\x04\x20\x81\x89\x02\xa9\x04\x1e\x81\x83\x02\xa8"
  "\x04\x1c\x81\x8b\x02\xa7\x04\x1a\x81\x89\x02\xa6\x04\x18\x81\x83"
  "\x02\xa5\x04\x16\x81\x87\x02\xa4\x04\x14\x81\x89\x02\xa3\x04\x12"
  "\x81\x83\x02\xa2\x04\x10\x81\x87\x02\xa1\x04\x0e\x81\x85\x02\xa0"
  "\x04\x0c\x81\x89\x02\x9f\x04\x0a\x81\x85\x02\x9e\x04\x08\x81\x85"
  "\x02\x9d\x04\x06\x81\x83\x02\x9c\x04\x04\x83\x04\x47\x64\x3c\x02"
  "\x1d\x02\x2e\x06\x48\x54\x54\x50\x2f\x04\x0d\x77\x72\x69\x74\x65"
  "\x2d\x73\x74\x72\x69\x6e\x67\x3d\x04\x06\x77\x72\x69\x74\x65\x3e"
  "\x03\xc4\x04\x0e\x81\x85\x02\xc3\x04\x0c\x81\x85\x02\xc2\x04\x0a"
  "\x81\x85\x02\xc1\x04\x08\x81\x89\x02\xc0\x04\x06\x81\x85\x02\xbf"
  "\x04\x04\x84\x06\x0d\x19\x3f\x02\x1e\x02\x11\x68\x74\x74\x70\x2d"
  "\x76\x65\x72\x73\x69\x6f\x6e\x3a\x31\x2e\x30\x40\x02\x04\x33\x02"
  "\xc7\x04\x08\x81\x81\x02\xc6\x04\x06\x81\x81\x02\xc5\x04\x04\x82"
  "\x02\x07\x12\x41\x02\x1f\x02\x11\x68\x74\x74\x70\x2d\x76\x65\x72"
  "\x73\x69\x6f\x6e\x3a\x31\x2e\x31\x42\x02\x04\x33\x02\xca\x04\x08"
  "\x81\x81\x02\xc9\x04\x06\x81\x81\x02\xc8\x04\x04\x82\x02\x07\x11"
  "\x43\x02\x20\xe9\x07\x03\x25\x02\xcc\x04\x06\x81\x83\x02\xcb\x04"
  "\x04\x83\x04\x05\x0d\x44\x02\x21\x02\x03\x0d\x68\x74\x74\x70\x2d"
  "\x73\x74\x61\x74\x75\x73\x3f\x45\x04\x16\x65\x72\x72\x6f\x72\x3a"
  "\x6e\x6f\x74\x2d\x68\x74\x74\x70\x2d\x73\x74\x61\x74\x75\x73\x46"
  "\x03\xce\x04\x06\x81\x85\x02\xcd\x04\x04\x84\x04\x05\x0e\x47\x02"
  "\x22\x08\x11\x48\x54\x54\x50\x20\x73\x74\x61\x74\x75\x73\x20\x63"
  "\x6f\x64\x65\x05\x2a\x02\xcf\x04\x04\x84\x04\x03\x0c\x48\x02\x23"
  "\x65\x04\x07\x6d\x6f\x64\x75\x6c\x6f\x02\xd0\x04\x04\x83\x04\x03"
  "\x0a\x49\x02\x24\x31\x32\x03\x03\x34\x04\x36\x04\x37\x04\x35\x04"
  "\x38\x06\xdb\x04\x18\x81\x83\x02\xda\x04\x16\x81\x85\x02\xd9\x04"
  "\x14\x81\x85\x02\xd8\x04\x12\x81\x87\x02\xd7\x04\x10\x81\x85\x02"
  "\xd6\x04\x0e\x81\x87\x02\xd5\x04\x0c\x81\x85\x02\xd4\x04\x0a\x81"
  "\x85\x02\xd3\x04\x08\x81\x87\x02\xd2\x04\x06\x81\x83\x02\xd1\x04"
  "\x04\x83\x04\x17\x28\x4a\x02\x25\x01\x31\x03\x0f\x6e\x75\x6d\x62"
  "\x65\x72\x2d\x3e\x73\x74\x72\x69\x6e\x67\x04\x3d\x05\x10\x73\x74"
  "\x72\x69\x6e\x67\x2d\x70\x61\x64\x2d\x6c\x65\x66\x74\x04\xde\x04"
  "\x08\x81\x8b\x02\xdd\x04\x06\x81\x85\x02\xdc\x04\x04\x84\x06\x07"
  "\x13\x4b\x02\x26\x02\x03\x0d\x68\x74\x74\x70\x2d\x68\x65\x61\x64"
  "\x65\x72\x3f\x4c\x04\x16\x65\x72\x72\x6f\x72\x3a\x6e\x6f\x74\x2d"
  "\x68\x74\x74\x70\x2d\x68\x65\x61\x64\x65\x72\x4d\x03\xe0\x04\x06"
  "\x81\x85\x02\xdf\x04\x04\x84\x04\x05\x0e\x4e\x02\x27\x08\x12\x48"
  "\x54\x54\x50\x20\x68\x65\x61\x64\x65\x72\x20\x66\x69\x65\x6c\x64"
  "\x05\x2a\x02\xe1\x04\x04\x84\x04\x03\x0c\x4f\x02\x28\x03\x11\x68"
  "\x74\x74\x70\x2d\x68\x65\x61\x64\x65\x72\x2d\x6e\x61\x6d\x65\x50"
  "\x02\xe3\x04\x06\x81\x83\x02\xe2\x04\x04\x83\x04\x05\x0c\x51\x02"
  "\x29\x0c\x25\x72\x65\x63\x6f\x72\x64\x2d\x72\x65\x66\x52\x11\x6d"
  "\x61\x6b\x65\x2d\x68\x74\x74\x70\x2d\x68\x65\x61\x64\x65\x72\x53"
  "\x04\x15\x67\x75\x61\x72\x61\x6e\x74\x65\x65\x2d\x68\x74\x74\x70"
  "\x2d\x74\x6f\x6b\x65\x6e\x54\x03\x12\x68\x65\x61\x64\x65\x72\x2d"
  "\x76\x61\x6c\x75\x65\x2d\x64\x65\x66\x6e\x55\x04\x14\x67\x75\x61"
  "\x72\x61\x6e\x74\x65\x65\x2d\x68\x74\x74\x70\x2d\x74\x65\x78\x74"
  "\x56\x03\x18\x63\x61\x6c\x6c\x2d\x77\x69\x74\x68\x2d\x6f\x75\x74"
  "\x70\x75\x74\x2d\x73\x74\x72\x69\x6e\x67\x57\x02\x10\x25\x75\x6e"
  "\x70\x61\x72\x73\x65\x64\x2d\x76\x61\x6c\x75\x65\x58\x05\x0d\x25"
  "\x6d\x61\x6b\x65\x2d\x68\x65\x61\x64\x65\x72\x59\x05\x0d\x25\x63"
  "\x61\x6c\x6c\x2d\x70\x61\x72\x73\x65\x72\x5a\x08\xf0\x04\x1c\x81"
  "\x87\x02\xef\x04\x1a\x81\x87\x02\xee\x04\x18\x81\x8d\x02\xed\x04"
  "\x16\x81\x87\x02\xec\x04\x14\x81\x85\x02\xeb\x04\x12\x81\x85\x02"
  "\xea\x04\x10\x81\x87\x02\xe9\x04\x0e\x81\x87\x02\xe8\x04\x0c\x81"
  "\x87\x02\xe7\x04\x0a\x81\x8b\x02\xe6\x04\x08\x81\x85\x02\xe5\x04"
  "\x06\x81\x85\x02\xe4\x04\x04\x84\x06\x1b\x33\x5b\x02\x2a\x04\x0f"
  "\x67\x75\x61\x72\x61\x6e\x74\x65\x65\x2d\x6c\x69\x73\x74\x04\x04"
  "\x6d\x61\x70\x5c\x03\x4c\x04\x53\x03\x0c\x68\x74\x74\x70\x2d\x74"
  "\x6f\x6b\x65\x6e\x3f\x5d\x04\x4d\x07\x83\x05\x28\x81\x87\x02\x82"
  "\x05\x26\x81\x87\x02\x81\x05\x24\x81\x85\x02\x80\x05\x22\x81\x85"
  "\x02\xff\x04\x20\x81\x85\x02\xfe\x04\x1e\x81\x85\x02\xfd\x04\x1c"
  "\x81\x85\x02\xfc\x04\x1a\x81\x85\x02\xfb\x04\x18\x81\x85\x02\xfa"
  "\x04\x16\x81\x85\x02\xf9\x04\x14\x81\x85\x02\xf8\x04\x12\x81\x85"
  "\x02\xf7\x04\x10\x81\x85\x02\xf6\x04\x0e\x81\x85\x02\xf5\x04\x0c"
  "\x81\x85\x02\xf4\x04\x0a\x81\x85\x02\xf3\x04\x08\x81\x85\x02\xf2"
  "\x04\x06\x81\x85\x02\xf1\x04\x04\x84\x04\x27\x3a\x5e\x02\x2b\x0d"
  "\x48\x54\x54\x50\x20\x68\x65\x61\x64\x65\x72\x73\x4c\x02\x06\x17"
  "\x67\x75\x61\x72\x61\x6e\x74\x65\x65\x2d\x6c\x69\x73\x74\x2d\x6f"
  "\x66\x2d\x74\x79\x70\x65\x02\x85\x05\x06\x81\x85\x02\x84\x05\x04"
  "\x84\x04\x05\x0e\x5f\x02\x2c\x0c\x68\x74\x74\x70\x2d\x68\x65\x61"
  "\x64\x65\x72\x60\x04\x05\x66\x69\x6e\x64\x04\x19\x65\x72\x72\x6f"
  "\x72\x3a\x62\x61\x64\x2d\x72\x61\x6e\x67\x65\x2d\x61\x72\x67\x75"
  "\x6d\x65\x6e\x74\x03\x50\x04\x8a\x05\x0c\x81\x85\x02\x89\x05\x0a"
  "\x81\x85\x02\x88\x05\x08\x81\x87\x02\x87\x05\x06\x81\x89\x02\x86"
  "\x05\x04\x85\x08\x0b\x17\x61\x02\x2d\x03\x11\x69\x6e\x74\x65\x72"
  "\x6e\x65\x64\x2d\x73\x79\x6d\x62\x6f\x6c\x3f\x03\x0c\x73\x79\x6d"
  "\x62\x6f\x6c\x2d\x6e\x61\x6d\x65\x62\x03\x16\x73\x74\x72\x69\x6e"
  "\x67\x2d\x69\x73\x2d\x68\x74\x74\x70\x2d\x74\x6f\x6b\x65\x6e\x3f"
  "\x63\x04\x8d\x05\x08\x81\x83\x02\x8c\x05\x06\x81\x83\x02\x8b\x05"
  "\x04\x83\x04\x07\x11\x64\x02\x2e\x02\x03\x5d\x04\x15\x65\x72\x72"
  "\x6f\x72\x3a\x6e\x6f\x74\x2d\x68\x74\x74\x70\x2d\x74\x6f\x6b\x65"
  "\x6e\x65\x03\x8f\x05\x06\x81\x85\x02\x8e\x05\x04\x84\x04\x05\x0e"
  "\x66\x02\x2f\x08\x0b\x48\x54\x54\x50\x20\x74\x6f\x6b\x65\x6e\x05"
  "\x2a\x02\x90\x05\x04\x84\x04\x03\x0c\x67\x02\x30\x03\x62\x04\x3d"
  "\x03\x92\x05\x06\x81\x85\x02\x91\x05\x04\x84\x06\x05\x0d\x68\x02"
  "\x31\x03\x63\x02\x93\x05\x04\x83\x04\x03\x69\x02\x32\x02\x03\x13"
  "\x68\x74\x74\x70\x2d\x74\x6f\x6b\x65\x6e\x2d\x73\x74\x72\x69\x6e"
  "\x67\x3f\x6a\x04\x1c\x65\x72\x72\x6f\x72\x3a\x6e\x6f\x74\x2d\x68"
  "\x74\x74\x70\x2d\x74\x6f\x6b\x65\x6e\x2d\x73\x74\x72\x69\x6e\x67"
  "\x6b\x03\x95\x05\x06\x81\x85\x02\x94\x05\x04\x84\x04\x05\x0e\x6c"
  "\x02\x33\x08\x12\x48\x54\x54\x50\x20\x74\x6f\x6b\x65\x6e\x20\x73"
  "\x74\x72\x69\x6e\x67\x05\x2a\x02\x96\x05\x04\x84\x04\x03\x0c\x6d"
  "\x02\x34\x11\x6d\x61\x74\x63\x68\x2d\x68\x74\x74\x70\x2d\x74\x6f"
  "\x6b\x65\x6e\x6e\x02\x04\x0e\x2a\x6d\x61\x74\x63\x68\x2d\x73\x74"
  "\x72\x69\x6e\x67\x6f\x02\x98\x05\x06\x81\x83\x02\x97\x05\x04\x83"
  "\x04\x05\x0d\x70\x02\x35\x07\x69\x6e\x74\x65\x72\x6e\x71\x02\x03"
  "\x34\x03\x6e\x04\x35\x04\x37\x04\x38\x06\x9e\x05\x0e\x81\x85\x02"
  "\x9d\x05\x0c\x81\x83\x02\x9c\x05\x0a\x81\x85\x02\x9b\x05\x08\x81"
  "\x85\x02\x9a\x05\x06\x81\x83\x02\x99\x05\x04\x83\x04\x0d\x1d\x72"
  "\x02\x36\x14\x63\x68\x61\x72\x2d\x73\x65\x74\x3a\x68\x74\x74\x70"
  "\x2d\x74\x6f\x6b\x65\x6e\x73\x02\x03\x34\x04\x36\x04\x35\x04\xa8"
  "\x05\x16\x81\x85\x02\xa7\x05\x14\x81\x85\x02\xa6\x05\x12\x81\x87"
  "\x02\xa5\x05\x10\x81\x83\x02\xa4\x05\x0e\x81\x85\x02\xa3\x05\x0c"
  "\x81\x83\x02\xa2\x05\x0a\x81\x85\x02\xa1\x05\x08\x81\x87\x02\xa0"
  "\x05\x06\x81\x83\x02\x9f\x05\x04\x83\x04\x15\x22\x74\x02\x37\xa9"
  "\x05\x04\x83\x04\x03\x75\x02\x38\x02\x03\x0b\x68\x74\x74\x70\x2d"
  "\x74\x65\x78\x74\x3f\x76\x04\x14\x65\x72\x72\x6f\x72\x3a\x6e\x6f"
  "\x74\x2d\x68\x74\x74\x70\x2d\x74\x65\x78\x74\x77\x03\xab\x05\x06"
  "\x81\x85\x02\xaa\x05\x04\x84\x04\x05\x0e\x78\x02\x39\x08\x0a\x48"
  "\x54\x54\x50\x20\x74\x65\x78\x74\x05\x2a\x02\xac\x05\x04\x84\x04"
  "\x03\x0c\x79\x02\x3a\x01\x23\x15\x63\x68\x61\x72\x2d\x73\x65\x74"
  "\x3a\x68\x74\x74\x70\x2d\x71\x64\x74\x65\x78\x74\x7a\x02\x04\x0b"
  "\x77\x72\x69\x74\x65\x2d\x63\x68\x61\x72\x7b\x05\x17\x25\x77\x72"
  "\x69\x74\x65\x2d\x77\x69\x74\x68\x2d\x71\x75\x6f\x74\x61\x74\x69"
  "\x6f\x6e\x73\x7c\x03\xb0\x05\x0a\x81\x85\x02\xaf\x05\x08\x81\x89"
  "\x02\xae\x05\x06\x81\x85\x02\xad\x05\x04\x84\x06\x09\x14\x7d\x02"
  "\x3b\x01\x5d\x0b\x73\x74\x72\x69\x6e\x67\x2d\x72\x65\x66\x7e\x0e"
  "\x73\x74\x72\x69\x6e\x67\x2d\x6c\x65\x6e\x67\x74\x68\x7f\x04\x11"
  "\x63\x68\x61\x72\x2d\x73\x65\x74\x2d\x6d\x65\x6d\x62\x65\x72\x3f"
  "\x80\x01\x04\x7b\x03\xb7\x05\x10\x81\x83\x02\xb6\x05\x0e\x81\x83"
  "\x02\xb5\x05\x0c\x81\x8b\x02\xb4\x05\x0a\x81\x8d\x02\xb3\x05\x08"
  "\x81\x8b\x02\xb2\x05\x06\x81\x87\x02\xb1\x05\x04\x85\x08\x0f\x1c"
  "\x81\x01\x02\x3c\x01\x2a\x01\x29\x03\x12\x6f\x70\x65\x6e\x2d\x69"
  "\x6e\x70\x75\x74\x2d\x73\x74\x72\x69\x6e\x67\x82\x01\x03\x0a\x72"
  "\x65\x61\x64\x2d\x63\x68\x61\x72\x83\x01\x03\x0c\x65\x6f\x66\x2d"
  "\x6f\x62\x6a\x65\x63\x74\x3f\x84\x01\x04\xbe\x05\x10\x81\x87\x02"
  "\xbd\x05\x0e\x81\x87\x02\xbc\x05\x0c\x81\x87\x02\xbb\x05\x0a\x81"
  "\x85\x02\xba\x05\x08\x81\x85\x02\xb9\x05\x06\x81\x83\x02\xb8\x05"
  "\x04\x83\x04\x0f\x1d\x85\x01\x02\x3d\x01\x2a\x01\x29\x13\x63\x68"
  "\x61\x72\x2d\x73\x65\x74\x3a\x68\x74\x74\x70\x2d\x74\x65\x78\x74"
  "\x86\x01\x02\x04\x7b\x05\x7c\x03\xc2\x05\x0a\x81\x85\x02\xc1\x05"
  "\x08\x81\x89\x02\xc0\x05\x06\x81\x85\x02\xbf\x05\x04\x84\x06\x09"
  "\x15\x87\x01\x02\x3e\x03\x19\x72\x65\x61\x64\x2d\x72\x66\x63\x32"
  "\x38\x32\x32\x2d\x66\x6f\x6c\x64\x65\x64\x2d\x6c\x69\x6e\x65\x03"
  "\x09\x72\x65\x76\x65\x72\x73\x65\x21\x03\x0d\x70\x61\x72\x73\x65"
  "\x2d\x68\x65\x61\x64\x65\x72\x88\x01\x04\xc6\x05\x0a\x81\x87\x02"
  "\xc5\x05\x08\x81\x85\x02\xc4\x05\x06\x81\x85\x02\xc3\x05\x04\x83"
  "\x04\x09\x14\x89\x01\x02\x3f\x1e\x49\x6c\x6c\x2d\x66\x6f\x72\x6d"
  "\x65\x64\x20\x48\x54\x54\x50\x20\x68\x65\x61\x64\x65\x72\x20\x76"
  "\x61\x6c\x75\x65\x3a\x04\x05\x77\x61\x72\x6e\x04\x1e\x02\x58\x04"
  "\xca\x05\x0a\x81\x83\x02\xc9\x05\x08\x83\x04\xc8\x05\x06\x81\x83"
  "\x02\xc7\x05\x04\x85\x08\x09\x14\x8a\x01\x02\x40\x02\x0f\x64\x65"
  "\x66\x61\x75\x6c\x74\x2d\x6f\x62\x6a\x65\x63\x74\x02\xcb\x05\x04"
  "\x82\x02\x03\x8b\x01\x02\x41\x52\x03\x3a\x20\x13\x77\x72\x69\x74"
  "\x65\x2d\x68\x74\x74\x70\x2d\x68\x65\x61\x64\x65\x72\x73\x8c\x01"
  "\x04\x17\x67\x75\x61\x72\x61\x6e\x74\x65\x65\x2d\x68\x74\x74\x70"
  "\x2d\x68\x65\x61\x64\x65\x72\x73\x8d\x01\x04\x17\x03\x08\x6e\x65"
  "\x77\x6c\x69\x6e\x65\x03\x50\x04\x3d\x03\x55\x03\x12\x68\x74\x74"
  "\x70\x2d\x68\x65\x61\x64\x65\x72\x2d\x76\x61\x6c\x75\x65\x8e\x01"
  "\x04\x23\x09\xd6\x05\x18\x81\x89\x02\xd5\x05\x16\x81\x85\x02\xd4"
  "\x05\x14\x81\x85\x02\xd3\x05\x12\x81\x83\x02\xd2\x05\x10\x81\x85"
  "\x02\xd1\x05\x0e\x81\x87\x02\xd0\x05\x0c\x81\x85\x02\xcf\x05\x0a"
  "\x81\x85\x02\xce\x05\x08\x81\x85\x02\xcd\x05\x06\x81\x85\x02\xcc"
  "\x05\x04\x84\x06\x17\x2f\x8f\x01\x02\x42\x71\x02\x05\x10\x6c\x70"
  "\x3a\x74\x6f\x6b\x65\x6e\x2d\x73\x74\x72\x69\x6e\x67\x90\x01\x04"
  "\x1c\x6d\x61\x70\x2d\x73\x74\x72\x75\x63\x74\x75\x72\x65\x2d\x70"
  "\x61\x72\x73\x65\x72\x2d\x76\x61\x6c\x75\x65\x73\x91\x01\x03\xda"
  "\x05\x0a\x81\x89\x02\xd9\x05\x08\x81\x8d\x02\xd8\x05\x06\x81\x89"
  "\x02\xd7\x05\x04\x85\x08\x09\x13\x92\x01\x02\x43\x14\x74\x6f\x6b"
  "\x65\x6e\x2d\x74\x6f\x6b\x65\x6e\x2d\x3e\x73\x74\x72\x69\x6e\x67"
  "\x93\x01\x02\x04\x91\x01\x03\x0d\x74\x6f\x6b\x65\x6e\x2d\x74\x6f"
  "\x6b\x65\x6e\x3f\x94\x01\x03\xe1\x05\x10\x81\x89\x02\xe0\x05\x0e"
  "\x81\x89\x02\xdf\x05\x0c\x81\x89\x02\xde\x05\x0a\x85\x08\xdd\x05"
  "\x08\x81\x8d\x02\xdc\x05\x06\x81\x8b\x02\xdb\x05\x04\x81\x87\x02"
  "\x0f\x1c\x95\x01\x02\x44\x05\x90\x01\x05\x11\x6c\x70\x3a\x71\x75"
  "\x6f\x74\x65\x64\x2d\x73\x74\x72\x69\x6e\x67\x96\x01\x03\xe4\x05"
  "\x08\x81\x83\x02\xe3\x05\x06\x81\x83\x02\xe2\x05\x04\x85\x08\x07"
  "\x0f\x97\x01\x02\x45\x1c\x71\x75\x6f\x74\x65\x64\x2d\x73\x74\x72"
  "\x69\x6e\x67\x2d\x74\x6f\x6b\x65\x6e\x2d\x3e\x73\x74\x72\x69\x6e"
  "\x67\x98\x01\x02\x04\x91\x01\x03\x15\x71\x75\x6f\x74\x65\x64\x2d"
  "\x73\x74\x72\x69\x6e\x67\x2d\x74\x6f\x6b\x65\x6e\x3f\x99\x01\x03"
  "\xeb\x05\x10\x81\x89\x02\xea\x05\x0e\x81\x89\x02\xe9\x05\x0c\x81"
  "\x89\x02\xe8\x05\x0a\x85\x08\xe7\x05\x08\x81\x8d\x02\xe6\x05\x06"
  "\x81\x8b\x02\xe5\x05\x04\x81\x87\x02\x0f\x1c\x9a\x01\x02\x46\x16"
  "\x63\x6f\x6d\x6d\x65\x6e\x74\x2d\x74\x6f\x6b\x65\x6e\x2d\x3e\x73"
  "\x74\x72\x69\x6e\x67\x9b\x01\x02\x04\x91\x01\x03\x0f\x63\x6f\x6d"
  "\x6d\x65\x6e\x74\x2d\x74\x6f\x6b\x65\x6e\x3f\x9c\x01\x03\xf2\x05"
  "\x10\x81\x89\x02\xf1\x05\x0e\x81\x89\x02\xf0\x05\x0c\x81\x89\x02"
  "\xef\x05\x0a\x85\x08\xee\x05\x08\x81\x8d\x02\xed\x05\x06\x81\x8b"
  "\x02\xec\x05\x04\x81\x87\x02\x0f\x1c\x9d\x01\x02\x47\x01\x21\x04"
  "\x05\x65\x71\x76\x3f\x9e\x01\x02\xf6\x05\x0a\x81\x8b\x02\xf5\x05"
  "\x08\x85\x08\xf4\x05\x06\x81\x89\x02\xf3\x05\x04\x81\x87\x02\x09"
  "\x13\x9f\x01\x02\x48\x03\x2a\x3f\xa0\x01\x02\x05\x09\x6c\x70\x3a"
  "\x74\x6f\x6b\x65\x6e\xa1\x01\x03\x03\xfb\x05\x0c\x81\x8d\x02\xfa"
  "\x05\x0a\x81\x8b\x02\xf9\x05\x08\x81\x89\x02\xf8\x05\x06\x81\x89"
  "\x02\xf7\x05\x04\x85\x08\x0b\x16\xa2\x01\x02\x49\x02\x05\x0d\x6c"
  "\x70\x3a\x73\x65\x6d\x69\x63\x6f\x6c\x6f\x6e\xa3\x01\x03\x05\x0d"
  "\x6c\x70\x3a\x70\x61\x72\x61\x6d\x65\x74\x65\x72\xa4\x01\x04\x83"
  "\x06\x12\x81\x89\x02\x82\x06\x10\x81\x87\x02\x81\x06\x0e\x81\x85"
  "\x02\x80\x06\x0c\x81\x83\x02\xff\x05\x0a\x81\x89\x02\xfe\x05\x08"
  "\x81\x83\x02\xfd\x05\x06\x81\x89\x02\xfc\x05\x04\x85\x08\x11\x20"
  "\xa5\x01\x02\x4a\x05\x63\x6f\x6e\x73\xa6\x01\x02\x05\xa1\x01\x05"
  "\x05\x6c\x70\x3a\x3d\xa7\x01\x05\x08\x6c\x70\x3a\x74\x65\x78\x74"
  "\xa8\x01\x03\x05\x8a\x06\x10\x81\x8d\x02\x89\x06\x0e\x81\x8b\x02"
  "\x88\x06\x0c\x81\x89\x02\x87\x06\x0a\x81\x89\x02\x86\x06\x08\x81"
  "\x89\x02\x85\x06\x06\x81\x89\x02\x84\x06\x04\x85\x08\x0f\x1f\xa9"
  "\x01\x02\x4b\xa6\x01\x02\x05\xa1\x01\x05\xa7\x01\x03\x05\xa8\x01"
  "\x05\x94\x06\x16\x81\x83\x02\x93\x06\x14\x81\x89\x02\x92\x06\x12"
  "\x81\x8d\x02\x91\x06\x10\x81\x8b\x02\x90\x06\x0e\x81\x89\x02\x8f"
  "\x06\x0c\x81\x83\x02\x8e\x06\x0a\x81\x89\x02\x8d\x06\x08\x81\x89"
  "\x02\x8c\x06\x06\x81\x89\x02\x8b\x06\x04\x85\x08\x15\x25\xaa\x01"
  "\x02\x4c\x01\x3e\x05\x02\x9e\x06\x16\x81\x83\x02\x9d\x06\x14\x81"
  "\x83\x02\x9c\x06\x12\x81\x85\x02\x9b\x06\x10\x81\x83\x02\x9a\x06"
  "\x0e\x81\x89\x02\x99\x06\x0c\x81\x83\x02\x98\x06\x0a\x81\x8b\x02"
  "\x97\x06\x08\x81\x89\x02\x96\x06\x06\x81\x89\x02\x95\x06\x04\x85"
  "\x08\x15\x1f\xab\x01\x02\x4d\x01\x3c\x05\x02\xa8\x06\x16\x81\x83"
  "\x02\xa7\x06\x14\x81\x83\x02\xa6\x06\x12\x81\x85\x02\xa5\x06\x10"
  "\x81\x83\x02\xa4\x06\x0e\x81\x89\x02\xa3\x06\x0c\x81\x83\x02\xa2"
  "\x06\x0a\x81\x8b\x02\xa1\x06\x08\x81\x89\x02\xa0\x06\x06\x81\x89"
  "\x02\x9f\x06\x04\x85\x08\x15\x1f\xac\x01\x02\x4e\x11\x68\x74\x74"
  "\x70\x2d\x70\x61\x72\x61\x6d\x65\x74\x65\x72\x73\x3f\xad\x01\x02"
  "\x04\x0f\x70\x61\x69\x72\x2d\x70\x72\x65\x64\x69\x63\x61\x74\x65"
  "\xae\x01\x02\xaa\x06\x06\x81\x85\x02\xa9\x06\x04\x83\x04\x05\x0d"
  "\xaf\x01\x02\x4f\x10\x77\x72\x69\x74\x65\x2d\x70\x61\x72\x61\x6d"
  "\x65\x74\x65\x72\xb0\x01\x02\x04\x1a\x05\x0c\x70\x61\x69\x72\x2d"
  "\x77\x72\x69\x74\x65\x72\xb1\x01\x03\x1f\x04\xae\x06\x0a\x81\x89"
  "\x02\xad\x06\x08\x81\x87\x02\xac\x06\x06\x81\x8b\x02\xab\x06\x04"
  "\x84\x06\x09\x15\xb2\x01\x02\x50\xa6\x01\x02\x05\xa1\x01\x05\x0e"
  "\x6c\x70\x3a\x70\x61\x72\x61\x6d\x65\x74\x65\x72\x73\xb3\x01\x03"
  "\x04\xb4\x06\x0e\x81\x8d\x02\xb3\x06\x0c\x81\x8b\x02\xb2\x06\x0a"
  "\x81\x89\x02\xb1\x06\x08\x81\x89\x02\xb0\x06\x06\x81\x89\x02\xaf"
  "\x06\x04\x85\x08\x0d\x1b\xb4\x01\x02\x51\x02\x71\x03\x0b\x70\x61"
  "\x72\x61\x6d\x65\x74\x65\x72\x3f\xb5\x01\x02\xb7\x06\x08\x81\x83"
  "\x02\xb6\x06\x06\x81\x83\x02\xb5\x06\x04\x83\x04\x07\x10\xb6\x01"
  "\x02\x52\x08\x71\x70\x61\x72\x61\x6d\x3f\xb7\x01\x03\x05\xa1\x01"
  "\x05\xa3\x01\x03\x05\xa4\x01\x05\xc4\x06\x1c\x81\x8d\x02\xc3\x06"
  "\x1a\x81\x8b\x02\xc2\x06\x18\x81\x89\x02\xc1\x06\x16\x81\x83\x02"
  "\xc0\x06\x14\x81\x89\x02\xbf\x06\x12\x81\x8d\x02\xbe\x06\x10\x81"
  "\x8b\x02\xbd\x06\x0e\x81\x89\x02\xbc\x06\x0c\x81\x83\x02\xbb\x06"
  "\x0a\x81\x89\x02\xba\x06\x08\x81\x89\x02\xb9\x06\x06\x81\x89\x02"
  "\xb8\x06\x04\x85\x08\x1b\x2d\xb8\x01\x02\x53\x03\xb7\x01\x02\xc8"
  "\x06\x0a\x81\x83\x02\xc7\x06\x08\x81\x83\x02\xc6\x06\x06\x81\x85"
  "\x02\xc5\x06\x04\x83\x04\x09\x13\xb9\x01\x02\x54\xb7\x01\x03\x05"
  "\xa3\x01\x05\xa4\x01\x03\x05\x0e\x6c\x70\x3a\x70\x61\x72\x61\x6d"
  "\x65\x74\x65\x72\x25\xba\x01\x05\xdf\x06\x30\x81\x89\x02\xde\x06"
  "\x2e\x81\x89\x02\xdd\x06\x2c\x81\x83\x02\xdc\x06\x2a\x81\x89\x02"
  "\xdb\x06\x28\x81\x8d\x02\xda\x06\x26\x81\x8b\x02\xd9\x06\x24\x81"
  "\x89\x02\xd8\x06\x22\x81\x8d\x02\xd7\x06\x20\x81\x8b\x02\xd6\x06"
  "\x1e\x81\x89\x02\xd5\x06\x1c\x81\x89\x02\xd4\x06\x1a\x81\x83\x02"
  "\xd3\x06\x18\x81\x8d\x02\xd2\x06\x16\x81\x8b\x02\xd1\x06\x14\x81"
  "\x89\x02\xd0\x06\x12\x81\x89\x02\xcf\x06\x10\x81\x89\x02\xce\x06"
  "\x0e\x81\x83\x02\xcd\x06\x0c\x81\x89\x02\xcc\x06\x0a\x81\x89\x02"
  "\xcb\x06\x08\x81\x83\x02\xca\x06\x06\x81\x89\x02\xc9\x06\x04\x85"
  "\x08\x2f\x41\xbb\x01\x02\x55\x0c\x70\x61\x72\x61\x6d\x65\x74\x65"
  "\x72\x25\x3f\xbc\x01\x02\x03\x06\x6c\x69\x73\x74\x3f\x03\xb5\x01"
  "\x03\xb7\x01\x04\x15\x05\xe9\x06\x16\x81\x85\x02\xe8\x06\x14\x81"
  "\x83\x02\xe7\x06\x12\x81\x83\x02\xe6\x06\x10\x81\x83\x02\xe5\x06"
  "\x0e\x81\x85\x02\xe4\x06\x0c\x81\x83\x02\xe3\x06\x0a\x81\x85\x02"
  "\xe2\x06\x08\x81\x83\x02\xe1\x06\x06\x81\x83\x02\xe0\x06\x04\x83"
  "\x04\x15\x26\x15\x02\x56\xed\x06\x0a\x81\x85\x02\xec\x06\x08\x81"
  "\x83\x02\xeb\x06\x06\x81\x83\x02\xea\x06\x04\x83\x04\x09\x10\xbd"
  "\x01\x02\x57\x05\x90\x01\x03\x03\x1e\x6c\x69\x73\x74\x2d\x3e\x73"
  "\x74\x72\x75\x63\x74\x75\x72\x65\x2d\x70\x61\x72\x73\x65\x72\x2d"
  "\x76\x61\x6c\x75\x65\x73\xbe\x01\x05\x32\x05\xf5\x06\x12\x81\x85"
  "\x02\xf4\x06\x10\x81\x85\x02\xf3\x06\x0e\x81\x8b\x02\xf2\x06\x0c"
  "\x81\x8b\x02\xf1\x06\x0a\x81\x89\x02\xf0\x06\x08\x81\x89\x02\xef"
  "\x06\x06\x81\x89\x02\xee\x06\x04\x83\x04\x11\x1f\x32\x02\x58\x02"
  "\x04\x3e\x02\xf6\x06\x04\x84\x06\x03\x0a\xbf\x01\x02\x59\x01\x30"
  "\x0f\x6d\x61\x6b\x65\x2d\x6d\x69\x6d\x65\x2d\x74\x79\x70\x65\xc0"
  "\x01\x02\x05\xa1\x01\x03\x03\xfe\x06\x12\x81\x8d\x02\xfd\x06\x10"
  "\x81\x8b\x02\xfc\x06\x0e\x81\x89\x02\xfb\x06\x0c\x81\x89\x02\xfa"
  "\x06\x0a\x81\x89\x02\xf9\x06\x08\x81\x89\x02\xf8\x06\x06\x81\x89"
  "\x02\xf7\x06\x04\x85\x08\x11\x20\xc1\x01\x02\x5a\x02\x11\x70\x61"
  "\x72\x73\x65\x72\x3a\x68\x74\x74\x70\x2d\x64\x61\x74\x65\xc2\x01"
  "\x02\x12\x64\x65\x63\x6f\x64\x65\x64\x2d\x74\x69\x6d\x65\x2d\x3e"
  "\x75\x74\x63\x02\x03\x0d\x70\x61\x72\x73\x65\x72\x3a\x63\x74\x69"
  "\x6d\x65\x03\x34\x03\x14\x70\x61\x72\x73\x65\x72\x3a\x72\x66\x63"
  "\x32\x38\x32\x32\x2d\x74\x69\x6d\x65\x04\x35\x04\x38\x03\x13\x70"
  "\x61\x72\x73\x65\x72\x3a\x72\x66\x63\x38\x35\x30\x2d\x74\x69\x6d"
  "\x65\x07\x8c\x07\x1e\x81\x89\x02\x8b\x07\x1c\x81\x8b\x02\x8a\x07"
  "\x1a\x81\x8b\x02\x89\x07\x18\x81\x8b\x02\x88\x07\x16\x81\x8b\x02"
  "\x87\x07\x14\x81\x83\x02\x86\x07\x12\x81\x83\x02\x85\x07\x10\x81"
  "\x89\x02\x84\x07\x0e\x81\x87\x02\x83\x07\x0c\x81\x85\x02\x82\x07"
  "\x0a\x81\x85\x02\x81\x07\x08\x81\x81\x02\x80\x07\x06\x81\x81\x02"
  "\xff\x06\x04\x82\x02\x1d\x33\x38\x02\x5b\x03\x0e\x64\x65\x63\x6f"
  "\x64\x65\x64\x2d\x74\x69\x6d\x65\x3f\xc3\x01\x03\x12\x64\x65\x63"
  "\x6f\x64\x65\x64\x2d\x74\x69\x6d\x65\x2f\x7a\x6f\x6e\x65\x04\x9e"
  "\x01\x04\x8f\x07\x08\x81\x83\x02\x8e\x07\x06\x81\x83\x02\x8d\x07"
  "\x04\x83\x04\x07\x12\xc4\x01\x02\x5c\x04\x1b\x77\x72\x69\x74\x65"
  "\x2d\x64\x65\x63\x6f\x64\x65\x64\x2d\x74\x69\x6d\x65\x2d\x61\x73"
  "\x2d\x68\x74\x74\x70\x02\x90\x07\x04\x84\x06\x03\xc5\x01\x02\x5d"
  "\x11\x02\x3a\x01\x3b\x0f\x70\x61\x72\x73\x65\x2d\x68\x6f\x73\x74"
  "\x70\x6f\x72\x74\xc6\x01\x02\x05\x90\x01\x03\x03\xbe\x01\x04\x0e"
  "\x2a\x70\x61\x72\x73\x65\x2d\x73\x74\x72\x69\x6e\x67\xc7\x01\x05"
  "\x0e\x73\x74\x72\x69\x6e\x67\x2d\x61\x70\x70\x65\x6e\x64\x06\xa0"
  "\x07\x22\x81\x83\x02\x9f\x07\x20\x81\x85\x02\x9e\x07\x1e\x81\x89"
  "\x02\x9d\x07\x1c\x84\x06\x9c\x07\x1a\x81\x87\x02\x9b\x07\x18\x81"
  "\x8b\x02\x9a\x07\x16\x81\x83\x02\x99\x07\x14\x81\x8b\x02\x98\x07"
  "\x12\x81\x89\x02\x97\x07\x10\x81\x89\x02\x96\x07\x0e\x81\x83\x02"
  "\x95\x07\x0c\x81\x89\x02\x94\x07\x0a\x81\x8d\x02\x93\x07\x08\x81"
  "\x8d\x02\x92\x07\x06\x81\x89\x02\x91\x07\x04\x85\x08\x21\x3a\xc8"
  "\x01\x02\x5e\xa6\x01\x02\x03\x34\x03\x13\x75\x72\x6c\x3a\x70\x61"
  "\x72\x73\x65\x3a\x68\x6f\x73\x74\x70\x6f\x72\x74\x04\x35\x03\x3a"
  "\x05\xa7\x07\x10\x81\x87\x02\xa6\x07\x0e\x81\x85\x02\xa5\x07\x0c"
  "\x81\x87\x02\xa4\x07\x0a\x81\x83\x02\xa3\x07\x08\x81\x85\x02\xa2"
  "\x07\x06\x81\x83\x02\xa1\x07\x04\x83\x04\x0f\x1e\xc9\x01\x02\x5f"
  "\x05\x0c\x6c\x70\x3a\x68\x6f\x73\x74\x70\x6f\x72\x74\xca\x01\x05"
  "\xa1\x01\x03\xaa\x07\x08\x81\x83\x02\xa9\x07\x06\x81\x83\x02\xa8"
  "\x07\x04\x85\x08\x07\x0f\xcb\x01\x02\x60\x08\x01\x2e\x0f\x63\x68"
  "\x61\x72\x2d\x73\x65\x74\x3a\x61\x6c\x70\x68\x61\xcc\x01\x02\x03"
  "\x5d\x03\x62\x03\x34\x04\x6f\x04\x35\x04\x36\x04\x39\x08\xc2\x07"
  "\x32\x81\x85\x02\xc1\x07\x30\x81\x85\x02\xc0\x07\x2e\x81\x85\x02"
  "\xbf\x07\x2c\x81\x85\x02\xbe\x07\x2a\x81\x85\x02\xbd\x07\x28\x81"
  "\x87\x02\xbc\x07\x26\x81\x87\x02\xbb\x07\x24\x81\x85\x02\xba\x07"
  "\x22\x81\x85\x02\xb9\x07\x20\x81\x85\x02\xb8\x07\x1e\x81\x85\x02"
  "\xb7\x07\x1c\x81\x85\x02\xb6\x07\x1a\x81\x83\x02\xb5\x07\x18\x81"
  "\x87\x02\xb4\x07\x16\x81\x83\x02\xb3\x07\x14\x81\x85\x02\xb2\x07"
  "\x12\x81\x83\x02\xb1\x07\x10\x81\x83\x02\xb0\x07\x0e\x81\x85\x02"
  "\xaf\x07\x0c\x81\x83\x02\xae\x07\x0a\x81\x85\x02\xad\x07\x08\x83"
  "\x04\xac\x07\x06\x81\x83\x02\xab\x07\x04\x83\x04\x31\x49\x6f\x02"
  "\x61\x02\x57\x01\x30\xa6\x01\x02\x05\x90\x01\x05\x96\x01\x03\x04"
  "\x91\x01\x04\x09\x73\x74\x72\x69\x6e\x67\x3d\x3f\x06\xd2\x07\x22"
  "\x83\x04\xd1\x07\x20\x83\x04\xd0\x07\x1e\x81\x89\x02\xcf\x07\x1c"
  "\x81\x8d\x02\xce\x07\x1a\x81\x8b\x02\xcd\x07\x18\x81\x89\x02\xcc"
  "\x07\x16\x81\x83\x02\xcb\x07\x14\x81\x8b\x02\xca\x07\x12\x81\x89"
  "\x02\xc9\x07\x10\x81\x89\x02\xc8\x07\x0e\x81\x89\x02\xc7\x07\x0c"
  "\x81\x89\x02\xc6\x07\x0a\x81\x83\x02\xc5\x07\x08\x81\x89\x02\xc4"
  "\x07\x06\x81\x89\x02\xc3\x07\x04\x85\x08\x21\x38\x91\x01\x02\x62"
  "\x03\x57\x2f\x02\x04\x3d\x02\xd3\x07\x04\x84\x06\x03\x0b\x62\x02"
  "\x63\x0c\x62\x79\x74\x65\x73\x2d\x75\x6e\x69\x74\x3f\xcd\x01\x02"
  "\x05\xa1\x01\x03\x03\xd8\x07\x0c\x81\x8d\x02\xd7\x07\x0a\x81\x8b"
  "\x02\xd6\x07\x08\x81\x89\x02\xd5\x07\x06\x81\x89\x02\xd4\x07\x04"
  "\x85\x08\x0b\x16\xce\x01\x02\x64\xe0\x07\x12\x81\x83\x02\xdf\x07"
  "\x10\x81\x85\x02\xde\x07\x0e\x81\x83\x02\xdd\x07\x0c\x81\x83\x02"
  "\xdc\x07\x0a\x81\x83\x02\xdb\x07\x08\x81\x83\x02\xda\x07\x06\x81"
  "\x83\x02\xd9\x07\x04\x83\x04\x11\x17\xcf\x01\x02\x65\x01\x2e\x11"
  "\x62\x79\x74\x65\x2d\x72\x61\x6e\x67\x65\x2d\x73\x70\x65\x63\x3f"
  "\xd0\x01\x31\xa6\x01\x04\x05\x90\x01\x03\x03\xbe\x01\x03\x12\x2a"
  "\x70\x61\x72\x73\x65\x72\x2d\x74\x72\x61\x6e\x73\x66\x6f\x72\x6d"
  "\x31\x03\x34\x04\x39\x04\x35\x04\x37\x04\x36\x04\x3b\x03\x3a\x0c"
  "\x87\x08\x50\x81\x85\x02\x86\x08\x4e\x81\x85\x02\x85\x08\x4c\x81"
  "\x85\x02\x84\x08\x4a\x81\x83\x02\x83\x08\x48\x81\x8b\x02\x82\x08"
  "\x46\x81\x89\x02\x81\x08\x44\x81\x87\x02\x80\x08\x42\x81\x83\x02"
  "\xff\x07\x40\x81\x89\x02\xfe\x07\x3e\x81\x85\x02\xfd\x07\x3c\x81"
  "\x83\x02\xfc\x07\x3a\x81\x83\x02\xfb\x07\x38\x81\x89\x02\xfa\x07"
  "\x36\x81\x89\x02\xf9\x07\x34\x81\x85\x02\xf8\x07\x32\x81\x83\x02"
  "\xf7\x07\x30\x81\x89\x02\xf6\x07\x2e\x81\x87\x02\xf5\x07\x2c\x81"
  "\x83\x02\xf4\x07\x2a\x81\x8d\x02\xf3\x07\x28\x81\x83\x02\xf2\x07"
  "\x26\x81\x87\x02\xf1\x07\x24\x81\x83\x02\xf0\x07\x22\x81\x8b\x02"
  "\xef\x07\x20\x81\x83\x02\xee\x07\x1e\x81\x87\x02\xed\x07\x1c\x81"
  "\x87\x02\xec\x07\x1a\x81\x87\x02\xeb\x07\x18\x81\x83\x02\xea\x07"
  "\x16\x81\x8f\x02\xe9\x07\x14\x81\x8d\x02\xe8\x07\x12\x81\x8b\x02"
  "\xe7\x07\x10\x83\x04\xe6\x07\x0e\x81\x8d\x02\xe5\x07\x0c\x81\x8b"
  "\x02\xe4\x07\x0a\x81\x8b\x02\xe3\x07\x08\x81\x89\x02\xe2\x07\x06"
  "\x81\x89\x02\xe1\x07\x04\x85\x08\x4f\x70\xd1\x01\x02\x66\xa6\x01"
  "\x02\x05\x90\x01\x05\x0b\x6c\x70\x3a\x73\x6f\x6c\x69\x64\x75\x73"
  "\xd2\x01\x03\x04\x91\x08\x16\x81\x83\x02\x90\x08\x14\x81\x89\x02"
  "\x8f\x08\x12\x81\x8d\x02\x8e\x08\x10\x81\x8b\x02\x8d\x08\x0e\x81"
  "\x89\x02\x8c\x08\x0c\x81\x83\x02\x8b\x08\x0a\x81\x89\x02\x8a\x08"
  "\x08\x81\x89\x02\x89\x08\x06\x81\x89\x02\x88\x08\x04\x85\x08\x15"
  "\x23\xd3\x01\x02\x67\x01\x30\x05\x02\x9b\x08\x16\x81\x83\x02\x9a"
  "\x08\x14\x81\x83\x02\x99\x08\x12\x81\x85\x02\x98\x08\x10\x81\x83"
  "\x02\x97\x08\x0e\x81\x89\x02\x96\x08\x0c\x81\x83\x02\x95\x08\x0a"
  "\x81\x8b\x02\x94\x08\x08\x81\x89\x02\x93\x08\x06\x81\x89\x02\x92"
  "\x08\x04\x85\x08\x15\x1f\xd4\x01\x02\x68\x02\x05\x0b\x6c\x70\x3a"
  "\x70\x72\x6f\x64\x75\x63\x74\xd5\x01\x05\x0b\x6c\x70\x3a\x63\x6f"
  "\x6d\x6d\x65\x6e\x74\xd6\x01\x05\x03\x05\xa9\x08\x1e\x81\x87\x02"
  "\xa8\x08\x1c\x81\x85\x02\xa7\x08\x1a\x81\x83\x02\xa6\x08\x18\x81"
  "\x83\x02\xa5\x08\x16\x81\x83\x02\xa4\x08\x14\x81\x83\x02\xa3\x08"
  "\x12\x81\x89\x02\xa2\x08\x10\x81\x83\x02\xa1\x08\x0e\x81\x89\x02"
  "\xa0\x08\x0c\x81\x83\x02\x9f\x08\x0a\x81\x89\x02\x9e\x08\x08\x81"
  "\x83\x02\x9d\x08\x06\x81\x89\x02\x9c\x08\x04\x85\x08\x1d\x2e\xd7"
  "\x01\x02\x69\x01\x21\x02\x0e\x77\x72\x69\x74\x65\x2d\x63\x6f\x6d"
  "\x6d\x65\x6e\x74\xd8\x01\x0e\x77\x72\x69\x74\x65\x2d\x70\x72\x6f"
  "\x64\x75\x63\x74\xd9\x01\x09\x70\x72\x6f\x64\x75\x63\x74\x3f\xda"
  "\x01\x04\x05\x0b\x61\x6c\x74\x2d\x77\x72\x69\x74\x65\x72\xdb\x01"
  "\x04\x17\x04\x7b\x04\xb3\x08\x16\x81\x85\x02\xb2\x08\x14\x81\x85"
  "\x02\xb1\x08\x12\x81\x87\x02\xb0\x08\x10\x81\x87\x02\xaf\x08\x0e"
  "\x81\x8b\x02\xae\x08\x0c\x81\x85\x02\xad\x08\x0a\x81\x8b\x02\xac"
  "\x08\x08\x81\x89\x02\xab\x08\x06\x81\x87\x02\xaa\x08\x04\x84\x06"
  "\x15\x27\xdc\x01\x02\x6a\x02\x09\x73\x65\x74\x2d\x63\x64\x72\x21"
  "\x08\x03\x82\x01\x02\x13\x6f\x70\x65\x6e\x2d\x6f\x75\x74\x70\x75"
  "\x74\x2d\x73\x74\x72\x69\x6e\x67\x05\x19\x74\x6f\x6b\x65\x6e\x69"
  "\x7a\x65\x72\x2d\x73\x74\x61\x74\x65\x3a\x74\x6f\x6b\x65\x6e\x69"
  "\x7a\x65\x82\x01\x03\x13\x67\x65\x74\x2d\x6f\x75\x74\x70\x75\x74"
  "\x2d\x73\x74\x72\x69\x6e\x67\x21\x04\x7b\x06\xb9\x08\x0e\x81\x85"
  "\x02\xb8\x08\x0c\x81\x87\x02\xb7\x08\x0a\x81\x85\x02\xb6\x08\x08"
  "\x81\x87\x02\xb5\x08\x06\x81\x85\x02\xb4\x08\x04\x83\x04\x0d\x1f"
  "\x7b\x02\x6b\x02\x11\x11\x63\x68\x61\x72\x20\x6f\x72\x20\x63\x68"
  "\x61\x72\x2d\x73\x65\x74\x0c\x76\x65\x63\x74\x6f\x72\x2d\x73\x65"
  "\x74\x21\x0e\x63\x68\x61\x72\x2d\x3e\x69\x6e\x74\x65\x67\x65\x72"
  "\x81\x02\x04\x0c\x6d\x61\x6b\x65\x2d\x76\x65\x63\x74\x6f\x72\x03"
  "\x0a\x63\x68\x61\x72\x2d\x73\x65\x74\x3f\x03\x83\x01\x04\x2a\x03"
  "\x11\x63\x68\x61\x72\x2d\x73\x65\x74\x2d\x6d\x65\x6d\x62\x65\x72"
  "\x73\x03\x84\x01\x04\x17\x08\xcd\x08\x2a\x81\x87\x02\xcc\x08\x28"
  "\x81\x85\x02\xcb\x08\x26\x81\x85\x02\xca\x08\x24\x81\x8d\x02\xc9"
  "\x08\x22\x81\x8d\x02\xc8\x08\x20\x81\x8b\x02\xc7\x08\x1e\x81\x85"
  "\x02\xc6\x08\x1c\x81\x89\x02\xc5\x08\x1a\x81\x85\x02\xc4\x08\x18"
  "\x81\x89\x02\xc3\x08\x16\x81\x8b\x02\xc2\x08\x14\x81\x8b\x02\xc1"
  "\x08\x12\x81\x87\x02\xc0\x08\x10\x81\x8f\x02\xbf\x08\x0e\x81\x8d"
  "\x02\xbe\x08\x0c\x81\x8d\x02\xbd\x08\x0a\x81\x8b\x02\xbc\x08\x08"
  "\x81\x8b\x02\xbb\x08\x06\x81\x87\x02\xba\x08\x04\xfd\x07\x29\x43"
  "\x2a\x02\x6c\x01\x21\x04\x9e\x01\x02\xce\x08\x04\x83\x04\x03\x0a"
  "\x9e\x01\x02\x6d\x19\x63\x68\x61\x72\x2d\x73\x65\x74\x3a\x68\x74"
  "\x74\x70\x2d\x73\x65\x70\x61\x72\x61\x74\x6f\x72\x73\x17\x02\x04"
  "\x80\x01\x02\xd0\x08\x06\x81\x83\x02\xcf\x08\x04\x83\x04\x05\x0d"
  "\xdd\x01\x02\x6e\xd1\x08\x04\x83\x04\x03\xde\x01\x02\x6f\xd2\x08"
  "\x04\x83\x04\x03\xdf\x01\x02\x70\xd3\x08\x04\x83\x04\x03\xe0\x01"
  "\x02\x71\xd4\x08\x04\x83\x04\x03\xe1\x01\x02\x72\xd5\x08\x04\x83"
  "\x04\x03\xe2\x01\x02\x73\x0c\x75\x6e\x72\x65\x61\x64\x2d\x63\x68"
  "\x61\x72\xe3\x01\x05\x63\x68\x61\x72\xe4\x01\x05\x70\x6f\x72\x74"
  "\xe5\x01\xe3\x01\x05\x66\x69\x66\x6f\xe6\x01\xe4\x01\x0a\x73\x61"
  "\x76\x65\x2d\x63\x68\x61\x72\x07\x6c\x61\x6d\x62\x64\x61\x08\x64"
  "\x65\x63\x6c\x61\x72\x65\x0a\x69\x67\x6e\x6f\x72\x61\x62\x6c\x65"
  "\x0d\x6f\x62\x6a\x65\x63\x74\x2d\x74\x79\x70\x65\x3f\x1e\x05\x65"
  "\x6d\x69\x74\xe7\x01\x05\x64\x6f\x6e\x65\xe5\x01\xe7\x01\xe6\x01"
  "\xe5\x01\xe7\x01\xe6\x01\x11\x74\x6f\x6b\x65\x6e\x69\x7a\x65\x72"
  "\x2d\x73\x74\x61\x74\x65\x3a\x10\x64\x65\x66\x69\x6e\x65\x2d\x64"
  "\x65\x66\x65\x72\x72\x65\x64\x0b\x6d\x61\x6b\x65\x2d\x73\x74\x61"
  "\x74\x65\xe7\x01\xe4\x01\x05\x65\x6c\x73\x65\x07\x73\x79\x6d\x62"
  "\x6f\x6c\xe6\x01\x06\x71\x75\x6f\x74\x65\x04\x65\x6f\x66\x02\x2b"
  "\xe5\x01\x06\x64\x61\x74\x75\x6d\xe4\x01\xe5\x01\x0b\x65\x78\x70"
  "\x72\x65\x73\x73\x69\x6f\x6e\xe5\x01\xe4\x01\x04\x0e\x73\x79\x6e"
  "\x74\x61\x78\x2d\x6d\x61\x74\x63\x68\x3f\x03\x05\x6c\x61\x73\x74"
  "\x03\x12\x69\x6c\x6c\x2d\x66\x6f\x72\x6d\x65\x64\x2d\x73\x79\x6e"
  "\x74\x61\x78\x03\x11\x65\x78\x63\x65\x70\x74\x2d\x6c\x61\x73\x74"
  "\x2d\x70\x61\x69\x72\x04\x0b\x61\x70\x70\x65\x6e\x64\x2d\x6d\x61"
  "\x70\x04\xe6\x01\x04\x07\x61\x70\x70\x65\x6e\x64\x04\x5c\x09\x80"
  "\x09\x58\x83\x04\xff\x08\x56\x81\x89\x02\xfe\x08\x54\x81\x8d\x02"
  "\xfd\x08\x52\x81\x8b\x02\xfc\x08\x50\x81\x89\x02\xfb\x08\x4e\x81"
  "\x83\x02\xfa\x08\x4c\x81\x89\x02\xf9\x08\x4a\x81\x8b\x02\xf8\x08"
  "\x48\x81\x8b\x02\xf7\x08\x46\x81\x87\x02\xf6\x08\x44\x81\x83\x02"
  "\xf5\x08\x42\x81\x8b\x02\xf4\x08\x40\x81\x85\x02\xf3\x08\x3e\x81"
  "\x83\x02\xf2\x08\x3c\x81\x85\x02\xf1\x08\x3a\x81\x85\x02\xf0\x08"
  "\x38\x81\x8b\x02\xef\x08\x36\x81\x8b\x02\xee\x08\x34\x83\x04\xed"
  "\x08\x32\x81\x89\x02\xec\x08\x30\x81\x89\x02\xeb\x08\x2e\x81\x8b"
  "\x02\xea\x08\x2c\x81\x8b\x02\xe9\x08\x2a\x81\x8b\x02\xe8\x08\x28"
  "\x81\x89\x02\xe7\x08\x26\x81\x85\x02\xe6\x08\x24\x81\x85\x02\xe5"
  "\x08\x22\x81\x85\x02\xe4\x08\x20\x81\x87\x02\xe3\x08\x1e\x81\x8b"
  "\x02\xe2\x08\x1c\x81\x8b\x02\xe1\x08\x1a\x81\x8b\x02\xe0\x08\x18"
  "\x81\x87\x02\xdf\x08\x16\x81\x87\x02\xde\x08\x14\x81\x85\x02\xdd"
  "\x08\x12\x81\x85\x02\xdc\x08\x10\x81\x85\x02\xdb\x08\x0e\x81\x87"
  "\x02\xda\x08\x0c\x81\x87\x02\xd9\x08\x0a\x81\x87\x02\xd8\x08\x08"
  "\x81\x87\x02\xd7\x08\x06\x81\x87\x02\xd6\x08\x04\x84\x06\x57\x86"
  "\x01\xe6\x01\x02\x74\x02\x14\x28\x29\x3c\x3e\x40\x2c\x3b\x3a\x5c"
  "\x22\x2f\x5b\x5d\x3f\x3d\x7b\x7d\x20\x09\x17\x02\x03\x11\x73\x74"
  "\x72\x69\x6e\x67\x2d\x3e\x63\x68\x61\x72\x2d\x73\x65\x74\x02\x83"
  "\x09\x08\x81\x81\x02\x82\x09\x06\x81\x81\x02\x81\x09\x04\x82\x02"
  "\x07\x11\xe5\x01\x02\x75\x02\x73\x02\x17\x0e\x63\x68\x61\x72\x2d"
  "\x73\x65\x74\x3a\x63\x74\x6c\x73\xe4\x01\x0f\x63\x68\x61\x72\x2d"
  "\x73\x65\x74\x3a\x61\x73\x63\x69\x69\x04\x04\x0f\x63\x68\x61\x72"
  "\x2d\x73\x65\x74\x2d\x75\x6e\x69\x6f\x6e\x5c\x04\x14\x63\x68\x61"
  "\x72\x2d\x73\x65\x74\x2d\x64\x69\x66\x66\x65\x72\x65\x6e\x63\x65"
  "\xe8\x01\x03\x8a\x09\x10\x81\x85\x02\x89\x09\x0e\x81\x83\x02\x88"
  "\x09\x0c\x81\x81\x02\x87\x09\x0a\x81\x81\x02\x86\x09\x08\x81\x87"
  "\x02\x85\x09\x06\x81\x85\x02\x84\x09\x04\x82\x02\x0f\x1e\xe9\x01"
  "\x02\x76\x02\x86\x01\x02\xe4\x01\x02\x03\x10\x63\x68\x61\x72\x2d"
  "\x73\x65\x74\x2d\x69\x6e\x76\x65\x72\x74\x02\x8e\x09\x0a\x81\x81"
  "\x02\x8d\x09\x08\x81\x81\x02\x8c\x09\x06\x81\x83\x02\x8b\x09\x04"
  "\x82\x02\x09\x14\xe4\x01\x02\x77\x02\x01\x29\x01\x2a\x14\x63\x68"
  "\x61\x72\x2d\x73\x65\x74\x3a\x68\x74\x74\x70\x2d\x63\x74\x65\x78"
  "\x74\xea\x01\x02\x86\x01\x02\x04\x09\x63\x68\x61\x72\x2d\x73\x65"
  "\x74\xeb\x01\x04\xe8\x01\x03\x93\x09\x0c\x81\x85\x02\x92\x09\x0a"
  "\x81\x83\x02\x91\x09\x08\x81\x81\x02\x90\x09\x06\x81\x81\x02\x8f"
  "\x09\x04\x82\x02\x0b\x1a\xec\x01\x02\x78\x02\x01\x23\x7a\x02\x86"
  "\x01\x02\x03\xeb\x01\x04\xe8\x01\x03\x98\x09\x0c\x81\x85\x02\x97"
  "\x09\x0a\x81\x83\x02\x96\x09\x08\x81\x81\x02\x95\x09\x06\x81\x81"
  "\x02\x94\x09\x04\x82\x02\x0b\x19\xeb\x01\x02\x79\x42\x5c\x02\x62"
  "\x7c\xcc\x01\x02\x04\x16\x61\x73\x63\x69\x69\x2d\x72\x61\x6e\x67"
  "\x65\x2d\x3e\x63\x68\x61\x72\x2d\x73\x65\x74\x04\x5c\x03\x9d\x09"
  "\x0c\x81\x85\x02\x9c\x09\x0a\x81\x83\x02\x9b\x09\x08\x81\x81\x02"
  "\x9a\x09\x06\x81\x81\x02\x99\x09\x04\x82\x02\x0b\x1a\xe8\x01\x02"
  "\x7a\x14\x49\x6c\x6c\x65\x67\x61\x6c\x20\x69\x6e\x70\x75\x74\x20"
  "\x63\x68\x61\x72\x3a\x02\x01\x23\x01\x29\x01\x2a\x82\x01\x02\x17"
  "\x73\x0d\x63\x68\x61\x72\x2d\x73\x65\x74\x3a\x77\x73\x70\x5c\x04"
  "\x10\xe7\x01\x04\x1e\x05\x1b\x74\x6f\x6b\x65\x6e\x69\x7a\x65\x72"
  "\x2d\x73\x74\x61\x74\x65\x3a\x69\x6e\x2d\x63\x6f\x6d\x6d\x65\x6e"
  "\x74\xed\x01\x05\x21\x74\x6f\x6b\x65\x6e\x69\x7a\x65\x72\x2d\x73"
  "\x74\x61\x74\x65\x3a\x69\x6e\x2d\x71\x75\x6f\x74\x65\x64\x2d\x73"
  "\x74\x72\x69\x6e\x67\xee\x01\x05\x17\x74\x6f\x6b\x65\x6e\x69\x7a"
  "\x65\x72\x2d\x73\x74\x61\x74\x65\x3a\x69\x6e\x2d\x77\x73\x70\xef"
  "\x01\x05\x82\x01\x05\x19\x74\x6f\x6b\x65\x6e\x69\x7a\x65\x72\x2d"
  "\x73\x74\x61\x74\x65\x3a\x69\x6e\x2d\x74\x6f\x6b\x65\x6e\xf0\x01"
  "\x08\xad\x09\x22\x81\x89\x02\xac\x09\x20\x81\x89\x02\xab\x09\x1e"
  "\x85\x08\xaa\x09\x1c\x86\x0a\xa9\x09\x1a\x86\x0a\xa8\x09\x18\x86"
  "\x0a\xa7\x09\x16\x86\x0a\xa6\x09\x14\x86\x0a\xa5\x09\x12\x86\x0a"
  "\xa4\x09\x10\x86\x0a\xa3\x09\x0e\x81\x81\x02\xa2\x09\x0c\x81\x81"
  "\x02\xa1\x09\x0a\x81\x99\x02\xa0\x09\x08\x81\x95\x02\x9f\x09\x06"
  "\x81\x85\x02\x9e\x09\x04\x82\x02\x21\x3e\xf1\x01\x02\x7b\x01\x21"
  "\x02\xef\x01\x02\x5c\x02\x06\xe7\x01\x05\xef\x01\x04\xe3\x01\x05"
  "\x82\x01\x05\xb6\x09\x14\x81\x89\x02\xb5\x09\x12\x81\x89\x02\xb4"
  "\x09\x10\x85\x08\xb3\x09\x0e\x86\x0a\xb2\x09\x0c\x86\x0a\xb1\x09"
  "\x0a\x81\x81\x02\xb0\x09\x08\x81\x81\x02\xaf\x09\x06\x81\x85\x02"
  "\xae\x09\x04\x82\x02\x13\x25\xf2\x01\x02\x7c\x02\xf0\x01\x02\x73"
  "\x02\x06\xe7\x01\x05\xf0\x01\x04\xe3\x01\x05\x82\x01\x05\xc3\x09"
  "\x1c\x81\x89\x02\xc2\x09\x1a\x81\x89\x02\xc1\x09\x18\x81\x87\x02"
  "\xc0\x09\x16\x81\x8b\x02\xbf\x09\x14\x81\x89\x02\xbe\x09\x12\x81"
  "\x89\x02\xbd\x09\x10\x85\x08\xbc\x09\x0e\x86\x0a\xbb\x09\x0c\x86"
  "\x0a\xba\x09\x0a\x81\x81\x02\xb9\x09\x08\x81\x81\x02\xb8\x09\x06"
  "\x81\x85\x02\xb7\x09\x04\x82\x02\x1b\x2c\xe3\x01\x02\x7d\x0e\x71"
  "\x75\x6f\x74\x65\x64\x2d\x73\x74\x72\x69\x6e\x67\xf3\x01\x20\x50"
  "\x72\x65\x6d\x61\x74\x75\x72\x65\x20\x45\x4f\x46\x20\x69\x6e\x20"
  "\x71\x75\x6f\x74\x65\x64\x20\x73\x74\x72\x69\x6e\x67\x2e\x1f\x49"
  "\x6c\x6c\x65\x67\x61\x6c\x20\x63\x68\x61\x72\x20\x69\x6e\x20\x71"
  "\x75\x6f\x74\x65\x64\x20\x73\x74\x72\x69\x6e\x67\x3a\x02\x01\x5d"
  "\x01\x23\xee\x01\x02\x7a\x02\x0a\xe7\x01\x05\x2b\x74\x6f\x6b\x65"
  "\x6e\x69\x7a\x65\x72\x2d\x73\x74\x61\x74\x65\x3a\x69\x6e\x2d\x71"
  "\x75\x6f\x74\x65\x64\x2d\x73\x74\x72\x69\x6e\x67\x2d\x71\x75\x6f"
  "\x74\x61\x74\x69\x6f\x6e\xf4\x01\x04\x1e\x03\x1e\x05\x82\x01\x05"
  "\xee\x01\x07\xcf\x09\x1a\x81\x89\x02\xce\x09\x18\x81\x8b\x02\xcd"
  "\x09\x16\x81\x89\x02\xcc\x09\x14\x85\x08\xcb\x09\x12\x86\x0a\xca"
  "\x09\x10\x86\x0a\xc9\x09\x0e\x86\x0a\xc8\x09\x0c\x86\x0a\xc7\x09"
  "\x0a\x81\x81\x02\xc6\x09\x08\x81\x81\x02\xc5\x09\x06\x81\x8d\x02"
  "\xc4\x09\x04\x82\x02\x19\x33\xf5\x01\x02\x7e\x20\x50\x72\x65\x6d"
  "\x61\x74\x75\x72\x65\x20\x45\x4f\x46\x20\x69\x6e\x20\x71\x75\x6f"
  "\x74\x65\x64\x20\x73\x74\x72\x69\x6e\x67\x2e\x02\xf4\x01\x02\x04"
  "\xe7\x01\x03\x1e\x05\xee\x01\x04\xd5\x09\x0e\x81\x89\x02\xd4\x09"
  "\x0c\x85\x08\xd3\x09\x0a\x86\x0a\xd2\x09\x08\x81\x81\x02\xd1\x09"
  "\x06\x81\x81\x02\xd0\x09\x04\x82\x02\x0d\x1b\xf6\x01\x02\x7f\x25"
  "\x50\x72\x65\x6d\x61\x74\x75\x72\x65\x20\x45\x4f\x46\x20\x77\x68"
  "\x69\x6c\x65\x20\x72\x65\x61\x64\x69\x6e\x67\x20\x63\x6f\x6d\x6d"
  "\x65\x6e\x74\x2e\x08\x63\x6f\x6d\x6d\x65\x6e\x74\xf7\x01\x19\x49"
  "\x6c\x6c\x65\x67\x61\x6c\x20\x63\x68\x61\x72\x20\x69\x6e\x20\x63"
  "\x6f\x6d\x6d\x65\x6e\x74\x3a\x01\x5d\x01\x2a\x01\x29\x86\x01\x02"
  "\x04\x80\x01\x03\x83\x01\x04\x1e\x03\x1e\x05\x82\x01\x03\x84\x01"
  "\x07\xe8\x09\x28\x81\x83\x02\xe7\x09\x26\x81\x83\x02\xe6\x09\x24"
  "\x81\x8b\x02\xe5\x09\x22\x81\x83\x02\xe4\x09\x20\x81\x8b\x02\xe3"
  "\x09\x1e\x81\x8b\x02\xe2\x09\x1c\x81\x8d\x02\xe1\x09\x1a\x81\x8b"
  "\x02\xe0\x09\x18\x81\x8b\x02\xdf\x09\x16\x81\x8b\x02\xde\x09\x14"
  "\x81\x8d\x02\xdd\x09\x12\x81\x8b\x02\xdc\x09\x10\x81\x8b\x02\xdb"
  "\x09\x0e\x81\x83\x02\xda\x09\x0c\x81\x8f\x02\xd9\x09\x0a\x81\x8b"
  "\x02\xd8\x09\x08\x81\x89\x02\xd7\x09\x06\x81\x89\x02\xd6\x09\x04"
  "\x85\x08\x27\x40\x84\x01\x02\x80\x01\x13\x68\x65\x61\x64\x65\x72"
  "\x2d\x76\x61\x6c\x75\x65\x2d\x64\x65\x66\x6e\x73\x83\x01\x02\x06"
  "\x0c\x6d\x61\x6b\x65\x2d\x68\x76\x64\x65\x66\x6e\xf8\x01\x03\x71"
  "\x05\x10\x68\x61\x73\x68\x2d\x74\x61\x62\x6c\x65\x2d\x73\x65\x74"
  "\x21\x04\xec\x09\x0a\x81\x89\x02\xeb\x09\x08\x81\x89\x02\xea\x09"
  "\x06\x81\x89\x02\xe9\x09\x04\x86\x0a\x09\x15\xf9\x01\x02\x81\x01"
  "\x83\x01\x02\x05\x17\x68\x61\x73\x68\x2d\x74\x61\x62\x6c\x65\x2d"
  "\x72\x65\x66\x2f\x64\x65\x66\x61\x75\x6c\x74\x02\xee\x09\x06\x81"
  "\x85\x02\xed\x09\x04\x83\x04\x05\x0d\xfa\x01\x02\x82\x01\x02\x83"
  "\x01\x02\x02\x1a\x6d\x61\x6b\x65\x2d\x73\x74\x72\x6f\x6e\x67\x2d"
  "\x65\x71\x2d\x68\x61\x73\x68\x2d\x74\x61\x62\x6c\x65\x02\xf1\x09"
  "\x08\x81\x81\x02\xf0\x09\x06\x81\x81\x02\xef\x09\x04\x82\x02\x07"
  "\x10\xfb\x01\x02\x83\x01\xf2\x09\x04\x82\x02\x03\xfc\x01\x02\x84"
  "\x01\xf3\x09\x04\x82\x02\x03\xfd\x01\x02\x85\x01\xf4\x09\x04\x82"
  "\x02\x03\xfe\x01\x02\x86\x01\xf5\x09\x04\x82\x02\x03\xff\x01\x02"
  "\x87\x01\x52\xf6\x09\x04\x83\x04\x03\x80\x02\x02\x88\x01\x52\xf7"
  "\x09\x04\x83\x04\x03\x81\x02\x02\x89\x01\x52\xf8\x09\x04\x83\x04"
  "\x03\x82\x02\x02\x8a\x01\x52\xf9\x09\x04\x83\x04\x03\x83\x02\x02"
  "\x8b\x01\x52\x07\x2e\x74\x61\x67\x2e\x31\x84\x02\x02\xfb\x09\x06"
  "\x81\x85\x02\xfa\x09\x04\x83\x04\x05\x0d\x85\x02\x02\x8c\x01\x03"
  "\x0a\x03\x0f\x6c\x69\x73\x74\x2d\x70\x72\x65\x64\x69\x63\x61\x74"
  "\x65\x86\x02\x03\x11\x74\x6f\x6b\x65\x6e\x69\x7a\x65\x64\x2d\x70"
  "\x61\x72\x73\x65\x72\x87\x02\x03\x12\x63\x6f\x6d\x6d\x61\x2d\x6c"
  "\x69\x73\x74\x2d\x77\x72\x69\x74\x65\x72\x88\x02\x06\x0e\x64\x65"
  "\x66\x69\x6e\x65\x2d\x68\x65\x61\x64\x65\x72\x89\x02\x06\x80\x0a"
  "\x0c\x81\x89\x02\xff\x09\x0a\x81\x89\x02\xfe\x09\x08\x81\x8b\x02"
  "\xfd\x09\x06\x81\x89\x02\xfc\x09\x04\x86\x0a\x0b\x19\x8a\x02\x02"
  "\x8d\x01\x03\x0f\x6c\x70\x3a\x63\x6f\x6d\x6d\x61\x2d\x6c\x69\x73"
  "\x74\x2b\x8b\x02\x03\x10\x6c\x69\x73\x74\x2b\x2d\x70\x72\x65\x64"
  "\x69\x63\x61\x74\x65\x8c\x02\x03\x87\x02\x03\x88\x02\x06\x89\x02"
  "\x06\x85\x0a\x0c\x81\x89\x02\x84\x0a\x0a\x81\x89\x02\x83\x0a\x08"
  "\x81\x8b\x02\x82\x0a\x06\x81\x89\x02\x81\x0a\x04\x86\x0a\x0b\x19"
  "\x8d\x02\x02\x8e\x01\x30\x57\x72\x6f\x6e\x67\x20\x6e\x75\x6d\x62"
  "\x65\x72\x20\x6f\x66\x20\x76\x61\x6c\x75\x65\x73\x20\x66\x72\x6f"
  "\x6d\x20\x48\x54\x54\x50\x20\x68\x65\x61\x64\x65\x72\x20\x70\x61"
  "\x72\x73\x65\x72\x2e\x03\x0f\x73\x74\x72\x69\x6e\x67\x2d\x3e\x74"
  "\x6f\x6b\x65\x6e\x73\x8e\x02\x03\x1f\x73\x74\x72\x75\x63\x74\x75"
  "\x72\x65\x2d\x70\x61\x72\x73\x65\x72\x2d\x76\x61\x6c\x75\x65\x73"
  "\x2d\x6c\x65\x6e\x67\x74\x68\x03\x1e\x04\x1c\x73\x74\x72\x75\x63"
  "\x74\x75\x72\x65\x2d\x70\x61\x72\x73\x65\x72\x2d\x76\x61\x6c\x75"
  "\x65\x73\x2d\x72\x65\x66\x8f\x02\x05\x8d\x0a\x12\x81\x89\x02\x8c"
  "\x0a\x10\x81\x89\x02\x8b\x0a\x0e\x81\x89\x02\x8a\x0a\x0c\x81\x89"
  "\x02\x89\x0a\x0a\x81\x89\x02\x88\x0a\x08\x81\x89\x02\x87\x0a\x06"
  "\x81\x89\x02\x86\x0a\x04\x83\x04\x11\x21\x90\x02\x02\x8f\x01\x30"
  "\x57\x72\x6f\x6e\x67\x20\x6e\x75\x6d\x62\x65\x72\x20\x6f\x66\x20"
  "\x76\x61\x6c\x75\x65\x73\x20\x66\x72\x6f\x6d\x20\x48\x54\x54\x50"
  "\x20\x68\x65\x61\x64\x65\x72\x20\x70\x61\x72\x73\x65\x72\x2e\x11"
  "\x12\x04\xc7\x01\x03\x1e\x03\x93\x0a\x0e\x81\x8b\x02\x92\x0a\x0c"
  "\x81\x8b\x02\x91\x0a\x0a\x81\x89\x02\x90\x0a\x08\x81\x8b\x02\x8f"
  "\x0a\x06\x81\x89\x02\x8e\x0a\x04\x83\x04\x0d\x1a\x12\x02\x90\x01"
  "\x01\x2e\x08\x45\x78\x70\x69\x72\x65\x73\x0d\x43\x6f\x6e\x74\x65"
  "\x6e\x74\x2d\x54\x79\x70\x65\x0e\x4c\x61\x73\x74\x2d\x4d\x6f\x64"
  "\x69\x66\x69\x65\x64\x0e\x43\x6f\x6e\x74\x65\x6e\x74\x2d\x52\x61"
  "\x6e\x67\x65\x03\x2d\x31\x11\x03\x3b\x20\x11\x43\x6f\x6e\x74\x65"
  "\x6e\x74\x2d\x4c\x6f\x63\x61\x74\x69\x6f\x6e\x0c\x43\x6f\x6e\x74"
  "\x65\x6e\x74\x2d\x4d\x44\x35\x0f\x43\x6f\x6e\x74\x65\x6e\x74\x2d"
  "\x4c\x65\x6e\x67\x74\x68\x05\x56\x61\x72\x79\x11\x43\x6f\x6e\x74"
  "\x65\x6e\x74\x2d\x4c\x61\x6e\x67\x75\x61\x67\x65\x11\x43\x6f\x6e"
  "\x74\x65\x6e\x74\x2d\x45\x6e\x63\x6f\x64\x69\x6e\x67\x0c\x52\x65"
  "\x74\x72\x79\x2d\x41\x66\x74\x65\x72\x06\x41\x6c\x6c\x6f\x77\x07"
  "\x53\x65\x72\x76\x65\x72\x09\x4c\x6f\x63\x61\x74\x69\x6f\x6e\x0e"
  "\x41\x63\x63\x65\x70\x74\x2d\x52\x61\x6e\x67\x65\x73\x05\x45\x54"
  "\x61\x67\x11\x04\x41\x67\x65\x0b\x55\x73\x65\x72\x2d\x41\x67\x65"
  "\x6e\x74\x05\x6e\x6f\x6e\x65\x06\x52\x61\x6e\x67\x65\x03\x54\x45"
  "\x08\x52\x65\x66\x65\x72\x65\x72\x09\x49\x66\x2d\x52\x61\x6e\x67"
  "\x65\x0d\x4d\x61\x78\x2d\x46\x6f\x72\x77\x61\x72\x64\x73\x01\x3e"
  "\x14\x49\x66\x2d\x55\x6e\x6d\x6f\x64\x69\x66\x69\x65\x64\x2d\x53"
  "\x69\x6e\x63\x65\x0e\x49\x66\x2d\x4e\x6f\x6e\x65\x2d\x4d\x61\x74"
  "\x63\x68\x12\x49\x66\x2d\x4d\x6f\x64\x69\x66\x69\x65\x64\x2d\x53"
  "\x69\x6e\x63\x65\x09\x49\x66\x2d\x4d\x61\x74\x63\x68\x05\x48\x6f"
  "\x73\x74\x07\x45\x78\x70\x65\x63\x74\x10\x41\x63\x63\x65\x70\x74"
  "\x2d\x4c\x61\x6e\x67\x75\x61\x67\x65\x03\x2f\x2a\x07\x41\x63\x63"
  "\x65\x70\x74\x10\x41\x63\x63\x65\x70\x74\x2d\x45\x6e\x63\x6f\x64"
  "\x69\x6e\x67\x08\x57\x61\x72\x6e\x69\x6e\x67\x0f\x41\x63\x63\x65"
  "\x70\x74\x2d\x43\x68\x61\x72\x73\x65\x74\x04\x56\x69\x61\x02\x3b"
  "\x01\x30\x01\x21\x08\x55\x70\x67\x72\x61\x64\x65\x12\x54\x72\x61"
  "\x6e\x73\x66\x65\x72\x2d\x45\x6e\x63\x6f\x64\x69\x6e\x67\x08\x54"
  "\x72\x61\x69\x6c\x65\x72\x05\x44\x61\x74\x65\x07\x50\x72\x61\x67"
  "\x6d\x61\x0b\x43\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x0e\x43\x61"
  "\x63\x68\x65\x2d\x43\x6f\x6e\x74\x72\x6f\x6c\xb0\x01\xbc\x01\xba"
  "\x01\x23\x5d\xa1\x01\x10\x77\x72\x69\x74\x65\x2d\x68\x74\x74\x70"
  "\x2d\x64\x61\x74\x65\x0b\x68\x74\x74\x70\x2d\x64\x61\x74\x65\x3f"
  "\xc2\x01\x13\x77\x72\x69\x74\x65\x2d\x74\x6f\x6b\x65\x6e\x2b\x70"
  "\x61\x72\x61\x6d\x73\x91\x02\x0e\x74\x6f\x6b\x65\x6e\x2b\x70\x61"
  "\x72\x61\x6d\x73\x3f\x92\x02\x10\x6c\x70\x3a\x74\x6f\x6b\x65\x6e"
  "\x2b\x70\x61\x72\x61\x6d\x73\x93\x02\xd9\x01\xda\x01\xd5\x01\xd8"
  "\x01\x09\x63\x6f\x6d\x6d\x65\x6e\x74\x3f\x94\x02\x15\x77\x72\x69"
  "\x74\x65\x2d\x68\x6f\x73\x74\x70\x6f\x72\x74\x2f\x74\x6f\x6b\x65"
  "\x6e\x95\x02\x10\x77\x72\x69\x74\x65\x2d\x6d\x69\x6d\x65\x2d\x74"
  "\x79\x70\x65\x0b\x6d\x69\x6d\x65\x2d\x74\x79\x70\x65\x3f\xc3\x01"
  "\x14\x77\x72\x69\x74\x65\x2d\x71\x75\x6f\x74\x65\x64\x2d\x73\x74"
  "\x72\x69\x6e\x67\xc3\x01\x12\x77\x72\x69\x74\x65\x2d\x68\x74\x74"
  "\x70\x2d\x73\x74\x61\x74\x75\x73\x96\x02\x10\x68\x6f\x73\x74\x70"
  "\x6f\x72\x74\x2f\x74\x6f\x6b\x65\x6e\x3f\x97\x02\x13\x77\x72\x69"
  "\x74\x65\x2d\x74\x6f\x6b\x65\x6e\x2b\x71\x70\x61\x72\x61\x6d\x98"
  "\x02\x0e\x74\x6f\x6b\x65\x6e\x2b\x71\x70\x61\x72\x61\x6d\x3f\x99"
  "\x02\x10\x6c\x70\x3a\x74\x6f\x6b\x65\x6e\x2b\x71\x70\x61\x72\x61"
  "\x6d\x9a\x02\x0f\x61\x63\x63\x65\x70\x74\x2d\x70\x61\x72\x61\x6d"
  "\x73\x3f\x9b\x02\x76\x45\x11\x77\x72\x69\x74\x65\x2d\x70\x61\x72"
  "\x61\x6d\x65\x74\x65\x72\x73\x9c\x02\x18\x70\x61\x72\x61\x6d\x73"
  "\x2d\x61\x72\x65\x2d\x65\x78\x70\x65\x63\x74\x61\x74\x69\x6f\x6e"
  "\x3f\x9d\x02\x0f\x77\x72\x69\x74\x65\x2d\x68\x6f\x73\x74\x70\x6f"
  "\x72\x74\x9e\x02\x0a\x68\x6f\x73\x74\x70\x6f\x72\x74\x3f\x9f\x02"
  "\xc6\x01\x12\x77\x72\x69\x74\x65\x2d\x65\x6e\x74\x69\x74\x79\x2d"
  "\x74\x61\x67\x73\xa0\x02\x0d\x65\x6e\x74\x69\x74\x79\x2d\x74\x61"
  "\x67\x73\x3f\xa1\x02\x0f\x6c\x70\x3a\x65\x6e\x74\x69\x74\x79\x2d"
  "\x74\x61\x67\x73\xa2\x02\xa6\x01\x07\x76\x65\x63\x74\x6f\x72\x11"
  "\x77\x72\x69\x74\x65\x2d\x65\x6e\x74\x69\x74\x79\x2d\x74\x61\x67"
  "\xa6\x01\x0c\x65\x6e\x74\x69\x74\x79\x2d\x74\x61\x67\x3f\xa3\x02"
  "\x3e\x25\x0b\x6c\x70\x3a\x64\x65\x63\x69\x6d\x61\x6c\xa4\x02\x15"
  "\x77\x72\x69\x74\x65\x2d\x62\x79\x74\x65\x2d\x72\x61\x6e\x67\x65"
  "\x2d\x73\x65\x74\xa5\x02\x11\x77\x72\x69\x74\x65\x2d\x62\x79\x74"
  "\x65\x73\x2d\x75\x6e\x69\x74\xa6\x02\x0e\x6c\x70\x3a\x65\x6e\x74"
  "\x69\x74\x79\x2d\x74\x61\x67\xa7\x02\x0a\x77\x72\x69\x74\x65\x2d"
  "\x75\x72\x69\x10\x62\x79\x74\x65\x2d\x72\x61\x6e\x67\x65\x2d\x73"
  "\x65\x74\x3f\xa8\x02\xcd\x01\x1b\x77\x72\x69\x74\x65\x2d\x70\x72"
  "\x6f\x64\x75\x63\x74\x2f\x63\x6f\x6d\x6d\x65\x6e\x74\x2d\x6c\x69"
  "\x73\x74\xa9\x02\x16\x70\x72\x6f\x64\x75\x63\x74\x2f\x63\x6f\x6d"
  "\x6d\x65\x6e\x74\x2d\x6c\x69\x73\x74\x3f\xaa\x02\x18\x6c\x70\x3a"
  "\x70\x72\x6f\x64\x75\x63\x74\x2f\x63\x6f\x6d\x6d\x65\x6e\x74\x2d"
  "\x6c\x69\x73\x74\xab\x02\x0d\x77\x72\x69\x74\x65\x2d\x74\x6f\x6b"
  "\x65\x6e\x73\xac\x02\x06\x6e\x75\x6c\x6c\x3f\x0e\x61\x62\x73\x6f"
  "\x6c\x75\x74\x65\x2d\x75\x72\x69\x3f\x13\x70\x61\x72\x73\x65\x2d"
  "\x61\x62\x73\x6f\x6c\x75\x74\x65\x2d\x75\x72\x69\xad\x02\x08\x77"
  "\x72\x69\x74\x65\x2d\x2a\xae\x02\xa0\x01\x3d\x6a\x90\x01\x0e\x6c"
  "\x61\x6e\x67\x75\x61\x67\x65\x2d\x74\x61\x67\x3f\xaf\x02\x0c\x77"
  "\x72\x69\x74\x65\x2d\x72\x61\x6e\x67\x65\xb0\x02\x07\x72\x61\x6e"
  "\x67\x65\x3f\xb1\x02\x86\x01\x45\x06\x1a\x64\x65\x66\x69\x6e\x65"
  "\x2d\x63\x6f\x6d\x6d\x61\x2d\x6c\x69\x73\x74\x2b\x2d\x68\x65\x61"
  "\x64\x65\x72\xb2\x02\x03\x0e\x64\x69\x72\x65\x63\x74\x2d\x70\x61"
  "\x72\x73\x65\x72\xb3\x02\x06\x89\x02\x03\x1f\x03\x0e\x6f\x70\x74"
  "\x2d\x70\x72\x65\x64\x69\x63\x61\x74\x65\xb4\x02\x05\xdb\x01\x09"
  "\x0e\x76\x65\x63\x74\x6f\x72\x2d\x77\x72\x69\x74\x65\x72\xb5\x02"
  "\x07\xb5\x02\x03\x57\x05\xb1\x01\x04\x0e\x61\x6c\x74\x2d\x70\x72"
  "\x65\x64\x69\x63\x61\x74\x65\xb6\x02\x05\xb6\x02\x04\x14\x76\x61"
  "\x6c\x75\x65\x2b\x70\x61\x72\x61\x6d\x73\x2d\x77\x72\x69\x74\x65"
  "\x72\xb7\x02\x04\x23\x06\x11\x76\x65\x63\x74\x6f\x72\x2d\x70\x72"
  "\x65\x64\x69\x63\x61\x74\x65\xb8\x02\x05\xb8\x02\x04\xc3\x01\x04"
  "\x05\xa1\x01\x04\xae\x01\x06\x19\x64\x65\x66\x69\x6e\x65\x2d\x63"
  "\x6f\x6d\x6d\x61\x2d\x6c\x69\x73\x74\x2d\x68\x65\x61\x64\x65\x72"
  "\xb9\x02\x04\x3d\x05\xa4\x02\x03\xa4\x02\x05\xd2\x01\x04\x11\x6a"
  "\x6f\x69\x6e\x65\x64\x2d\x70\x72\x65\x64\x69\x63\x61\x74\x65\xba"
  "\x02\x03\x05\x03\x86\x02\x03\x10\x6c\x61\x6e\x67\x75\x61\x67\x65"
  "\x2d\x72\x61\x6e\x67\x65\x3f\xbb\x02\x05\xca\x01\x05\x12\x6c\x70"
  "\x3a\x68\x6f\x73\x74\x70\x6f\x72\x74\x2f\x74\x6f\x6b\x65\x6e\xbc"
  "\x02\x05\x9a\x02\x05\x11\x6c\x70\x3a\x61\x63\x63\x65\x70\x74\x2d"
  "\x70\x61\x72\x61\x6d\x73\xbd\x02\x05\x96\x01\x03\x87\x02\x05\xd6"
  "\x01\x05\xa3\x01\x05\xba\x01\x03\xa0\x01\x03\xbe\x01\x03\x31\x04"
  "\xc0\x01\x03\x05\x75\x72\x69\x3f\x03\x34\x03\x0d\x75\x72\x69\x2d"
  "\x66\x72\x61\x67\x6d\x65\x6e\x74\x05\x0e\x6c\x70\x3a\x62\x79\x74"
  "\x65\x73\x2d\x75\x6e\x69\x74\xc0\x01\x03\x0d\x74\x6f\x6b\x65\x6e"
  "\x2d\x77\x72\x69\x74\x65\x72\xbe\x01\x03\xad\x02\x05\xa7\x01\x04"
  "\x35\x05\x12\x6c\x70\x3a\x62\x79\x74\x65\x2d\x72\x61\x6e\x67\x65"
  "\x2d\x73\x65\x74\xad\x02\x03\x10\x74\x6f\x6b\x65\x6e\x2d\x70\x72"
  "\x65\x64\x69\x63\x61\x74\x65\xbe\x02\x03\x13\x70\x61\x72\x73\x65"
  "\x2d\x72\x65\x6c\x61\x74\x69\x76\x65\x2d\x75\x72\x69\x05\x0a\x6c"
  "\x70\x3a\x74\x6f\x6b\x65\x6e\x2b\xbf\x02\x03\x8c\x02\x03\xc2\x01"
  "\x05\x05\x6c\x70\x3a\x2a\xc0\x02\x03\x15\x65\x6e\x63\x6f\x64\x65"
  "\x2d\x62\x61\x73\x65\x36\x34\x2d\x6f\x63\x74\x65\x74\x73\xc1\x02"
  "\x03\x0b\x76\x65\x63\x74\x6f\x72\x2d\x38\x62\x3f\x04\x15\x64\x65"
  "\x63\x6f\x64\x65\x2d\x62\x61\x73\x65\x36\x34\x2d\x6f\x63\x74\x65"
  "\x74\x73\xc2\x02\x03\x12\x73\x74\x72\x69\x6e\x67\x2d\x74\x72\x69"
  "\x6d\x2d\x72\x69\x67\x68\x74\x03\x11\x76\x65\x63\x74\x6f\x72\x2d"
  "\x38\x62\x2d\x6c\x65\x6e\x67\x74\x68\xc3\x02\x03\x18\x73\x74\x72"
  "\x75\x63\x74\x75\x72\x65\x2d\x70\x61\x72\x73\x65\x72\x2d\x76\x61"
  "\x6c\x75\x65\x73\x03\x17\x76\x61\x6c\x75\x65\x2b\x70\x61\x72\x61"
  "\x6d\x73\x2d\x70\x72\x65\x64\x69\x63\x61\x74\x65\xc4\x02\x05\x0d"
  "\x6c\x70\x3a\x6d\x69\x6d\x65\x2d\x74\x79\x70\x65\xc5\x02\x05\xb3"
  "\x01\x04\x36\x45\xd9\x0d\x8e\x07\x81\x85\x02\xd8\x0d\x8c\x07\x81"
  "\x85\x02\xd7\x0d\x8a\x07\x81\x87\x02\xd6\x0d\x88\x07\x81\x83\x02"
  "\xd5\x0d\x86\x07\x81\x87\x02\xd4\x0d\x84\x07\x81\x83\x02\xd3\x0d"
  "\x82\x07\x81\x87\x02\xd2\x0d\x80\x07\x81\x83\x02\xd1\x0d\xfe\x06"
  "\x81\x8d\x02\xd0\x0d\xfc\x06\x81\x8b\x02\xcf\x0d\xfa\x06\x81\x89"
  "\x02\xce\x0d\xf8\x06\x81\x89\x02\xcd\x0d\xf6\x06\x81\x87\x02\xcc"
  "\x0d\xf4\x06\x81\x8d\x02\xcb\x0d\xf2\x06\x81\x8b\x02\xca\x0d\xf0"
  "\x06\x81\x89\x02\xc9\x0d\xee\x06\x81\x83\x02\xc8\x0d\xec\x06\x81"
  "\x89\x02\xc7\x0d\xea\x06\x81\x8d\x02\xc6\x0d\xe8\x06\x81\x8b\x02"
  "\xc5\x0d\xe6\x06\x81\x89\x02\xc4\x0d\xe4\x06\x81\x85\x02\xc3\x0d"
  "\xe2\x06\x81\x83\x02\xc2\x0d\xe0\x06\x81\x89\x02\xc1\x0d\xde\x06"
  "\x81\x89\x02\xc0\x0d\xdc\x06\x81\x89\x02\xbf\x0d\xda\x06\x81\x83"
  "\x02\xbe\x0d\xd8\x06\x81\x85\x02\xbd\x0d\xd6\x06\x81\x83\x02\xbc"
  "\x0d\xd4\x06\x81\x89\x02\xbb\x0d\xd2\x06\x81\x89\x02\xba\x0d\xd0"
  "\x06\x81\x89\x02\xb9\x0d\xce\x06\x81\x89\x02\xb8\x0d\xcc\x06\x81"
  "\x89\x02\xb7\x0d\xca\x06\x83\x04\xb6\x0d\xc8\x06\x81\x87\x02\xb5"
  "\x0d\xc6\x06\x81\x87\x02\xb4\x0d\xc4\x06\x81\x8b\x02\xb3\x0d\xc2"
  "\x06\x81\x89\x02\xb2\x0d\xc0\x06\x81\x89\x02\xb1\x0d\xbe\x06\x85"
  "\x08\xb0\x0d\xbc\x06\x81\x87\x02\xaf\x0d\xba\x06\x81\x85\x02\xae"
  "\x0d\xb8\x06\x81\x85\x02\xad\x0d\xb6\x06\x81\x87\x02\xac\x0d\xb4"
  "\x06\x81\x89\x02\xab\x0d\xb2\x06\x81\x8b\x02\xaa\x0d\xb0\x06\x81"
  "\x89\x02\xa9\x0d\xae\x06\x85\x08\xa8\x0d\xac\x06\x81\x87\x02\xa7"
  "\x0d\xaa\x06\x81\x85\x02\xa6\x0d\xa8\x06\x84\x06\xa5\x0d\xa6\x06"
  "\x81\x87\x02\xa4\x0d\xa4\x06\x81\x83\x02\xa3\x0d\xa2\x06\x81\x87"
  "\x02\xa2\x0d\xa0\x06\x81\x83\x02\xa1\x0d\x9e\x06\x81\x81\x02\xa0"
  "\x0d\x9c\x06\x81\x81\x02\x9f\x0d\x9a\x06\x81\x87\x02\x9e\x0d\x98"
  "\x06\x81\x83\x02\x9d\x0d\x96\x06\x81\x8d\x02\x9c\x0d\x94\x06\x81"
  "\x89\x02\x9b\x0d\x92\x06\x81\x8d\x02\x9a\x0d\x90\x06\x81\x8b\x02"
  "\x99\x0d\x8e\x06\x81\x87\x02\x98\x0d\x8c\x06\x81\x85\x02\x97\x0d"
  "\x8a\x06\x81\x87\x02\x96\x0d\x88\x06\x81\x83\x02\x95\x0d\x86\x06"
  "\x81\x89\x02\x94\x0d\x84\x06\x81\x87\x02\x93\x0d\x82\x06\x81\x81"
  "\x02\x92\x0d\x80\x06\x81\x85\x02\x91\x0d\xfe\x05\x81\x83\x02\x90"
  "\x0d\xfc\x05\x81\x87\x02\x8f\x0d\xfa\x05\x81\x89\x02\x8e\x0d\xf8"
  "\x05\x81\x89\x02\x8d\x0d\xf6\x05\x81\x83\x02\x8c\x0d\xf4\x05\x81"
  "\x87\x02\x8b\x0d\xf2\x05\x81\x85\x02\x8a\x0d\xf0\x05\x81\x8f\x02"
  "\x89\x0d\xee\x05\x81\x8d\x02\x88\x0d\xec\x05\x81\x8b\x02\x87\x0d"
  "\xea\x05\x81\x85\x02\x86\x0d\xe8\x05\x81\x8b\x02\x85\x0d\xe6\x05"
  "\x81\x89\x02\x84\x0d\xe4\x05\x81\x83\x02\x83\x0d\xe2\x05\x81\x87"
  "\x02\x82\x0d\xe0\x05\x81\x81\x02\x81\x0d\xde\x05\x81\x83\x02\x80"
  "\x0d\xdc\x05\x81\x83\x02\xff\x0c\xda\x05\x85\x08\xfe\x0c\xd8\x05"
  "\x83\x04\xfd\x0c\xd6\x05\x84\x06\xfc\x0c\xd4\x05\x81\x8b\x02\xfb"
  "\x0c\xd2\x05\x81\x89\x02\xfa\x0c\xd0\x05\x81\x87\x02\xf9\x0c\xce"
  "\x05\x81\x81\x02\xf8\x0c\xcc\x05\x81\x87\x02\xf7\x0c\xca\x05\x81"
  "\x8d\x02\xf6\x0c\xc8\x05\x81\x8b\x02\xf5\x0c\xc6\x05\x81\x89\x02"
  "\xf4\x0c\xc4\x05\x83\x04\xf3\x0c\xc2\x05\x81\x87\x02\xf2\x0c\xc0"
  "\x05\x83\x04\xf1\x0c\xbe\x05\x81\x81\x02\xf0\x0c\xbc\x05\x81\x87"
  "\x02\xef\x0c\xba\x05\x81\x83\x02\xee\x0c\xb8\x05\x81\x89\x02\xed"
  "\x0c\xb6\x05\x81\x87\x02\xec\x0c\xb4\x05\x81\x83\x02\xeb\x0c\xb2"
  "\x05\x81\x81\x02\xea\x0c\xb0\x05\x81\x87\x02\xe9\x0c\xae\x05\x81"
  "\x83\x02\xe8\x0c\xac\x05\x85\x08\xe7\x0c\xaa\x05\x81\x89\x02\xe6"
  "\x0c\xa8\x05\x81\x85\x02\xe5\x0c\xa6\x05\x81\x83\x02\xe4\x0c\xa4"
  "\x05\x81\x81\x02\xe3\x0c\xa2\x05\x81\x85\x02\xe2\x0c\xa0\x05\x85"
  "\x08\xe1\x0c\x9e\x05\x81\x87\x02\xe0\x0c\x9c\x05\x81\x85\x02\xdf"
  "\x0c\x9a\x05\x81\x83\x02\xde\x0c\x98\x05\x81\x81\x02\xdd\x0c\x96"
  "\x05\x83\x04\xdc\x0c\x94\x05\x81\x83\x02\xdb\x0c\x92\x05\x81\x89"
  "\x02\xda\x0c\x90\x05\x81\x87\x02\xd9\x0c\x8e\x05\x81\x85\x02\xd8"
  "\x0c\x8c\x05\x81\x87\x02\xd7\x0c\x8a\x05\x81\x85\x02\xd6\x0c\x88"
  "\x05\x81\x83\x02\xd5\x0c\x86\x05\x81\x81\x02\xd4\x0c\x84\x05\x81"
  "\x8b\x02\xd3\x0c\x82\x05\x81\x89\x02\xd2\x0c\x80\x05\x83\x04\xd1"
  "\x0c\xfe\x04\x81\x87\x02\xd0\x0c\xfc\x04\x81\x89\x02\xcf\x0c\xfa"
  "\x04\x81\x83\x02\xce\x0c\xf8\x04\x81\x87\x02\xcd\x0c\xf6\x04\x81"
  "\x85\x02\xcc\x0c\xf4\x04\x81\x83\x02\xcb\x0c\xf2\x04\x81\x81\x02"
  "\xca\x0c\xf0\x04\x81\x8b\x02\xc9\x0c\xee\x04\x81\x89\x02\xc8\x0c"
  "\xec\x04\x81\x83\x02\xc7\x0c\xea\x04\x81\x85\x02\xc6\x0c\xe8\x04"
  "\x81\x87\x02\xc5\x0c\xe6\x04\x81\x89\x02\xc4\x0c\xe4\x04\x81\x87"
  "\x02\xc3\x0c\xe2\x04\x81\x85\x02\xc2\x0c\xe0\x04\x81\x81\x02\xc1"
  "\x0c\xde\x04\x81\x83\x02\xc0\x0c\xdc\x04\x81\x89\x02\xbf\x0c\xda"
  "\x04\x81\x83\x02\xbe\x0c\xd8\x04\x81\x89\x02\xbd\x0c\xd6\x04\x81"
  "\x87\x02\xbc\x0c\xd4\x04\x81\x83\x02\xbb\x0c\xd2\x04\x81\x89\x02"
  "\xba\x0c\xd0\x04\x81\x85\x02\xb9\x0c\xce\x04\x81\x83\x02\xb8\x0c"
  "\xcc\x04\x81\x81\x02\xb7\x0c\xca\x04\x81\x85\x02\xb6\x0c\xc8\x04"
  "\x81\x83\x02\xb5\x0c\xc6\x04\x81\x89\x02\xb4\x0c\xc4\x04\x81\x87"
  "\x02\xb3\x0c\xc2\x04\x81\x89\x02\xb2\x0c\xc0\x04\x81\x87\x02\xb1"
  "\x0c\xbe\x04\x81\x85\x02\xb0\x0c\xbc\x04\x81\x81\x02\xaf\x0c\xba"
  "\x04\x81\x8d\x02\xae\x0c\xb8\x04\x81\x8b\x02\xad\x0c\xb6\x04\x81"
  "\x89\x02\xac\x0c\xb4\x04\x81\x87\x02\xab\x0c\xb2\x04\x81\x83\x02"
  "\xaa\x0c\xb0\x04\x81\x8d\x02\xa9\x0c\xae\x04\x81\x8b\x02\xa8\x0c"
  "\xac\x04\x81\x89\x02\xa7\x0c\xaa\x04\x81\x89\x02\xa6\x0c\xa8\x04"
  "\x81\x87\x02\xa5\x0c\xa6\x04\x81\x87\x02\xa4\x0c\xa4\x04\x81\x89"
  "\x02\xa3\x0c\xa2\x04\x81\x85\x02\xa2\x0c\xa0\x04\x81\x83\x02\xa1"
  "\x0c\x9e\x04\x81\x81\x02\xa0\x0c\x9c\x04\x81\x89\x02\x9f\x0c\x9a"
  "\x04\x81\x89\x02\x9e\x0c\x98\x04\x81\x85\x02\x9d\x0c\x96\x04\x81"
  "\x83\x02\x9c\x0c\x94\x04\x81\x89\x02\x9b\x0c\x92\x04\x81\x85\x02"
  "\x9a\x0c\x90\x04\x81\x87\x02\x99\x0c\x8e\x04\x81\x89\x02\x98\x0c"
  "\x8c\x04\x81\x85\x02\x97\x0c\x8a\x04\x81\x83\x02\x96\x0c\x88\x04"
  "\x81\x81\x02\x95\x0c\x86\x04\x81\x89\x02\x94\x0c\x84\x04\x81\x85"
  "\x02\x93\x0c\x82\x04\x81\x83\x02\x92\x0c\x80\x04\x81\x89\x02\x91"
  "\x0c\xfe\x03\x81\x89\x02\x90\x0c\xfc\x03\x81\x87\x02\x8f\x0c\xfa"
  "\x03\x81\x87\x02\x8e\x0c\xf8\x03\x81\x83\x02\x8d\x0c\xf6\x03\x81"
  "\x89\x02\x8c\x0c\xf4\x03\x81\x85\x02\x8b\x0c\xf2\x03\x81\x83\x02"
  "\x8a\x0c\xf0\x03\x81\x81\x02\x89\x0c\xee\x03\x81\x89\x02\x88\x0c"
  "\xec\x03\x81\x85\x02\x87\x0c\xea\x03\x81\x83\x02\x86\x0c\xe8\x03"
  "\x85\x08\x85\x0c\xe6\x03\x81\x87\x02\x84\x0c\xe4\x03\x81\x85\x02"
  "\x83\x0c\xe2\x03\x81\x81\x02\x82\x0c\xe0\x03\x81\x83\x02\x81\x0c"
  "\xde\x03\x85\x08\x80\x0c\xdc\x03\x81\x87\x02\xff\x0b\xda\x03\x81"
  "\x83\x02\xfe\x0b\xd8\x03\x81\x83\x02\xfd\x0b\xd6\x03\x81\x85\x02"
  "\xfc\x0b\xd4\x03\x81\x89\x02\xfb\x0b\xd2\x03\x81\x85\x02\xfa\x0b"
  "\xd0\x03\x81\x83\x02\xf9\x0b\xce\x03\x81\x81\x02\xf8\x0b\xcc\x03"
  "\x81\x89\x02\xf7\x0b\xca\x03\x81\x85\x02\xf6\x0b\xc8\x03\x83\x04"
  "\xf5\x0b\xc6\x03\x81\x87\x02\xf4\x0b\xc4\x03\x83\x04\xf3\x0b\xc2"
  "\x03\x81\x89\x02\xf2\x0b\xc0\x03\x81\x87\x02\xf1\x0b\xbe\x03\x81"
  "\x83\x02\xf0\x0b\xbc\x03\x81\x81\x02\xef\x0b\xba\x03\x81\x89\x02"
  "\xee\x0b\xb8\x03\x81\x89\x02\xed\x0b\xb6\x03\x81\x87\x02\xec\x0b"
  "\xb4\x03\x81\x83\x02\xeb\x0b\xb2\x03\x81\x83\x02\xea\x0b\xb0\x03"
  "\x81\x81\x02\xe9\x0b\xae\x03\x81\x8b\x02\xe8\x0b\xac\x03\x81\x87"
  "\x02\xe7\x0b\xaa\x03\x81\x87\x02\xe6\x0b\xa8\x03\x81\x89\x02\xe5"
  "\x0b\xa6\x03\x81\x85\x02\xe4\x0b\xa4\x03\x81\x81\x02\xe3\x0b\xa2"
  "\x03\x81\x89\x02\xe2\x0b\xa0\x03\x81\x85\x02\xe1\x0b\x9e\x03\x81"
  "\x87\x02\xe0\x0b\x9c\x03\x81\x89\x02\xdf\x0b\x9a\x03\x81\x85\x02"
  "\xde\x0b\x98\x03\x81\x83\x02\xdd\x0b\x96\x03\x81\x81\x02\xdc\x0b"
  "\x94\x03\x81\x89\x02\xdb\x0b\x92\x03\x81\x87\x02\xda\x0b\x90\x03"
  "\x81\x85\x02\xd9\x0b\x8e\x03\x81\x89\x02\xd8\x0b\x8c\x03\x81\x87"
  "\x02\xd7\x0b\x8a\x03\x81\x83\x02\xd6\x0b\x88\x03\x81\x89\x02\xd5"
  "\x0b\x86\x03\x81\x85\x02\xd4\x0b\x84\x03\x81\x83\x02\xd3\x0b\x82"
  "\x03\x81\x81\x02\xd2\x0b\x80\x03\x81\x8d\x02\xd1\x0b\xfe\x02\x81"
  "\x8b\x02\xd0\x0b\xfc\x02\x81\x85\x02\xcf\x0b\xfa\x02\x81\x89\x02"
  "\xce\x0b\xf8\x02\x81\x87\x02\xcd\x0b\xf6\x02\x81\x85\x02\xcc\x0b"
  "\xf4\x02\x81\x83\x02\xcb\x0b\xf2\x02\x81\x87\x02\xca\x0b\xf0\x02"
  "\x81\x89\x02\xc9\x0b\xee\x02\x81\x87\x02\xc8\x0b\xec\x02\x81\x85"
  "\x02\xc7\x0b\xea\x02\x81\x81\x02\xc6\x0b\xe8\x02\x81\x83\x02\xc5"
  "\x0b\xe6\x02\x81\x8f\x02\xc4\x0b\xe4\x02\x81\x8b\x02\xc3\x0b\xe2"
  "\x02\x81\x89\x02\xc2\x0b\xe0\x02\x81\x83\x02\xc1\x0b\xde\x02\x81"
  "\x8d\x02\xc0\x0b\xdc\x02\x81\x8b\x02\xbf\x0b\xda\x02\x81\x89\x02"
  "\xbe\x0b\xd8\x02\x84\x06\xbd\x0b\xd6\x02\x81\x89\x02\xbc\x0b\xd4"
  "\x02\x81\x83\x02\xbb\x0b\xd2\x02\x81\x87\x02\xba\x0b\xd0\x02\x81"
  "\x89\x02\xb9\x0b\xce\x02\x81\x85\x02\xb8\x0b\xcc\x02\x81\x83\x02"
  "\xb7\x0b\xca\x02\x81\x81\x02\xb6\x0b\xc8\x02\x81\x83\x02\xb5\x0b"
  "\xc6\x02\x81\x89\x02\xb4\x0b\xc4\x02\x81\x91\x02\xb3\x0b\xc2\x02"
  "\x81\x8f\x02\xb2\x0b\xc0\x02\x81\x8d\x02\xb1\x0b\xbe\x02\x81\x8d"
  "\x02\xb0\x0b\xbc\x02\x81\x8b\x02\xaf\x0b\xba\x02\x81\x89\x02\xae"
  "\x0b\xb8\x02\x81\x89\x02\xad\x0b\xb6\x02\x81\x83\x02\xac\x0b\xb4"
  "\x02\x81\x89\x02\xab\x0b\xb2\x02\x81\x8f\x02\xaa\x0b\xb0\x02\x81"
  "\x8d\x02\xa9\x0b\xae\x02\x81\x8d\x02\xa8\x0b\xac\x02\x81\x8b\x02"
  "\xa7\x0b\xaa\x02\x81\x89\x02\xa6\x0b\xa8\x02\x81\x8b\x02\xa5\x0b"
  "\xa6\x02\x81\x89\x02\xa4\x0b\xa4\x02\x81\x89\x02\xa3\x0b\xa2\x02"
  "\x81\x87\x02\xa2\x0b\xa0\x02\x81\x89\x02\xa1\x0b\x9e\x02\x81\x85"
  "\x02\xa0\x0b\x9c\x02\x81\x83\x02\x9f\x0b\x9a\x02\x81\x81\x02\x9e"
  "\x0b\x98\x02\x81\x83\x02\x9d\x0b\x96\x02\x81\x89\x02\x9c\x0b\x94"
  "\x02\x81\x89\x02\x9b\x0b\x92\x02\x81\x83\x02\x9a\x0b\x90\x02\x81"
  "\x8d\x02\x99\x0b\x8e\x02\x81\x8d\x02\x98\x0b\x8c\x02\x81\x89\x02"
  "\x97\x0b\x8a\x02\x81\x89\x02\x96\x0b\x88\x02\x81\x89\x02\x95\x0b"
  "\x86\x02\x85\x08\x94\x0b\x84\x02\x81\x87\x02\x93\x0b\x82\x02\x81"
  "\x89\x02\x92\x0b\x80\x02\x81\x85\x02\x91\x0b\xfe\x01\x81\x83\x02"
  "\x90\x0b\xfc\x01\x81\x81\x02\x8f\x0b\xfa\x01\x81\x89\x02\x8e\x0b"
  "\xf8\x01\x81\x85\x02\x8d\x0b\xf6\x01\x81\x83\x02\x8c\x0b\xf4\x01"
  "\x81\x89\x02\x8b\x0b\xf2\x01\x81\x89\x02\x8a\x0b\xf0\x01\x81\x89"
  "\x02\x89\x0b\xee\x01\x81\x89\x02\x88\x0b\xec\x01\x85\x08\x87\x0b"
  "\xea\x01\x81\x89\x02\x86\x0b\xe8\x01\x81\x85\x02\x85\x0b\xe6\x01"
  "\x81\x89\x02\x84\x0b\xe4\x01\x81\x85\x02\x83\x0b\xe2\x01\x81\x83"
  "\x02\x82\x0b\xe0\x01\x81\x81\x02\x81\x0b\xde\x01\x81\x89\x02\x80"
  "\x0b\xdc\x01\x81\x8d\x02\xff\x0a\xda\x01\x81\x8b\x02\xfe\x0a\xd8"
  "\x01\x81\x8b\x02\xfd\x0a\xd6\x01\x81\x89\x02\xfc\x0a\xd4\x01\x81"
  "\x89\x02\xfb\x0a\xd2\x01\x81\x89\x02\xfa\x0a\xd0\x01\x81\x89\x02"
  "\xf9\x0a\xce\x01\x81\x89\x02\xf8\x0a\xcc\x01\x81\x83\x02\xf7\x0a"
  "\xca\x01\x83\x04\xf6\x0a\xc8\x01\x81\x83\x02\xf5\x0a\xc6\x01\x81"
  "\x8b\x02\xf4\x0a\xc4\x01\x81\x87\x02\xf3\x0a\xc2\x01\x81\x83\x02"
  "\xf2\x0a\xc0\x01\x81\x81\x02\xf1\x0a\xbe\x01\x81\x83\x02\xf0\x0a"
  "\xbc\x01\x81\x89\x02\xef\x0a\xba\x01\x81\x89\x02\xee\x0a\xb8\x01"
  "\x81\x89\x02\xed\x0a\xb6\x01\x85\x08\xec\x0a\xb4\x01\x81\x87\x02"
  "\xeb\x0a\xb2\x01\x81\x81\x02\xea\x0a\xb0\x01\x81\x81\x02\xe9\x0a"
  "\xae\x01\x81\x83\x02\xe8\x0a\xac\x01\x81\x89\x02\xe7\x0a\xaa\x01"
  "\x81\x89\x02\xe6\x0a\xa8\x01\x85\x08\xe5\x0a\xa6\x01\x81\x85\x02"
  "\xe4\x0a\xa4\x01\x81\x89\x02\xe3\x0a\xa2\x01\x81\x85\x02\xe2\x0a"
  "\xa0\x01\x81\x87\x02\xe1\x0a\x9e\x01\x81\x85\x02\xe0\x0a\x9c\x01"
  "\x81\x83\x02\xdf\x0a\x9a\x01\x81\x81\x02\xde\x0a\x98\x01\x81\x8f"
  "\x02\xdd\x0a\x96\x01\x81\x8b\x02\xdc\x0a\x94\x01\x85\x08\xdb\x0a"
  "\x92\x01\x81\x85\x02\xda\x0a\x90\x01\x81\x85\x02\xd9\x0a\x8e\x01"
  "\x81\x8d\x02\xd8\x0a\x8c\x01\x81\x8b\x02\xd7\x0a\x8a\x01\x81\x89"
  "\x02\xd6\x0a\x88\x01\x81\x87\x02\xd5\x0a\x86\x01\x81\x85\x02\xd4"
  "\x0a\x84\x01\x84\x06\xd3\x0a\x82\x01\x81\x87\x02\xd2\x0a\x80\x01"
  "\x81\x8d\x02\xd1\x0a\x7e\x81\x8b\x02\xd0\x0a\x7c\x81\x87\x02\xcf"
  "\x0a\x7a\x81\x83\x02\xce\x0a\x78\x81\x87\x02\xcd\x0a\x76\x81\x85"
  "\x02\xcc\x0a\x74\x81\x83\x02\xcb\x0a\x72\x81\x81\x02\xca\x0a\x70"
  "\x81\x93\x02\xc9\x0a\x6e\x81\x8d\x02\xc8\x0a\x6c\x81\x91\x02\xc7"
  "\x0a\x6a\x81\x8d\x02\xc6\x0a\x68\x81\x89\x02\xc5\x0a\x66\x81\x87"
  "\x02\xc4\x0a\x64\x81\x85\x02\xc3\x0a\x62\x84\x06\xc2\x0a\x60\x81"
  "\x91\x02\xc1\x0a\x5e\x81\x8d\x02\xc0\x0a\x5c\x81\x89\x02\xbf\x0a"
  "\x5a\x81\x85\x02\xbe\x0a\x58\x81\x89\x02\xbd\x0a\x56\x81\x83\x02"
  "\xbc\x0a\x54\x81\x8d\x02\xbb\x0a\x52\x81\x8b\x02\xba\x0a\x50\x81"
  "\x81\x02\xb9\x0a\x4e\x81\x95\x02\xb8\x0a\x4c\x81\x8f\x02\xb7\x0a"
  "\x4a\x81\x89\x02\xb6\x0a\x48\x81\x85\x02\xb5\x0a\x46\x81\x89\x02"
  "\xb4\x0a\x44\x81\x83\x02\xb3\x0a\x42\x81\x81\x02\xb2\x0a\x40\x81"
  "\x87\x02\xb1\x0a\x3e\x81\x81\x02\xb0\x0a\x3c\x81\x87\x02\xaf\x0a"
  "\x3a\x81\x85\x02\xae\x0a\x38\x81\x83\x02\xad\x0a\x36\x81\x81\x02"
  "\xac\x0a\x34\x81\x87\x02\xab\x0a\x32\x81\x85\x02\xaa\x0a\x30\x81"
  "\x83\x02\xa9\x0a\x2e\x81\x81\x02\xa8\x0a\x2c\x81\x87\x02\xa7\x0a"
  "\x2a\x81\x85\x02\xa6\x0a\x28\x81\x83\x02\xa5\x0a\x26\x81\x81\x02"
  "\xa4\x0a\x24\x81\x87\x02\xa3\x0a\x22\x81\x87\x02\xa2\x0a\x20\x81"
  "\x85\x02\xa1\x0a\x1e\x81\x83\x02\xa0\x0a\x1c\x81\x81\x02\x9f\x0a"
  "\x1a\x81\x89\x02\x9e\x0a\x18\x81\x85\x02\x9d\x0a\x16\x81\x83\x02"
  "\x9c\x0a\x14\x81\x81\x02\x9b\x0a\x12\x81\x87\x02\x9a\x0a\x10\x81"
  "\x85\x02\x99\x0a\x0e\x81\x83\x02\x98\x0a\x0c\x81\x81\x02\x97\x0a"
  "\x0a\x81\x87\x02\x96\x0a\x08\x81\x85\x02\x95\x0a\x06\x81\x83\x02"
  "\x94\x0a\x04\x82\x02\x8d\x07\x9a\x09\xc6\x02\x02\x91\x01\x02\x03"
  "\x8e\x02\x05\x0f\x6c\x70\x3a\x68\x65\x78\x61\x64\x65\x63\x69\x6d"
  "\x61\x6c\x05\xa3\x01\x03\x05\xba\x01\x04\x8f\x02\x07\xe4\x0d\x18"
  "\x81\x89\x02\xe3\x0d\x16\x81\x87\x02\xe2\x0d\x14\x81\x85\x02\xe1"
  "\x0d\x12\x81\x83\x02\xe0\x0d\x10\x81\x89\x02\xdf\x0d\x0e\x81\x83"
  "\x02\xde\x0d\x0c\x81\x89\x02\xdd\x0d\x0a\x82\x02\xdc\x0d\x08\x85"
  "\x08\xdb\x0d\x06\x81\x83\x02\xda\x0d\x04\x83\x04\x17\x2d\x8f\x02"
  "\x02\x92\x01\x0c\x73\x74\x72\x69\x6e\x67\x2d\x73\x65\x74\x21\x01"
  "\x60\x7e\x02\x0f\x4d\x49\x54\x2d\x47\x4e\x55\x2d\x53\x63\x68\x65"
  "\x6d\x65\x7f\x08\x72\x65\x6c\x65\x61\x73\x65\x18\x64\x65\x66\x61"
  "\x75\x6c\x74\x2d\x68\x74\x74\x70\x2d\x75\x73\x65\x72\x2d\x61\x67"
  "\x65\x6e\x74\x7e\x02\x73\x02\x03\x1d\x67\x65\x74\x2d\x73\x75\x62"
  "\x73\x79\x73\x74\x65\x6d\x2d\x76\x65\x72\x73\x69\x6f\x6e\x2d\x73"
  "\x74\x72\x69\x6e\x67\x03\x0c\x73\x74\x72\x69\x6e\x67\x2d\x63\x6f"
  "\x70\x79\x04\x80\x01\x04\xf0\x0d\x1a\x81\x87\x02\xef\x0d\x18\x81"
  "\x87\x02\xee\x0d\x16\x81\x87\x02\xed\x0d\x14\x81\x8b\x02\xec\x0d"
  "\x12\x81\x89\x02\xeb\x0d\x10\x81\x81\x02\xea\x0d\x0e\x81\x87\x02"
  "\xe9\x0d\x0c\x81\x87\x02\xe8\x0d\x0a\x81\x83\x02\xe7\x0d\x08\x81"
  "\x83\x02\xe6\x0d\x06\x81\x81\x02\xe5\x0d\x04\x82\x02\x19\x30\x80"
  "\x01\x02\x93\x01\x07\x76\x61\x6c\x75\x65\x73\x02\x03\x3a\x02\xf3"
  "\x0d\x08\x81\x85\x02\xf2\x0d\x06\x81\x83\x02\xf1\x0d\x04\x83\x04"
  "\x07\x10\x3a\x02\x94\x01\x11\x04\xc7\x01\x02\xf7\x0d\x0a\x81\x83"
  "\x02\xf6\x0d\x08\x81\x85\x02\xf5\x0d\x06\x81\x85\x02\xf4\x0d\x04"
  "\x83\x04\x09\x12\x02\x95\x01\x03\x57\x04\x19\x65\x6e\x63\x6f\x64"
  "\x65\x2d\x62\x61\x73\x65\x36\x34\x3a\x69\x6e\x69\x74\x69\x61\x6c"
  "\x69\x7a\x65\x03\xc3\x02\x03\x17\x65\x6e\x63\x6f\x64\x65\x2d\x62"
  "\x61\x73\x65\x36\x34\x3a\x66\x69\x6e\x61\x6c\x69\x7a\x65\x06\x15"
  "\x65\x6e\x63\x6f\x64\x65\x2d\x62\x61\x73\x65\x36\x34\x3a\x75\x70"
  "\x64\x61\x74\x65\x06\xfc\x0d\x0c\x81\x89\x02\xfb\x0d\x0a\x81\x87"
  "\x02\xfa\x0d\x08\x81\x85\x02\xf9\x0d\x06\x81\x85\x02\xf8\x0d\x04"
  "\x83\x04\x0b\x1a\xc3\x02\x02\x96\x01\x7f\x07\x62\x69\x6e\x61\x72"
  "\x79\x1d\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x2d\x74\x79\x70\x65"
  "\x3a\x64\x65\x63\x6f\x64\x65\x2d\x62\x61\x73\x65\x36\x34\x02\x03"
  "\x1f\x63\x61\x6c\x6c\x2d\x77\x69\x74\x68\x2d\x63\x75\x72\x72\x65"
  "\x6e\x74\x2d\x63\x6f\x6e\x74\x69\x6e\x75\x61\x74\x69\x6f\x6e\x05"
  "\x17\x62\x69\x6e\x64\x2d\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x2d"
  "\x68\x61\x6e\x64\x6c\x65\x72\x03\x18\x63\x61\x6c\x6c\x2d\x77\x69"
  "\x74\x68\x2d\x6f\x75\x74\x70\x75\x74\x2d\x6f\x63\x74\x65\x74\x73"
  "\x04\x10\x70\x6f\x72\x74\x2f\x73\x65\x74\x2d\x63\x6f\x64\x69\x6e"
  "\x67\x04\x15\x70\x6f\x72\x74\x2f\x73\x65\x74\x2d\x6c\x69\x6e\x65"
  "\x2d\x65\x6e\x64\x69\x6e\x67\x04\x19\x64\x65\x63\x6f\x64\x65\x2d"
  "\x62\x61\x73\x65\x36\x34\x3a\x69\x6e\x69\x74\x69\x61\x6c\x69\x7a"
  "\x65\x06\x15\x64\x65\x63\x6f\x64\x65\x2d\x62\x61\x73\x65\x36\x34"
  "\x3a\x75\x70\x64\x61\x74\x65\x03\x17\x64\x65\x63\x6f\x64\x65\x2d"
  "\x62\x61\x73\x65\x36\x34\x3a\x66\x69\x6e\x61\x6c\x69\x7a\x65\x09"
  "\x87\x0e\x18\x81\x87\x02\x86\x0e\x16\x81\x89\x02\x85\x0e\x14\x81"
  "\x85\x02\x84\x0e\x12\x81\x85\x02\x83\x0e\x10\x81\x85\x02\x82\x0e"
  "\x0e\x81\x85\x02\x81\x0e\x0c\x81\x85\x02\x80\x0e\x0a\x81\x83\x02"
  "\xff\x0d\x08\x81\x85\x02\xfe\x0d\x06\x81\x85\x02\xfd\x0d\x04\x83"
  "\x04\x17\x31\x7f\x96\x01\x57\x57\x7f\x04\xc2\x02\xc1\x02\xc3\x02"
  "\x04\x31\x04\x0f\x76\x65\x63\x74\x6f\x72\x2d\x3e\x76\x61\x6c\x75"
  "\x65\x73\x3a\x04\x80\x01\x04\x7e\x18\x70\x61\x72\x73\x65\x2d\x68"
  "\x74\x74\x70\x2d\x63\x68\x75\x6e\x6b\x2d\x6c\x65\x61\x64\x65\x72"
  "\x8f\x02\x04\xc6\x02\x04\xb3\x02\x12\x04\x87\x02\x90\x02\x04\xb2"
  "\x02\x8d\x02\x04\xb9\x02\x8a\x02\x04\x84\x02\x08\x68\x76\x64\x65"
  "\x66\x6e\x3f\x85\x02\x04\x0e\x68\x76\x64\x65\x66\x6e\x2d\x77\x72"
  "\x69\x74\x65\x72\x83\x02\x04\x11\x68\x76\x64\x65\x66\x6e\x2d\x70"
  "\x72\x65\x64\x69\x63\x61\x74\x65\x82\x02\x04\x0e\x68\x76\x64\x65"
  "\x66\x6e\x2d\x70\x61\x72\x73\x65\x72\x81\x02\x04\xf8\x01\x0c\x68"
  "\x76\x64\x65\x66\x6e\x2d\x6e\x61\x6d\x65\x80\x02\x04\x0b\x72\x74"
  "\x64\x3a\x68\x76\x64\x65\x66\x6e\xc6\x02\x07\x68\x76\x64\x65\x66"
  "\x6e\x05\x6e\x61\x6d\x65\xc3\x02\x07\x70\x61\x72\x73\x65\x72\x0a"
  "\x70\x72\x65\x64\x69\x63\x61\x74\x65\x07\x77\x72\x69\x74\x65\x72"
  "\xfc\x01\x04\xfd\x01\x04\xfe\x01\x04\xff\x01\x04\xfb\x01\x04\x83"
  "\x01\x55\xfa\x01\x04\x89\x02\xf9\x01\x04\xed\x01\x84\x01\x04\xf6"
  "\x01\x04\xf4\x01\xf5\x01\x04\xee\x01\xe3\x01\x04\xf0\x01\xf2\x01"
  "\x04\xef\x01\xf1\x01\x04\x82\x01\xe8\x01\x04\xcc\x01\xeb\x01\x04"
  "\x7a\xec\x01\x04\xea\x01\xe4\x01\x04\x86\x01\xe9\x01\x04\x73\xe5"
  "\x01\x04\x1a\x70\x72\x69\x6d\x69\x74\x69\x76\x65\x2d\x6f\x62\x6a"
  "\x65\x63\x74\x2d\x73\x65\x74\x2d\x74\x79\x70\x65\x33\x10\x17\x64"
  "\x65\x66\x69\x6e\x65\x2d\x74\x6f\x6b\x65\x6e\x69\x7a\x65\x72\x2d"
  "\x73\x74\x61\x74\x65\x17\xe6\x01\x04\x9c\x01\x9b\x01\xe2\x01\x04"
  "\xf7\x01\x99\x01\x98\x01\xe1\x01\x04\xf3\x01\x93\x01\xe0\x01\x04"
  "\x94\x01\xdf\x01\x04\x16\x73\x65\x70\x61\x72\x61\x74\x6f\x72\x2d"
  "\x74\x6f\x6b\x65\x6e\x2d\x3e\x63\x68\x61\x72\xde\x01\x04\x11\x73"
  "\x65\x70\x61\x72\x61\x74\x6f\x72\x2d\x74\x6f\x6b\x65\x6e\x3f\xdd"
  "\x01\x04\x0b\x6c\x77\x73\x2d\x74\x6f\x6b\x65\x6e\x3f\x9e\x01\x04"
  "\xe7\x01\x2a\x04\x8e\x02\x7b\x04\xaa\x02\xa9\x02\xdc\x01\x04\x01"
  "\x30\xd9\x01\xab\x02\xd7\x01\x04\xda\x01\xd2\x01\xd4\x01\x04\xa5"
  "\x02\xd5\x01\xd3\x01\x04\xa8\x02\xad\x02\xd0\x01\xd1\x01\x04\xa6"
  "\x02\xcf\x01\x04\xcd\x01\x06\x62\x79\x74\x65\x73\xa0\x02\xc0\x01"
  "\xce\x01\x04\xa1\x02\xa2\x02\xa6\x01\xa3\x02\x62\x04\xbb\x02\xa7"
  "\x02\x91\x01\x04\x95\x02\xaf\x02\x6f\x04\x97\x02\x9e\x02\xbc\x02"
  "\xcb\x01\x04\x9f\x02\xc6\x01\xc9\x01\x04\xca\x01\xc8\x01\x04\xc5"
  "\x01\x04\xc4\x01\x04\x38\x04\xc2\x01\xc5\x02\xc1\x01\x04\x12\x77"
  "\x72\x69\x74\x65\x2d\x6f\x70\x74\x2d\x64\x65\x63\x69\x6d\x61\x6c"
  "\xc5\x02\xbf\x01\x04\xa4\x02\x11\x0b\xb0\x02\x11\x6c\x70\x3a\x6e"
  "\x75\x6d\x65\x72\x69\x63\x2d\x74\x6f\x6b\x65\x6e\xc2\x02\x32\x04"
  "\xb1\x02\x01\x2e\x9d\x02\xbd\x01\x04\x9b\x02\x15\x04\x98\x02\xbd"
  "\x02\xbb\x01\x04\x99\x02\xb9\x01\x04\x9a\x02\xb8\x01\x04\x91\x02"
  "\xb7\x01\xb6\x01\x04\x92\x02\x02\x3b\x93\x02\xb4\x01\x04\xb7\x02"
  "\xb2\x01\x04\x9c\x02\xc4\x02\xaf\x01\x04\xad\x01\x03\x3b\x20\x01"
  "\x3e\xb0\x01\xa3\x01\xac\x01\x04\xbc\x01\xa7\x01\xab\x01\x04\xba"
  "\x01\xaa\x01\x04\xb5\x01\xa4\x01\xa9\x01\x04\xae\x02\xb3\x01\xa5"
  "\x01\x04\xa0\x01\x01\x3b\x02\x2a\xc0\x02\xa2\x01\x04\x9f\x01\x08"
  "\xd6\x01\x9d\x01\x0a\x96\x01\x9a\x01\x0a\xac\x02\xa8\x01\x97\x01"
  "\x04\xbf\x02\x90\x01\x95\x01\x0a\x52\xa1\x01\x92\x01\x04\x8c\x01"
  "\x8f\x01\x04\x11\x18\x49\x6c\x6c\x2d\x66\x6f\x72\x6d\x65\x64\x20"
  "\x48\x54\x54\x50\x20\x68\x65\x61\x64\x65\x72\x3a\x58\x8b\x01\x04"
  "\x5a\x8a\x01\x04\x88\x01\x12\x72\x65\x61\x64\x2d\x68\x74\x74\x70"
  "\x2d\x68\x65\x61\x64\x65\x72\x73\x89\x01\x04\xd8\x01\x87\x01\x04"
  "\x0b\x77\x72\x69\x74\x65\x2d\x74\x65\x78\x74\xc1\x02\x94\x02\x85"
  "\x01\x04\x7c\x81\x01\x04\xc3\x01\x7d\x04\x77\x79\x04\x56\x78\x04"
  "\x76\x75\x04\x6e\x74\x04\x11\x70\x61\x72\x73\x65\x2d\x68\x74\x74"
  "\x70\x2d\x74\x6f\x6b\x65\x6e\x72\x04\x63\x70\x04\x6b\x6d\x04\x1c"
  "\x67\x75\x61\x72\x61\x6e\x74\x65\x65\x2d\x68\x74\x74\x70\x2d\x74"
  "\x6f\x6b\x65\x6e\x2d\x73\x74\x72\x69\x6e\x67\x6c\x04\x6a\x69\x04"
  "\x23\x68\x04\x65\x67\x04\x54\x66\x04\x5d\x64\x04\x61\x04\x8d\x01"
  "\x5f\x04\x15\x63\x6f\x6e\x76\x65\x72\x74\x2d\x68\x74\x74\x70\x2d"
  "\x68\x65\x61\x64\x65\x72\x73\x5e\x04\x53\x5b\x04\x60\x51\x04\x4d"
  "\x4f\x04\x19\x68\x74\x74\x70\x2d\x68\x65\x61\x64\x65\x72\x2d\x70"
  "\x61\x72\x73\x65\x64\x2d\x76\x61\x6c\x75\x65\x16\x67\x75\x61\x72"
  "\x61\x6e\x74\x65\x65\x2d\x68\x74\x74\x70\x2d\x68\x65\x61\x64\x65"
  "\x72\x4e\x04\x8e\x01\x0d\x70\x61\x72\x73\x65\x64\x2d\x76\x61\x6c"
  "\x75\x65\xbf\x02\x50\x06\x76\x61\x6c\x75\x65\xbd\x02\x4c\xc3\x02"
  "\x59\x0e\x3c\x68\x74\x74\x70\x2d\x68\x65\x61\x64\x65\x72\x3e\xbc"
  "\x02\xc3\x02\xbd\x02\xbf\x02\x96\x02\x4b\x04\x12\x70\x61\x72\x73"
  "\x65\x2d\x68\x74\x74\x70\x2d\x73\x74\x61\x74\x75\x73\x4a\x04\x12"
  "\x68\x74\x74\x70\x2d\x73\x74\x61\x74\x75\x73\x2d\x6d\x61\x6a\x6f"
  "\x72\x49\x04\x46\x48\x04\x16\x67\x75\x61\x72\x61\x6e\x74\x65\x65"
  "\x2d\x68\x74\x74\x70\x2d\x73\x74\x61\x74\x75\x73\x47\x04\x45\x44"
  "\x04\x43\x04\x42\x41\x04\x40\x13\x77\x72\x69\x74\x65\x2d\x68\x74"
  "\x74\x70\x2d\x76\x65\x72\x73\x69\x6f\x6e\x3f\x04\x13\x70\x61\x72"
  "\x73\x65\x2d\x68\x74\x74\x70\x2d\x76\x65\x72\x73\x69\x6f\x6e\x3c"
  "\x04\x0f\x68\x74\x74\x70\x2d\x76\x65\x72\x73\x69\x6f\x6e\x3c\x3f"
  "\x30\x04\x0f\x68\x74\x74\x70\x2d\x76\x65\x72\x73\x69\x6f\x6e\x3d"
  "\x3f\x2f\x04\x13\x68\x74\x74\x70\x2d\x76\x65\x72\x73\x69\x6f\x6e"
  "\x2d\x6d\x69\x6e\x6f\x72\x2e\x04\x13\x68\x74\x74\x70\x2d\x76\x65"
  "\x72\x73\x69\x6f\x6e\x2d\x6d\x61\x6a\x6f\x72\x2d\x04\x33\x2c\x04"
  "\x28\x2b\x04\x17\x67\x75\x61\x72\x61\x6e\x74\x65\x65\x2d\x68\x74"
  "\x74\x70\x2d\x76\x65\x72\x73\x69\x6f\x6e\x29\x04\x27\x26\x04\xbe"
  "\x01\x24\x04\xdb\x01\x22\x04\x1c\x21\x04\x1f\x20\x04\xb5\x02\x18"
  "\x04\xb1\x01\x1d\x04\x88\x02\x1b\x04\x1a\x19\x04\xba\x02\x16\x04"
  "\xb6\x02\x0c\x04\xb4\x02\x14\x04\xb8\x02\x13\x04\x8c\x02\x0f\x04"
  "\x86\x02\x10\x04\xae\x01\x0e\x04\xbe\x02\x0d\x04\x8b\x02\x0b\x04"
  "\x11\x6c\x6f\x63\x61\x6c\x2d\x61\x73\x73\x69\x67\x6e\x6d\x65\x6e"
  "\x74\x0a\x09\x04\x04\x1f\x73\x63\x2d\x6d\x61\x63\x72\x6f\x2d\x74"
  "\x72\x61\x6e\x73\x66\x6f\x72\x6d\x65\x72\x2d\x3e\x65\x78\x70\x61"
  "\x6e\x64\x65\x72\x06\x11\x6d\x61\x6b\x65\x2d\x72\x65\x63\x6f\x72"
  "\x64\x2d\x74\x79\x70\x65\xc3\x02\x03\x19\x72\x65\x63\x6f\x72\x64"
  "\x2d\x74\x79\x70\x65\x2d\x64\x69\x73\x70\x61\x74\x63\x68\x2d\x74"
  "\x61\x67\x04\xbc\x02\xc3\x01\x3d\x63\x73\xa1\x01\x23\x5c\x76\x5d"
  "\x86\x01\xc1\x02\xb5\x01\xb0\x01\x25\x3e\x08\x73\x74\x72\x69\x6e"
  "\x67\x3f\x9f\x02\x9e\x02\xaf\x02\xa0\x01\x09\x62\x6f\x6f\x6c\x65"
  "\x61\x6e\x3f\xa7\x02\xa3\x02\xa6\x01\xae\x02\xd0\x01\xc5\x02\x6a"
  "\x94\x02\xda\x01\xc6\x02\x21\x03\x0f\x61\x64\x64\x2d\x62\x6f\x6f"
  "\x74\x2d\x69\x6e\x69\x74\x21\x04\xc3\x02\x04\x13\x72\x65\x63\x6f"
  "\x72\x64\x2d\x63\x6f\x6e\x73\x74\x72\x75\x63\x74\x6f\x72\x03\x11"
  "\x72\x65\x63\x6f\x72\x64\x2d\x70\x72\x65\x64\x69\x63\x61\x74\x65"
  "\x04\x10\x72\x65\x63\x6f\x72\x64\x2d\x61\x63\x63\x65\x73\x73\x6f"
  "\x72\x04\x17\x73\x69\x6d\x70\x6c\x65\x2d\x75\x6e\x70\x61\x72\x73"
  "\x65\x72\x2d\x6d\x65\x74\x68\x6f\x64\x04\x21\x73\x65\x74\x2d\x72"
  "\x65\x63\x6f\x72\x64\x2d\x74\x79\x70\x65\x2d\x75\x6e\x70\x61\x72"
  "\x73\x65\x72\x2d\x6d\x65\x74\x68\x6f\x64\x21\x05\xdb\x01\x04\xc7"
  "\x01\x04\x1e\x03\x71\x03\x34\x03\x55\x04\x36\x05\x59\x02\x58\x05"
  "\x5a\x04\x35\x03\x8b\x02\x03\x88\x02\x04\x37\x03\xbe\x02\x04\x39"
  "\x03\xbe\x01\x04\xae\x01\x03\xb4\x02\x03\x1f\x05\xb1\x01\x03\x86"
  "\x02\x04\x3b\x04\x1a\x03\xc4\x02\x04\xb7\x02\x03\xc2\x02\x04\xb6"
  "\x02\x03\x8c\x02\x05\xc0\x02\x04\xba\x02\x27\xfd\x02\xfc\x05\x80"
  "\x80\x04\xfc\x02\xfa\x05\x81\x81\x02\xfb\x02\xf8\x05\x81\x81\x02"
  "\xfa\x02\xf6\x05\x81\x83\x02\xf9\x02\xf4\x05\x81\x83\x02\xf8\x02"
  "\xf2\x05\x81\x83\x02\xf7\x02\xf0\x05\x81\x83\x02\xf6\x02\xee\x05"
  "\x81\x83\x02\xf5\x02\xec\x05\x81\x83\x02\xf4\x02\xea\x05\x81\x83"
  "\x02\xf3\x02\xe8\x05\x81\x83\x02\xf2\x02\xe6\x05\x81\x83\x02\xf1"
  "\x02\xe4\x05\x81\x83\x02\xf0\x02\xe2\x05\x81\x83\x02\xef\x02\xe0"
  "\x05\x81\x83\x02\xee\x02\xde\x05\x81\x85\x02\xed\x02\xdc\x05\x81"
  "\x83\x02\xec\x02\xda\x05\x81\x87\x02\xeb\x02\xd8\x05\x81\x83\x02"
  "\xea\x02\xd6\x05\x81\x83\x02\xe9\x02\xd4\x05\x81\x83\x02\xe8\x02"
  "\xd2\x05\x81\x8b\x02\xe7\x02\xd0\x05\x81\x83\x02\xe6\x02\xce\x05"
  "\x81\x85\x02\xe5\x02\xcc\x05\x81\x83\x02\xe4\x02\xca\x05\x81\x85"
  "\x02\xe3\x02\xc8\x05\x81\x87\x02\xe2\x02\xc6\x05\x81\x83\x02\xe1"
  "\x02\xc4\x05\x81\x83\x02\xe0\x02\xc2\x05\x81\x83\x02\xdf\x02\xc0"
  "\x05\x81\x83\x02\xde\x02\xbe\x05\x81\x83\x02\xdd\x02\xbc\x05\x81"
  "\x83\x02\xdc\x02\xba\x05\x81\x83\x02\xdb\x02\xb8\x05\x81\x83\x02"
  "\xda\x02\xb6\x05\x81\x83\x02\xd9\x02\xb4\x05\x81\x83\x02\xd8\x02"
  "\xb2\x05\x81\x83\x02\xd7\x02\xb0\x05\x81\x83\x02\xd6\x02\xae\x05"
  "\x81\x83\x02\xd5\x02\xac\x05\x81\x83\x02\xd4\x02\xaa\x05\x81\x83"
  "\x02\xd3\x02\xa8\x05\x81\x83\x02\xd2\x02\xa6\x05\x81\x83\x02\xd1"
  "\x02\xa4\x05\x81\x83\x02\xd0\x02\xa2\x05\x81\x83\x02\xcf\x02\xa0"
  "\x05\x81\x83\x02\xce\x02\x9e\x05\x81\x83\x02\xcd\x02\x9c\x05\x81"
  "\x83\x02\xcc\x02\x9a\x05\x81\x83\x02\xcb\x02\x98\x05\x81\x83\x02"
  "\xca\x02\x96\x05\x81\x83\x02\xc9\x02\x94\x05\x81\x83\x02\xc8\x02"
  "\x92\x05\x81\x83\x02\xc7\x02\x90\x05\x81\x83\x02\xc6\x02\x8e\x05"
  "\x81\x87\x02\xc5\x02\x8c\x05\x81\x85\x02\xc4\x02\x8a\x05\x81\x83"
  "\x02\xc3\x02\x88\x05\x81\x83\x02\xc2\x02\x86\x05\x81\x89\x02\xc1"
  "\x02\x84\x05\x81\x85\x02\xc0\x02\x82\x05\x81\x83\x02\xbf\x02\x80"
  "\x05\x81\x87\x02\xbe\x02\xfe\x04\x81\x83\x02\xbd\x02\xfc\x04\x81"
  "\x89\x02\xbc\x02\xfa\x04\x81\x85\x02\xbb\x02\xf8\x04\x81\x83\x02"
  "\xba\x02\xf6\x04\x81\x87\x02\xb9\x02\xf4\x04\x81\x83\x02\xb8\x02"
  "\xf2\x04\x81\x83\x02\xb7\x02\xf0\x04\x81\x83\x02\xb6\x02\xee\x04"
  "\x81\x83\x02\xb5\x02\xec\x04\x81\x83\x02\xb4\x02\xea\x04\x81\x83"
  "\x02\xb3\x02\xe8\x04\x81\x83\x02\xb2\x02\xe6\x04\x81\x83\x02\xb1"
  "\x02\xe4\x04\x81\x87\x02\xb0\x02\xe2\x04\x81\x85\x02\xaf\x02\xe0"
  "\x04\x81\x83\x02\xae\x02\xde\x04\x81\x8b\x02\xad\x02\xdc\x04\x81"
  "\x89\x02\xac\x02\xda\x04\x81\x83\x02\xab\x02\xd8\x04\x81\x8b\x02"
  "\xaa\x02\xd6\x04\x81\x87\x02\xa9\x02\xd4\x04\x81\x85\x02\xa8\x02"
  "\xd2\x04\x81\x83\x02\xa7\x02\xd0\x04\x81\x89\x02\xa6\x02\xce\x04"
  "\x81\x87\x02\xa5\x02\xcc\x04\x81\x85\x02\xa4\x02\xca\x04\x81\x89"
  "\x02\xa3\x02\xc8\x04\x81\x83\x02\xa2\x02\xc6\x04\x81\x89\x02\xa1"
  "\x02\xc4\x04\x81\x83\x02\xa0\x02\xc2\x04\x81\x83\x02\x9f\x02\xc0"
  "\x04\x81\x87\x02\x9e\x02\xbe\x04\x81\x85\x02\x9d\x02\xbc\x04\x81"
  "\x83\x02\x9c\x02\xba\x04\x81\x85\x02\x9b\x02\xb8\x04\x81\x8d\x02"
  "\x9a\x02\xb6\x04\x81\x89\x02\x99\x02\xb4\x04\x81\x83\x02\x98\x02"
  "\xb2\x04\x81\x8d\x02\x97\x02\xb0\x04\x81\x85\x02\x96\x02\xae\x04"
  "\x81\x87\x02\x95\x02\xac\x04\x81\x83\x02\x94\x02\xaa\x04\x81\x8f"
  "\x02\x93\x02\xa8\x04\x81\x8b\x02\x92\x02\xa6\x04\x81\x89\x02\x91"
  "\x02\xa4\x04\x81\x85\x02\x90\x02\xa2\x04\x81\x83\x02\x8f\x02\xa0"
  "\x04\x81\x85\x02\x8e\x02\x9e\x04\x81\x8d\x02\x8d\x02\x9c\x04\x81"
  "\x83\x02\x8c\x02\x9a\x04\x81\x85\x02\x8b\x02\x98\x04\x81\x83\x02"
  "\x8a\x02\x96\x04\x81\x83\x02\x89\x02\x94\x04\x81\x83\x02\x88\x02"
  "\x92\x04\x81\x83\x02\x87\x02\x90\x04\x81\x8b\x02\x86\x02\x8e\x04"
  "\x81\x89\x02\x85\x02\x8c\x04\x81\x87\x02\x84\x02\x8a\x04\x81\x85"
  "\x02\x83\x02\x88\x04\x81\x83\x02\x82\x02\x86\x04\x81\x89\x02\x81"
  "\x02\x84\x04\x81\x89\x02\x80\x02\x82\x04\x81\x87\x02\xff\x01\x80"
  "\x04\x81\x85\x02\xfe\x01\xfe\x03\x81\x89\x02\xfd\x01\xfc\x03\x81"
  "\x83\x02\xfc\x01\xfa\x03\x81\x85\x02\xfb\x01\xf8\x03\x81\x89\x02"
  "\xfa\x01\xf6\x03\x81\x83\x02\xf9\x01\xf4\x03\x81\x85\x02\xf8\x01"
  "\xf2\x03\x81\x87\x02\xf7\x01\xf0\x03\x81\x83\x02\xf6\x01\xee\x03"
  "\x81\x85\x02\xf5\x01\xec\x03\x81\x87\x02\xf4\x01\xea\x03\x81\x83"
  "\x02\xf3\x01\xe8\x03\x81\x89\x02\xf2\x01\xe6\x03\x81\x87\x02\xf1"
  "\x01\xe4\x03\x81\x83\x02\xf0\x01\xe2\x03\x81\x85\x02\xef\x01\xe0"
  "\x03\x81\x83\x02\xee\x01\xde\x03\x81\x89\x02\xed\x01\xdc\x03\x81"
  "\x87\x02\xec\x01\xda\x03\x81\x83\x02\xeb\x01\xd8\x03\x81\x85\x02"
  "\xea\x01\xd6\x03\x81\x83\x02\xe9\x01\xd4\x03\x81\x85\x02\xe8\x01"
  "\xd2\x03\x81\x8b\x02\xe7\x01\xd0\x03\x81\x89\x02\xe6\x01\xce\x03"
  "\x81\x87\x02\xe5\x01\xcc\x03\x81\x83\x02\xe4\x01\xca\x03\x81\x89"
  "\x02\xe3\x01\xc8\x03\x81\x87\x02\xe2\x01\xc6\x03\x81\x83\x02\xe1"
  "\x01\xc4\x03\x81\x8b\x02\xe0\x01\xc2\x03\x81\x87\x02\xdf\x01\xc0"
  "\x03\x81\x85\x02\xde\x01\xbe\x03\x81\x83\x02\xdd\x01\xbc\x03\x81"
  "\x89\x02\xdc\x01\xba\x03\x81\x87\x02\xdb\x01\xb8\x03\x81\x85\x02"
  "\xda\x01\xb6\x03\x81\x89\x02\xd9\x01\xb4\x03\x81\x83\x02\xd8\x01"
  "\xb2\x03\x81\x89\x02\xd7\x01\xb0\x03\x81\x83\x02\xd6\x01\xae\x03"
  "\x81\x83\x02\xd5\x01\xac\x03\x81\x83\x02\xd4\x01\xaa\x03\x81\x83"
  "\x02\xd3\x01\xa8\x03\x81\x83\x02\xd2\x01\xa6\x03\x81\x83\x02\xd1"
  "\x01\xa4\x03\x81\x83\x02\xd0\x01\xa2\x03\x81\x83\x02\xcf\x01\xa0"
  "\x03\x81\x85\x02\xce\x01\x9e\x03\x81\x83\x02\xcd\x01\x9c\x03\x81"
  "\x85\x02\xcc\x01\x9a\x03\x81\x83\x02\xcb\x01\x98\x03\x81\x83\x02"
  "\xca\x01\x96\x03\x81\x85\x02\xc9\x01\x94\x03\x81\x83\x02\xc8\x01"
  "\x92\x03\x81\x85\x02\xc7\x01\x90\x03\x81\x8b\x02\xc6\x01\x8e\x03"
  "\x81\x87\x02\xc5\x01\x8c\x03\x81\x83\x02\xc4\x01\x8a\x03\x81\x89"
  "\x02\xc3\x01\x88\x03\x81\x87\x02\xc2\x01\x86\x03\x81\x83\x02\xc1"
  "\x01\x84\x03\x81\x83\x02\xc0\x01\x82\x03\x81\x83\x02\xbf\x01\x80"
  "\x03\x81\x85\x02\xbe\x01\xfe\x02\x81\x83\x02\xbd\x01\xfc\x02\x81"
  "\x85\x02\xbc\x01\xfa\x02\x81\x89\x02\xbb\x01\xf8\x02\x81\x83\x02"
  "\xba\x01\xf6\x02\x81\x89\x02\xb9\x01\xf4\x02\x81\x83\x02\xb8\x01"
  "\xf2\x02\x81\x83\x02\xb7\x01\xf0\x02\x81\x85\x02\xb6\x01\xee\x02"
  "\x81\x83\x02\xb5\x01\xec\x02\x81\x85\x02\xb4\x01\xea\x02\x81\x89"
  "\x02\xb3\x01\xe8\x02\x81\x83\x02\xb2\x01\xe6\x02\x81\x87\x02\xb1"
  "\x01\xe4\x02\x81\x83\x02\xb0\x01\xe2\x02\x81\x83\x02\xaf\x01\xe0"
  "\x02\x81\x83\x02\xae\x01\xde\x02\x81\x85\x02\xad\x01\xdc\x02\x81"
  "\x83\x02\xac\x01\xda\x02\x81\x85\x02\xab\x01\xd8\x02\x81\x87\x02"
  "\xaa\x01\xd6\x02\x81\x83\x02\xa9\x01\xd4\x02\x81\x87\x02\xa8\x01"
  "\xd2\x02\x81\x87\x02\xa7\x01\xd0\x02\x81\x83\x02\xa6\x01\xce\x02"
  "\x81\x87\x02\xa5\x01\xcc\x02\x81\x8b\x02\xa4\x01\xca\x02\x81\x87"
  "\x02\xa3\x01\xc8\x02\x81\x85\x02\xa2\x01\xc6\x02\x81\x83\x02\xa1"
  "\x01\xc4\x02\x81\x87\x02\xa0\x01\xc2\x02\x81\x89\x02\x9f\x01\xc0"
  "\x02\x81\x87\x02\x9e\x01\xbe\x02\x81\x85\x02\x9d\x01\xbc\x02\x81"
  "\x89\x02\x9c\x01\xba\x02\x81\x83\x02\x9b\x01\xb8\x02\x81\x89\x02"
  "\x9a\x01\xb6\x02\x81\x85\x02\x99\x01\xb4\x02\x81\x89\x02\x98\x01"
  "\xb2\x02\x81\x83\x02\x97\x01\xb0\x02\x81\x85\x02\x96\x01\xae\x02"
  "\x81\x83\x02\x95\x01\xac\x02\x81\x85\x02\x94\x01\xaa\x02\x81\x83"
  "\x02\x93\x01\xa8\x02\x81\x85\x02\x92\x01\xa6\x02\x81\x85\x02\x91"
  "\x01\xa4\x02\x81\x83\x02\x90\x01\xa2\x02\x81\x87\x02\x8f\x01\xa0"
  "\x02\x81\x83\x02\x8e\x01\x9e\x02\x81\x89\x02\x8d\x01\x9c\x02\x81"
  "\x87\x02\x8c\x01\x9a\x02\x81\x83\x02\x8b\x01\x98\x02\x81\x83\x02"
  "\x8a\x01\x96\x02\x81\x85\x02\x89\x01\x94\x02\x81\x83\x02\x88\x01"
  "\x92\x02\x81\x83\x02\x87\x01\x90\x02\x81\x85\x02\x86\x01\x8e\x02"
  "\x81\x83\x02\x85\x01\x8c\x02\x81\x83\x02\x84\x01\x8a\x02\x81\x83"
  "\x02\x83\x01\x88\x02\x81\x87\x02\x82\x01\x86\x02\x81\x83\x02\x81"
  "\x01\x84\x02\x81\x83\x02\x80\x01\x82\x02\x81\x89\x02\x7f\x80\x02"
  "\x81\x87\x02\x7e\xfe\x01\x81\x83\x02\x7d\xfc\x01\x81\x87\x02\x7c"
  "\xfa\x01\x81\x83\x02\x7b\xf8\x01\x81\x83\x02\x7a\xf6\x01\x81\x83"
  "\x02\x79\xf4\x01\x81\x83\x02\x78\xf2\x01\x81\x85\x02\x77\xf0\x01"
  "\x81\x83\x02\x76\xee\x01\x81\x87\x02\x75\xec\x01\x81\x83\x02\x74"
  "\xea\x01\x81\x85\x02\x73\xe8\x01\x81\x87\x02\x72\xe6\x01\x81\x83"
  "\x02\x71\xe4\x01\x81\x89\x02\x70\xe2\x01\x81\x87\x02\x6f\xe0\x01"
  "\x81\x83\x02\x6e\xde\x01\x81\x87\x02\x6d\xdc\x01\x81\x83\x02\x6c"
  "\xda\x01\x81\x85\x02\x6b\xd8\x01\x81\x87\x02\x6a\xd6\x01\x81\x83"
  "\x02\x69\xd4\x01\x81\x83\x02\x68\xd2\x01\x81\x85\x02\x67\xd0\x01"
  "\x81\x85\x02\x66\xce\x01\x81\x89\x02\x65\xcc\x01\x81\x87\x02\x64"
  "\xca\x01\x81\x83\x02\x63\xc8\x01\x81\x87\x02\x62\xc6\x01\x81\x83"
  "\x02\x61\xc4\x01\x81\x85\x02\x60\xc2\x01\x81\x83\x02\x5f\xc0\x01"
  "\x83\x04\x5e\xbe\x01\x81\x87\x02\x5d\xbc\x01\x81\x85\x02\x5c\xba"
  "\x01\x81\x83\x02\x5b\xb8\x01\x81\x85\x02\x5a\xb6\x01\x81\x83\x02"
  "\x59\xb4\x01\x83\x04\x58\xb2\x01\x81\x83\x02\x57\xb0\x01\x81\x83"
  "\x02\x56\xae\x01\x81\x83\x02\x55\xac\x01\x81\x83\x02\x54\xaa\x01"
  "\x81\x85\x02\x53\xa8\x01\x81\x83\x02\x52\xa6\x01\x81\x8b\x02\x51"
  "\xa4\x01\x81\x89\x02\x50\xa2\x01\x81\x87\x02\x4f\xa0\x01\x81\x83"
  "\x02\x4e\x9e\x01\x81\x83\x02\x4d\x9c\x01\x81\x83\x02\x4c\x9a\x01"
  "\x81\x83\x02\x4b\x98\x01\x81\x83\x02\x4a\x96\x01\x81\x83\x02\x49"
  "\x94\x01\x81\x83\x02\x48\x92\x01\x81\x83\x02\x47\x90\x01\x81\x83"
  "\x02\x46\x8e\x01\x81\x83\x02\x45\x8c\x01\x81\x83\x02\x44\x8a\x01"
  "\x81\x83\x02\x43\x88\x01\x81\x83\x02\x42\x86\x01\x81\x83\x02\x41"
  "\x84\x01\x81\x83\x02\x40\x82\x01\x81\x83\x02\x3f\x80\x01\x81\x83"
  "\x02\x3e\x7e\x81\x83\x02\x3d\x7c\x81\x83\x02\x3c\x7a\x81\x87\x02"
  "\x3b\x78\x81\x85\x02\x3a\x76\x81\x83\x02\x39\x74\x81\x83\x02\x38"
  "\x72\x81\x83\x02\x37\x70\x81\x85\x02\x36\x6e\x81\x83\x02\x35\x6c"
  "\x81\x85\x02\x34\x6a\x81\x89\x02\x33\x68\x81\x83\x02\x32\x66\x81"
  "\x85\x02\x31\x64\x81\x89\x02\x30\x62\x81\x83\x02\x2f\x60\x81\x85"
  "\x02\x2e\x5e\x81\x89\x02\x2d\x5c\x81\x83\x02\x2c\x5a\x81\x85\x02"
  "\x2b\x58\x81\x87\x02\x2a\x56\x81\x83\x02\x29\x54\x81\x85\x02\x28"
  "\x52\x81\x89\x02\x27\x50\x81\x83\x02\x26\x4e\x81\x83\x02\x25\x4c"
  "\x81\x83\x02\x24\x4a\x81\x83\x02\x23\x48\x81\x83\x02\x22\x46\x81"
  "\x83\x02\x21\x44\x81\x83\x02\x20\x42\x81\x83\x02\x1f\x40\x81\x83"
  "\x02\x1e\x3e\x81\x83\x02\x1d\x3c\x81\x83\x02\x1c\x3a\x81\x83\x02"
  "\x1b\x38\x81\x83\x02\x1a\x36\x81\x83\x02\x19\x34\x81\x83\x02\x18"
  "\x32\x81\x83\x02\x17\x30\x81\x83\x02\x16\x2e\x81\x83\x02\x15\x2c"
  "\x81\x83\x02\x14\x2a\x81\x83\x02\x13\x28\x81\x83\x02\x12\x26\x81"
  "\x83\x02\x11\x24\x81\x83\x02\x10\x22\x81\x83\x02\x0f\x20\x81\x83"
  "\x02\x0e\x1e\x81\x83\x02\x0d\x1c\x81\x83\x02\x0c\x1a\x81\x83\x02"
  "\x0b\x18\x81\x83\x02\x0a\x16\x81\x83\x02\x09\x14\x81\x83\x02\x08"
  "\x12\x81\x83\x02\x07\x10\x81\x83\x02\x06\x0e\x81\x83\x02\x05\x0c"
  "\x81\x83\x02\x04\x0a\x81\x83\x02\x03\x08\x81\x83\x02\x02\x06\x81"
  "\x83\x02\x01\x04\x81\x83\x02\xfb\x05\xe3\x09";

SCHEME_OBJECT *
http_syntax_so_data_a55ad10acee7df26 (entry_count_t dispatch_base)
{
  SCHEME_OBJECT ccb;
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES_FOR_DATA ();

  ccb = (unstackify (((unsigned char *) (& (prog_http_syntax_so_data_a55ad10acee7df26 [0]))), (sizeof (prog_http_syntax_so_data_a55ad10acee7df26)), dispatch_base));
  current_block = (OBJECT_ADDRESS (ccb));
  return (& (current_block [LABEL_432]));
}

DECLARE_COMPILED_DATA_NS ("http-syntax.so", http_syntax_so_data_a55ad10acee7df26)

#endif /* !WANT_ONLY_CODE */

DECLARE_DYNAMIC_INITIALIZATION ("http-syntax.so", "5a40b2590f30ad5c")
