/* Emacs: this is -*- C -*- code, */
/* generated 2011-11-08T22:50:59-08 by Liar version 4.118. */

#include "liarc.h"

#define LABEL_1_4 3
#define LABEL_1_5 5
#define LABEL_1_8 7
#define LABEL_1_9 9
#define LABEL_1_6 11
#define ENVIRONMENT_LABEL_1_3 24
#define DEBUGGING_LABEL_1_2 23
#define OBJECT_1_1 22
#define OBJECT_1_0 21
#define EXECUTE_CACHE_1_10 13
#define EXECUTE_CACHE_1_7 15
#define FREE_REFERENCE_1_0 18
#define FREE_ASSIGNMENT_1_0 20
#define FREE_REFERENCES_LABEL_1_0 12
#define NUMBER_OF_LINKER_SECTIONS_1_1 3

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
scomb_so_code_1 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd6;
  machine_word Wrd10;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_1_4);
      goto initialize_packageB_4;

    case 1:
      current_block = (Rpc - LABEL_1_5);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_1_8);
      goto label_6;

    case 3:
      current_block = (Rpc - LABEL_1_9);
      goto label_7;

    case 4:
      current_block = (Rpc - LABEL_1_6);
      goto lambda_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (initialize_packageB_9)
DEFLABEL (initialize_packageB_4)
  INTERRUPT_CHECK (26, LABEL_1_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_1_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_1_6]))));
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_7]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_1_5);
  (* (--Rsp)) = Rvl;
  (Wrd6.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_1_0]));
  (Wrd9.Obj) = ((Wrd6.pObj) [0]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd10.uLng) == 50)
    goto label_16;

DEFLABEL (label_15)
  Wrd5 = Wrd9;

DEFLABEL (label_14)
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd17.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_ASSIGNMENT_1_0]));
  (Wrd18.Obj) = (Rsp [1]);
  (Wrd25.Obj) = ((Wrd17.pObj) [0]);
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd25.Obj));
  if ((Wrd26.uLng) == 50)
    goto label_13;

DEFLABEL (label_12)
  ((Wrd17.pObj) [0]) = (Wrd18.Obj);

DEFLABEL (label_11)
  Rvl = (Rsp [0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_13)
  if ((Wrd25.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_12;
  INVOKE_INTERFACE_3 (29, (& (current_block [LABEL_1_9])), (Wrd17.pObj), (Wrd18.Obj));

DEFLABEL (label_7)
  goto label_11;

DEFLABEL (label_16)
  if ((Wrd9.Obj) == (MAKE_OBJECT (50, 0)))
    goto label_15;
  INVOKE_INTERFACE_2 (32, (& (current_block [LABEL_1_8])), (Wrd6.pObj));

DEFLABEL (label_6)
  (Wrd5.Obj) = Rvl;
  goto label_14;

DEFLABEL (lambda_10)
DEFLABEL (lambda_0)
  INTERRUPT_CHECK (26, LABEL_1_6);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_1_1]);
  (Rsp [1]) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_1_10]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_2_5 3
#define LABEL_2_4 5
#define LABEL_2_7 7
#define LABEL_2_8 9
#define LABEL_2_9 11
#define LABEL_2_11 13
#define LABEL_2_10 15
#define ENVIRONMENT_LABEL_2_3 27
#define DEBUGGING_LABEL_2_2 26
#define OBJECT_2_4 25
#define OBJECT_2_3 24
#define OBJECT_2_2 23
#define OBJECT_2_1 22
#define OBJECT_2_0 21
#define EXECUTE_CACHE_2_12 17
#define EXECUTE_CACHE_2_6 19
#define FREE_REFERENCES_LABEL_2_0 16
#define NUMBER_OF_LINKER_SECTIONS_2_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
scomb_so_code_2 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd36;
  machine_word Wrd30;
  machine_word Wrd29;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd27;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd39;
  machine_word Wrd42;
  machine_word Wrd41;
  machine_word Wrd13;
  machine_word Wrd7;
  machine_word Wrd8;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_2_5);
      goto continuation_1;

    case 1:
      current_block = (Rpc - LABEL_2_4);
      goto make_sequence_10;

    case 2:
      current_block = (Rpc - LABEL_2_7);
      goto loop_8;

    case 3:
      current_block = (Rpc - LABEL_2_8);
      goto label_12;

    case 4:
      current_block = (Rpc - LABEL_2_9);
      goto label_13;

    case 5:
      current_block = (Rpc - LABEL_2_11);
      goto label_14;

    case 6:
      current_block = (Rpc - LABEL_2_10);
      goto continuation_7;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (make_sequence_16)
DEFLABEL (make_sequence_10)
  INTERRUPT_CHECK (26, LABEL_2_4);
  (Wrd5.Obj) = (Rsp [0]);
  if ((Wrd5.Obj) == (current_block [OBJECT_2_0]))
    goto label_19;

DEFLABEL (label_18)
  goto loop_8;

DEFLABEL (label_19)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_5]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_2_1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_6]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_2_5);
  goto label_18;

DEFLABEL (loop_17)
DEFLABEL (loop_8)
  INTERRUPT_CHECK (26, LABEL_2_7);
  (Wrd8.Obj) = (Rsp [0]);
  (Wrd9.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd9.uLng) == 1))
    goto label_27;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd5.Obj) = ((Wrd7.pObj) [1]);

DEFLABEL (label_26)
  if ((Wrd5.Obj) == (current_block [OBJECT_2_0]))
    goto label_24;
  (Wrd18.Obj) = (Rsp [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if (! ((Wrd19.uLng) == 1))
    goto label_23;
  (Wrd16.pObj) = (OBJECT_ADDRESS (Wrd18.Obj));
  (Wrd17.Obj) = ((Wrd16.pObj) [0]);
  (* (--Rsp)) = (Wrd17.Obj);

DEFLABEL (label_22)
  (Wrd24.Obj) = (current_block [OBJECT_2_4]);
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_10]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd31.Obj) = (Rsp [3]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if (! ((Wrd32.uLng) == 1))
    goto label_21;
  (Wrd29.pObj) = (OBJECT_ADDRESS (Wrd31.Obj));
  (Wrd30.Obj) = ((Wrd29.pObj) [1]);
  (* (--Rsp)) = (Wrd30.Obj);

DEFLABEL (label_20)
  goto loop_8;

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_2_10);
  (Rsp [2]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_2_12]));

DEFLABEL (label_21)
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_11]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd31.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_2]), 1);

DEFLABEL (label_14)
  (* (--Rsp)) = Rvl;
  goto label_20;

DEFLABEL (label_23)
  (Wrd23.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_9]))));
  (* (--Rsp)) = (Wrd23.Obj);
  (* (--Rsp)) = (Wrd18.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_3]), 1);

DEFLABEL (label_13)
  (* (--Rsp)) = Rvl;
  goto label_22;

DEFLABEL (label_24)
  (Wrd41.Obj) = (Rsp [0]);
  (Wrd42.uLng) = (OBJECT_TYPE (Wrd41.Obj));
  if (! ((Wrd42.uLng) == 1))
    goto label_25;
  (Wrd39.pObj) = (OBJECT_ADDRESS (Wrd41.Obj));
  Rvl = ((Wrd39.pObj) [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_25)
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_3]), 1);

DEFLABEL (label_27)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_2_8]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2_2]), 1);

DEFLABEL (label_12)
  (Wrd5.Obj) = Rvl;
  goto label_26;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_3_4 3
#define LABEL_3_5 5
#define ENVIRONMENT_LABEL_3_3 11
#define DEBUGGING_LABEL_3_2 10
#define OBJECT_3_3 9
#define OBJECT_3_2 8
#define OBJECT_3_1 7
#define OBJECT_3_0 6
#define FREE_REFERENCES_LABEL_3_0 6
#define NUMBER_OF_LINKER_SECTIONS_3_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
scomb_so_code_3 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd20;
  machine_word Wrd9;
  machine_word Wrd31;
  machine_word Wrd28;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd26;
  machine_word Wrd23;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_3_4);
      goto sequenceP_1;

    case 1:
      current_block = (Rpc - LABEL_3_5);
      goto label_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (sequenceP_5)
DEFLABEL (sequenceP_1)
  INTERRUPT_CHECK (26, LABEL_3_4);
  (Wrd23.Obj) = (current_block [OBJECT_3_0]);
  (Wrd26.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 25L) < ((unsigned long) (Wrd26.Lng))))
    goto label_12;
  (Wrd6.uLng) = (OBJECT_DATUM (Wrd23.Obj));
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd6.Obj) == (Wrd8.Obj)))
    goto label_7;

DEFLABEL (label_6)
  Rvl = (current_block [OBJECT_3_3]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_7)
  (Wrd9.Obj) = (current_block [OBJECT_3_2]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd20.Lng) = (1 << TYPE_CODE_LENGTH);
  if (((unsigned long) 51L) < ((unsigned long) (Wrd20.Lng)))
    goto label_8;
  INVOKE_PRIMITIVE ((current_block [OBJECT_3_1]), 2);

DEFLABEL (label_8)
  (Wrd12.uLng) = (OBJECT_DATUM (Wrd9.Obj));
  (Wrd13.Obj) = (Rsp [1]);
  (Wrd14.uLng) = (OBJECT_TYPE (Wrd13.Obj));
  if ((Wrd12.Obj) == (Wrd14.Obj))
    goto label_10;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_9;

DEFLABEL (label_10)
  Rvl = (current_block [OBJECT_3_3]);

DEFLABEL (label_9)
DEFLABEL (label_11)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_12)
  (Wrd28.Obj) = (Rsp [0]);
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_3_5]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  (* (--Rsp)) = (Wrd23.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_3_1]), 2);

DEFLABEL (label_3)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_7;
  goto label_6;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_4_4 3
#define LABEL_4_5 5
#define ENVIRONMENT_LABEL_4_3 13
#define DEBUGGING_LABEL_4_2 12
#define OBJECT_4_0 11
#define EXECUTE_CACHE_4_7 7
#define EXECUTE_CACHE_4_6 9
#define FREE_REFERENCES_LABEL_4_0 6
#define NUMBER_OF_LINKER_SECTIONS_4_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
scomb_so_code_4 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_4_4);
      goto guarantee_sequence_1;

    case 1:
      current_block = (Rpc - LABEL_4_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (guarantee_sequence_4)
DEFLABEL (guarantee_sequence_1)
  INTERRUPT_CHECK (26, LABEL_4_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_4_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_5;
  Rvl = (current_block [OBJECT_4_0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_5)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_4_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_5_4 3
#define ENVIRONMENT_LABEL_5_3 11
#define DEBUGGING_LABEL_5_2 10
#define OBJECT_5_2 9
#define OBJECT_5_1 8
#define OBJECT_5_0 7
#define EXECUTE_CACHE_5_5 5
#define FREE_REFERENCES_LABEL_5_0 4
#define NUMBER_OF_LINKER_SECTIONS_5_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
scomb_so_code_5 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_5_4);
      goto error_not_sequence_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (error_not_sequence_5)
DEFLABEL (error_not_sequence_2)
  INTERRUPT_CHECK (26, LABEL_5_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_5_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [2]);
  if ((Wrd7.Obj) == (current_block [OBJECT_5_1]))
    goto label_7;
  Wrd9 = Wrd7;
  goto label_6;

DEFLABEL (label_7)
  (Wrd9.Obj) = (current_block [OBJECT_5_2]);

DEFLABEL (label_6)
DEFLABEL (label_8)
  (Rsp [2]) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_5_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_6_4 3
#define LABEL_6_5 5
#define LABEL_6_6 7
#define LABEL_6_7 9
#define LABEL_6_8 11
#define LABEL_6_10 13
#define LABEL_6_11 15
#define LABEL_6_13 17
#define LABEL_6_14 19
#define LABEL_6_17 21
#define LABEL_6_18 23
#define LABEL_6_20 25
#define LABEL_6_21 27
#define ENVIRONMENT_LABEL_6_3 50
#define DEBUGGING_LABEL_6_2 49
#define OBJECT_6_3 48
#define OBJECT_6_2 47
#define OBJECT_6_1 46
#define OBJECT_6_0 45
#define EXECUTE_CACHE_6_24 29
#define EXECUTE_CACHE_6_23 31
#define EXECUTE_CACHE_6_22 33
#define EXECUTE_CACHE_6_19 35
#define EXECUTE_CACHE_6_16 37
#define EXECUTE_CACHE_6_15 39
#define EXECUTE_CACHE_6_12 41
#define EXECUTE_CACHE_6_9 43
#define FREE_REFERENCES_LABEL_6_0 28
#define NUMBER_OF_LINKER_SECTIONS_6_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
scomb_so_code_6 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd42;
  machine_word Wrd41;
  machine_word Wrd38;
  machine_word Wrd25;
  machine_word Wrd24;
  machine_word Wrd21;
  machine_word Wrd15;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd34;
  machine_word Wrd31;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd29;
  machine_word Wrd26;
  machine_word Wrd51;
  machine_word Wrd48;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd46;
  machine_word Wrd43;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_6_4);
      goto sequence_actions_12;

    case 1:
      current_block = (Rpc - LABEL_6_5);
      goto label_15;

    case 2:
      current_block = (Rpc - LABEL_6_6);
      goto label_14;

    case 3:
      current_block = (Rpc - LABEL_6_7);
      goto continuation_5;

    case 4:
      current_block = (Rpc - LABEL_6_8);
      goto continuation_4;

    case 5:
      current_block = (Rpc - LABEL_6_10);
      goto continuation_9;

    case 6:
      current_block = (Rpc - LABEL_6_11);
      goto continuation_8;

    case 7:
      current_block = (Rpc - LABEL_6_13);
      goto continuation_3;

    case 8:
      current_block = (Rpc - LABEL_6_14);
      goto continuation_2;

    case 9:
      current_block = (Rpc - LABEL_6_17);
      goto continuation_11;

    case 10:
      current_block = (Rpc - LABEL_6_18);
      goto continuation_10;

    case 11:
      current_block = (Rpc - LABEL_6_20);
      goto continuation_7;

    case 12:
      current_block = (Rpc - LABEL_6_21);
      goto continuation_6;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (sequence_actions_17)
DEFLABEL (sequence_actions_12)
  INTERRUPT_CHECK (26, LABEL_6_4);
  (Wrd43.Obj) = (current_block [OBJECT_6_0]);
  (Wrd46.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 25L) < ((unsigned long) (Wrd46.Lng))))
    goto label_23;
  (Wrd6.uLng) = (OBJECT_DATUM (Wrd43.Obj));
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd6.Obj) == (Wrd8.Obj)))
    goto label_19;

DEFLABEL (label_18)
  (Wrd38.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_10]))));
  (* (--Rsp)) = (Wrd38.Obj);
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_11]))));
  (* (--Rsp)) = (Wrd41.Obj);
  (Wrd42.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd42.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_6_12]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_6_11);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_6_16]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_6_10);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_17]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_18]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_6_19]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_6_18);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_6_16]));

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_6_17);
  (Rsp [1]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_6_23]));

DEFLABEL (label_19)
  (Wrd26.Obj) = (current_block [OBJECT_6_2]);
  (Wrd29.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 51L) < ((unsigned long) (Wrd29.Lng))))
    goto label_22;
  (Wrd10.uLng) = (OBJECT_DATUM (Wrd26.Obj));
  (Wrd11.Obj) = (Rsp [0]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if ((Wrd10.Obj) == (Wrd12.Obj))
    goto label_21;

DEFLABEL (label_20)
  (Wrd17.Obj) = (Rsp [0]);
  (Wrd18.Obj) = (current_block [OBJECT_6_3]);
  (* (Rhp++)) = (Wrd17.Obj);
  (* (Rhp++)) = (Wrd18.Obj);
  (Wrd15.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd15.pObj)));
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_21)
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_7]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (Wrd24.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_8]))));
  (* (--Rsp)) = (Wrd24.Obj);
  (Wrd25.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd25.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_6_9]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_6_8);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_6_16]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_6_7);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_13]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_14]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_6_15]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_6_14);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_6_16]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_6_13);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_20]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_21]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_6_22]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_6_21);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_6_16]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_6_20);
  (Rsp [2]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_6_24]));

DEFLABEL (label_22)
  (Wrd31.Obj) = (Rsp [0]);
  (Wrd34.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_6]))));
  (* (--Rsp)) = (Wrd34.Obj);
  (* (--Rsp)) = (Wrd31.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6_1]), 2);

DEFLABEL (label_14)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_20;
  goto label_21;

DEFLABEL (label_23)
  (Wrd48.Obj) = (Rsp [0]);
  (Wrd51.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6_5]))));
  (* (--Rsp)) = (Wrd51.Obj);
  (* (--Rsp)) = (Wrd48.Obj);
  (* (--Rsp)) = (Wrd43.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_6_1]), 2);

DEFLABEL (label_15)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_19;
  goto label_18;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_7_4 3
#define LABEL_7_5 5
#define LABEL_7_6 7
#define LABEL_7_8 9
#define LABEL_7_10 11
#define LABEL_7_12 13
#define LABEL_7_14 15
#define LABEL_7_16 17
#define ENVIRONMENT_LABEL_7_3 37
#define DEBUGGING_LABEL_7_2 36
#define OBJECT_7_4 35
#define OBJECT_7_3 34
#define OBJECT_7_2 33
#define OBJECT_7_1 32
#define OBJECT_7_0 31
#define EXECUTE_CACHE_7_17 19
#define EXECUTE_CACHE_7_15 21
#define EXECUTE_CACHE_7_13 23
#define EXECUTE_CACHE_7_11 25
#define EXECUTE_CACHE_7_9 27
#define EXECUTE_CACHE_7_7 29
#define FREE_REFERENCES_LABEL_7_0 18
#define NUMBER_OF_LINKER_SECTIONS_7_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
scomb_so_code_7 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd18;
  machine_word Wrd17;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd27;
  machine_word Wrd24;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd22;
  machine_word Wrd19;
  machine_word Wrd41;
  machine_word Wrd38;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd36;
  machine_word Wrd33;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_7_4);
      goto sequence_immediate_actions_10;

    case 1:
      current_block = (Rpc - LABEL_7_5);
      goto label_13;

    case 2:
      current_block = (Rpc - LABEL_7_6);
      goto label_12;

    case 3:
      current_block = (Rpc - LABEL_7_8);
      goto continuation_4;

    case 4:
      current_block = (Rpc - LABEL_7_10);
      goto continuation_8;

    case 5:
      current_block = (Rpc - LABEL_7_12);
      goto continuation_3;

    case 6:
      current_block = (Rpc - LABEL_7_14);
      goto continuation_7;

    case 7:
      current_block = (Rpc - LABEL_7_16);
      goto continuation_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (sequence_immediate_actions_15)
DEFLABEL (sequence_immediate_actions_10)
  INTERRUPT_CHECK (26, LABEL_7_4);
  (Wrd33.Obj) = (current_block [OBJECT_7_0]);
  (Wrd36.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 25L) < ((unsigned long) (Wrd36.Lng))))
    goto label_21;
  (Wrd6.uLng) = (OBJECT_DATUM (Wrd33.Obj));
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd6.Obj) == (Wrd8.Obj)))
    goto label_17;

DEFLABEL (label_16)
  (Wrd31.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_10]))));
  (* (--Rsp)) = (Wrd31.Obj);
  (Wrd32.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd32.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7_11]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_7_10);
  (Wrd9.Obj) = (current_block [OBJECT_7_4]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_14]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7_15]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_7_14);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_17)
  (Wrd19.Obj) = (current_block [OBJECT_7_2]);
  (Wrd22.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 51L) < ((unsigned long) (Wrd22.Lng))))
    goto label_20;
  (Wrd10.uLng) = (OBJECT_DATUM (Wrd19.Obj));
  (Wrd11.Obj) = (Rsp [0]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if ((Wrd10.Obj) == (Wrd12.Obj))
    goto label_19;

DEFLABEL (label_18)
  (Wrd13.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_7_3]);
  (Rsp [1]) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7_7]));

DEFLABEL (label_19)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_8]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (Wrd18.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd18.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7_9]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_7_8);
  (Wrd9.Obj) = (current_block [OBJECT_7_4]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_12]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7_13]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_7_12);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_16]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_7_17]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_7_16);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_20)
  (Wrd24.Obj) = (Rsp [0]);
  (Wrd27.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_6]))));
  (* (--Rsp)) = (Wrd27.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  (* (--Rsp)) = (Wrd19.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_7_1]), 2);

DEFLABEL (label_12)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_18;
  goto label_19;

DEFLABEL (label_21)
  (Wrd38.Obj) = (Rsp [0]);
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7_5]))));
  (* (--Rsp)) = (Wrd41.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  (* (--Rsp)) = (Wrd33.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_7_1]), 2);

DEFLABEL (label_13)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_17;
  goto label_16;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_8_4 3
#define LABEL_8_5 5
#define ENVIRONMENT_LABEL_8_3 10
#define DEBUGGING_LABEL_8_2 9
#define EXECUTE_CACHE_8_6 7
#define FREE_REFERENCES_LABEL_8_0 6
#define NUMBER_OF_LINKER_SECTIONS_8_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
scomb_so_code_8 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_8_4);
      goto sequence_components_1;

    case 1:
      current_block = (Rpc - LABEL_8_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (sequence_components_4)
DEFLABEL (sequence_components_1)
  INTERRUPT_CHECK (26, LABEL_8_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_8_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_8_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_8_5);
  (Wrd5.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd5.Obj);
  (Rsp [1]) = Rvl;
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_9_4 3
#define LABEL_9_7 5
#define LABEL_9_5 7
#define LABEL_9_8 9
#define LABEL_9_12 11
#define ENVIRONMENT_LABEL_9_3 27
#define DEBUGGING_LABEL_9_2 26
#define OBJECT_9_2 25
#define OBJECT_9_1 24
#define OBJECT_9_0 23
#define EXECUTE_CACHE_9_13 13
#define EXECUTE_CACHE_9_11 15
#define EXECUTE_CACHE_9_10 17
#define EXECUTE_CACHE_9_9 19
#define EXECUTE_CACHE_9_6 21
#define FREE_REFERENCES_LABEL_9_0 12
#define NUMBER_OF_LINKER_SECTIONS_9_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
scomb_so_code_9 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd6;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_9_4);
      goto make_conditional_5;

    case 1:
      current_block = (Rpc - LABEL_9_7);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_9_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_9_8);
      goto continuation_3;

    case 4:
      current_block = (Rpc - LABEL_9_12);
      goto label_7;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (make_conditional_9)
DEFLABEL (make_conditional_5)
  INTERRUPT_CHECK (26, LABEL_9_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_9_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_9_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_11;

DEFLABEL (label_10)
  (Wrd11.Obj) = (current_block [OBJECT_9_1]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_9_10]));

DEFLABEL (label_11)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_7]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_9_11]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_9_7);
  if (! (Rvl == (current_block [OBJECT_9_0])))
    goto label_10;
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_8]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_9_9]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_9_8);
  (Wrd8.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd8.uLng) == 1))
    goto label_13;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd6.Obj) = ((Wrd7.pObj) [0]);

DEFLABEL (label_12)
  (Rsp [0]) = (Wrd6.Obj);
  (Wrd13.Obj) = (Rsp [1]);
  (Wrd14.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd14.Obj);
  (Rsp [2]) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_9_13]));

DEFLABEL (label_13)
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9_12]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (* (--Rsp)) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_9_2]), 1);

DEFLABEL (label_7)
  (Wrd6.Obj) = Rvl;
  goto label_12;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_10_4 3
#define ENVIRONMENT_LABEL_10_3 8
#define DEBUGGING_LABEL_10_2 7
#define OBJECT_10_2 6
#define OBJECT_10_1 5
#define OBJECT_10_0 4
#define FREE_REFERENCES_LABEL_10_0 4
#define NUMBER_OF_LINKER_SECTIONS_10_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
scomb_so_code_10 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd16;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_10_4);
      goto conditionalP_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (conditionalP_3)
DEFLABEL (conditionalP_0)
  INTERRUPT_CHECK (26, LABEL_10_4);
  (Wrd5.Obj) = (current_block [OBJECT_10_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd16.Lng) = (1 << TYPE_CODE_LENGTH);
  if (((unsigned long) 52L) < ((unsigned long) (Wrd16.Lng)))
    goto label_4;
  INVOKE_PRIMITIVE ((current_block [OBJECT_10_2]), 2);

DEFLABEL (label_4)
  (Wrd8.uLng) = (OBJECT_DATUM (Wrd5.Obj));
  (Wrd9.Obj) = (Rsp [1]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd8.Obj) == (Wrd10.Obj))
    goto label_6;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_5;

DEFLABEL (label_6)
  Rvl = (current_block [OBJECT_10_1]);

DEFLABEL (label_5)
DEFLABEL (label_7)
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_11_4 3
#define LABEL_11_5 5
#define ENVIRONMENT_LABEL_11_3 13
#define DEBUGGING_LABEL_11_2 12
#define OBJECT_11_0 11
#define EXECUTE_CACHE_11_7 7
#define EXECUTE_CACHE_11_6 9
#define FREE_REFERENCES_LABEL_11_0 6
#define NUMBER_OF_LINKER_SECTIONS_11_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
scomb_so_code_11 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_11_4);
      goto guarantee_conditional_1;

    case 1:
      current_block = (Rpc - LABEL_11_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (guarantee_conditional_4)
DEFLABEL (guarantee_conditional_1)
  INTERRUPT_CHECK (26, LABEL_11_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_11_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_11_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_5;
  Rvl = (current_block [OBJECT_11_0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_5)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_11_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_12_4 3
#define ENVIRONMENT_LABEL_12_3 11
#define DEBUGGING_LABEL_12_2 10
#define OBJECT_12_2 9
#define OBJECT_12_1 8
#define OBJECT_12_0 7
#define EXECUTE_CACHE_12_5 5
#define FREE_REFERENCES_LABEL_12_0 4
#define NUMBER_OF_LINKER_SECTIONS_12_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
scomb_so_code_12 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_12_4);
      goto error_not_conditional_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (error_not_conditional_5)
DEFLABEL (error_not_conditional_2)
  INTERRUPT_CHECK (26, LABEL_12_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_12_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [2]);
  if ((Wrd7.Obj) == (current_block [OBJECT_12_1]))
    goto label_7;
  Wrd9 = Wrd7;
  goto label_6;

DEFLABEL (label_7)
  (Wrd9.Obj) = (current_block [OBJECT_12_2]);

DEFLABEL (label_6)
DEFLABEL (label_8)
  (Rsp [2]) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_12_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_13_4 3
#define LABEL_13_5 5
#define ENVIRONMENT_LABEL_13_3 13
#define DEBUGGING_LABEL_13_2 12
#define OBJECT_13_0 11
#define EXECUTE_CACHE_13_7 7
#define EXECUTE_CACHE_13_6 9
#define FREE_REFERENCES_LABEL_13_0 6
#define NUMBER_OF_LINKER_SECTIONS_13_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
scomb_so_code_13 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_13_4);
      goto conditional_predicate_1;

    case 1:
      current_block = (Rpc - LABEL_13_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (conditional_predicate_4)
DEFLABEL (conditional_predicate_1)
  INTERRUPT_CHECK (26, LABEL_13_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_13_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_13_5);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_13_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_14_4 3
#define LABEL_14_5 5
#define ENVIRONMENT_LABEL_14_3 13
#define DEBUGGING_LABEL_14_2 12
#define OBJECT_14_0 11
#define EXECUTE_CACHE_14_7 7
#define EXECUTE_CACHE_14_6 9
#define FREE_REFERENCES_LABEL_14_0 6
#define NUMBER_OF_LINKER_SECTIONS_14_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
scomb_so_code_14 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_14_4);
      goto conditional_consequent_1;

    case 1:
      current_block = (Rpc - LABEL_14_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (conditional_consequent_4)
DEFLABEL (conditional_consequent_1)
  INTERRUPT_CHECK (26, LABEL_14_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_14_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_14_5);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_14_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_15_4 3
#define LABEL_15_5 5
#define ENVIRONMENT_LABEL_15_3 13
#define DEBUGGING_LABEL_15_2 12
#define OBJECT_15_0 11
#define EXECUTE_CACHE_15_7 7
#define EXECUTE_CACHE_15_6 9
#define FREE_REFERENCES_LABEL_15_0 6
#define NUMBER_OF_LINKER_SECTIONS_15_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
scomb_so_code_15 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_15_4);
      goto conditional_alternative_1;

    case 1:
      current_block = (Rpc - LABEL_15_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (conditional_alternative_4)
DEFLABEL (conditional_alternative_1)
  INTERRUPT_CHECK (26, LABEL_15_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_15_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_15_5);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_15_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_16_4 3
#define LABEL_16_5 5
#define LABEL_16_7 7
#define LABEL_16_9 9
#define ENVIRONMENT_LABEL_16_3 18
#define DEBUGGING_LABEL_16_2 17
#define EXECUTE_CACHE_16_10 11
#define EXECUTE_CACHE_16_8 13
#define EXECUTE_CACHE_16_6 15
#define FREE_REFERENCES_LABEL_16_0 10
#define NUMBER_OF_LINKER_SECTIONS_16_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
scomb_so_code_16 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd5;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_16_4);
      goto conditional_components_3;

    case 1:
      current_block = (Rpc - LABEL_16_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_16_7);
      goto continuation_2;

    case 3:
      current_block = (Rpc - LABEL_16_9);
      goto continuation_1;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (conditional_components_6)
DEFLABEL (conditional_components_3)
  INTERRUPT_CHECK (26, LABEL_16_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_16_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_16_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_16_5);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_16_7]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_16_8]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_16_7);
  (Rsp [3]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_16_9]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_16_10]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_16_9);
  (Rsp [2]) = Rvl;
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 4);
  }

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_17_4 3
#define LABEL_17_5 5
#define ENVIRONMENT_LABEL_17_3 12
#define DEBUGGING_LABEL_17_2 11
#define EXECUTE_CACHE_17_6 7
#define FREE_REFERENCE_17_0 10
#define FREE_REFERENCES_LABEL_17_0 6
#define NUMBER_OF_LINKER_SECTIONS_17_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
scomb_so_code_17 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd7;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_17_4);
      goto conditional_subexpressions_0;

    case 1:
      current_block = (Rpc - LABEL_17_5);
      goto label_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (conditional_subexpressions_4)
DEFLABEL (conditional_subexpressions_0)
  INTERRUPT_CHECK (26, LABEL_17_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_17_0]));
  (Wrd11.Obj) = ((Wrd8.pObj) [0]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if ((Wrd12.uLng) == 50)
    goto label_6;
  Wrd7 = Wrd11;

DEFLABEL (label_5)
  (Rsp [1]) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_17_6]));

DEFLABEL (label_6)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_17_5])), (Wrd8.pObj));

DEFLABEL (label_2)
  (Wrd7.Obj) = Rvl;
  goto label_5;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_18_4 3
#define LABEL_18_7 5
#define LABEL_18_5 7
#define LABEL_18_8 9
#define LABEL_18_12 11
#define ENVIRONMENT_LABEL_18_3 28
#define DEBUGGING_LABEL_18_2 27
#define OBJECT_18_3 26
#define OBJECT_18_2 25
#define OBJECT_18_1 24
#define OBJECT_18_0 23
#define EXECUTE_CACHE_18_13 13
#define EXECUTE_CACHE_18_11 15
#define EXECUTE_CACHE_18_10 17
#define EXECUTE_CACHE_18_9 19
#define EXECUTE_CACHE_18_6 21
#define FREE_REFERENCES_LABEL_18_0 12
#define NUMBER_OF_LINKER_SECTIONS_18_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
scomb_so_code_18 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd6;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd17;
  machine_word Wrd16;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_18_4);
      goto make_disjunction_5;

    case 1:
      current_block = (Rpc - LABEL_18_7);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_18_5);
      goto continuation_0;

    case 3:
      current_block = (Rpc - LABEL_18_8);
      goto continuation_3;

    case 4:
      current_block = (Rpc - LABEL_18_12);
      goto label_7;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (make_disjunction_9)
DEFLABEL (make_disjunction_5)
  INTERRUPT_CHECK (26, LABEL_18_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_18_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_11;

DEFLABEL (label_10)
  (Wrd11.Obj) = (current_block [OBJECT_18_1]);
  (* (--Rsp)) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_10]));

DEFLABEL (label_11)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_7]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_11]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_18_7);
  if (! (Rvl == (current_block [OBJECT_18_0])))
    goto label_10;
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_8]))));
  (* (--Rsp)) = (Wrd16.Obj);
  (Wrd17.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd17.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_9]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_18_8);
  (Wrd8.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd8.uLng) == 1))
    goto label_13;
  (Wrd6.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd7.Obj) = ((Wrd6.pObj) [0]);
  (* (--Rsp)) = (Wrd7.Obj);

DEFLABEL (label_12)
  (Wrd13.Obj) = (Rsp [2]);
  (Rsp [1]) = (Wrd13.Obj);
  (Wrd14.Obj) = (current_block [OBJECT_18_3]);
  (Rsp [2]) = (Wrd14.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_18_13]));

DEFLABEL (label_13)
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18_12]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (* (--Rsp)) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_18_2]), 1);

DEFLABEL (label_7)
  (* (--Rsp)) = Rvl;
  goto label_12;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_19_4 3
#define ENVIRONMENT_LABEL_19_3 8
#define DEBUGGING_LABEL_19_2 7
#define OBJECT_19_2 6
#define OBJECT_19_1 5
#define OBJECT_19_0 4
#define FREE_REFERENCES_LABEL_19_0 4
#define NUMBER_OF_LINKER_SECTIONS_19_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
scomb_so_code_19 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd16;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_19_4);
      goto disjunctionP_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (disjunctionP_3)
DEFLABEL (disjunctionP_0)
  INTERRUPT_CHECK (26, LABEL_19_4);
  (Wrd5.Obj) = (current_block [OBJECT_19_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd16.Lng) = (1 << TYPE_CODE_LENGTH);
  if (((unsigned long) 53L) < ((unsigned long) (Wrd16.Lng)))
    goto label_4;
  INVOKE_PRIMITIVE ((current_block [OBJECT_19_2]), 2);

DEFLABEL (label_4)
  (Wrd8.uLng) = (OBJECT_DATUM (Wrd5.Obj));
  (Wrd9.Obj) = (Rsp [1]);
  (Wrd10.uLng) = (OBJECT_TYPE (Wrd9.Obj));
  if ((Wrd8.Obj) == (Wrd10.Obj))
    goto label_6;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_5;

DEFLABEL (label_6)
  Rvl = (current_block [OBJECT_19_1]);

DEFLABEL (label_5)
DEFLABEL (label_7)
  Rsp = (& (Rsp [2]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_20_4 3
#define LABEL_20_5 5
#define ENVIRONMENT_LABEL_20_3 13
#define DEBUGGING_LABEL_20_2 12
#define OBJECT_20_0 11
#define EXECUTE_CACHE_20_7 7
#define EXECUTE_CACHE_20_6 9
#define FREE_REFERENCES_LABEL_20_0 6
#define NUMBER_OF_LINKER_SECTIONS_20_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
scomb_so_code_20 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_20_4);
      goto guarantee_disjunction_1;

    case 1:
      current_block = (Rpc - LABEL_20_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (guarantee_disjunction_4)
DEFLABEL (guarantee_disjunction_1)
  INTERRUPT_CHECK (26, LABEL_20_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_20_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_5;
  Rvl = (current_block [OBJECT_20_0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_5)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_20_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_21_4 3
#define ENVIRONMENT_LABEL_21_3 11
#define DEBUGGING_LABEL_21_2 10
#define OBJECT_21_2 9
#define OBJECT_21_1 8
#define OBJECT_21_0 7
#define EXECUTE_CACHE_21_5 5
#define FREE_REFERENCES_LABEL_21_0 4
#define NUMBER_OF_LINKER_SECTIONS_21_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
scomb_so_code_21 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_21_4);
      goto error_not_disjunction_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (error_not_disjunction_5)
DEFLABEL (error_not_disjunction_2)
  INTERRUPT_CHECK (26, LABEL_21_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_21_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [2]);
  if ((Wrd7.Obj) == (current_block [OBJECT_21_1]))
    goto label_7;
  Wrd9 = Wrd7;
  goto label_6;

DEFLABEL (label_7)
  (Wrd9.Obj) = (current_block [OBJECT_21_2]);

DEFLABEL (label_6)
DEFLABEL (label_8)
  (Rsp [2]) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_21_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_22_4 3
#define LABEL_22_5 5
#define ENVIRONMENT_LABEL_22_3 13
#define DEBUGGING_LABEL_22_2 12
#define OBJECT_22_0 11
#define EXECUTE_CACHE_22_7 7
#define EXECUTE_CACHE_22_6 9
#define FREE_REFERENCES_LABEL_22_0 6
#define NUMBER_OF_LINKER_SECTIONS_22_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
scomb_so_code_22 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_22_4);
      goto disjunction_predicate_1;

    case 1:
      current_block = (Rpc - LABEL_22_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (disjunction_predicate_4)
DEFLABEL (disjunction_predicate_1)
  INTERRUPT_CHECK (26, LABEL_22_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_22_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_22_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_22_5);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_22_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_23_4 3
#define LABEL_23_5 5
#define ENVIRONMENT_LABEL_23_3 13
#define DEBUGGING_LABEL_23_2 12
#define OBJECT_23_0 11
#define EXECUTE_CACHE_23_7 7
#define EXECUTE_CACHE_23_6 9
#define FREE_REFERENCES_LABEL_23_0 6
#define NUMBER_OF_LINKER_SECTIONS_23_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
scomb_so_code_23 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_23_4);
      goto disjunction_alternative_1;

    case 1:
      current_block = (Rpc - LABEL_23_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (disjunction_alternative_4)
DEFLABEL (disjunction_alternative_1)
  INTERRUPT_CHECK (26, LABEL_23_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_23_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_23_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_23_5);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_23_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_24_4 3
#define LABEL_24_5 5
#define LABEL_24_7 7
#define ENVIRONMENT_LABEL_24_3 14
#define DEBUGGING_LABEL_24_2 13
#define EXECUTE_CACHE_24_8 9
#define EXECUTE_CACHE_24_6 11
#define FREE_REFERENCES_LABEL_24_0 8
#define NUMBER_OF_LINKER_SECTIONS_24_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
scomb_so_code_24 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_24_4);
      goto disjunction_components_2;

    case 1:
      current_block = (Rpc - LABEL_24_5);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_24_7);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (disjunction_components_5)
DEFLABEL (disjunction_components_2)
  INTERRUPT_CHECK (26, LABEL_24_4);
  (Wrd5.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_5]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_24_6]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_24_5);
  (Rsp [2]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24_7]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_24_8]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_24_7);
  (Rsp [1]) = Rvl;
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_25_4 3
#define LABEL_25_5 5
#define ENVIRONMENT_LABEL_25_3 12
#define DEBUGGING_LABEL_25_2 11
#define EXECUTE_CACHE_25_6 7
#define FREE_REFERENCE_25_0 10
#define FREE_REFERENCES_LABEL_25_0 6
#define NUMBER_OF_LINKER_SECTIONS_25_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
scomb_so_code_25 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd7;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_25_4);
      goto disjunction_subexpressions_0;

    case 1:
      current_block = (Rpc - LABEL_25_5);
      goto label_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (disjunction_subexpressions_4)
DEFLABEL (disjunction_subexpressions_0)
  INTERRUPT_CHECK (26, LABEL_25_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_25_0]));
  (Wrd11.Obj) = ((Wrd8.pObj) [0]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if ((Wrd12.uLng) == 50)
    goto label_6;
  Wrd7 = Wrd11;

DEFLABEL (label_5)
  (Rsp [1]) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_25_6]));

DEFLABEL (label_6)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_25_5])), (Wrd8.pObj));

DEFLABEL (label_2)
  (Wrd7.Obj) = Rvl;
  goto label_5;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_26_4 3
#define LABEL_26_5 5
#define LABEL_26_6 7
#define LABEL_26_7 9
#define LABEL_26_8 11
#define LABEL_26_9 13
#define LABEL_26_10 15
#define ENVIRONMENT_LABEL_26_3 26
#define DEBUGGING_LABEL_26_2 25
#define OBJECT_26_8 24
#define OBJECT_26_7 23
#define OBJECT_26_6 22
#define OBJECT_26_5 21
#define OBJECT_26_4 20
#define OBJECT_26_3 19
#define OBJECT_26_2 18
#define OBJECT_26_1 17
#define OBJECT_26_0 16
#define FREE_REFERENCES_LABEL_26_0 16
#define NUMBER_OF_LINKER_SECTIONS_26_1 0

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
scomb_so_code_26 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd32;
  machine_word Wrd40;
  machine_word Wrd29;
  machine_word Wrd51;
  machine_word Wrd48;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd46;
  machine_word Wrd43;
  machine_word Wrd61;
  machine_word Wrd58;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd56;
  machine_word Wrd53;
  machine_word Wrd71;
  machine_word Wrd68;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd66;
  machine_word Wrd63;
  machine_word Wrd81;
  machine_word Wrd78;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd76;
  machine_word Wrd73;
  machine_word Wrd91;
  machine_word Wrd88;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd86;
  machine_word Wrd83;
  machine_word Wrd101;
  machine_word Wrd98;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd96;
  machine_word Wrd93;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_26_4);
      goto combinationP_6;

    case 1:
      current_block = (Rpc - LABEL_26_5);
      goto label_13;

    case 2:
      current_block = (Rpc - LABEL_26_6);
      goto label_12;

    case 3:
      current_block = (Rpc - LABEL_26_7);
      goto label_11;

    case 4:
      current_block = (Rpc - LABEL_26_8);
      goto label_10;

    case 5:
      current_block = (Rpc - LABEL_26_9);
      goto label_9;

    case 6:
      current_block = (Rpc - LABEL_26_10);
      goto label_8;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (combinationP_15)
DEFLABEL (combinationP_6)
  INTERRUPT_CHECK (26, LABEL_26_4);
  (Wrd93.Obj) = (current_block [OBJECT_26_0]);
  (Wrd96.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 38L) < ((unsigned long) (Wrd96.Lng))))
    goto label_32;
  (Wrd6.uLng) = (OBJECT_DATUM (Wrd93.Obj));
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd6.Obj) == (Wrd8.Obj)))
    goto label_17;

DEFLABEL (label_16)
  Rvl = (current_block [OBJECT_26_8]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_17)
  (Wrd83.Obj) = (current_block [OBJECT_26_2]);
  (Wrd86.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 7L) < ((unsigned long) (Wrd86.Lng))))
    goto label_31;
  (Wrd10.uLng) = (OBJECT_DATUM (Wrd83.Obj));
  (Wrd11.Obj) = (Rsp [0]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if ((Wrd10.Obj) == (Wrd12.Obj))
    goto label_16;

DEFLABEL (label_30)
  (Wrd73.Obj) = (current_block [OBJECT_26_3]);
  (Wrd76.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 12L) < ((unsigned long) (Wrd76.Lng))))
    goto label_29;
  (Wrd14.uLng) = (OBJECT_DATUM (Wrd73.Obj));
  (Wrd15.Obj) = (Rsp [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd14.Obj) == (Wrd16.Obj))
    goto label_16;

DEFLABEL (label_28)
  (Wrd63.Obj) = (current_block [OBJECT_26_4]);
  (Wrd66.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 48L) < ((unsigned long) (Wrd66.Lng))))
    goto label_27;
  (Wrd18.uLng) = (OBJECT_DATUM (Wrd63.Obj));
  (Wrd19.Obj) = (Rsp [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if ((Wrd18.Obj) == (Wrd20.Obj))
    goto label_16;

DEFLABEL (label_26)
  (Wrd53.Obj) = (current_block [OBJECT_26_5]);
  (Wrd56.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 27L) < ((unsigned long) (Wrd56.Lng))))
    goto label_25;
  (Wrd22.uLng) = (OBJECT_DATUM (Wrd53.Obj));
  (Wrd23.Obj) = (Rsp [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd22.Obj) == (Wrd24.Obj))
    goto label_16;

DEFLABEL (label_24)
  (Wrd43.Obj) = (current_block [OBJECT_26_6]);
  (Wrd46.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd46.Lng))))
    goto label_23;
  (Wrd26.uLng) = (OBJECT_DATUM (Wrd43.Obj));
  (Wrd27.Obj) = (Rsp [0]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if ((Wrd26.Obj) == (Wrd28.Obj))
    goto label_16;

DEFLABEL (label_22)
  (Wrd29.Obj) = (current_block [OBJECT_26_7]);
  (* (--Rsp)) = (Wrd29.Obj);
  (Wrd40.Lng) = (1 << TYPE_CODE_LENGTH);
  if (((unsigned long) 42L) < ((unsigned long) (Wrd40.Lng)))
    goto label_18;
  INVOKE_PRIMITIVE ((current_block [OBJECT_26_1]), 2);

DEFLABEL (label_18)
  (Wrd32.uLng) = (OBJECT_DATUM (Wrd29.Obj));
  (Wrd33.Obj) = (Rsp [1]);
  (Wrd34.uLng) = (OBJECT_TYPE (Wrd33.Obj));
  if ((Wrd32.Obj) == (Wrd34.Obj))
    goto label_20;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_19;

DEFLABEL (label_20)
  Rvl = (current_block [OBJECT_26_8]);

DEFLABEL (label_19)
DEFLABEL (label_21)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_23)
  (Wrd48.Obj) = (Rsp [0]);
  (Wrd51.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_10]))));
  (* (--Rsp)) = (Wrd51.Obj);
  (* (--Rsp)) = (Wrd48.Obj);
  (* (--Rsp)) = (Wrd43.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_26_1]), 2);

DEFLABEL (label_8)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_22;
  goto label_16;

DEFLABEL (label_25)
  (Wrd58.Obj) = (Rsp [0]);
  (Wrd61.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_9]))));
  (* (--Rsp)) = (Wrd61.Obj);
  (* (--Rsp)) = (Wrd58.Obj);
  (* (--Rsp)) = (Wrd53.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_26_1]), 2);

DEFLABEL (label_9)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_24;
  goto label_16;

DEFLABEL (label_27)
  (Wrd68.Obj) = (Rsp [0]);
  (Wrd71.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_8]))));
  (* (--Rsp)) = (Wrd71.Obj);
  (* (--Rsp)) = (Wrd68.Obj);
  (* (--Rsp)) = (Wrd63.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_26_1]), 2);

DEFLABEL (label_10)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_26;
  goto label_16;

DEFLABEL (label_29)
  (Wrd78.Obj) = (Rsp [0]);
  (Wrd81.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_7]))));
  (* (--Rsp)) = (Wrd81.Obj);
  (* (--Rsp)) = (Wrd78.Obj);
  (* (--Rsp)) = (Wrd73.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_26_1]), 2);

DEFLABEL (label_11)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_28;
  goto label_16;

DEFLABEL (label_31)
  (Wrd88.Obj) = (Rsp [0]);
  (Wrd91.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_6]))));
  (* (--Rsp)) = (Wrd91.Obj);
  (* (--Rsp)) = (Wrd88.Obj);
  (* (--Rsp)) = (Wrd83.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_26_1]), 2);

DEFLABEL (label_12)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_30;
  goto label_16;

DEFLABEL (label_32)
  (Wrd98.Obj) = (Rsp [0]);
  (Wrd101.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26_5]))));
  (* (--Rsp)) = (Wrd101.Obj);
  (* (--Rsp)) = (Wrd98.Obj);
  (* (--Rsp)) = (Wrd93.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_26_1]), 2);

DEFLABEL (label_13)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_17;
  goto label_16;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_27_4 3
#define LABEL_27_5 5
#define ENVIRONMENT_LABEL_27_3 13
#define DEBUGGING_LABEL_27_2 12
#define OBJECT_27_0 11
#define EXECUTE_CACHE_27_7 7
#define EXECUTE_CACHE_27_6 9
#define FREE_REFERENCES_LABEL_27_0 6
#define NUMBER_OF_LINKER_SECTIONS_27_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
scomb_so_code_27 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_27_4);
      goto guarantee_combination_1;

    case 1:
      current_block = (Rpc - LABEL_27_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (guarantee_combination_4)
DEFLABEL (guarantee_combination_1)
  INTERRUPT_CHECK (26, LABEL_27_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_27_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_27_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_5;
  Rvl = (current_block [OBJECT_27_0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_5)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_27_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_28_4 3
#define ENVIRONMENT_LABEL_28_3 11
#define DEBUGGING_LABEL_28_2 10
#define OBJECT_28_2 9
#define OBJECT_28_1 8
#define OBJECT_28_0 7
#define EXECUTE_CACHE_28_5 5
#define FREE_REFERENCES_LABEL_28_0 4
#define NUMBER_OF_LINKER_SECTIONS_28_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
scomb_so_code_28 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_28_4);
      goto error_not_combination_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (error_not_combination_5)
DEFLABEL (error_not_combination_2)
  INTERRUPT_CHECK (26, LABEL_28_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_28_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [2]);
  if ((Wrd7.Obj) == (current_block [OBJECT_28_1]))
    goto label_7;
  Wrd9 = Wrd7;
  goto label_6;

DEFLABEL (label_7)
  (Wrd9.Obj) = (current_block [OBJECT_28_2]);

DEFLABEL (label_6)
DEFLABEL (label_8)
  (Rsp [2]) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_28_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_29_4 3
#define LABEL_29_7 5
#define LABEL_29_8 7
#define LABEL_29_5 9
#define LABEL_29_11 11
#define LABEL_29_14 13
#define LABEL_29_15 15
#define LABEL_29_16 17
#define LABEL_29_17 19
#define LABEL_29_10 21
#define ENVIRONMENT_LABEL_29_3 44
#define DEBUGGING_LABEL_29_2 43
#define OBJECT_29_5 42
#define OBJECT_29_4 41
#define OBJECT_29_3 40
#define OBJECT_29_2 39
#define OBJECT_29_1 38
#define OBJECT_29_0 37
#define EXECUTE_CACHE_29_19 23
#define EXECUTE_CACHE_29_18 25
#define EXECUTE_CACHE_29_13 27
#define EXECUTE_CACHE_29_12 29
#define EXECUTE_CACHE_29_9 31
#define EXECUTE_CACHE_29_6 33
#define FREE_REFERENCE_29_0 36
#define FREE_REFERENCES_LABEL_29_0 22
#define NUMBER_OF_LINKER_SECTIONS_29_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
scomb_so_code_29 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd21;
  machine_word Wrd17;
  machine_word Wrd12;
  machine_word Wrd33;
  machine_word Wrd29;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd20;
  machine_word Wrd14;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd13;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd25;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_29_4);
      goto make_combination_12;

    case 1:
      current_block = (Rpc - LABEL_29_7);
      goto continuation_2;

    case 2:
      current_block = (Rpc - LABEL_29_8);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_29_5);
      goto continuation_0;

    case 4:
      current_block = (Rpc - LABEL_29_11);
      goto label_14;

    case 5:
      current_block = (Rpc - LABEL_29_14);
      goto continuation_8;

    case 6:
      current_block = (Rpc - LABEL_29_15);
      goto label_16;

    case 7:
      current_block = (Rpc - LABEL_29_16);
      goto loop_10;

    case 8:
      current_block = (Rpc - LABEL_29_17);
      goto label_15;

    case 9:
      current_block = (Rpc - LABEL_29_10);
      goto continuation_3;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (make_combination_18)
DEFLABEL (make_combination_12)
  INTERRUPT_CHECK (26, LABEL_29_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_29_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_29_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_29_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_23;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_29_8]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_29_13]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_29_8);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_23;
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_29_7]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (Wrd26.Obj) = (current_block [OBJECT_29_0]);
  (* (--Rsp)) = (Wrd26.Obj);
  (Wrd27.Obj) = (current_block [OBJECT_29_1]);
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd28.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd28.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_29_9]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_29_7);

DEFLABEL (label_23)
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_29_10]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd15.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_29_0]));
  (Wrd18.Obj) = ((Wrd15.pObj) [0]);
  (Wrd19.uLng) = (OBJECT_TYPE (Wrd18.Obj));
  if ((Wrd19.uLng) == 50)
    goto label_22;
  Wrd14 = Wrd18;

DEFLABEL (label_21)
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd20.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd20.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_29_12]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_29_10);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_20;
  (Wrd7.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd7.Obj);
  goto loop_10;

DEFLABEL (label_20)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_29_19]));

DEFLABEL (label_22)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_29_11])), (Wrd15.pObj));

DEFLABEL (label_14)
  (Wrd14.Obj) = Rvl;
  goto label_21;

DEFLABEL (loop_19)
DEFLABEL (loop_10)
  INTERRUPT_CHECK (26, LABEL_29_16);
  (Wrd8.Obj) = (Rsp [0]);
  if (! ((Wrd8.Obj) == (current_block [OBJECT_29_3])))
    goto label_24;
  Rsp = (& (Rsp [1]));
  INVOKE_PRIMITIVE ((current_block [OBJECT_29_4]), 2);

DEFLABEL (label_24)
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_29_14]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd17.uLng) = (OBJECT_TYPE (Wrd8.Obj));
  if (! ((Wrd17.uLng) == 1))
    goto label_29;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd8.Obj));
  (Wrd15.Obj) = ((Wrd14.pObj) [0]);
  (* (--Rsp)) = (Wrd15.Obj);

DEFLABEL (label_28)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_29_18]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_29_14);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_27;
  (Wrd28.Obj) = (Rsp [0]);
  (Wrd29.uLng) = (OBJECT_TYPE (Wrd28.Obj));
  if (! ((Wrd29.uLng) == 1))
    goto label_26;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd28.Obj));
  (Wrd25.Obj) = ((Wrd27.pObj) [1]);

DEFLABEL (label_25)
  (Rsp [0]) = (Wrd25.Obj);
  goto loop_10;

DEFLABEL (label_26)
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_29_15]))));
  (* (--Rsp)) = (Wrd33.Obj);
  (* (--Rsp)) = (Wrd28.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_29_2]), 1);

DEFLABEL (label_16)
  (Wrd25.Obj) = Rvl;
  goto label_25;

DEFLABEL (label_27)
  Rsp = (& (Rsp [1]));
  goto label_20;

DEFLABEL (label_29)
  (Wrd21.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_29_17]))));
  (* (--Rsp)) = (Wrd21.Obj);
  (* (--Rsp)) = (Wrd8.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_29_5]), 1);

DEFLABEL (label_15)
  (* (--Rsp)) = Rvl;
  goto label_28;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_30_5 3
#define LABEL_30_6 5
#define LABEL_30_7 7
#define LABEL_30_4 9
#define LABEL_30_9 11
#define LABEL_30_12 13
#define LABEL_30_13 15
#define LABEL_30_15 17
#define LABEL_30_16 19
#define LABEL_30_17 21
#define LABEL_30_19 23
#define LABEL_30_20 25
#define LABEL_30_14 27
#define LABEL_30_21 29
#define LABEL_30_22 31
#define LABEL_30_23 33
#define LABEL_30_25 35
#define LABEL_30_26 37
#define LABEL_30_10 39
#define LABEL_30_27 41
#define LABEL_30_29 43
#define LABEL_30_30 45
#define LABEL_30_8 47
#define ENVIRONMENT_LABEL_30_3 73
#define DEBUGGING_LABEL_30_2 72
#define OBJECT_30_14 71
#define OBJECT_30_13 70
#define OBJECT_30_12 69
#define OBJECT_30_11 68
#define OBJECT_30_10 67
#define OBJECT_30_9 66
#define OBJECT_30_8 65
#define OBJECT_30_7 64
#define OBJECT_30_6 63
#define OBJECT_30_5 62
#define OBJECT_30_4 61
#define OBJECT_30_3 60
#define OBJECT_30_2 59
#define OBJECT_30_1 58
#define OBJECT_30_0 57
#define EXECUTE_CACHE_30_28 49
#define EXECUTE_CACHE_30_24 51
#define EXECUTE_CACHE_30_18 53
#define EXECUTE_CACHE_30_11 55
#define FREE_REFERENCES_LABEL_30_0 48
#define NUMBER_OF_LINKER_SECTIONS_30_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
scomb_so_code_30 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd13;
  machine_word Wrd18;
  machine_word Wrd22;
  machine_word Wrd10;
  machine_word Wrd30;
  machine_word Wrd31;
  machine_word Wrd29;
  machine_word Wrd23;
  machine_word Wrd24;
  machine_word Wrd12;
  machine_word Wrd14;
  machine_word Wrd16;
  machine_word Wrd40;
  machine_word Wrd45;
  machine_word Wrd42;
  machine_word Wrd64;
  machine_word Wrd68;
  machine_word Wrd67;
  machine_word Wrd61;
  machine_word Wrd55;
  machine_word Wrd56;
  machine_word Wrd57;
  machine_word Wrd54;
  machine_word Wrd48;
  machine_word Wrd49;
  machine_word Wrd50;
  machine_word Wrd47;
  machine_word Wrd39;
  machine_word Wrd41;
  machine_word Wrd43;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd38;
  machine_word Wrd37;
  machine_word Wrd72;
  machine_word Wrd69;
  machine_word Wrd32;
  machine_word Wrd26;
  machine_word Wrd27;
  machine_word Wrd28;
  machine_word Wrd25;
  machine_word Wrd17;
  machine_word Wrd19;
  machine_word Wrd21;
  machine_word Wrd20;
  machine_word Wrd81;
  machine_word Wrd76;
  machine_word Wrd15;
  machine_word Wrd7;
  machine_word Wrd9;
  machine_word Wrd11;
  machine_word Wrd80;
  machine_word Wrd5;
  machine_word Wrd87;
  machine_word Wrd86;
  machine_word Wrd63;
  machine_word Wrd95;
  machine_word Wrd92;
  machine_word Wrd89;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_30_5);
      goto continuation_11;

    case 1:
      current_block = (Rpc - LABEL_30_6);
      goto label_43;

    case 2:
      current_block = (Rpc - LABEL_30_7);
      goto continuation_10;

    case 3:
      current_block = (Rpc - LABEL_30_4);
      goto Z__make_combination_31;

    case 4:
      current_block = (Rpc - LABEL_30_9);
      goto label_33;

    case 5:
      current_block = (Rpc - LABEL_30_12);
      goto label_34;

    case 6:
      current_block = (Rpc - LABEL_30_13);
      goto label_35;

    case 7:
      current_block = (Rpc - LABEL_30_15);
      goto label_36;

    case 8:
      current_block = (Rpc - LABEL_30_16);
      goto label_37;

    case 9:
      current_block = (Rpc - LABEL_30_17);
      goto label_38;

    case 10:
      current_block = (Rpc - LABEL_30_19);
      goto continuation_16;

    case 11:
      current_block = (Rpc - LABEL_30_20);
      goto label_44;

    case 12:
      current_block = (Rpc - LABEL_30_14);
      goto continuation_15;

    case 13:
      current_block = (Rpc - LABEL_30_21);
      goto label_39;

    case 14:
      current_block = (Rpc - LABEL_30_22);
      goto label_40;

    case 15:
      current_block = (Rpc - LABEL_30_23);
      goto label_41;

    case 16:
      current_block = (Rpc - LABEL_30_25);
      goto continuation_23;

    case 17:
      current_block = (Rpc - LABEL_30_26);
      goto label_45;

    case 18:
      current_block = (Rpc - LABEL_30_10);
      goto continuation_22;

    case 19:
      current_block = (Rpc - LABEL_30_27);
      goto label_42;

    case 20:
      current_block = (Rpc - LABEL_30_29);
      goto continuation_28;

    case 21:
      current_block = (Rpc - LABEL_30_30);
      goto label_46;

    case 22:
      current_block = (Rpc - LABEL_30_8);
      goto continuation_27;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (Z__make_combination_48)
DEFLABEL (Z__make_combination_31)
  INTERRUPT_CHECK (26, LABEL_30_4);
  (Wrd5.Obj) = (Rsp [1]);
  if ((Wrd5.Obj) == (current_block [OBJECT_30_3]))
    goto label_80;
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd5.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_79;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd5.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_78)
  if ((Wrd7.Obj) == (current_block [OBJECT_30_3]))
    goto label_76;
  (Wrd20.Obj) = (Rsp [1]);
  (Wrd21.uLng) = (OBJECT_TYPE (Wrd20.Obj));
  if (! ((Wrd21.uLng) == 1))
    goto label_75;
  (Wrd19.pObj) = (OBJECT_ADDRESS (Wrd20.Obj));
  (Wrd17.Obj) = ((Wrd19.pObj) [1]);

DEFLABEL (label_74)
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd17.Obj));
  if (! ((Wrd28.uLng) == 1))
    goto label_73;
  (Wrd27.pObj) = (OBJECT_ADDRESS (Wrd17.Obj));
  (Wrd26.Obj) = ((Wrd27.pObj) [1]);

DEFLABEL (label_72)
  if (! ((Wrd26.Obj) == (current_block [OBJECT_30_3])))
    goto label_60;
  (Wrd69.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd69.Obj);
  (Wrd72.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30_14]))));
  (* (--Rsp)) = (Wrd72.Obj);
  (* (--Rsp)) = (Wrd69.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_30_11]));

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_30_14);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_51;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30_19]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_30_2]), 1);

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_30_19);
  (Wrd38.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd38.uLng) == 26))
    goto label_59;
  if (Rvl == (current_block [OBJECT_30_6]))
    goto label_50;

DEFLABEL (label_51)
  (Wrd11.Obj) = (current_block [OBJECT_30_8]);
  (* (--Rsp)) = (Wrd11.Obj);
  goto label_49;

DEFLABEL (label_50)
  (Wrd40.Obj) = (current_block [OBJECT_30_7]);
  (* (--Rsp)) = (Wrd40.Obj);

DEFLABEL (label_49)
DEFLABEL (label_58)
  (Wrd15.Obj) = (Rsp [3]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 1))
    goto label_57;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd12.Obj) = ((Wrd14.pObj) [0]);

DEFLABEL (label_56)
  (Rsp [2]) = (Wrd12.Obj);
  (Wrd24.Obj) = (Rsp [3]);
  (Wrd25.uLng) = (OBJECT_TYPE (Wrd24.Obj));
  if (! ((Wrd25.uLng) == 1))
    goto label_55;
  (Wrd23.pObj) = (OBJECT_ADDRESS (Wrd24.Obj));
  (Wrd21.Obj) = ((Wrd23.pObj) [1]);

DEFLABEL (label_54)
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd21.Obj));
  if (! ((Wrd32.uLng) == 1))
    goto label_53;
  (Wrd31.pObj) = (OBJECT_ADDRESS (Wrd21.Obj));
  (Wrd30.Obj) = ((Wrd31.pObj) [0]);

DEFLABEL (label_52)
  (Rsp [3]) = (Wrd30.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_30_24]));

DEFLABEL (label_53)
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30_23]))));
  (* (--Rsp)) = (Wrd36.Obj);
  (* (--Rsp)) = (Wrd21.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_30_9]), 1);

DEFLABEL (label_41)
  (Wrd30.Obj) = Rvl;
  goto label_52;

DEFLABEL (label_55)
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30_22]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd24.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_30_4]), 1);

DEFLABEL (label_40)
  (Wrd21.Obj) = Rvl;
  goto label_54;

DEFLABEL (label_57)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30_21]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd15.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_30_9]), 1);

DEFLABEL (label_39)
  (Wrd12.Obj) = Rvl;
  goto label_56;

DEFLABEL (label_59)
  (Wrd42.Obj) = (current_block [OBJECT_30_6]);
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30_20]))));
  (* (--Rsp)) = (Wrd45.Obj);
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = Rvl;
  INVOKE_INTERFACE_0 (36);

DEFLABEL (label_44)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_51;
  goto label_50;

DEFLABEL (label_60)
  (Wrd37.Obj) = (Rsp [0]);
  (Wrd38.Obj) = (Rsp [1]);
  (* (Rhp++)) = (Wrd37.Obj);
  (* (Rhp++)) = (Wrd38.Obj);
  (Wrd35.pObj) = (& (Rhp [-2]));
  (Wrd36.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd35.pObj)));
  (* (--Rsp)) = (Wrd36.Obj);
  (Wrd43.uLng) = (OBJECT_TYPE (Wrd38.Obj));
  if (! ((Wrd43.uLng) == 1))
    goto label_71;
  (Wrd41.pObj) = (OBJECT_ADDRESS (Wrd38.Obj));
  (Wrd39.Obj) = ((Wrd41.pObj) [1]);

DEFLABEL (label_70)
  (Wrd50.uLng) = (OBJECT_TYPE (Wrd39.Obj));
  if (! ((Wrd50.uLng) == 1))
    goto label_69;
  (Wrd49.pObj) = (OBJECT_ADDRESS (Wrd39.Obj));
  (Wrd48.Obj) = ((Wrd49.pObj) [1]);

DEFLABEL (label_68)
  (Wrd57.uLng) = (OBJECT_TYPE (Wrd48.Obj));
  if (! ((Wrd57.uLng) == 1))
    goto label_67;
  (Wrd56.pObj) = (OBJECT_ADDRESS (Wrd48.Obj));
  (Wrd55.Obj) = ((Wrd56.pObj) [1]);

DEFLABEL (label_66)
  if (! ((Wrd55.Obj) == (current_block [OBJECT_30_3])))
    goto label_63;
  (Wrd67.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30_7]))));
  (* (--Rsp)) = (Wrd67.Obj);
  (Wrd68.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd68.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_30_11]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_30_7);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_63;
  (Wrd86.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30_5]))));
  (* (--Rsp)) = (Wrd86.Obj);
  (Wrd87.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd87.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_30_2]), 1);

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_30_5);
  (Wrd89.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd89.uLng) == 26))
    goto label_65;
  if (Rvl == (current_block [OBJECT_30_0]))
    goto label_62;

DEFLABEL (label_63)
  (Wrd63.Obj) = (current_block [OBJECT_30_5]);
  goto label_61;

DEFLABEL (label_62)
  (Wrd63.Obj) = (current_block [OBJECT_30_1]);

DEFLABEL (label_61)
DEFLABEL (label_64)
  (Rsp [1]) = (Wrd63.Obj);
  (Wrd64.Obj) = (* (Rsp++));
  (Rsp [1]) = (Wrd64.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_30_18]));

DEFLABEL (label_65)
  (Wrd92.Obj) = (current_block [OBJECT_30_0]);
  (Wrd95.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30_6]))));
  (* (--Rsp)) = (Wrd95.Obj);
  (* (--Rsp)) = (Wrd92.Obj);
  (* (--Rsp)) = Rvl;
  INVOKE_INTERFACE_0 (36);

DEFLABEL (label_43)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_63;
  goto label_62;

DEFLABEL (label_67)
  (Wrd61.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30_17]))));
  (* (--Rsp)) = (Wrd61.Obj);
  (* (--Rsp)) = (Wrd48.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_30_4]), 1);

DEFLABEL (label_38)
  (Wrd55.Obj) = Rvl;
  goto label_66;

DEFLABEL (label_69)
  (Wrd54.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30_16]))));
  (* (--Rsp)) = (Wrd54.Obj);
  (* (--Rsp)) = (Wrd39.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_30_4]), 1);

DEFLABEL (label_37)
  (Wrd48.Obj) = Rvl;
  goto label_68;

DEFLABEL (label_71)
  (Wrd47.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30_15]))));
  (* (--Rsp)) = (Wrd47.Obj);
  (* (--Rsp)) = (Wrd38.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_30_4]), 1);

DEFLABEL (label_36)
  (Wrd39.Obj) = Rvl;
  goto label_70;

DEFLABEL (label_73)
  (Wrd32.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30_13]))));
  (* (--Rsp)) = (Wrd32.Obj);
  (* (--Rsp)) = (Wrd17.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_30_4]), 1);

DEFLABEL (label_35)
  (Wrd26.Obj) = Rvl;
  goto label_72;

DEFLABEL (label_75)
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30_12]))));
  (* (--Rsp)) = (Wrd25.Obj);
  (* (--Rsp)) = (Wrd20.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_30_4]), 1);

DEFLABEL (label_34)
  (Wrd17.Obj) = Rvl;
  goto label_74;

DEFLABEL (label_76)
  (Wrd76.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30_10]))));
  (* (--Rsp)) = (Wrd76.Obj);

DEFLABEL (label_77)
  (Wrd81.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd81.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_30_11]));

DEFLABEL (label_79)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30_9]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_30_4]), 1);

DEFLABEL (label_33)
  (Wrd7.Obj) = Rvl;
  goto label_78;

DEFLABEL (label_80)
  (Wrd80.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30_8]))));
  (* (--Rsp)) = (Wrd80.Obj);
  goto label_77;

DEFLABEL (continuation_22)
  INTERRUPT_CHECK (27, LABEL_30_10);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_83;
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30_25]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_30_2]), 1);

DEFLABEL (continuation_23)
  INTERRUPT_CHECK (27, LABEL_30_25);
  (Wrd22.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd22.uLng) == 26))
    goto label_87;
  if (Rvl == (current_block [OBJECT_30_10]))
    goto label_82;

DEFLABEL (label_83)
  (Wrd11.Obj) = (current_block [OBJECT_30_12]);
  (* (--Rsp)) = (Wrd11.Obj);
  goto label_81;

DEFLABEL (label_82)
  (Wrd24.Obj) = (current_block [OBJECT_30_11]);
  (* (--Rsp)) = (Wrd24.Obj);

DEFLABEL (label_81)
DEFLABEL (label_86)
  (Wrd15.Obj) = (Rsp [2]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if (! ((Wrd16.uLng) == 1))
    goto label_85;
  (Wrd14.pObj) = (OBJECT_ADDRESS (Wrd15.Obj));
  (Wrd12.Obj) = ((Wrd14.pObj) [0]);

DEFLABEL (label_84)
  (Rsp [2]) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_30_28]));

DEFLABEL (label_85)
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30_27]))));
  (* (--Rsp)) = (Wrd20.Obj);
  (* (--Rsp)) = (Wrd15.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_30_9]), 1);

DEFLABEL (label_42)
  (Wrd12.Obj) = Rvl;
  goto label_84;

DEFLABEL (label_87)
  (Wrd26.Obj) = (current_block [OBJECT_30_10]);
  (Wrd29.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30_26]))));
  (* (--Rsp)) = (Wrd29.Obj);
  (* (--Rsp)) = (Wrd26.Obj);
  (* (--Rsp)) = Rvl;
  INVOKE_INTERFACE_0 (36);

DEFLABEL (label_45)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_83;
  goto label_82;

DEFLABEL (continuation_27)
  INTERRUPT_CHECK (27, LABEL_30_8);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_89;

DEFLABEL (label_88)
  (Wrd14.Obj) = (Rsp [0]);
  (Wrd15.Obj) = (current_block [OBJECT_30_3]);
  (* (Rhp++)) = (Wrd14.Obj);
  (* (Rhp++)) = (Wrd15.Obj);
  (Wrd13.pObj) = (& (Rhp [-2]));
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd13.pObj)));
  (Rsp [1]) = (Wrd11.Obj);
  (Wrd16.Obj) = (current_block [OBJECT_30_5]);
  (Rsp [0]) = (Wrd16.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_30_18]));

DEFLABEL (label_89)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30_29]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_30_2]), 1);

DEFLABEL (continuation_28)
  INTERRUPT_CHECK (27, LABEL_30_29);
  (Wrd18.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd18.uLng) == 26))
    goto label_91;
  (Wrd26.Lng) = (FIXNUM_TO_LONG (Rvl));
  if (! ((Wrd26.Lng) == 0))
    goto label_88;

DEFLABEL (label_90)
  (Wrd24.Obj) = (Rsp [0]);
  (Rsp [1]) = (Wrd24.Obj);
  (Wrd25.Obj) = (current_block [OBJECT_30_13]);
  (Rsp [0]) = (Wrd25.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_30_14]), 2);

DEFLABEL (label_91)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30_30]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = Rvl;
  INVOKE_INTERFACE_0 (45);

DEFLABEL (label_46)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_88;
  goto label_90;

INVOKE_INTERFACE_TARGET_0
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_31_4 3
#define LABEL_31_5 5
#define LABEL_31_6 7
#define LABEL_31_8 9
#define LABEL_31_9 11
#define LABEL_31_11 13
#define LABEL_31_12 15
#define LABEL_31_13 17
#define LABEL_31_14 19
#define LABEL_31_15 21
#define LABEL_31_16 23
#define LABEL_31_17 25
#define ENVIRONMENT_LABEL_31_3 52
#define DEBUGGING_LABEL_31_2 51
#define OBJECT_31_19 50
#define OBJECT_31_18 49
#define OBJECT_31_17 48
#define OBJECT_31_16 47
#define OBJECT_31_15 46
#define OBJECT_31_14 45
#define OBJECT_31_13 44
#define OBJECT_31_12 43
#define OBJECT_31_11 42
#define OBJECT_31_10 41
#define OBJECT_31_9 40
#define OBJECT_31_8 39
#define OBJECT_31_7 38
#define OBJECT_31_6 37
#define OBJECT_31_5 36
#define OBJECT_31_4 35
#define OBJECT_31_3 34
#define OBJECT_31_2 33
#define OBJECT_31_1 32
#define OBJECT_31_0 31
#define EXECUTE_CACHE_31_10 27
#define EXECUTE_CACHE_31_7 29
#define FREE_REFERENCES_LABEL_31_0 26
#define NUMBER_OF_LINKER_SECTIONS_31_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
scomb_so_code_31 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd210;
  machine_word Wrd212;
  machine_word Wrd205;
  machine_word Wrd207;
  machine_word Wrd202;
  machine_word Wrd204;
  machine_word Wrd199;
  machine_word Wrd201;
  machine_word Wrd196;
  machine_word Wrd198;
  machine_word Wrd192;
  machine_word Wrd194;
  machine_word Wrd188;
  machine_word Wrd190;
  machine_word Wrd191;
  machine_word Wrd184;
  machine_word Wrd186;
  machine_word Wrd180;
  machine_word Wrd182;
  machine_word Wrd183;
  machine_word Wrd176;
  machine_word Wrd178;
  machine_word Wrd172;
  machine_word Wrd174;
  machine_word Wrd168;
  machine_word Wrd170;
  machine_word Wrd171;
  machine_word Wrd163;
  machine_word Wrd165;
  machine_word Wrd166;
  machine_word Wrd160;
  machine_word Wrd162;
  machine_word Wrd155;
  machine_word Wrd157;
  machine_word Wrd151;
  machine_word Wrd153;
  machine_word Wrd148;
  machine_word Wrd150;
  machine_word Wrd144;
  machine_word Wrd146;
  machine_word Wrd140;
  machine_word Wrd142;
  machine_word Wrd136;
  machine_word Wrd138;
  machine_word Wrd139;
  machine_word Wrd131;
  machine_word Wrd133;
  machine_word Wrd127;
  machine_word Wrd129;
  machine_word Wrd123;
  machine_word Wrd125;
  machine_word Wrd126;
  machine_word Wrd118;
  machine_word Wrd120;
  machine_word Wrd115;
  machine_word Wrd117;
  machine_word Wrd110;
  machine_word Wrd112;
  machine_word Wrd106;
  machine_word Wrd108;
  machine_word Wrd103;
  machine_word Wrd105;
  machine_word Wrd99;
  machine_word Wrd101;
  machine_word Wrd95;
  machine_word Wrd97;
  machine_word Wrd91;
  machine_word Wrd93;
  machine_word Wrd94;
  machine_word Wrd86;
  machine_word Wrd88;
  machine_word Wrd82;
  machine_word Wrd84;
  machine_word Wrd78;
  machine_word Wrd80;
  machine_word Wrd81;
  machine_word Wrd73;
  machine_word Wrd75;
  machine_word Wrd70;
  machine_word Wrd72;
  machine_word Wrd65;
  machine_word Wrd67;
  machine_word Wrd68;
  machine_word Wrd61;
  machine_word Wrd63;
  machine_word Wrd64;
  machine_word Wrd58;
  machine_word Wrd60;
  machine_word Wrd54;
  machine_word Wrd56;
  machine_word Wrd50;
  machine_word Wrd52;
  machine_word Wrd46;
  machine_word Wrd48;
  machine_word Wrd49;
  machine_word Wrd41;
  machine_word Wrd43;
  machine_word Wrd37;
  machine_word Wrd39;
  machine_word Wrd33;
  machine_word Wrd35;
  machine_word Wrd36;
  machine_word Wrd28;
  machine_word Wrd30;
  machine_word Wrd25;
  machine_word Wrd27;
  machine_word Wrd20;
  machine_word Wrd22;
  machine_word Wrd23;
  machine_word Wrd16;
  machine_word Wrd18;
  machine_word Wrd19;
  machine_word Wrd14;
  machine_word Wrd15;
  machine_word Wrd10;
  machine_word Wrd6;
  machine_word Wrd9;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_31_4);
      goto lambda_62;

    case 1:
      current_block = (Rpc - LABEL_31_5);
      goto continuation_6;

    case 2:
      current_block = (Rpc - LABEL_31_6);
      goto continuation_5;

    case 3:
      current_block = (Rpc - LABEL_31_8);
      goto continuation_4;

    case 4:
      current_block = (Rpc - LABEL_31_9);
      goto continuation_3;

    case 5:
      current_block = (Rpc - LABEL_31_11);
      goto continuation_2;

    case 6:
      current_block = (Rpc - LABEL_31_12);
      goto continuation_1;

    case 7:
      current_block = (Rpc - LABEL_31_13);
      goto continuation_0;

    case 8:
      current_block = (Rpc - LABEL_31_14);
      goto continuation_10;

    case 9:
      current_block = (Rpc - LABEL_31_15);
      goto continuation_9;

    case 10:
      current_block = (Rpc - LABEL_31_16);
      goto continuation_8;

    case 11:
      current_block = (Rpc - LABEL_31_17);
      goto continuation_7;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (lambda_65)
DEFLABEL (lambda_62)
  INTERRUPT_CHECK (26, LABEL_31_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31_6]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_31_0]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_31_7]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_31_6);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_31_10]));

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_31_5);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31_9]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_31_1]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_31_7]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_31_9);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_31_10]));

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_31_8);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31_11]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31_12]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_31_2]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_31_7]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_31_12);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_31_10]));

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_31_11);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31_13]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_31_3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [5]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_31_7]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_31_13);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31_14]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [6]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31_15]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_31_4]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [8]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_31_7]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_31_15);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_31_10]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_31_14);
  (* (--Rsp)) = Rvl;
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31_16]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [7]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31_17]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (current_block [OBJECT_31_5]);
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [9]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_31_7]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_31_17);
  (* (--Rsp)) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_31_10]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_31_16);
  (Rsp [5]) = Rvl;
  (Wrd6.Obj) = (* (Rsp++));
  (Rsp [5]) = (Wrd6.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (Wrd11.Obj) = (current_block [OBJECT_31_6]);
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  (Wrd15.Obj) = (current_block [OBJECT_31_7]);
  (* (Rhp++)) = (Wrd15.Obj);
  (* (Rhp++)) = (Wrd7.Obj);
  (Wrd14.pObj) = (& (Rhp [-2]));
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd14.pObj)));
  (Wrd19.Obj) = (current_block [OBJECT_31_8]);
  (* (Rhp++)) = (Wrd19.Obj);
  (* (Rhp++)) = (Wrd12.Obj);
  (Wrd18.pObj) = (& (Rhp [-2]));
  (Wrd16.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd18.pObj)));
  (Wrd23.Obj) = (Rsp [2]);
  (* (Rhp++)) = (Wrd23.Obj);
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd22.pObj) = (& (Rhp [-2]));
  (Wrd20.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd22.pObj)));
  (* (Rhp++)) = (Wrd16.Obj);
  (* (Rhp++)) = (Wrd20.Obj);
  (Wrd27.pObj) = (& (Rhp [-2]));
  (Wrd25.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd27.pObj)));
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd30.pObj) = (& (Rhp [-2]));
  (Wrd28.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd30.pObj)));
  (Wrd36.Obj) = (current_block [OBJECT_31_9]);
  (* (Rhp++)) = (Wrd36.Obj);
  (* (Rhp++)) = (Wrd28.Obj);
  (Wrd35.pObj) = (& (Rhp [-2]));
  (Wrd33.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd35.pObj)));
  (* (Rhp++)) = (Wrd19.Obj);
  (* (Rhp++)) = (Wrd33.Obj);
  (Wrd39.pObj) = (& (Rhp [-2]));
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd39.pObj)));
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd43.pObj) = (& (Rhp [-2]));
  (Wrd41.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd43.pObj)));
  (Wrd49.Obj) = (current_block [OBJECT_31_10]);
  (* (Rhp++)) = (Wrd49.Obj);
  (* (Rhp++)) = (Wrd41.Obj);
  (Wrd48.pObj) = (& (Rhp [-2]));
  (Wrd46.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd48.pObj)));
  (* (Rhp++)) = (Wrd19.Obj);
  (* (Rhp++)) = (Wrd46.Obj);
  (Wrd52.pObj) = (& (Rhp [-2]));
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd52.pObj)));
  (* (Rhp++)) = (Wrd50.Obj);
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd56.pObj) = (& (Rhp [-2]));
  (Wrd54.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd56.pObj)));
  (* (Rhp++)) = (Wrd37.Obj);
  (* (Rhp++)) = (Wrd54.Obj);
  (Wrd60.pObj) = (& (Rhp [-2]));
  (Wrd58.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd60.pObj)));
  (Wrd64.Obj) = (current_block [OBJECT_31_11]);
  (* (Rhp++)) = (Wrd64.Obj);
  (* (Rhp++)) = (Wrd58.Obj);
  (Wrd63.pObj) = (& (Rhp [-2]));
  (Wrd61.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd63.pObj)));
  (Wrd68.Obj) = (Rsp [3]);
  (* (Rhp++)) = (Wrd68.Obj);
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd67.pObj) = (& (Rhp [-2]));
  (Wrd65.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd67.pObj)));
  (* (Rhp++)) = (Wrd61.Obj);
  (* (Rhp++)) = (Wrd65.Obj);
  (Wrd72.pObj) = (& (Rhp [-2]));
  (Wrd70.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd72.pObj)));
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd75.pObj) = (& (Rhp [-2]));
  (Wrd73.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd75.pObj)));
  (Wrd81.Obj) = (current_block [OBJECT_31_12]);
  (* (Rhp++)) = (Wrd81.Obj);
  (* (Rhp++)) = (Wrd73.Obj);
  (Wrd80.pObj) = (& (Rhp [-2]));
  (Wrd78.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd80.pObj)));
  (* (Rhp++)) = (Wrd19.Obj);
  (* (Rhp++)) = (Wrd78.Obj);
  (Wrd84.pObj) = (& (Rhp [-2]));
  (Wrd82.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd84.pObj)));
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd88.pObj) = (& (Rhp [-2]));
  (Wrd86.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd88.pObj)));
  (Wrd94.Obj) = (current_block [OBJECT_31_13]);
  (* (Rhp++)) = (Wrd94.Obj);
  (* (Rhp++)) = (Wrd86.Obj);
  (Wrd93.pObj) = (& (Rhp [-2]));
  (Wrd91.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd93.pObj)));
  (* (Rhp++)) = (Wrd19.Obj);
  (* (Rhp++)) = (Wrd91.Obj);
  (Wrd97.pObj) = (& (Rhp [-2]));
  (Wrd95.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd97.pObj)));
  (* (Rhp++)) = (Wrd95.Obj);
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd101.pObj) = (& (Rhp [-2]));
  (Wrd99.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd101.pObj)));
  (* (Rhp++)) = (Wrd82.Obj);
  (* (Rhp++)) = (Wrd99.Obj);
  (Wrd105.pObj) = (& (Rhp [-2]));
  (Wrd103.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd105.pObj)));
  (* (Rhp++)) = (Wrd64.Obj);
  (* (Rhp++)) = (Wrd103.Obj);
  (Wrd108.pObj) = (& (Rhp [-2]));
  (Wrd106.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd108.pObj)));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd112.pObj) = (& (Rhp [-2]));
  (Wrd110.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd112.pObj)));
  (* (Rhp++)) = (Wrd106.Obj);
  (* (Rhp++)) = (Wrd110.Obj);
  (Wrd117.pObj) = (& (Rhp [-2]));
  (Wrd115.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd117.pObj)));
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd120.pObj) = (& (Rhp [-2]));
  (Wrd118.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd120.pObj)));
  (Wrd126.Obj) = (current_block [OBJECT_31_14]);
  (* (Rhp++)) = (Wrd126.Obj);
  (* (Rhp++)) = (Wrd118.Obj);
  (Wrd125.pObj) = (& (Rhp [-2]));
  (Wrd123.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd125.pObj)));
  (* (Rhp++)) = (Wrd19.Obj);
  (* (Rhp++)) = (Wrd123.Obj);
  (Wrd129.pObj) = (& (Rhp [-2]));
  (Wrd127.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd129.pObj)));
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd133.pObj) = (& (Rhp [-2]));
  (Wrd131.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd133.pObj)));
  (Wrd139.Obj) = (current_block [OBJECT_31_15]);
  (* (Rhp++)) = (Wrd139.Obj);
  (* (Rhp++)) = (Wrd131.Obj);
  (Wrd138.pObj) = (& (Rhp [-2]));
  (Wrd136.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd138.pObj)));
  (* (Rhp++)) = (Wrd19.Obj);
  (* (Rhp++)) = (Wrd136.Obj);
  (Wrd142.pObj) = (& (Rhp [-2]));
  (Wrd140.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd142.pObj)));
  (* (Rhp++)) = (Wrd140.Obj);
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd146.pObj) = (& (Rhp [-2]));
  (Wrd144.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd146.pObj)));
  (* (Rhp++)) = (Wrd127.Obj);
  (* (Rhp++)) = (Wrd144.Obj);
  (Wrd150.pObj) = (& (Rhp [-2]));
  (Wrd148.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd150.pObj)));
  (* (Rhp++)) = (Wrd64.Obj);
  (* (Rhp++)) = (Wrd148.Obj);
  (Wrd153.pObj) = (& (Rhp [-2]));
  (Wrd151.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd153.pObj)));
  (* (Rhp++)) = (Wrd6.Obj);
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd157.pObj) = (& (Rhp [-2]));
  (Wrd155.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd157.pObj)));
  (* (Rhp++)) = (Wrd151.Obj);
  (* (Rhp++)) = (Wrd155.Obj);
  (Wrd162.pObj) = (& (Rhp [-2]));
  (Wrd160.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd162.pObj)));
  (Wrd166.Obj) = (Rsp [0]);
  (* (Rhp++)) = (Wrd166.Obj);
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd165.pObj) = (& (Rhp [-2]));
  (Wrd163.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd165.pObj)));
  (Wrd171.Obj) = (current_block [OBJECT_31_16]);
  (* (Rhp++)) = (Wrd171.Obj);
  (* (Rhp++)) = (Wrd163.Obj);
  (Wrd170.pObj) = (& (Rhp [-2]));
  (Wrd168.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd170.pObj)));
  (* (Rhp++)) = (Wrd168.Obj);
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd174.pObj) = (& (Rhp [-2]));
  (Wrd172.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd174.pObj)));
  (* (Rhp++)) = (Wrd10.Obj);
  (* (Rhp++)) = (Wrd172.Obj);
  (Wrd178.pObj) = (& (Rhp [-2]));
  (Wrd176.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd178.pObj)));
  (Wrd183.Obj) = (current_block [OBJECT_31_17]);
  (* (Rhp++)) = (Wrd183.Obj);
  (* (Rhp++)) = (Wrd176.Obj);
  (Wrd182.pObj) = (& (Rhp [-2]));
  (Wrd180.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd182.pObj)));
  (* (Rhp++)) = (Wrd180.Obj);
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd186.pObj) = (& (Rhp [-2]));
  (Wrd184.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd186.pObj)));
  (Wrd191.Obj) = (current_block [OBJECT_31_18]);
  (* (Rhp++)) = (Wrd191.Obj);
  (* (Rhp++)) = (Wrd184.Obj);
  (Wrd190.pObj) = (& (Rhp [-2]));
  (Wrd188.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd190.pObj)));
  (* (Rhp++)) = (Wrd188.Obj);
  (* (Rhp++)) = (Wrd11.Obj);
  (Wrd194.pObj) = (& (Rhp [-2]));
  (Wrd192.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd194.pObj)));
  (* (Rhp++)) = (Wrd160.Obj);
  (* (Rhp++)) = (Wrd192.Obj);
  (Wrd198.pObj) = (& (Rhp [-2]));
  (Wrd196.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd198.pObj)));
  (* (Rhp++)) = (Wrd115.Obj);
  (* (Rhp++)) = (Wrd196.Obj);
  (Wrd201.pObj) = (& (Rhp [-2]));
  (Wrd199.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd201.pObj)));
  (* (Rhp++)) = (Wrd70.Obj);
  (* (Rhp++)) = (Wrd199.Obj);
  (Wrd204.pObj) = (& (Rhp [-2]));
  (Wrd202.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd204.pObj)));
  (* (Rhp++)) = (Wrd25.Obj);
  (* (Rhp++)) = (Wrd202.Obj);
  (Wrd207.pObj) = (& (Rhp [-2]));
  (Wrd205.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd207.pObj)));
  (Wrd212.Obj) = (current_block [OBJECT_31_19]);
  (* (Rhp++)) = (Wrd212.Obj);
  (* (Rhp++)) = (Wrd205.Obj);
  (Wrd210.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd210.pObj)));
  Rsp = (& (Rsp [6]));
  goto pop_return;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_32_4 3
#define LABEL_32_5 5
#define LABEL_32_6 7
#define LABEL_32_7 9
#define LABEL_32_8 11
#define LABEL_32_9 13
#define LABEL_32_10 15
#define LABEL_32_11 17
#define ENVIRONMENT_LABEL_32_3 36
#define DEBUGGING_LABEL_32_2 35
#define OBJECT_32_11 34
#define OBJECT_32_10 33
#define OBJECT_32_9 32
#define OBJECT_32_8 31
#define OBJECT_32_7 30
#define OBJECT_32_6 29
#define OBJECT_32_5 28
#define OBJECT_32_4 27
#define OBJECT_32_3 26
#define OBJECT_32_2 25
#define OBJECT_32_1 24
#define OBJECT_32_0 23
#define EXECUTE_CACHE_32_13 19
#define EXECUTE_CACHE_32_12 21
#define FREE_REFERENCES_LABEL_32_0 18
#define NUMBER_OF_LINKER_SECTIONS_32_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
scomb_so_code_32 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd43;
  machine_word Wrd40;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd38;
  machine_word Wrd35;
  machine_word Wrd53;
  machine_word Wrd50;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd48;
  machine_word Wrd45;
  machine_word Wrd65;
  machine_word Wrd62;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd60;
  machine_word Wrd57;
  machine_word Wrd75;
  machine_word Wrd72;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd70;
  machine_word Wrd67;
  machine_word Wrd87;
  machine_word Wrd84;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd82;
  machine_word Wrd79;
  machine_word Wrd97;
  machine_word Wrd94;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd92;
  machine_word Wrd89;
  machine_word Wrd109;
  machine_word Wrd106;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd104;
  machine_word Wrd101;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_32_4);
      goto combination_size_7;

    case 1:
      current_block = (Rpc - LABEL_32_5);
      goto label_15;

    case 2:
      current_block = (Rpc - LABEL_32_6);
      goto label_14;

    case 3:
      current_block = (Rpc - LABEL_32_7);
      goto label_13;

    case 4:
      current_block = (Rpc - LABEL_32_8);
      goto label_12;

    case 5:
      current_block = (Rpc - LABEL_32_9);
      goto label_11;

    case 6:
      current_block = (Rpc - LABEL_32_10);
      goto label_10;

    case 7:
      current_block = (Rpc - LABEL_32_11);
      goto label_9;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (combination_size_17)
DEFLABEL (combination_size_7)
  INTERRUPT_CHECK (26, LABEL_32_4);
  (Wrd101.Obj) = (current_block [OBJECT_32_0]);
  (Wrd104.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 48L) < ((unsigned long) (Wrd104.Lng))))
    goto label_36;
  (Wrd6.uLng) = (OBJECT_DATUM (Wrd101.Obj));
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if ((Wrd6.Obj) == (Wrd8.Obj))
    goto label_35;

DEFLABEL (label_34)
  (Wrd89.Obj) = (current_block [OBJECT_32_2]);
  (Wrd92.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 7L) < ((unsigned long) (Wrd92.Lng))))
    goto label_33;
  (Wrd10.uLng) = (OBJECT_DATUM (Wrd89.Obj));
  (Wrd11.Obj) = (Rsp [0]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if ((Wrd10.Obj) == (Wrd12.Obj))
    goto label_30;

DEFLABEL (label_32)
  (Wrd79.Obj) = (current_block [OBJECT_32_3]);
  (Wrd82.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 27L) < ((unsigned long) (Wrd82.Lng))))
    goto label_31;
  (Wrd14.uLng) = (OBJECT_DATUM (Wrd79.Obj));
  (Wrd15.Obj) = (Rsp [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd14.Obj) == (Wrd16.Obj))
    goto label_30;

DEFLABEL (label_29)
  (Wrd67.Obj) = (current_block [OBJECT_32_4]);
  (Wrd70.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 12L) < ((unsigned long) (Wrd70.Lng))))
    goto label_28;
  (Wrd18.uLng) = (OBJECT_DATUM (Wrd67.Obj));
  (Wrd19.Obj) = (Rsp [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if ((Wrd18.Obj) == (Wrd20.Obj))
    goto label_24;

DEFLABEL (label_27)
  (Wrd57.Obj) = (current_block [OBJECT_32_5]);
  (Wrd60.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd60.Lng))))
    goto label_26;
  (Wrd22.uLng) = (OBJECT_DATUM (Wrd57.Obj));
  (Wrd23.Obj) = (Rsp [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd22.Obj) == (Wrd24.Obj))
    goto label_24;

DEFLABEL (label_23)
  (Wrd45.Obj) = (current_block [OBJECT_32_6]);
  (Wrd48.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 38L) < ((unsigned long) (Wrd48.Lng))))
    goto label_22;
  (Wrd26.uLng) = (OBJECT_DATUM (Wrd45.Obj));
  (Wrd27.Obj) = (Rsp [0]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if (! ((Wrd26.Obj) == (Wrd28.Obj)))
    goto label_19;

DEFLABEL (label_18)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_32_13]));

DEFLABEL (label_19)
  (Wrd35.Obj) = (current_block [OBJECT_32_7]);
  (Wrd38.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 42L) < ((unsigned long) (Wrd38.Lng))))
    goto label_21;
  (Wrd30.uLng) = (OBJECT_DATUM (Wrd35.Obj));
  (Wrd31.Obj) = (Rsp [0]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if ((Wrd30.Obj) == (Wrd32.Obj))
    goto label_18;

DEFLABEL (label_20)
  (Wrd33.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd34.Obj) = (current_block [OBJECT_32_8]);
  (Rsp [1]) = (Wrd34.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_32_12]));

DEFLABEL (label_21)
  (Wrd40.Obj) = (Rsp [0]);
  (Wrd43.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_32_11]))));
  (* (--Rsp)) = (Wrd43.Obj);
  (* (--Rsp)) = (Wrd40.Obj);
  (* (--Rsp)) = (Wrd35.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_32_1]), 2);

DEFLABEL (label_9)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_20;
  goto label_18;

DEFLABEL (label_22)
  (Wrd50.Obj) = (Rsp [0]);
  (Wrd53.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_32_10]))));
  (* (--Rsp)) = (Wrd53.Obj);
  (* (--Rsp)) = (Wrd50.Obj);
  (* (--Rsp)) = (Wrd45.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_32_1]), 2);

DEFLABEL (label_10)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_19;
  goto label_18;

DEFLABEL (label_24)
  Rvl = (current_block [OBJECT_32_9]);

DEFLABEL (label_25)
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_26)
  (Wrd62.Obj) = (Rsp [0]);
  (Wrd65.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_32_9]))));
  (* (--Rsp)) = (Wrd65.Obj);
  (* (--Rsp)) = (Wrd62.Obj);
  (* (--Rsp)) = (Wrd57.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_32_1]), 2);

DEFLABEL (label_11)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_23;
  goto label_24;

DEFLABEL (label_28)
  (Wrd72.Obj) = (Rsp [0]);
  (Wrd75.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_32_8]))));
  (* (--Rsp)) = (Wrd75.Obj);
  (* (--Rsp)) = (Wrd72.Obj);
  (* (--Rsp)) = (Wrd67.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_32_1]), 2);

DEFLABEL (label_12)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_27;
  goto label_24;

DEFLABEL (label_30)
  Rvl = (current_block [OBJECT_32_10]);
  goto label_25;

DEFLABEL (label_31)
  (Wrd84.Obj) = (Rsp [0]);
  (Wrd87.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_32_7]))));
  (* (--Rsp)) = (Wrd87.Obj);
  (* (--Rsp)) = (Wrd84.Obj);
  (* (--Rsp)) = (Wrd79.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_32_1]), 2);

DEFLABEL (label_13)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_29;
  goto label_30;

DEFLABEL (label_33)
  (Wrd94.Obj) = (Rsp [0]);
  (Wrd97.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_32_6]))));
  (* (--Rsp)) = (Wrd97.Obj);
  (* (--Rsp)) = (Wrd94.Obj);
  (* (--Rsp)) = (Wrd89.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_32_1]), 2);

DEFLABEL (label_14)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_32;
  goto label_30;

DEFLABEL (label_35)
  Rvl = (current_block [OBJECT_32_11]);
  goto label_25;

DEFLABEL (label_36)
  (Wrd106.Obj) = (Rsp [0]);
  (Wrd109.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_32_5]))));
  (* (--Rsp)) = (Wrd109.Obj);
  (* (--Rsp)) = (Wrd106.Obj);
  (* (--Rsp)) = (Wrd101.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_32_1]), 2);

DEFLABEL (label_15)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_34;
  goto label_35;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_33_4 3
#define LABEL_33_5 5
#define LABEL_33_6 7
#define LABEL_33_7 9
#define LABEL_33_8 11
#define LABEL_33_9 13
#define LABEL_33_10 15
#define LABEL_33_11 17
#define ENVIRONMENT_LABEL_33_3 40
#define DEBUGGING_LABEL_33_2 39
#define OBJECT_33_11 38
#define OBJECT_33_10 37
#define OBJECT_33_9 36
#define OBJECT_33_8 35
#define OBJECT_33_7 34
#define OBJECT_33_6 33
#define OBJECT_33_5 32
#define OBJECT_33_4 31
#define OBJECT_33_3 30
#define OBJECT_33_2 29
#define OBJECT_33_1 28
#define OBJECT_33_0 27
#define EXECUTE_CACHE_33_15 19
#define EXECUTE_CACHE_33_14 21
#define EXECUTE_CACHE_33_13 23
#define EXECUTE_CACHE_33_12 25
#define FREE_REFERENCES_LABEL_33_0 18
#define NUMBER_OF_LINKER_SECTIONS_33_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
scomb_so_code_33 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd97;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd45;
  machine_word Wrd42;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd40;
  machine_word Wrd37;
  machine_word Wrd55;
  machine_word Wrd52;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd50;
  machine_word Wrd47;
  machine_word Wrd65;
  machine_word Wrd62;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd60;
  machine_word Wrd57;
  machine_word Wrd75;
  machine_word Wrd72;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd70;
  machine_word Wrd67;
  machine_word Wrd85;
  machine_word Wrd82;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd80;
  machine_word Wrd77;
  machine_word Wrd95;
  machine_word Wrd92;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd90;
  machine_word Wrd87;
  machine_word Wrd106;
  machine_word Wrd103;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd101;
  machine_word Wrd98;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_33_4);
      goto combination_operator_7;

    case 1:
      current_block = (Rpc - LABEL_33_5);
      goto label_15;

    case 2:
      current_block = (Rpc - LABEL_33_6);
      goto label_14;

    case 3:
      current_block = (Rpc - LABEL_33_7);
      goto label_13;

    case 4:
      current_block = (Rpc - LABEL_33_8);
      goto label_12;

    case 5:
      current_block = (Rpc - LABEL_33_9);
      goto label_11;

    case 6:
      current_block = (Rpc - LABEL_33_10);
      goto label_10;

    case 7:
      current_block = (Rpc - LABEL_33_11);
      goto label_9;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (combination_operator_17)
DEFLABEL (combination_operator_7)
  INTERRUPT_CHECK (26, LABEL_33_4);
  (Wrd98.Obj) = (current_block [OBJECT_33_0]);
  (Wrd101.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 48L) < ((unsigned long) (Wrd101.Lng))))
    goto label_35;
  (Wrd6.uLng) = (OBJECT_DATUM (Wrd98.Obj));
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd6.Obj) == (Wrd8.Obj)))
    goto label_19;

DEFLABEL (label_18)
  (Wrd97.Obj) = (current_block [OBJECT_33_10]);
  (* (--Rsp)) = (Wrd97.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_11]), 2);

DEFLABEL (label_19)
  (Wrd87.Obj) = (current_block [OBJECT_33_2]);
  (Wrd90.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 7L) < ((unsigned long) (Wrd90.Lng))))
    goto label_34;
  (Wrd10.uLng) = (OBJECT_DATUM (Wrd87.Obj));
  (Wrd11.Obj) = (Rsp [0]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd10.Obj) == (Wrd12.Obj)))
    goto label_21;

DEFLABEL (label_20)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_33_15]));

DEFLABEL (label_21)
  (Wrd77.Obj) = (current_block [OBJECT_33_3]);
  (Wrd80.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 27L) < ((unsigned long) (Wrd80.Lng))))
    goto label_33;
  (Wrd14.uLng) = (OBJECT_DATUM (Wrd77.Obj));
  (Wrd15.Obj) = (Rsp [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd14.Obj) == (Wrd16.Obj))
    goto label_20;

DEFLABEL (label_32)
  (Wrd67.Obj) = (current_block [OBJECT_33_4]);
  (Wrd70.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 12L) < ((unsigned long) (Wrd70.Lng))))
    goto label_31;
  (Wrd18.uLng) = (OBJECT_DATUM (Wrd67.Obj));
  (Wrd19.Obj) = (Rsp [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd18.Obj) == (Wrd20.Obj)))
    goto label_23;

DEFLABEL (label_22)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_33_14]));

DEFLABEL (label_23)
  (Wrd57.Obj) = (current_block [OBJECT_33_5]);
  (Wrd60.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd60.Lng))))
    goto label_30;
  (Wrd22.uLng) = (OBJECT_DATUM (Wrd57.Obj));
  (Wrd23.Obj) = (Rsp [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd22.Obj) == (Wrd24.Obj))
    goto label_22;

DEFLABEL (label_29)
  (Wrd47.Obj) = (current_block [OBJECT_33_6]);
  (Wrd50.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 38L) < ((unsigned long) (Wrd50.Lng))))
    goto label_28;
  (Wrd26.uLng) = (OBJECT_DATUM (Wrd47.Obj));
  (Wrd27.Obj) = (Rsp [0]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if (! ((Wrd26.Obj) == (Wrd28.Obj)))
    goto label_25;

DEFLABEL (label_24)
  (Wrd35.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd35.Obj);
  (Wrd36.Obj) = (current_block [OBJECT_33_9]);
  (Rsp [1]) = (Wrd36.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_33_13]));

DEFLABEL (label_25)
  (Wrd37.Obj) = (current_block [OBJECT_33_7]);
  (Wrd40.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 42L) < ((unsigned long) (Wrd40.Lng))))
    goto label_27;
  (Wrd30.uLng) = (OBJECT_DATUM (Wrd37.Obj));
  (Wrd31.Obj) = (Rsp [0]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if ((Wrd30.Obj) == (Wrd32.Obj))
    goto label_24;

DEFLABEL (label_26)
  (Wrd33.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd34.Obj) = (current_block [OBJECT_33_8]);
  (Rsp [1]) = (Wrd34.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_33_12]));

DEFLABEL (label_27)
  (Wrd42.Obj) = (Rsp [0]);
  (Wrd45.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_11]))));
  (* (--Rsp)) = (Wrd45.Obj);
  (* (--Rsp)) = (Wrd42.Obj);
  (* (--Rsp)) = (Wrd37.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_1]), 2);

DEFLABEL (label_9)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_26;
  goto label_24;

DEFLABEL (label_28)
  (Wrd52.Obj) = (Rsp [0]);
  (Wrd55.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_10]))));
  (* (--Rsp)) = (Wrd55.Obj);
  (* (--Rsp)) = (Wrd52.Obj);
  (* (--Rsp)) = (Wrd47.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_1]), 2);

DEFLABEL (label_10)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_25;
  goto label_24;

DEFLABEL (label_30)
  (Wrd62.Obj) = (Rsp [0]);
  (Wrd65.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_9]))));
  (* (--Rsp)) = (Wrd65.Obj);
  (* (--Rsp)) = (Wrd62.Obj);
  (* (--Rsp)) = (Wrd57.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_1]), 2);

DEFLABEL (label_11)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_29;
  goto label_22;

DEFLABEL (label_31)
  (Wrd72.Obj) = (Rsp [0]);
  (Wrd75.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_8]))));
  (* (--Rsp)) = (Wrd75.Obj);
  (* (--Rsp)) = (Wrd72.Obj);
  (* (--Rsp)) = (Wrd67.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_1]), 2);

DEFLABEL (label_12)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_23;
  goto label_22;

DEFLABEL (label_33)
  (Wrd82.Obj) = (Rsp [0]);
  (Wrd85.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_7]))));
  (* (--Rsp)) = (Wrd85.Obj);
  (* (--Rsp)) = (Wrd82.Obj);
  (* (--Rsp)) = (Wrd77.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_1]), 2);

DEFLABEL (label_13)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_32;
  goto label_20;

DEFLABEL (label_34)
  (Wrd92.Obj) = (Rsp [0]);
  (Wrd95.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_6]))));
  (* (--Rsp)) = (Wrd95.Obj);
  (* (--Rsp)) = (Wrd92.Obj);
  (* (--Rsp)) = (Wrd87.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_1]), 2);

DEFLABEL (label_14)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_21;
  goto label_20;

DEFLABEL (label_35)
  (Wrd103.Obj) = (Rsp [0]);
  (Wrd106.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33_5]))));
  (* (--Rsp)) = (Wrd106.Obj);
  (* (--Rsp)) = (Wrd103.Obj);
  (* (--Rsp)) = (Wrd98.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_33_1]), 2);

DEFLABEL (label_15)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_19;
  goto label_18;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_34_4 3
#define LABEL_34_5 5
#define LABEL_34_6 7
#define LABEL_34_7 9
#define LABEL_34_8 11
#define LABEL_34_9 13
#define LABEL_34_10 15
#define LABEL_34_11 17
#define LABEL_34_13 19
#define LABEL_34_15 21
#define LABEL_34_17 23
#define LABEL_34_20 25
#define ENVIRONMENT_LABEL_34_3 51
#define DEBUGGING_LABEL_34_2 50
#define OBJECT_34_10 49
#define OBJECT_34_9 48
#define OBJECT_34_8 47
#define OBJECT_34_7 46
#define OBJECT_34_6 45
#define OBJECT_34_5 44
#define OBJECT_34_4 43
#define OBJECT_34_3 42
#define OBJECT_34_2 41
#define OBJECT_34_1 40
#define OBJECT_34_0 39
#define EXECUTE_CACHE_34_21 27
#define EXECUTE_CACHE_34_19 29
#define EXECUTE_CACHE_34_18 31
#define EXECUTE_CACHE_34_16 33
#define EXECUTE_CACHE_34_14 35
#define EXECUTE_CACHE_34_12 37
#define FREE_REFERENCES_LABEL_34_0 26
#define NUMBER_OF_LINKER_SECTIONS_34_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
scomb_so_code_34 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd13;
  machine_word Wrd9;
  machine_word Wrd88;
  machine_word Wrd87;
  machine_word Wrd64;
  machine_word Wrd63;
  machine_word Wrd39;
  machine_word Wrd36;
  machine_word Wrd35;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd49;
  machine_word Wrd46;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd44;
  machine_word Wrd41;
  machine_word Wrd59;
  machine_word Wrd56;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd54;
  machine_word Wrd51;
  machine_word Wrd73;
  machine_word Wrd70;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd68;
  machine_word Wrd65;
  machine_word Wrd83;
  machine_word Wrd80;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd78;
  machine_word Wrd75;
  machine_word Wrd97;
  machine_word Wrd94;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd92;
  machine_word Wrd89;
  machine_word Wrd107;
  machine_word Wrd104;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd102;
  machine_word Wrd99;
  machine_word Wrd119;
  machine_word Wrd116;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd114;
  machine_word Wrd111;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_34_4);
      goto combination_operands_12;

    case 1:
      current_block = (Rpc - LABEL_34_5);
      goto label_20;

    case 2:
      current_block = (Rpc - LABEL_34_6);
      goto label_19;

    case 3:
      current_block = (Rpc - LABEL_34_7);
      goto label_18;

    case 4:
      current_block = (Rpc - LABEL_34_8);
      goto label_17;

    case 5:
      current_block = (Rpc - LABEL_34_9);
      goto label_16;

    case 6:
      current_block = (Rpc - LABEL_34_10);
      goto label_15;

    case 7:
      current_block = (Rpc - LABEL_34_11);
      goto label_14;

    case 8:
      current_block = (Rpc - LABEL_34_13);
      goto continuation_7;

    case 9:
      current_block = (Rpc - LABEL_34_15);
      goto continuation_9;

    case 10:
      current_block = (Rpc - LABEL_34_17);
      goto continuation_11;

    case 11:
      current_block = (Rpc - LABEL_34_20);
      goto continuation_8;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (combination_operands_22)
DEFLABEL (combination_operands_12)
  INTERRUPT_CHECK (26, LABEL_34_4);
  (Wrd111.Obj) = (current_block [OBJECT_34_0]);
  (Wrd114.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 48L) < ((unsigned long) (Wrd114.Lng))))
    goto label_40;
  (Wrd6.uLng) = (OBJECT_DATUM (Wrd111.Obj));
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd6.Obj) == (Wrd8.Obj)))
    goto label_24;

DEFLABEL (label_23)
  Rvl = (current_block [OBJECT_34_10]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_24)
  (Wrd99.Obj) = (current_block [OBJECT_34_2]);
  (Wrd102.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 7L) < ((unsigned long) (Wrd102.Lng))))
    goto label_39;
  (Wrd10.uLng) = (OBJECT_DATUM (Wrd99.Obj));
  (Wrd11.Obj) = (Rsp [0]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd10.Obj) == (Wrd12.Obj)))
    goto label_26;

DEFLABEL (label_25)
  (Wrd87.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_17]))));
  (* (--Rsp)) = (Wrd87.Obj);
  (Wrd88.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd88.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34_18]));

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_34_17);
  (Wrd10.Obj) = (current_block [OBJECT_34_10]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd10.Obj);
  (Wrd8.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_26)
  (Wrd89.Obj) = (current_block [OBJECT_34_3]);
  (Wrd92.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 27L) < ((unsigned long) (Wrd92.Lng))))
    goto label_38;
  (Wrd14.uLng) = (OBJECT_DATUM (Wrd89.Obj));
  (Wrd15.Obj) = (Rsp [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd14.Obj) == (Wrd16.Obj))
    goto label_25;

DEFLABEL (label_37)
  (Wrd75.Obj) = (current_block [OBJECT_34_4]);
  (Wrd78.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 12L) < ((unsigned long) (Wrd78.Lng))))
    goto label_36;
  (Wrd18.uLng) = (OBJECT_DATUM (Wrd75.Obj));
  (Wrd19.Obj) = (Rsp [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd18.Obj) == (Wrd20.Obj)))
    goto label_28;

DEFLABEL (label_27)
  (Wrd63.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_15]))));
  (* (--Rsp)) = (Wrd63.Obj);
  (Wrd64.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd64.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34_16]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_34_15);
  (Wrd9.Obj) = (current_block [OBJECT_34_10]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_20]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34_21]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_34_20);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  Rvl = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_28)
  (Wrd65.Obj) = (current_block [OBJECT_34_5]);
  (Wrd68.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd68.Lng))))
    goto label_35;
  (Wrd22.uLng) = (OBJECT_DATUM (Wrd65.Obj));
  (Wrd23.Obj) = (Rsp [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd22.Obj) == (Wrd24.Obj))
    goto label_27;

DEFLABEL (label_34)
  (Wrd51.Obj) = (current_block [OBJECT_34_6]);
  (Wrd54.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 38L) < ((unsigned long) (Wrd54.Lng))))
    goto label_33;
  (Wrd26.uLng) = (OBJECT_DATUM (Wrd51.Obj));
  (Wrd27.Obj) = (Rsp [0]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if (! ((Wrd26.Obj) == (Wrd28.Obj)))
    goto label_30;

DEFLABEL (label_29)
  (Wrd35.Obj) = (current_block [OBJECT_34_9]);
  (* (--Rsp)) = (Wrd35.Obj);
  (Wrd36.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd36.Obj);
  (Wrd39.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_13]))));
  (* (--Rsp)) = (Wrd39.Obj);
  (* (--Rsp)) = (Wrd36.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34_14]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_34_13);
  (Rsp [2]) = Rvl;
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34_19]));

DEFLABEL (label_30)
  (Wrd41.Obj) = (current_block [OBJECT_34_7]);
  (Wrd44.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 42L) < ((unsigned long) (Wrd44.Lng))))
    goto label_32;
  (Wrd30.uLng) = (OBJECT_DATUM (Wrd41.Obj));
  (Wrd31.Obj) = (Rsp [0]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if ((Wrd30.Obj) == (Wrd32.Obj))
    goto label_29;

DEFLABEL (label_31)
  (Wrd33.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd33.Obj);
  (Wrd34.Obj) = (current_block [OBJECT_34_8]);
  (Rsp [1]) = (Wrd34.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_34_12]));

DEFLABEL (label_32)
  (Wrd46.Obj) = (Rsp [0]);
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_11]))));
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd46.Obj);
  (* (--Rsp)) = (Wrd41.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_34_1]), 2);

DEFLABEL (label_14)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_31;
  goto label_29;

DEFLABEL (label_33)
  (Wrd56.Obj) = (Rsp [0]);
  (Wrd59.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_10]))));
  (* (--Rsp)) = (Wrd59.Obj);
  (* (--Rsp)) = (Wrd56.Obj);
  (* (--Rsp)) = (Wrd51.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_34_1]), 2);

DEFLABEL (label_15)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_30;
  goto label_29;

DEFLABEL (label_35)
  (Wrd70.Obj) = (Rsp [0]);
  (Wrd73.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_9]))));
  (* (--Rsp)) = (Wrd73.Obj);
  (* (--Rsp)) = (Wrd70.Obj);
  (* (--Rsp)) = (Wrd65.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_34_1]), 2);

DEFLABEL (label_16)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_34;
  goto label_27;

DEFLABEL (label_36)
  (Wrd80.Obj) = (Rsp [0]);
  (Wrd83.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_8]))));
  (* (--Rsp)) = (Wrd83.Obj);
  (* (--Rsp)) = (Wrd80.Obj);
  (* (--Rsp)) = (Wrd75.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_34_1]), 2);

DEFLABEL (label_17)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_28;
  goto label_27;

DEFLABEL (label_38)
  (Wrd94.Obj) = (Rsp [0]);
  (Wrd97.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_7]))));
  (* (--Rsp)) = (Wrd97.Obj);
  (* (--Rsp)) = (Wrd94.Obj);
  (* (--Rsp)) = (Wrd89.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_34_1]), 2);

DEFLABEL (label_18)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_37;
  goto label_25;

DEFLABEL (label_39)
  (Wrd104.Obj) = (Rsp [0]);
  (Wrd107.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_6]))));
  (* (--Rsp)) = (Wrd107.Obj);
  (* (--Rsp)) = (Wrd104.Obj);
  (* (--Rsp)) = (Wrd99.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_34_1]), 2);

DEFLABEL (label_19)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_26;
  goto label_25;

DEFLABEL (label_40)
  (Wrd116.Obj) = (Rsp [0]);
  (Wrd119.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34_5]))));
  (* (--Rsp)) = (Wrd119.Obj);
  (* (--Rsp)) = (Wrd116.Obj);
  (* (--Rsp)) = (Wrd111.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_34_1]), 2);

DEFLABEL (label_20)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_24;
  goto label_23;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_35_4 3
#define LABEL_35_5 5
#define LABEL_35_6 7
#define LABEL_35_7 9
#define LABEL_35_8 11
#define LABEL_35_9 13
#define LABEL_35_10 15
#define LABEL_35_11 17
#define LABEL_35_13 19
#define LABEL_35_14 21
#define LABEL_35_16 23
#define LABEL_35_18 25
#define LABEL_35_20 27
#define LABEL_35_21 29
#define LABEL_35_24 31
#define LABEL_35_26 33
#define LABEL_35_28 35
#define ENVIRONMENT_LABEL_35_3 70
#define DEBUGGING_LABEL_35_2 69
#define OBJECT_35_13 68
#define OBJECT_35_12 67
#define OBJECT_35_11 66
#define OBJECT_35_10 65
#define OBJECT_35_9 64
#define OBJECT_35_8 63
#define OBJECT_35_7 62
#define OBJECT_35_6 61
#define OBJECT_35_5 60
#define OBJECT_35_4 59
#define OBJECT_35_3 58
#define OBJECT_35_2 57
#define OBJECT_35_1 56
#define OBJECT_35_0 55
#define EXECUTE_CACHE_35_29 37
#define EXECUTE_CACHE_35_27 39
#define EXECUTE_CACHE_35_25 41
#define EXECUTE_CACHE_35_23 43
#define EXECUTE_CACHE_35_22 45
#define EXECUTE_CACHE_35_19 47
#define EXECUTE_CACHE_35_17 49
#define EXECUTE_CACHE_35_15 51
#define EXECUTE_CACHE_35_12 53
#define FREE_REFERENCES_LABEL_35_0 36
#define NUMBER_OF_LINKER_SECTIONS_35_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
scomb_so_code_35 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd13;
  machine_word Wrd5;
  machine_word Wrd9;
  machine_word Wrd117;
  machine_word Wrd116;
  machine_word Wrd115;
  machine_word Wrd112;
  machine_word Wrd91;
  machine_word Wrd90;
  machine_word Wrd87;
  machine_word Wrd66;
  machine_word Wrd65;
  machine_word Wrd62;
  machine_word Wrd41;
  machine_word Wrd40;
  machine_word Wrd37;
  machine_word Wrd34;
  machine_word Wrd33;
  machine_word Wrd50;
  machine_word Wrd47;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd45;
  machine_word Wrd42;
  machine_word Wrd60;
  machine_word Wrd57;
  machine_word Wrd28;
  machine_word Wrd27;
  machine_word Wrd26;
  machine_word Wrd55;
  machine_word Wrd52;
  machine_word Wrd75;
  machine_word Wrd72;
  machine_word Wrd24;
  machine_word Wrd23;
  machine_word Wrd22;
  machine_word Wrd70;
  machine_word Wrd67;
  machine_word Wrd85;
  machine_word Wrd82;
  machine_word Wrd20;
  machine_word Wrd19;
  machine_word Wrd18;
  machine_word Wrd80;
  machine_word Wrd77;
  machine_word Wrd100;
  machine_word Wrd97;
  machine_word Wrd16;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd95;
  machine_word Wrd92;
  machine_word Wrd110;
  machine_word Wrd107;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd105;
  machine_word Wrd102;
  machine_word Wrd126;
  machine_word Wrd123;
  machine_word Wrd8;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd121;
  machine_word Wrd118;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_35_4);
      goto combination_components_19;

    case 1:
      current_block = (Rpc - LABEL_35_5);
      goto label_27;

    case 2:
      current_block = (Rpc - LABEL_35_6);
      goto label_26;

    case 3:
      current_block = (Rpc - LABEL_35_7);
      goto label_25;

    case 4:
      current_block = (Rpc - LABEL_35_8);
      goto label_24;

    case 5:
      current_block = (Rpc - LABEL_35_9);
      goto label_23;

    case 6:
      current_block = (Rpc - LABEL_35_10);
      goto label_22;

    case 7:
      current_block = (Rpc - LABEL_35_11);
      goto label_21;

    case 8:
      current_block = (Rpc - LABEL_35_13);
      goto continuation_9;

    case 9:
      current_block = (Rpc - LABEL_35_14);
      goto continuation_8;

    case 10:
      current_block = (Rpc - LABEL_35_16);
      goto continuation_12;

    case 11:
      current_block = (Rpc - LABEL_35_18);
      goto continuation_16;

    case 12:
      current_block = (Rpc - LABEL_35_20);
      goto continuation_18;

    case 13:
      current_block = (Rpc - LABEL_35_21);
      goto continuation_7;

    case 14:
      current_block = (Rpc - LABEL_35_24);
      goto continuation_11;

    case 15:
      current_block = (Rpc - LABEL_35_26);
      goto continuation_15;

    case 16:
      current_block = (Rpc - LABEL_35_28);
      goto continuation_10;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (combination_components_29)
DEFLABEL (combination_components_19)
  INTERRUPT_CHECK (26, LABEL_35_4);
  (Wrd118.Obj) = (current_block [OBJECT_35_0]);
  (Wrd121.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 48L) < ((unsigned long) (Wrd121.Lng))))
    goto label_47;
  (Wrd6.uLng) = (OBJECT_DATUM (Wrd118.Obj));
  (Wrd7.Obj) = (Rsp [0]);
  (Wrd8.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd6.Obj) == (Wrd8.Obj)))
    goto label_31;

DEFLABEL (label_30)
  (Wrd112.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd112.Obj);
  (Wrd115.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_20]))));
  (* (--Rsp)) = (Wrd115.Obj);
  (Wrd116.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd116.Obj);
  (Wrd117.Obj) = (current_block [OBJECT_35_9]);
  (* (--Rsp)) = (Wrd117.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_35_10]), 2);

DEFLABEL (continuation_18)
  INTERRUPT_CHECK (27, LABEL_35_20);
  (Rsp [1]) = Rvl;
  (Wrd6.Obj) = (current_block [OBJECT_35_13]);
  (Rsp [2]) = (Wrd6.Obj);
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (label_31)
  (Wrd102.Obj) = (current_block [OBJECT_35_2]);
  (Wrd105.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 7L) < ((unsigned long) (Wrd105.Lng))))
    goto label_46;
  (Wrd10.uLng) = (OBJECT_DATUM (Wrd102.Obj));
  (Wrd11.Obj) = (Rsp [0]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if (! ((Wrd10.Obj) == (Wrd12.Obj)))
    goto label_33;

DEFLABEL (label_32)
  (Wrd87.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd87.Obj);
  (Wrd90.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_18]))));
  (* (--Rsp)) = (Wrd90.Obj);
  (Wrd91.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd91.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_19]));

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_35_18);
  (Wrd9.Obj) = (current_block [OBJECT_35_13]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd8.pObj) = (& (Rhp [-2]));
  (Wrd6.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd8.pObj)));
  (Rsp [2]) = (Wrd6.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_26]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_27]));

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_35_26);
  (Rsp [1]) = Rvl;
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (label_33)
  (Wrd92.Obj) = (current_block [OBJECT_35_3]);
  (Wrd95.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 27L) < ((unsigned long) (Wrd95.Lng))))
    goto label_45;
  (Wrd14.uLng) = (OBJECT_DATUM (Wrd92.Obj));
  (Wrd15.Obj) = (Rsp [0]);
  (Wrd16.uLng) = (OBJECT_TYPE (Wrd15.Obj));
  if ((Wrd14.Obj) == (Wrd16.Obj))
    goto label_32;

DEFLABEL (label_44)
  (Wrd77.Obj) = (current_block [OBJECT_35_4]);
  (Wrd80.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 12L) < ((unsigned long) (Wrd80.Lng))))
    goto label_43;
  (Wrd18.uLng) = (OBJECT_DATUM (Wrd77.Obj));
  (Wrd19.Obj) = (Rsp [0]);
  (Wrd20.uLng) = (OBJECT_TYPE (Wrd19.Obj));
  if (! ((Wrd18.Obj) == (Wrd20.Obj)))
    goto label_35;

DEFLABEL (label_34)
  (Wrd62.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd62.Obj);
  (Wrd65.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_16]))));
  (* (--Rsp)) = (Wrd65.Obj);
  (Wrd66.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd66.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_17]));

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_35_16);
  (Wrd9.Obj) = (current_block [OBJECT_35_13]);
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_24]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_25]));

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_35_24);
  (Wrd5.Obj) = (* (Rsp++));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd9.pObj) = (& (Rhp [-2]));
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd9.pObj)));
  (Rsp [2]) = (Wrd7.Obj);
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_28]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (Wrd13.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd13.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_29]));

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_35_28);
  (Rsp [1]) = Rvl;
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (label_35)
  (Wrd67.Obj) = (current_block [OBJECT_35_5]);
  (Wrd70.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 4L) < ((unsigned long) (Wrd70.Lng))))
    goto label_42;
  (Wrd22.uLng) = (OBJECT_DATUM (Wrd67.Obj));
  (Wrd23.Obj) = (Rsp [0]);
  (Wrd24.uLng) = (OBJECT_TYPE (Wrd23.Obj));
  if ((Wrd22.Obj) == (Wrd24.Obj))
    goto label_34;

DEFLABEL (label_41)
  (Wrd52.Obj) = (current_block [OBJECT_35_6]);
  (Wrd55.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 38L) < ((unsigned long) (Wrd55.Lng))))
    goto label_40;
  (Wrd26.uLng) = (OBJECT_DATUM (Wrd52.Obj));
  (Wrd27.Obj) = (Rsp [0]);
  (Wrd28.uLng) = (OBJECT_TYPE (Wrd27.Obj));
  if (! ((Wrd26.Obj) == (Wrd28.Obj)))
    goto label_37;

DEFLABEL (label_36)
  (Wrd34.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd34.Obj);
  (Wrd37.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_13]))));
  (* (--Rsp)) = (Wrd37.Obj);
  (Wrd40.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_14]))));
  (* (--Rsp)) = (Wrd40.Obj);
  (Wrd41.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd41.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_15]));

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_35_14);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_35_12]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [4]);
  (* (--Rsp)) = (Wrd6.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_23]));

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_35_13);
  (Rsp [2]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_21]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_35_11]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_22]));

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_35_21);
  (Rsp [1]) = Rvl;
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 3);
  }

DEFLABEL (label_37)
  (Wrd42.Obj) = (current_block [OBJECT_35_7]);
  (Wrd45.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 42L) < ((unsigned long) (Wrd45.Lng))))
    goto label_39;
  (Wrd30.uLng) = (OBJECT_DATUM (Wrd42.Obj));
  (Wrd31.Obj) = (Rsp [0]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if ((Wrd30.Obj) == (Wrd32.Obj))
    goto label_36;

DEFLABEL (label_38)
  (Wrd33.Obj) = (current_block [OBJECT_35_8]);
  (Rsp [1]) = (Wrd33.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_35_12]));

DEFLABEL (label_39)
  (Wrd47.Obj) = (Rsp [0]);
  (Wrd50.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_11]))));
  (* (--Rsp)) = (Wrd50.Obj);
  (* (--Rsp)) = (Wrd47.Obj);
  (* (--Rsp)) = (Wrd42.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_35_1]), 2);

DEFLABEL (label_21)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_38;
  goto label_36;

DEFLABEL (label_40)
  (Wrd57.Obj) = (Rsp [0]);
  (Wrd60.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_10]))));
  (* (--Rsp)) = (Wrd60.Obj);
  (* (--Rsp)) = (Wrd57.Obj);
  (* (--Rsp)) = (Wrd52.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_35_1]), 2);

DEFLABEL (label_22)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_37;
  goto label_36;

DEFLABEL (label_42)
  (Wrd72.Obj) = (Rsp [0]);
  (Wrd75.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_9]))));
  (* (--Rsp)) = (Wrd75.Obj);
  (* (--Rsp)) = (Wrd72.Obj);
  (* (--Rsp)) = (Wrd67.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_35_1]), 2);

DEFLABEL (label_23)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_41;
  goto label_34;

DEFLABEL (label_43)
  (Wrd82.Obj) = (Rsp [0]);
  (Wrd85.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_8]))));
  (* (--Rsp)) = (Wrd85.Obj);
  (* (--Rsp)) = (Wrd82.Obj);
  (* (--Rsp)) = (Wrd77.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_35_1]), 2);

DEFLABEL (label_24)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_35;
  goto label_34;

DEFLABEL (label_45)
  (Wrd97.Obj) = (Rsp [0]);
  (Wrd100.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_7]))));
  (* (--Rsp)) = (Wrd100.Obj);
  (* (--Rsp)) = (Wrd97.Obj);
  (* (--Rsp)) = (Wrd92.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_35_1]), 2);

DEFLABEL (label_25)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_44;
  goto label_32;

DEFLABEL (label_46)
  (Wrd107.Obj) = (Rsp [0]);
  (Wrd110.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_6]))));
  (* (--Rsp)) = (Wrd110.Obj);
  (* (--Rsp)) = (Wrd107.Obj);
  (* (--Rsp)) = (Wrd102.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_35_1]), 2);

DEFLABEL (label_26)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_33;
  goto label_32;

DEFLABEL (label_47)
  (Wrd123.Obj) = (Rsp [0]);
  (Wrd126.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35_5]))));
  (* (--Rsp)) = (Wrd126.Obj);
  (* (--Rsp)) = (Wrd123.Obj);
  (* (--Rsp)) = (Wrd118.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_35_1]), 2);

DEFLABEL (label_27)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_31;
  goto label_30;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_36_4 3
#define LABEL_36_5 5
#define ENVIRONMENT_LABEL_36_3 12
#define DEBUGGING_LABEL_36_2 11
#define EXECUTE_CACHE_36_6 7
#define FREE_REFERENCE_36_0 10
#define FREE_REFERENCES_LABEL_36_0 6
#define NUMBER_OF_LINKER_SECTIONS_36_1 2

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
scomb_so_code_36 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd7;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_36_4);
      goto combination_subexpressions_0;

    case 1:
      current_block = (Rpc - LABEL_36_5);
      goto label_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (combination_subexpressions_4)
DEFLABEL (combination_subexpressions_0)
  INTERRUPT_CHECK (26, LABEL_36_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.pObj) = ((SCHEME_OBJECT *) (current_block [FREE_REFERENCE_36_0]));
  (Wrd11.Obj) = ((Wrd8.pObj) [0]);
  (Wrd12.uLng) = (OBJECT_TYPE (Wrd11.Obj));
  if ((Wrd12.uLng) == 50)
    goto label_6;
  Wrd7 = Wrd11;

DEFLABEL (label_5)
  (Rsp [1]) = (Wrd7.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_36_6]));

DEFLABEL (label_6)
  INVOKE_INTERFACE_2 (31, (& (current_block [LABEL_36_5])), (Wrd8.pObj));

DEFLABEL (label_2)
  (Wrd7.Obj) = Rvl;
  goto label_5;

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_37_4 3
#define LABEL_37_5 5
#define ENVIRONMENT_LABEL_37_3 14
#define DEBUGGING_LABEL_37_2 13
#define OBJECT_37_1 12
#define OBJECT_37_0 11
#define EXECUTE_CACHE_37_7 7
#define EXECUTE_CACHE_37_6 9
#define FREE_REFERENCES_LABEL_37_0 6
#define NUMBER_OF_LINKER_SECTIONS_37_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
scomb_so_code_37 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd11;
  machine_word Wrd13;
  machine_word Wrd7;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_37_4);
      goto make_unassignedP_3;

    case 1:
      current_block = (Rpc - LABEL_37_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (make_unassignedP_6)
DEFLABEL (make_unassignedP_3)
  INTERRUPT_CHECK (26, LABEL_37_4);
  (Wrd5.Obj) = (current_block [OBJECT_37_0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37_5]))));
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_37_5);
  (Wrd8.Obj) = (Rsp [1]);
  (Wrd9.Obj) = (current_block [OBJECT_37_1]);
  (* (Rhp++)) = (Wrd8.Obj);
  (* (Rhp++)) = (Wrd9.Obj);
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd5.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (* (Rhp++)) = Rvl;
  (* (Rhp++)) = (Wrd5.Obj);
  (Wrd13.pObj) = (& (Rhp [-2]));
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd13.pObj)));
  (Rsp [1]) = (Wrd11.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_37_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_38_4 3
#define LABEL_38_5 5
#define LABEL_38_7 7
#define LABEL_38_9 9
#define LABEL_38_12 11
#define LABEL_38_11 13
#define LABEL_38_14 15
#define LABEL_38_15 17
#define LABEL_38_16 19
#define ENVIRONMENT_LABEL_38_3 37
#define DEBUGGING_LABEL_38_2 36
#define OBJECT_38_6 35
#define OBJECT_38_5 34
#define OBJECT_38_4 33
#define OBJECT_38_3 32
#define OBJECT_38_2 31
#define OBJECT_38_1 30
#define OBJECT_38_0 29
#define EXECUTE_CACHE_38_13 21
#define EXECUTE_CACHE_38_10 23
#define EXECUTE_CACHE_38_8 25
#define EXECUTE_CACHE_38_6 27
#define FREE_REFERENCES_LABEL_38_0 20
#define NUMBER_OF_LINKER_SECTIONS_38_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
scomb_so_code_38 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd32;
  machine_word Wrd31;
  machine_word Wrd30;
  machine_word Wrd38;
  machine_word Wrd27;
  machine_word Wrd49;
  machine_word Wrd26;
  machine_word Wrd24;
  machine_word Wrd44;
  machine_word Wrd41;
  machine_word Wrd22;
  machine_word Wrd16;
  machine_word Wrd18;
  machine_word Wrd15;
  machine_word Wrd17;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_38_4);
      goto unassignedPP_11;

    case 1:
      current_block = (Rpc - LABEL_38_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_38_7);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_38_9);
      goto continuation_3;

    case 4:
      current_block = (Rpc - LABEL_38_12);
      goto label_13;

    case 5:
      current_block = (Rpc - LABEL_38_11);
      goto continuation_5;

    case 6:
      current_block = (Rpc - LABEL_38_14);
      goto label_14;

    case 7:
      current_block = (Rpc - LABEL_38_15);
      goto label_15;

    case 8:
      current_block = (Rpc - LABEL_38_16);
      goto label_16;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unassignedPP_18)
DEFLABEL (unassignedPP_11)
  INTERRUPT_CHECK (26, LABEL_38_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_38_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_38_5);
  if (! (Rvl == ((SCHEME_OBJECT) 0)))
    goto label_19;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_19)
  (Wrd9.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_7]))));
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd10.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_38_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_38_7);
  if (Rvl == (current_block [OBJECT_38_0]))
    goto label_20;
  Rvl = ((SCHEME_OBJECT) 0);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_20)
  (Wrd11.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_9]))));
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd12.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_38_10]));

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_38_9);
  (Rsp [0]) = Rvl;
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_11]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd13.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd13.uLng) == 1))
    goto label_35;
  (Wrd10.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd11.Obj) = ((Wrd10.pObj) [0]);
  (* (--Rsp)) = (Wrd11.Obj);

DEFLABEL (label_34)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_38_13]));

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_38_11);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_33;
  (Wrd10.Obj) = (Rsp [0]);
  (Wrd11.uLng) = (OBJECT_TYPE (Wrd10.Obj));
  if (! ((Wrd11.uLng) == 1))
    goto label_32;
  (Wrd9.pObj) = (OBJECT_ADDRESS (Wrd10.Obj));
  (Wrd7.Obj) = ((Wrd9.pObj) [1]);

DEFLABEL (label_31)
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd7.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_30;
  (Wrd17.pObj) = (OBJECT_ADDRESS (Wrd7.Obj));
  (Wrd16.Obj) = ((Wrd17.pObj) [0]);

DEFLABEL (label_29)
  (Rsp [0]) = (Wrd16.Obj);
  (Wrd41.Obj) = (current_block [OBJECT_38_3]);
  (Wrd44.Lng) = (1 << TYPE_CODE_LENGTH);
  if (! (((unsigned long) 29L) < ((unsigned long) (Wrd44.Lng))))
    goto label_28;
  (Wrd24.uLng) = (OBJECT_DATUM (Wrd41.Obj));
  (Wrd26.uLng) = (OBJECT_TYPE (Wrd16.Obj));
  if ((Wrd24.Obj) == (Wrd26.Obj))
    goto label_26;

DEFLABEL (label_25)
  (Wrd27.Obj) = (current_block [OBJECT_38_5]);
  (* (--Rsp)) = (Wrd27.Obj);
  (Wrd38.Lng) = (1 << TYPE_CODE_LENGTH);
  if (((unsigned long) 5L) < ((unsigned long) (Wrd38.Lng)))
    goto label_21;
  INVOKE_PRIMITIVE ((current_block [OBJECT_38_4]), 2);

DEFLABEL (label_21)
  (Wrd30.uLng) = (OBJECT_DATUM (Wrd27.Obj));
  (Wrd31.Obj) = (Rsp [1]);
  (Wrd32.uLng) = (OBJECT_TYPE (Wrd31.Obj));
  if ((Wrd30.Obj) == (Wrd32.Obj))
    goto label_23;
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_22;

DEFLABEL (label_23)
  Rvl = (current_block [OBJECT_38_6]);

DEFLABEL (label_22)
DEFLABEL (label_24)
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_26)
  Rvl = (current_block [OBJECT_38_6]);

DEFLABEL (label_27)
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_28)
  (Wrd49.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_16]))));
  (* (--Rsp)) = (Wrd49.Obj);
  (* (--Rsp)) = (Wrd16.Obj);
  (* (--Rsp)) = (Wrd41.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_38_4]), 2);

DEFLABEL (label_16)
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_25;
  goto label_26;

DEFLABEL (label_30)
  (Wrd22.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_15]))));
  (* (--Rsp)) = (Wrd22.Obj);
  (* (--Rsp)) = (Wrd7.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_38_1]), 1);

DEFLABEL (label_15)
  (Wrd16.Obj) = Rvl;
  goto label_29;

DEFLABEL (label_32)
  (Wrd15.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_14]))));
  (* (--Rsp)) = (Wrd15.Obj);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_38_2]), 1);

DEFLABEL (label_14)
  (Wrd7.Obj) = Rvl;
  goto label_31;

DEFLABEL (label_33)
  Rvl = ((SCHEME_OBJECT) 0);
  goto label_27;

DEFLABEL (label_35)
  (Wrd17.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38_12]))));
  (* (--Rsp)) = (Wrd17.Obj);
  (* (--Rsp)) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_38_1]), 1);

DEFLABEL (label_13)
  (* (--Rsp)) = Rvl;
  goto label_34;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_39_4 3
#define LABEL_39_5 5
#define ENVIRONMENT_LABEL_39_3 13
#define DEBUGGING_LABEL_39_2 12
#define OBJECT_39_0 11
#define EXECUTE_CACHE_39_7 7
#define EXECUTE_CACHE_39_6 9
#define FREE_REFERENCES_LABEL_39_0 6
#define NUMBER_OF_LINKER_SECTIONS_39_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
scomb_so_code_39 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_39_4);
      goto guarantee_unassignedP_1;

    case 1:
      current_block = (Rpc - LABEL_39_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (guarantee_unassignedP_4)
DEFLABEL (guarantee_unassignedP_1)
  INTERRUPT_CHECK (26, LABEL_39_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_39_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_39_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_39_5);
  if (Rvl == ((SCHEME_OBJECT) 0))
    goto label_5;
  Rvl = (current_block [OBJECT_39_0]);
  Rsp = (& (Rsp [2]));
  goto pop_return;

DEFLABEL (label_5)
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_39_7]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_40_4 3
#define ENVIRONMENT_LABEL_40_3 11
#define DEBUGGING_LABEL_40_2 10
#define OBJECT_40_2 9
#define OBJECT_40_1 8
#define OBJECT_40_0 7
#define EXECUTE_CACHE_40_5 5
#define FREE_REFERENCES_LABEL_40_0 4
#define NUMBER_OF_LINKER_SECTIONS_40_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
scomb_so_code_40 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd9;
  machine_word Wrd7;
  machine_word Wrd6;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_40_4);
      goto error_not_unassignedP_2;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (error_not_unassignedP_5)
DEFLABEL (error_not_unassignedP_2)
  INTERRUPT_CHECK (26, LABEL_40_4);
  (Wrd5.Obj) = (Rsp [0]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (current_block [OBJECT_40_0]);
  (Rsp [1]) = (Wrd6.Obj);
  (Wrd7.Obj) = (Rsp [2]);
  if ((Wrd7.Obj) == (current_block [OBJECT_40_1]))
    goto label_7;
  Wrd9 = Wrd7;
  goto label_6;

DEFLABEL (label_7)
  (Wrd9.Obj) = (current_block [OBJECT_40_2]);

DEFLABEL (label_6)
DEFLABEL (label_8)
  (Rsp [2]) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_40_5]));

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_41_4 3
#define LABEL_41_5 5
#define LABEL_41_7 7
#define LABEL_41_9 9
#define ENVIRONMENT_LABEL_41_3 19
#define DEBUGGING_LABEL_41_2 18
#define OBJECT_41_2 17
#define OBJECT_41_1 16
#define OBJECT_41_0 15
#define EXECUTE_CACHE_41_8 11
#define EXECUTE_CACHE_41_6 13
#define FREE_REFERENCES_LABEL_41_0 10
#define NUMBER_OF_LINKER_SECTIONS_41_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
scomb_so_code_41 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd15;
  machine_word Wrd18;
  machine_word Wrd12;
  machine_word Wrd6;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_41_4);
      goto unassignedP_name_3;

    case 1:
      current_block = (Rpc - LABEL_41_5);
      goto continuation_0;

    case 2:
      current_block = (Rpc - LABEL_41_7);
      goto continuation_1;

    case 3:
      current_block = (Rpc - LABEL_41_9);
      goto label_5;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unassignedP_name_7)
DEFLABEL (unassignedP_name_3)
  INTERRUPT_CHECK (26, LABEL_41_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_41_0]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (Rsp [2]);
  (* (--Rsp)) = (Wrd9.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_41_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_41_8]));

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_41_7);
  (Wrd8.uLng) = (OBJECT_TYPE (Rvl));
  if (! ((Wrd8.uLng) == 1))
    goto label_10;
  (Wrd7.pObj) = (OBJECT_ADDRESS (Rvl));
  (Wrd6.Obj) = ((Wrd7.pObj) [1]);

DEFLABEL (label_9)
  (Rsp [0]) = (Wrd6.Obj);
  (Wrd18.uLng) = (OBJECT_TYPE (Wrd6.Obj));
  if (! ((Wrd18.uLng) == 1))
    goto label_8;
  (Wrd15.pObj) = (OBJECT_ADDRESS (Wrd6.Obj));
  Rvl = ((Wrd15.pObj) [0]);
  Rsp = (& (Rsp [1]));
  goto pop_return;

DEFLABEL (label_8)
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_2]), 1);

DEFLABEL (label_10)
  (Wrd12.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41_9]))));
  (* (--Rsp)) = (Wrd12.Obj);
  (* (--Rsp)) = Rvl;
  INVOKE_PRIMITIVE ((current_block [OBJECT_41_1]), 1);

DEFLABEL (label_5)
  (Wrd6.Obj) = Rvl;
  goto label_9;

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_42_4 3
#define LABEL_42_5 5
#define ENVIRONMENT_LABEL_42_3 10
#define DEBUGGING_LABEL_42_2 9
#define EXECUTE_CACHE_42_6 7
#define FREE_REFERENCES_LABEL_42_0 6
#define NUMBER_OF_LINKER_SECTIONS_42_1 1

#ifndef WANT_ONLY_DATA

static SCHEME_OBJECT *
scomb_so_code_42 (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd5;
  machine_word Wrd8;
  machine_word Wrd7;
  INVOKE_INTERFACE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_42_4);
      goto unassignedP_components_1;

    case 1:
      current_block = (Rpc - LABEL_42_5);
      goto continuation_0;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (unassignedP_components_4)
DEFLABEL (unassignedP_components_1)
  INTERRUPT_CHECK (26, LABEL_42_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd8.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [EXECUTE_CACHE_42_6]));

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_42_5);
  (Wrd5.Obj) = (Rsp [1]);
  (Rsp [0]) = (Wrd5.Obj);
  (Rsp [1]) = Rvl;
  {
    SCHEME_OBJECT procedure = (* (Rsp++));
    INVOKE_INTERFACE_2 (20, procedure, 2);
  }

INVOKE_INTERFACE_TARGET_1
}

#endif /* !WANT_ONLY_DATA */

#define LABEL_4 3
#define LABEL_5 5
#define LABEL_6 7
#define LABEL_7 9
#define LABEL_8 11
#define LABEL_9 13
#define LABEL_10 15
#define LABEL_11 17
#define LABEL_12 19
#define LABEL_13 21
#define LABEL_14 23
#define LABEL_15 25
#define LABEL_16 27
#define LABEL_17 29
#define LABEL_18 31
#define LABEL_19 33
#define LABEL_20 35
#define LABEL_21 37
#define LABEL_22 39
#define LABEL_23 41
#define LABEL_24 43
#define LABEL_25 45
#define LABEL_26 47
#define LABEL_27 49
#define LABEL_28 51
#define LABEL_29 53
#define LABEL_30 55
#define LABEL_31 57
#define LABEL_32 59
#define LABEL_33 61
#define LABEL_34 63
#define LABEL_35 65
#define LABEL_36 67
#define LABEL_37 69
#define LABEL_38 71
#define LABEL_40 73
#define LABEL_41 75
#define LABEL_42 77
#define LABEL_43 79
#define LABEL_44 81
#define LABEL_45 83
#define LABEL_46 85
#define LABEL_47 87
#define LABEL_48 89
#define LABEL_49 91
#define LABEL_50 93
#define LABEL_51 95
#define LABEL_52 97
#define ENVIRONMENT_LABEL_3 195
#define DEBUGGING_LABEL_2 194
#define PURIFICATION_ROOT 193
#define OBJECT_91 192
#define OBJECT_90 191
#define OBJECT_89 190
#define OBJECT_88 189
#define OBJECT_87 188
#define OBJECT_86 187
#define OBJECT_85 186
#define OBJECT_84 185
#define OBJECT_83 184
#define OBJECT_82 183
#define OBJECT_81 182
#define OBJECT_80 181
#define OBJECT_79 180
#define OBJECT_78 179
#define OBJECT_77 178
#define OBJECT_76 177
#define OBJECT_75 176
#define OBJECT_74 175
#define OBJECT_73 174
#define OBJECT_72 173
#define OBJECT_71 172
#define OBJECT_70 171
#define OBJECT_69 170
#define OBJECT_68 169
#define OBJECT_67 168
#define OBJECT_66 167
#define OBJECT_65 166
#define OBJECT_64 165
#define OBJECT_63 164
#define OBJECT_62 163
#define OBJECT_61 162
#define OBJECT_60 161
#define OBJECT_59 160
#define OBJECT_58 159
#define OBJECT_57 158
#define OBJECT_56 157
#define OBJECT_55 156
#define OBJECT_54 155
#define OBJECT_53 154
#define OBJECT_52 153
#define OBJECT_51 152
#define OBJECT_50 151
#define OBJECT_49 150
#define OBJECT_48 149
#define OBJECT_47 148
#define OBJECT_46 147
#define OBJECT_45 146
#define OBJECT_44 145
#define OBJECT_43 144
#define OBJECT_42 143
#define OBJECT_41 142
#define OBJECT_40 141
#define OBJECT_39 140
#define OBJECT_38 139
#define OBJECT_37 138
#define OBJECT_36 137
#define OBJECT_35 136
#define OBJECT_34 135
#define OBJECT_33 134
#define OBJECT_32 133
#define OBJECT_31 132
#define OBJECT_30 131
#define OBJECT_29 130
#define OBJECT_28 129
#define OBJECT_27 128
#define OBJECT_26 127
#define OBJECT_25 126
#define OBJECT_24 125
#define OBJECT_23 124
#define OBJECT_22 123
#define OBJECT_21 122
#define OBJECT_20 121
#define OBJECT_19 120
#define OBJECT_18 119
#define OBJECT_17 118
#define OBJECT_16 117
#define OBJECT_15 116
#define OBJECT_14 115
#define OBJECT_13 114
#define OBJECT_12 113
#define OBJECT_11 112
#define OBJECT_10 111
#define OBJECT_9 110
#define OBJECT_8 109
#define OBJECT_7 108
#define OBJECT_6 107
#define OBJECT_5 106
#define OBJECT_4 105
#define OBJECT_3 104
#define OBJECT_2 103
#define OBJECT_1 102
#define OBJECT_0 101
#define GLOBAL_EXECUTE_CACHE_39 99
#define FREE_REFERENCES_LABEL_0 98
#define NUMBER_OF_LINKER_SECTIONS_1 1

#ifndef WANT_ONLY_DATA

SCHEME_OBJECT *
scomb_so_15ad9a954a04abcb (SCHEME_OBJECT * Rpc, entry_count_t dispatch_base)
{
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES ();
  SCHEME_OBJECT * Rdl;
  machine_word Wrd6;
  machine_word Wrd15;
  machine_word Wrd14;
  machine_word Wrd13;
  machine_word Wrd12;
  machine_word Wrd11;
  machine_word Wrd7;
  machine_word Wrd10;
  machine_word Wrd9;
  machine_word Wrd8;
  machine_word Wrd5;
  INVOKE_INTERFACE_DECLS
  INVOKE_PRIMITIVE_DECLS

  Rdl = (OBJECT_ADDRESS (Rvl));
  goto perform_dispatch;

DEFLABEL (pop_return)
  Rpc = (OBJECT_ADDRESS (* (Rsp++)));

DEFLABEL (perform_dispatch)
  switch ((* ((unsigned long *) Rpc)) - dispatch_base)
    {
    case 0:
      current_block = (Rpc - LABEL_4);
      goto continuation_0;

    case 1:
      current_block = (Rpc - LABEL_5);
      goto continuation_1;

    case 2:
      current_block = (Rpc - LABEL_6);
      goto continuation_2;

    case 3:
      current_block = (Rpc - LABEL_7);
      goto continuation_3;

    case 4:
      current_block = (Rpc - LABEL_8);
      goto continuation_4;

    case 5:
      current_block = (Rpc - LABEL_9);
      goto continuation_5;

    case 6:
      current_block = (Rpc - LABEL_10);
      goto continuation_6;

    case 7:
      current_block = (Rpc - LABEL_11);
      goto continuation_7;

    case 8:
      current_block = (Rpc - LABEL_12);
      goto continuation_8;

    case 9:
      current_block = (Rpc - LABEL_13);
      goto continuation_9;

    case 10:
      current_block = (Rpc - LABEL_14);
      goto continuation_10;

    case 11:
      current_block = (Rpc - LABEL_15);
      goto continuation_11;

    case 12:
      current_block = (Rpc - LABEL_16);
      goto continuation_12;

    case 13:
      current_block = (Rpc - LABEL_17);
      goto continuation_13;

    case 14:
      current_block = (Rpc - LABEL_18);
      goto continuation_14;

    case 15:
      current_block = (Rpc - LABEL_19);
      goto continuation_15;

    case 16:
      current_block = (Rpc - LABEL_20);
      goto continuation_16;

    case 17:
      current_block = (Rpc - LABEL_21);
      goto continuation_17;

    case 18:
      current_block = (Rpc - LABEL_22);
      goto continuation_18;

    case 19:
      current_block = (Rpc - LABEL_23);
      goto continuation_19;

    case 20:
      current_block = (Rpc - LABEL_24);
      goto continuation_20;

    case 21:
      current_block = (Rpc - LABEL_25);
      goto continuation_21;

    case 22:
      current_block = (Rpc - LABEL_26);
      goto continuation_22;

    case 23:
      current_block = (Rpc - LABEL_27);
      goto continuation_23;

    case 24:
      current_block = (Rpc - LABEL_28);
      goto continuation_24;

    case 25:
      current_block = (Rpc - LABEL_29);
      goto continuation_25;

    case 26:
      current_block = (Rpc - LABEL_30);
      goto continuation_26;

    case 27:
      current_block = (Rpc - LABEL_31);
      goto continuation_27;

    case 28:
      current_block = (Rpc - LABEL_32);
      goto continuation_28;

    case 29:
      current_block = (Rpc - LABEL_33);
      goto continuation_29;

    case 30:
      current_block = (Rpc - LABEL_34);
      goto continuation_30;

    case 31:
      current_block = (Rpc - LABEL_35);
      goto continuation_31;

    case 32:
      current_block = (Rpc - LABEL_36);
      goto continuation_35;

    case 33:
      current_block = (Rpc - LABEL_37);
      goto continuation_34;

    case 34:
      current_block = (Rpc - LABEL_38);
      goto continuation_32;

    case 35:
      current_block = (Rpc - LABEL_40);
      goto continuation_36;

    case 36:
      current_block = (Rpc - LABEL_41);
      goto continuation_37;

    case 37:
      current_block = (Rpc - LABEL_42);
      goto continuation_38;

    case 38:
      current_block = (Rpc - LABEL_43);
      goto continuation_39;

    case 39:
      current_block = (Rpc - LABEL_44);
      goto continuation_40;

    case 40:
      current_block = (Rpc - LABEL_45);
      goto continuation_41;

    case 41:
      current_block = (Rpc - LABEL_46);
      goto continuation_42;

    case 42:
      current_block = (Rpc - LABEL_47);
      goto continuation_43;

    case 43:
      current_block = (Rpc - LABEL_48);
      goto continuation_44;

    case 44:
      current_block = (Rpc - LABEL_49);
      goto continuation_45;

    case 45:
      current_block = (Rpc - LABEL_50);
      goto label_50;

    case 46:
      current_block = (Rpc - LABEL_51);
      goto label_51;

    case 47:
      current_block = (Rpc - LABEL_52);
      goto expression_47;

    default:
      UNCACHE_VARIABLES ();
      return (Rpc);
    }

DEFLABEL (expression_47)
  (current_block [ENVIRONMENT_LABEL_3]) = (Rrb [REGBLOCK_ENV]);
  INVOKE_INTERFACE_4 (23, (& (current_block [LABEL_51])), current_block, (& (current_block [FREE_REFERENCES_LABEL_0])), NUMBER_OF_LINKER_SECTIONS_1);

DEFLABEL (label_51)
  (* (--Rsp)) = (ULONG_TO_FIXNUM (1UL));

DEFLABEL (label_50)
  {
    static const short sections [] =
      {
	0,
	1,
	1,
	1,
	1,
	1,
	1,
	2,
	1,
	1,
	1,
	1,
	1,
	1,
	2,
	1,
	1,
	0,
	2,
	1,
	1,
	1,
	1,
	1,
	0,
	1,
	2,
	1,
	1,
	1,
	1,
	1,
	1,
	0,
	1,
	1,
	1,
	1,
	1,
	1,
	0,
	1,
	3
      };
    unsigned long counter = (OBJECT_DATUM (* Rsp));
    SCHEME_OBJECT blocks;
    SCHEME_OBJECT * sub_block;
    short section;
    if (counter > 42)
      goto label_49;
    blocks = (current_block [OBJECT_91]);
    sub_block = (OBJECT_ADDRESS (MEMORY_REF (blocks, counter)));
    (sub_block [(OBJECT_DATUM (sub_block [0]))]) = (Rrb [REGBLOCK_ENV]);
    section = (sections [counter]);
    (* Rsp) = (ULONG_TO_FIXNUM (counter + 1));
    INVOKE_INTERFACE_4 (23, (& (current_block [LABEL_50])), sub_block, (sub_block + (2 + (OBJECT_DATUM (sub_block [1])))), section);
  }

DEFLABEL (label_49)
  Rsp += 1;
  (Wrd5.Obj) = (Rrb [3]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_4]))));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_0]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_1]);
  (* (--Rsp)) = (Wrd10.Obj);
  (* (--Rsp)) = (Wrd5.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_0)
  INTERRUPT_CHECK (27, LABEL_4);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_5]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_3]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_4]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_1)
  INTERRUPT_CHECK (27, LABEL_5);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_6]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_5]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_6]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_2)
  INTERRUPT_CHECK (27, LABEL_6);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_7]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_7]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_8]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_3)
  INTERRUPT_CHECK (27, LABEL_7);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_8]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_9]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_10]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_4)
  INTERRUPT_CHECK (27, LABEL_8);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_9]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_11]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_12]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_5)
  INTERRUPT_CHECK (27, LABEL_9);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_10]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_13]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_14]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_6)
  INTERRUPT_CHECK (27, LABEL_10);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_11]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_15]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_16]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_7)
  INTERRUPT_CHECK (27, LABEL_11);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_12]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_17]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_18]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_8)
  INTERRUPT_CHECK (27, LABEL_12);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_13]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_19]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_20]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_9)
  INTERRUPT_CHECK (27, LABEL_13);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_14]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_21]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_22]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_10)
  INTERRUPT_CHECK (27, LABEL_14);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_15]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_23]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_24]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_11)
  INTERRUPT_CHECK (27, LABEL_15);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_16]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_25]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_26]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_12)
  INTERRUPT_CHECK (27, LABEL_16);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_17]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_27]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_28]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_13)
  INTERRUPT_CHECK (27, LABEL_17);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_18]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_29]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_30]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_14)
  INTERRUPT_CHECK (27, LABEL_18);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_19]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_31]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_32]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_15)
  INTERRUPT_CHECK (27, LABEL_19);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_20]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_33]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_34]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_16)
  INTERRUPT_CHECK (27, LABEL_20);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_21]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_35]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_36]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_17)
  INTERRUPT_CHECK (27, LABEL_21);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_22]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_37]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_38]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_18)
  INTERRUPT_CHECK (27, LABEL_22);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_23]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_39]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_40]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_19)
  INTERRUPT_CHECK (27, LABEL_23);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_24]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_41]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_42]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_20)
  INTERRUPT_CHECK (27, LABEL_24);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_25]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_43]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_44]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_21)
  INTERRUPT_CHECK (27, LABEL_25);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_26]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_45]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_46]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_22)
  INTERRUPT_CHECK (27, LABEL_26);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_27]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_47]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_48]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_23)
  INTERRUPT_CHECK (27, LABEL_27);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_28]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_49]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_50]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_24)
  INTERRUPT_CHECK (27, LABEL_28);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_29]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_51]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_52]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_25)
  INTERRUPT_CHECK (27, LABEL_29);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_30]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_53]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_54]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_26)
  INTERRUPT_CHECK (27, LABEL_30);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_31]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_55]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_56]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_27)
  INTERRUPT_CHECK (27, LABEL_31);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_32]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_57]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_58]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_28)
  INTERRUPT_CHECK (27, LABEL_32);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_33]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_59]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_60]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_29)
  INTERRUPT_CHECK (27, LABEL_33);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_34]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_OBJECT (50, 0));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd11.Obj) = (current_block [OBJECT_61]);
  (* (--Rsp)) = (Wrd11.Obj);
  (Wrd12.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd12.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_30)
  INTERRUPT_CHECK (27, LABEL_34);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_35]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_62]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_63]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_31)
  INTERRUPT_CHECK (27, LABEL_35);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_36]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd10.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_37]))));
  (* (--Rsp)) = (Wrd10.Obj);
  (Wrd13.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_38]))));
  (* (--Rsp)) = (Wrd13.Obj);
  (Wrd14.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd14.Obj);
  (Wrd15.Obj) = (current_block [OBJECT_64]);
  (* (--Rsp)) = (Wrd15.Obj);
  JUMP ((SCHEME_OBJECT *) (current_block [GLOBAL_EXECUTE_CACHE_39]));

DEFLABEL (continuation_32)
  INTERRUPT_CHECK (27, LABEL_38);
  (Wrd9.Obj) = (current_block [OBJECT_68]);
  (* (Rhp++)) = (Wrd9.Obj);
  (* (Rhp++)) = Rvl;
  (Wrd7.pObj) = (& (Rhp [-2]));
  (Wrd8.Obj) = (MAKE_POINTER_OBJECT (1, (Wrd7.pObj)));
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd10.Obj) = (current_block [OBJECT_69]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_70]), 2);

DEFLABEL (continuation_34)
  INTERRUPT_CHECK (27, LABEL_37);
  (* (--Rsp)) = Rvl;
  (Wrd5.Obj) = (current_block [OBJECT_67]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd6.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_35)
  INTERRUPT_CHECK (27, LABEL_36);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_40]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_65]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_66]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_36)
  INTERRUPT_CHECK (27, LABEL_40);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_41]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_71]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_72]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_37)
  INTERRUPT_CHECK (27, LABEL_41);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_42]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_73]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_74]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_38)
  INTERRUPT_CHECK (27, LABEL_42);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_43]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_75]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_76]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_39)
  INTERRUPT_CHECK (27, LABEL_43);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_44]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_77]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_78]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_40)
  INTERRUPT_CHECK (27, LABEL_44);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_45]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_79]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_80]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_41)
  INTERRUPT_CHECK (27, LABEL_45);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_46]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_81]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_82]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_42)
  INTERRUPT_CHECK (27, LABEL_46);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_47]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_83]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_84]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_43)
  INTERRUPT_CHECK (27, LABEL_47);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_48]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_85]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_86]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_44)
  INTERRUPT_CHECK (27, LABEL_48);
  (Wrd7.Obj) = (MAKE_POINTER_OBJECT (40, (& (current_block [LABEL_49]))));
  (* (--Rsp)) = (Wrd7.Obj);
  (Wrd8.Obj) = (current_block [OBJECT_87]);
  (* (--Rsp)) = (Wrd8.Obj);
  (Wrd9.Obj) = (current_block [OBJECT_88]);
  (* (--Rsp)) = (Wrd9.Obj);
  (Wrd10.Obj) = (Rsp [3]);
  (* (--Rsp)) = (Wrd10.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

DEFLABEL (continuation_45)
  INTERRUPT_CHECK (27, LABEL_49);
  (Wrd5.Obj) = (current_block [OBJECT_89]);
  (* (--Rsp)) = (Wrd5.Obj);
  (Wrd6.Obj) = (Rsp [1]);
  (* (--Rsp)) = (Wrd6.Obj);
  (Wrd7.Obj) = (current_block [OBJECT_90]);
  (Rsp [2]) = (Wrd7.Obj);
  INVOKE_PRIMITIVE ((current_block [OBJECT_2]), 3);

INVOKE_INTERFACE_TARGET_1
INVOKE_PRIMITIVE_TARGET
}

static const struct liarc_code_S arr_decl_scomb_so_15ad9a954a04abcb [42] =
  {
    { "scomb_so_code_1", 5, scomb_so_code_1 },
    { "scomb_so_code_2", 7, scomb_so_code_2 },
    { "scomb_so_code_3", 2, scomb_so_code_3 },
    { "scomb_so_code_4", 2, scomb_so_code_4 },
    { "scomb_so_code_5", 1, scomb_so_code_5 },
    { "scomb_so_code_6", 13, scomb_so_code_6 },
    { "scomb_so_code_7", 8, scomb_so_code_7 },
    { "scomb_so_code_8", 2, scomb_so_code_8 },
    { "scomb_so_code_9", 5, scomb_so_code_9 },
    { "scomb_so_code_10", 1, scomb_so_code_10 },
    { "scomb_so_code_11", 2, scomb_so_code_11 },
    { "scomb_so_code_12", 1, scomb_so_code_12 },
    { "scomb_so_code_13", 2, scomb_so_code_13 },
    { "scomb_so_code_14", 2, scomb_so_code_14 },
    { "scomb_so_code_15", 2, scomb_so_code_15 },
    { "scomb_so_code_16", 4, scomb_so_code_16 },
    { "scomb_so_code_17", 2, scomb_so_code_17 },
    { "scomb_so_code_18", 5, scomb_so_code_18 },
    { "scomb_so_code_19", 1, scomb_so_code_19 },
    { "scomb_so_code_20", 2, scomb_so_code_20 },
    { "scomb_so_code_21", 1, scomb_so_code_21 },
    { "scomb_so_code_22", 2, scomb_so_code_22 },
    { "scomb_so_code_23", 2, scomb_so_code_23 },
    { "scomb_so_code_24", 3, scomb_so_code_24 },
    { "scomb_so_code_25", 2, scomb_so_code_25 },
    { "scomb_so_code_26", 7, scomb_so_code_26 },
    { "scomb_so_code_27", 2, scomb_so_code_27 },
    { "scomb_so_code_28", 1, scomb_so_code_28 },
    { "scomb_so_code_29", 10, scomb_so_code_29 },
    { "scomb_so_code_30", 23, scomb_so_code_30 },
    { "scomb_so_code_31", 12, scomb_so_code_31 },
    { "scomb_so_code_32", 8, scomb_so_code_32 },
    { "scomb_so_code_33", 8, scomb_so_code_33 },
    { "scomb_so_code_34", 12, scomb_so_code_34 },
    { "scomb_so_code_35", 17, scomb_so_code_35 },
    { "scomb_so_code_36", 2, scomb_so_code_36 },
    { "scomb_so_code_37", 2, scomb_so_code_37 },
    { "scomb_so_code_38", 9, scomb_so_code_38 },
    { "scomb_so_code_39", 2, scomb_so_code_39 },
    { "scomb_so_code_40", 1, scomb_so_code_40 },
    { "scomb_so_code_41", 4, scomb_so_code_41 },
    { "scomb_so_code_42", 2, scomb_so_code_42 }
  };

int
decl_scomb_so_15ad9a954a04abcb (void)
{
  DECLARE_SUBCODE_MULTIPLE (arr_decl_scomb_so_15ad9a954a04abcb);
  return (0);
}

DECLARE_COMPILED_CODE ("scomb.so", 48, decl_scomb_so_15ad9a954a04abcb, scomb_so_15ad9a954a04abcb)

#endif /* !WANT_ONLY_DATA */

#ifndef WANT_ONLY_CODE

static const unsigned char prog_scomb_so_data_15ad9a954a04abcb [6499] =
  "\xc4\x01\x4b\xa0\x0c\x1d\x0c\xb8\x0d\x1d\xb0\x81\x88\x07\x0d\x0d"
  "\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d"
  "\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d"
  "\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d"
  "\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d"
  "\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\x0d\xb9\x0d\x0d\x0d\x0d\x0d\x0d"
  "\x0d\x0d\x0d\x0d\x08\x14\x0d\xba\x25\xb2\x24\x28\x0d\x28\x0d\x23"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\xbb\x1d\xb0"
  "\x82\x88\x02\xc1\xbc\xc1\xbd\x0c\x08\x28\x0d\x28\x0d\xbe\x23\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b"
  "\xbf\x1d\xb0\x83\x88\x07\x02\xc2\x1c\x02\x22\x29\x22\x29\x21\x17"
  "\x2b\x1c\x1d\xb0\x84\x88\x1d\x28\x0d\x1c\x28\x0d\x1c\x23\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x85\x88\x06\x1d\x0c\x28\x0d\x1c"
  "\x23\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x86\x88\x08\x02\x1b\x02\x28"
  "\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c\x28\x0d"
  "\x1c\x28\x0d\x1c\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x08\x0d\x1c\x02\x1b\x02\x28"
  "\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x28\x1b\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\xb4\x02\xc1\x1c\x28\x0d\x1c\x28\x0d\x1c\x28\x0d\x1c"
  "\x28\x0d\x1c\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x07\x02\x22\x29\x21\x9f"
  "\x2b\x1c\x1d\xb0\x02\x88\x1d\x28\x0d\x1c\x28\x0d\x1c\x23\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x06\x1d\x0c\x28\x1b\x23"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0d\x1c\x28\x0d\x1c\x28"
  "\x1b\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0d\x1c"
  "\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x0d\x1c\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x28\x1b\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0d\x1c\x24\x28\x0d"
  "\x1c\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x07\xb4"
  "\x02\x1b\x28\x1b\x28\x1b\x28\xb6\x28\x1b\x28\x1b\x23\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b"
  "\x07\x02\x22\x29\x21\x9f\x2b\x1c\x1d\xb0\x02\x88\x1d\x28\x0d\x1c"
  "\x28\x0d\x1c\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x06\x1d\x0c\x28\x1b\x23\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x0d\x1c\x28\x0d\x1c\x28\x1b\x23\x22\x29\x22\x29\x21\x17\x2b\x1c"
  "\x1d\xb0\x02\x88\x0d\x1c\x28\x1b\x28\x1b\x23\x22\x29\x22\x29\x21"
  "\x17\x2b\x1c\x1d\xb0\x02\x88\x28\x1b\x28\x1b\x23\x22\x29\x22\x29"
  "\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x24\x28\x0d\x1c\x23"
  "\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x07\x02\x84\x02"
  "\x02\x02\x02\x1b\x02\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1d\x28\x1b\x28\x0d"
  "\x1c\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x06\x1d"
  "\x0c\x28\x1b\x23\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\xb4\xc2"
  "\x08\xb5\x0c\x0d\x1c\xb2\x24\x28\x0d\x28\x1b\x28\x0d\x28\x0d\x1c"
  "\x28\x0d\x28\x0d\x1c\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\xc2\x1c\x02\x02\x02\x81\xb4\x02\x84\x82\x02\xb5\x08\xc1"
  "\x02\x83\x28\x1b\x28\x0d\x28\x1b\x28\xb6\x23\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x0d\x0d\x1b\x0d\x0d\x1c\x0d\x08\x89\x1b\x0d\x08\x89\x1b\x0d"
  "\x08\x89\x1b\x0d\x08\x89\x0d\x1b\x0d\x08\x89\x1b\x0d\x08\x89\xb1"
  "\x1b\x0d\x08\x89\x08\x85\x86\x81\x82\x83\x84\x28\x0d\x28\x0d\x23"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88"
  "\x81\x82\x83\x0d\xbe\x02\x02\x84\x02\x02\x02\x1b\x02\x28\x1b\x28"
  "\x0d\xb9\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1b\x02\x80\x1b\x02"
  "\x02\x84\x02\x02\x02\x1b\x02\x28\x1b\x28\x0d\x1c\x28\x1b\x28\x1b"
  "\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x08\x81\x1b\x02\x02\x84\x02"
  "\x02\x02\x1b\x02\x28\x1b\x28\xb1\x28\x1b\x28\x1b\x28\x0d\x1c\x28"
  "\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0"
  "\x02\x88\x08\x81\x80\x1b\x02\x0d\x1c\x02\x02\x84\x02\x02\x02\x1b"
  "\x02\x28\x1b\x28\xb1\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28\x1b\x28"
  "\x1b\x28\x1b\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x0d\x24"
  "\x28\x1b\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x08"
  "\xc2\x1c\x28\x0d\x28\x1b\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d"
  "\xb0\x02\x88\x07\x85\x1b\x02\xb5\xb4\x1b\x28\x1b\x28\x1b\x28\x1b"
  "\x28\x0d\x23\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02\x88\x1d\x28\x0d"
  "\x1c\x28\x0d\x1c\x23\x22\x29\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\x06\x1d\x0c\x28\x1b\x23\x22\x29\x21\x17\x2b\x1c\x1d\xb0\x02"
  "\x88\xb4\xb5\x0d\x1c\x28\x0d\xbd\x28\x1b\x23\x22\x29\x22\x29\x22"
  "\x29\x22\x29\x21\x17\x2b\xbc\x1d\xb0\x02\x88\x28\x1b\x23\x22\x29"
  "\x22\x29\x21\x17\x2b\xb9\x17\xb8\x88\xb0\xb1\x2a\x0d\x1b\xb4\x2a"
  "\x1b\x1b\x2a\xb5\x1b\x2a\x1b\x1b\x2a\x0d\x1b\x2a\x0d\x1b\x2a\x1b"
  "\x1b\x2a\x1b\x1b\x2a\x1b\x1b\x2a\xc2\x02\x02\x0d\xb6\x1b\x2a\x1b"
  "\x2a\x1b\x1b\x2a\xb2\x1b\x1b\x2a\x1b\x1b\x2a\x0d\x1b\x2a\x1b\x1b"
  "\x2a\x0d\x1b\x2a\x1b\x1b\x2a\x1b\x1b\x2a\x1b\x1b\x2a\x1b\x1b\x2a"
  "\x1b\x1b\x2a\x1b\x1b\x2a\x0d\x1b\x2a\x0d\x1b\x2a\x1b\x1b\x2a\x1b"
  "\x1b\x2a\x1b\x1b\x2a\x1b\x1b\x2a\x0d\x1d\x1b\x1b\x2a\x1b\x1b\x2a"
  "\x1b\x1b\x2a\x1b\x1b\x2a\x0d\x1b\x2a\x1b\x1b\x2a\x1b\x1b\x2a\x1b"
  "\x1b\x2a\x0d\x1b\x2a\x1b\x1b\x2a\x0d\xb7\x2a\xc3\x0d\xb3\x2a\x28"
  "\x0d\x26\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29\x22\x29"
  "\x22\x29\x21\x17\x02\x52\x2f\x55\x73\x65\x72\x73\x2f\x63\x70\x68"
  "\x2f\x53\x6f\x66\x74\x77\x61\x72\x65\x2f\x73\x63\x68\x65\x6d\x65"
  "\x2f\x72\x65\x6c\x65\x61\x73\x65\x2d\x39\x2e\x31\x2e\x31\x2f\x6d"
  "\x69\x74\x2d\x73\x63\x68\x65\x6d\x65\x2d\x63\x2d\x39\x2e\x31\x2e"
  "\x31\x2f\x73\x72\x63\x2f\x72\x75\x6e\x74\x69\x6d\x65\x2f\x73\x63"
  "\x6f\x6d\x62\x2e\x69\x6e\x66\x15\x23\x5b\x70\x75\x72\x69\x66\x69"
  "\x63\x61\x74\x69\x6f\x6e\x2d\x72\x6f\x6f\x74\x5d\x02\x03\x26\x2a"
  "\x03\x26\x2b\x03\x26\x2d\x03\x26\x2f\x04\x2d\x31\x2b\x03\x31\x2b"
  "\x0c\x61\x73\x63\x69\x69\x2d\x3e\x63\x68\x61\x72\x06\x63\x65\x6c"
  "\x6c\x3f\x0c\x63\x68\x61\x72\x2d\x3e\x61\x73\x63\x69\x69\x0e\x63"
  "\x68\x61\x72\x2d\x3e\x69\x6e\x74\x65\x67\x65\x72\x0c\x63\x68\x61"
  "\x72\x2d\x61\x73\x63\x69\x69\x3f\x0a\x63\x68\x61\x72\x2d\x62\x69"
  "\x74\x73\x0a\x63\x68\x61\x72\x2d\x63\x6f\x64\x65\x0e\x63\x68\x61"
  "\x72\x2d\x64\x6f\x77\x6e\x63\x61\x73\x65\x0c\x63\x68\x61\x72\x2d"
  "\x75\x70\x63\x61\x73\x65\x1d\x63\x6f\x6d\x70\x69\x6c\x65\x64\x2d"
  "\x63\x6f\x64\x65\x2d\x61\x64\x64\x72\x65\x73\x73\x2d\x3e\x62\x6c"
  "\x6f\x63\x6b\x1e\x63\x6f\x6d\x70\x69\x6c\x65\x64\x2d\x63\x6f\x64"
  "\x65\x2d\x61\x64\x64\x72\x65\x73\x73\x2d\x3e\x6f\x66\x66\x73\x65"
  "\x74\x0e\x64\x69\x76\x69\x64\x65\x2d\x66\x69\x78\x6e\x75\x6d\x04"
  "\x65\x71\x3f\x0e\x65\x71\x75\x61\x6c\x2d\x66\x69\x78\x6e\x75\x6d"
  "\x3f\x0b\x66\x69\x78\x6e\x75\x6d\x2d\x61\x6e\x64\x0c\x66\x69\x78"
  "\x6e\x75\x6d\x2d\x61\x6e\x64\x63\x0b\x66\x69\x78\x6e\x75\x6d\x2d"
  "\x6c\x73\x68\x0b\x66\x69\x78\x6e\x75\x6d\x2d\x6e\x6f\x74\x0a\x66"
  "\x69\x78\x6e\x75\x6d\x2d\x6f\x72\x10\x66\x69\x78\x6e\x75\x6d\x2d"
  "\x71\x75\x6f\x74\x69\x65\x6e\x74\x11\x66\x69\x78\x6e\x75\x6d\x2d"
  "\x72\x65\x6d\x61\x69\x6e\x64\x65\x72\x0b\x66\x69\x78\x6e\x75\x6d"
  "\x2d\x78\x6f\x72\x0b\x66\x6c\x6f\x6e\x75\x6d\x2d\x61\x62\x73\x0c"
  "\x66\x6c\x6f\x6e\x75\x6d\x2d\x61\x63\x6f\x73\x0b\x66\x6c\x6f\x6e"
  "\x75\x6d\x2d\x61\x64\x64\x0c\x66\x6c\x6f\x6e\x75\x6d\x2d\x61\x73"
  "\x69\x6e\x0c\x66\x6c\x6f\x6e\x75\x6d\x2d\x61\x74\x61\x6e\x0d\x66"
  "\x6c\x6f\x6e\x75\x6d\x2d\x61\x74\x61\x6e\x32\x0f\x66\x6c\x6f\x6e"
  "\x75\x6d\x2d\x63\x65\x69\x6c\x69\x6e\x67\x16\x66\x6c\x6f\x6e\x75"
  "\x6d\x2d\x63\x65\x69\x6c\x69\x6e\x67\x2d\x3e\x65\x78\x61\x63\x74"
  "\x0b\x66\x6c\x6f\x6e\x75\x6d\x2d\x63\x6f\x73\x0e\x66\x6c\x6f\x6e"
  "\x75\x6d\x2d\x64\x69\x76\x69\x64\x65\x0e\x66\x6c\x6f\x6e\x75\x6d"
  "\x2d\x65\x71\x75\x61\x6c\x3f\x0b\x66\x6c\x6f\x6e\x75\x6d\x2d\x65"
  "\x78\x70\x0c\x66\x6c\x6f\x6e\x75\x6d\x2d\x65\x78\x70\x74\x0d\x66"
  "\x6c\x6f\x6e\x75\x6d\x2d\x66\x6c\x6f\x6f\x72\x14\x66\x6c\x6f\x6e"
  "\x75\x6d\x2d\x66\x6c\x6f\x6f\x72\x2d\x3e\x65\x78\x61\x63\x74\x10"
  "\x66\x6c\x6f\x6e\x75\x6d\x2d\x67\x72\x65\x61\x74\x65\x72\x3f\x0d"
  "\x66\x6c\x6f\x6e\x75\x6d\x2d\x6c\x65\x73\x73\x3f\x0b\x66\x6c\x6f"
  "\x6e\x75\x6d\x2d\x6c\x6f\x67\x10\x66\x6c\x6f\x6e\x75\x6d\x2d\x6d"
  "\x75\x6c\x74\x69\x70\x6c\x79\x0e\x66\x6c\x6f\x6e\x75\x6d\x2d\x6e"
  "\x65\x67\x61\x74\x65\x11\x66\x6c\x6f\x6e\x75\x6d\x2d\x6e\x65\x67"
  "\x61\x74\x69\x76\x65\x3f\x11\x66\x6c\x6f\x6e\x75\x6d\x2d\x70\x6f"
  "\x73\x69\x74\x69\x76\x65\x3f\x0d\x66\x6c\x6f\x6e\x75\x6d\x2d\x72"
  "\x6f\x75\x6e\x64\x14\x66\x6c\x6f\x6e\x75\x6d\x2d\x72\x6f\x75\x6e"
  "\x64\x2d\x3e\x65\x78\x61\x63\x74\x0b\x66\x6c\x6f\x6e\x75\x6d\x2d"
  "\x73\x69\x6e\x0c\x66\x6c\x6f\x6e\x75\x6d\x2d\x73\x71\x72\x74\x10"
  "\x66\x6c\x6f\x6e\x75\x6d\x2d\x73\x75\x62\x74\x72\x61\x63\x74\x0b"
  "\x66\x6c\x6f\x6e\x75\x6d\x2d\x74\x61\x6e\x10\x66\x6c\x6f\x6e\x75"
  "\x6d\x2d\x74\x72\x75\x6e\x63\x61\x74\x65\x17\x66\x6c\x6f\x6e\x75"
  "\x6d\x2d\x74\x72\x75\x6e\x63\x61\x74\x65\x2d\x3e\x65\x78\x61\x63"
  "\x74\x0d\x66\x6c\x6f\x6e\x75\x6d\x2d\x7a\x65\x72\x6f\x3f\x0b\x67"
  "\x63\x64\x2d\x66\x69\x78\x6e\x75\x6d\x15\x67\x72\x65\x61\x74\x65"
  "\x72\x2d\x74\x68\x61\x6e\x2d\x66\x69\x78\x6e\x75\x6d\x3f\x0e\x69"
  "\x6e\x64\x65\x78\x2d\x66\x69\x78\x6e\x75\x6d\x3f\x0e\x69\x6e\x74"
  "\x65\x67\x65\x72\x2d\x3e\x63\x68\x61\x72\x12\x6c\x65\x73\x73\x2d"
  "\x74\x68\x61\x6e\x2d\x66\x69\x78\x6e\x75\x6d\x3f\x0a\x6d\x61\x6b"
  "\x65\x2d\x63\x68\x61\x72\x18\x6d\x61\x6b\x65\x2d\x6e\x6f\x6e\x2d"
  "\x70\x6f\x69\x6e\x74\x65\x72\x2d\x6f\x62\x6a\x65\x63\x74\x0d\x6d"
  "\x69\x6e\x75\x73\x2d\x66\x69\x78\x6e\x75\x6d\x16\x6d\x69\x6e\x75"
  "\x73\x2d\x6f\x6e\x65\x2d\x70\x6c\x75\x73\x2d\x66\x69\x78\x6e\x75"
  "\x6d\x10\x6d\x75\x6c\x74\x69\x70\x6c\x79\x2d\x66\x69\x78\x6e\x75"
  "\x6d\x11\x6e\x65\x67\x61\x74\x69\x76\x65\x2d\x66\x69\x78\x6e\x75"
  "\x6d\x3f\x0a\x6e\x65\x67\x61\x74\x69\x76\x65\x3f\x04\x6e\x6f\x74"
  "\x06\x6e\x75\x6c\x6c\x3f\x0c\x6f\x62\x6a\x65\x63\x74\x2d\x74\x79"
  "\x70\x65\x0d\x6f\x62\x6a\x65\x63\x74\x2d\x74\x79\x70\x65\x3f\x10"
  "\x6f\x6e\x65\x2d\x70\x6c\x75\x73\x2d\x66\x69\x78\x6e\x75\x6d\x06"
  "\x70\x61\x69\x72\x3f\x0c\x70\x6c\x75\x73\x2d\x66\x69\x78\x6e\x75"
  "\x6d\x11\x70\x6f\x73\x69\x74\x69\x76\x65\x2d\x66\x69\x78\x6e\x75"
  "\x6d\x3f\x0a\x70\x6f\x73\x69\x74\x69\x76\x65\x3f\x1a\x70\x72\x69"
  "\x6d\x69\x74\x69\x76\x65\x2d\x70\x72\x6f\x63\x65\x64\x75\x72\x65"
  "\x2d\x61\x72\x69\x74\x79\x0f\x73\x74\x72\x69\x6e\x67\x2d\x3e\x73"
  "\x79\x6d\x62\x6f\x6c\x0e\x73\x74\x72\x69\x6e\x67\x2d\x6c\x65\x6e"
  "\x67\x74\x68\x0d\x7a\x65\x72\x6f\x2d\x66\x69\x78\x6e\x75\x6d\x3f"
  "\x06\x7a\x65\x72\x6f\x3f\x55\x27\x63\x6f\x6d\x62\x69\x6e\x61\x74"
  "\x69\x6f\x6e\x2f\x63\x6f\x6e\x73\x74\x61\x6e\x74\x2d\x66\x6f\x6c"
  "\x64\x69\x6e\x67\x2d\x6f\x70\x65\x72\x61\x74\x6f\x72\x73\x02\x02"
  "\x04\x04\x6d\x61\x70\x04\x19\x6d\x61\x6b\x65\x2d\x70\x72\x69\x6d"
  "\x69\x74\x69\x76\x65\x2d\x70\x72\x6f\x63\x65\x64\x75\x72\x65\x03"
  "\x35\x0c\x83\x04\x34\x0a\x81\x85\x02\x33\x08\x81\x83\x02\x32\x06"
  "\x81\x81\x02\x31\x04\x82\x02\x0b\x19\x02\x1a\x04\x63\x61\x72\x04"
  "\x63\x64\x72\x1a\x4d\x41\x4b\x45\x2d\x53\x45\x51\x55\x45\x4e\x43"
  "\x45\x3a\x20\x4e\x6f\x20\x61\x63\x74\x69\x6f\x6e\x73\x03\x06\x65"
  "\x72\x72\x6f\x72\x05\x11\x26\x74\x79\x70\x65\x64\x2d\x70\x61\x69"
  "\x72\x2d\x63\x6f\x6e\x73\x03\x3c\x10\x81\x87\x02\x3b\x0e\x81\x89"
  "\x02\x3a\x0c\x81\x83\x02\x39\x0a\x81\x83\x02\x38\x08\x81\x83\x02"
  "\x37\x06\x83\x04\x36\x04\x81\x83\x02\x0f\x1c\x02\x34\x0d\x6f\x62"
  "\x6a\x65\x63\x74\x2d\x74\x79\x70\x65\x3f\x09\x1a\x3e\x06\x81\x83"
  "\x02\x3d\x04\x83\x04\x05\x0c\x0a\x02\x02\x03\x0a\x73\x65\x71\x75"
  "\x65\x6e\x63\x65\x3f\x0b\x04\x13\x65\x72\x72\x6f\x72\x3a\x6e\x6f"
  "\x74\x2d\x73\x65\x71\x75\x65\x6e\x63\x65\x0c\x03\x40\x06\x81\x85"
  "\x02\x3f\x04\x84\x04\x05\x0e\x0d\x02\x08\x0f\x53\x43\x6f\x64\x65"
  "\x20\x73\x65\x71\x75\x65\x6e\x63\x65\x05\x1a\x65\x72\x72\x6f\x72"
  "\x3a\x77\x72\x6f\x6e\x67\x2d\x74\x79\x70\x65\x2d\x61\x72\x67\x75"
  "\x6d\x65\x6e\x74\x0e\x02\x41\x04\x84\x04\x03\x0c\x0f\x02\x34\x09"
  "\x1a\x03\x0f\x26\x74\x72\x69\x70\x6c\x65\x2d\x73\x65\x63\x6f\x6e"
  "\x64\x10\x03\x0a\x26\x70\x61\x69\x72\x2d\x63\x61\x72\x11\x03\x0e"
  "\x26\x74\x72\x69\x70\x6c\x65\x2d\x66\x69\x72\x73\x74\x12\x03\x11"
  "\x73\x65\x71\x75\x65\x6e\x63\x65\x2d\x61\x63\x74\x69\x6f\x6e\x73"
  "\x13\x03\x0a\x26\x70\x61\x69\x72\x2d\x63\x64\x72\x14\x03\x0e\x26"
  "\x74\x72\x69\x70\x6c\x65\x2d\x74\x68\x69\x72\x64\x15\x04\x08\x61"
  "\x70\x70\x65\x6e\x64\x21\x16\x05\x16\x09\x4e\x1c\x81\x89\x02\x4d"
  "\x1a\x81\x87\x02\x4c\x18\x81\x87\x02\x4b\x16\x81\x85\x02\x4a\x14"
  "\x81\x87\x02\x49\x12\x81\x85\x02\x48\x10\x81\x85\x02\x47\x0e\x81"
  "\x83\x02\x46\x0c\x81\x85\x02\x45\x0a\x81\x83\x02\x44\x08\x81\x83"
  "\x02\x43\x06\x81\x83\x02\x42\x04\x83\x04\x1b\x33\x16\x02\x08\x1b"
  "\x73\x65\x71\x75\x65\x6e\x63\x65\x2d\x69\x6d\x6d\x65\x64\x69\x61"
  "\x74\x65\x2d\x61\x63\x74\x69\x6f\x6e\x73\x17\x34\x09\x1a\x04\x0c"
  "\x03\x15\x03\x14\x03\x10\x03\x11\x03\x12\x07\x56\x12\x81\x85\x02"
  "\x55\x10\x81\x85\x02\x54\x0e\x81\x85\x02\x53\x0c\x81\x83\x02\x52"
  "\x0a\x81\x83\x02\x51\x08\x81\x83\x02\x50\x06\x81\x83\x02\x4f\x04"
  "\x83\x04\x11\x26\x18\x02\x09\x03\x13\x02\x58\x06\x81\x85\x02\x57"
  "\x04\x84\x06\x05\x0b\x19\x02\x0a\x35\x04\x6e\x6f\x74\x1a\x03\x0d"
  "\x63\x6f\x6d\x62\x69\x6e\x61\x74\x69\x6f\x6e\x3f\x1b\x03\x15\x63"
  "\x6f\x6d\x62\x69\x6e\x61\x74\x69\x6f\x6e\x2d\x6f\x70\x65\x72\x61"
  "\x6e\x64\x73\x1c\x06\x13\x26\x74\x79\x70\x65\x64\x2d\x74\x72\x69"
  "\x70\x6c\x65\x2d\x63\x6f\x6e\x73\x1d\x03\x15\x63\x6f\x6d\x62\x69"
  "\x6e\x61\x74\x69\x6f\x6e\x2d\x6f\x70\x65\x72\x61\x74\x6f\x72\x1e"
  "\x05\x11\x6d\x61\x6b\x65\x2d\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e"
  "\x61\x6c\x1f\x06\x5d\x0c\x81\x87\x02\x5c\x0a\x81\x87\x02\x5b\x08"
  "\x81\x87\x02\x5a\x06\x81\x87\x02\x59\x04\x85\x08\x0b\x1c\x20\x02"
  "\x0b\x09\x35\x5e\x04\x83\x04\x03\x21\x02\x0c\x02\x03\x0d\x63\x6f"
  "\x6e\x64\x69\x74\x69\x6f\x6e\x61\x6c\x3f\x22\x04\x16\x65\x72\x72"
  "\x6f\x72\x3a\x6e\x6f\x74\x2d\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e"
  "\x61\x6c\x23\x03\x60\x06\x81\x85\x02\x5f\x04\x84\x04\x05\x0e\x24"
  "\x02\x0d\x08\x12\x53\x43\x6f\x64\x65\x20\x63\x6f\x6e\x64\x69\x74"
  "\x69\x6f\x6e\x61\x6c\x05\x0e\x02\x61\x04\x84\x04\x03\x0c\x25\x02"
  "\x0e\x16\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x61\x6c\x2d\x70\x72"
  "\x65\x64\x69\x63\x61\x74\x65\x26\x04\x16\x67\x75\x61\x72\x61\x6e"
  "\x74\x65\x65\x2d\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x61\x6c\x27"
  "\x03\x12\x03\x63\x06\x81\x83\x02\x62\x04\x83\x04\x05\x0e\x28\x02"
  "\x0f\x17\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x61\x6c\x2d\x63\x6f"
  "\x6e\x73\x65\x71\x75\x65\x6e\x74\x29\x04\x27\x03\x10\x03\x65\x06"
  "\x81\x83\x02\x64\x04\x83\x04\x05\x0e\x2a\x02\x10\x18\x63\x6f\x6e"
  "\x64\x69\x74\x69\x6f\x6e\x61\x6c\x2d\x61\x6c\x74\x65\x72\x6e\x61"
  "\x74\x69\x76\x65\x2b\x04\x27\x03\x15\x03\x67\x06\x81\x83\x02\x66"
  "\x04\x83\x04\x05\x0e\x2c\x02\x11\x03\x26\x03\x2b\x03\x29\x04\x6b"
  "\x0a\x81\x89\x02\x6a\x08\x81\x89\x02\x69\x06\x81\x85\x02\x68\x04"
  "\x84\x06\x09\x13\x2d\x02\x12\x05\x6c\x69\x73\x74\x2e\x02\x04\x17"
  "\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x61\x6c\x2d\x63\x6f\x6d\x70"
  "\x6f\x6e\x65\x6e\x74\x73\x2f\x02\x6d\x06\x81\x85\x02\x6c\x04\x83"
  "\x04\x05\x0d\x30\x02\x13\x36\x1a\x03\x1b\x03\x1c\x05\x03\x1e\x05"
  "\x1f\x06\x72\x0c\x81\x85\x02\x71\x0a\x81\x85\x02\x70\x08\x81\x85"
  "\x02\x6f\x06\x81\x85\x02\x6e\x04\x84\x06\x0b\x1d\x1a\x02\x14\x09"
  "\x36\x73\x04\x83\x04\x03\x31\x02\x15\x02\x03\x0d\x64\x69\x73\x6a"
  "\x75\x6e\x63\x74\x69\x6f\x6e\x3f\x32\x04\x16\x65\x72\x72\x6f\x72"
  "\x3a\x6e\x6f\x74\x2d\x64\x69\x73\x6a\x75\x6e\x63\x74\x69\x6f\x6e"
  "\x33\x03\x75\x06\x81\x85\x02\x74\x04\x84\x04\x05\x0e\x34\x02\x16"
  "\x08\x12\x53\x43\x6f\x64\x65\x20\x64\x69\x73\x6a\x75\x6e\x63\x74"
  "\x69\x6f\x6e\x05\x0e\x02\x76\x04\x84\x04\x03\x0c\x35\x02\x17\x16"
  "\x64\x69\x73\x6a\x75\x6e\x63\x74\x69\x6f\x6e\x2d\x70\x72\x65\x64"
  "\x69\x63\x61\x74\x65\x36\x04\x16\x67\x75\x61\x72\x61\x6e\x74\x65"
  "\x65\x2d\x64\x69\x73\x6a\x75\x6e\x63\x74\x69\x6f\x6e\x37\x03\x11"
  "\x03\x78\x06\x81\x83\x02\x77\x04\x83\x04\x05\x0e\x38\x02\x18\x18"
  "\x64\x69\x73\x6a\x75\x6e\x63\x74\x69\x6f\x6e\x2d\x61\x6c\x74\x65"
  "\x72\x6e\x61\x74\x69\x76\x65\x39\x04\x37\x03\x14\x03\x7a\x06\x81"
  "\x83\x02\x79\x04\x83\x04\x05\x0e\x3a\x02\x19\x03\x39\x03\x36\x03"
  "\x7d\x08\x81\x87\x02\x7c\x06\x81\x87\x02\x7b\x04\x84\x06\x07\x0f"
  "\x3b\x02\x1a\x2e\x02\x04\x17\x64\x69\x73\x6a\x75\x6e\x63\x74\x69"
  "\x6f\x6e\x2d\x63\x6f\x6d\x70\x6f\x6e\x65\x6e\x74\x73\x2e\x02\x7f"
  "\x06\x81\x85\x02\x7e\x04\x83\x04\x05\x0d\x3c\x02\x1b\x2b\x1c\x31"
  "\x0d\x08\x09\x27\x86\x01\x10\x81\x83\x02\x85\x01\x0e\x81\x83\x02"
  "\x84\x01\x0c\x81\x83\x02\x83\x01\x0a\x81\x83\x02\x82\x01\x08\x81"
  "\x83\x02\x81\x01\x06\x81\x83\x02\x80\x01\x04\x83\x04\x0f\x1b\x3d"
  "\x02\x1c\x02\x03\x1b\x04\x16\x65\x72\x72\x6f\x72\x3a\x6e\x6f\x74"
  "\x2d\x63\x6f\x6d\x62\x69\x6e\x61\x74\x69\x6f\x6e\x3e\x03\x88\x01"
  "\x06\x81\x85\x02\x87\x01\x04\x84\x04\x05\x0e\x3f\x02\x1d\x08\x12"
  "\x53\x43\x6f\x64\x65\x20\x63\x6f\x6d\x62\x69\x6e\x61\x74\x69\x6f"
  "\x6e\x05\x0e\x02\x89\x01\x04\x84\x04\x03\x0c\x40\x02\x1e\x06\x61"
  "\x70\x70\x6c\x79\x14\x6f\x70\x65\x72\x61\x74\x6f\x72\x20\x65\x78"
  "\x70\x72\x65\x73\x73\x69\x6f\x6e\x11\x6d\x61\x6b\x65\x2d\x63\x6f"
  "\x6d\x62\x69\x6e\x61\x74\x69\x6f\x6e\x41\x02\x03\x0b\x70\x72\x6f"
  "\x63\x65\x64\x75\x72\x65\x3f\x05\x0e\x04\x05\x6d\x65\x6d\x71\x03"
  "\x15\x70\x72\x69\x6d\x69\x74\x69\x76\x65\x2d\x70\x72\x6f\x63\x65"
  "\x64\x75\x72\x65\x3f\x42\x03\x10\x73\x63\x6f\x64\x65\x2d\x63\x6f"
  "\x6e\x73\x74\x61\x6e\x74\x3f\x04\x12\x25\x6d\x61\x6b\x65\x2d\x63"
  "\x6f\x6d\x62\x69\x6e\x61\x74\x69\x6f\x6e\x43\x07\x93\x01\x16\x81"
  "\x85\x02\x92\x01\x14\x81\x89\x02\x91\x01\x12\x81\x87\x02\x90\x01"
  "\x10\x81\x87\x02\x8f\x01\x0e\x81\x87\x02\x8e\x01\x0c\x81\x87\x02"
  "\x8d\x01\x0a\x81\x85\x02\x8c\x01\x08\x81\x85\x02\x8b\x01\x06\x81"
  "\x85\x02\x8a\x01\x04\x84\x06\x15\x2d\x44\x02\x1f\x10\x6f\x62\x6a"
  "\x65\x63\x74\x2d\x73\x65\x74\x2d\x74\x79\x70\x65\x45\x31\x08\x1c"
  "\x0d\x27\x1a\x70\x72\x69\x6d\x69\x74\x69\x76\x65\x2d\x70\x72\x6f"
  "\x63\x65\x64\x75\x72\x65\x2d\x61\x72\x69\x74\x79\x2b\x03\x42\x04"
  "\x13\x26\x74\x79\x70\x65\x64\x2d\x76\x65\x63\x74\x6f\x72\x2d\x63"
  "\x6f\x6e\x73\x06\x1d\x05\x05\xaa\x01\x30\x81\x85\x02\xa9\x01\x2e"
  "\x81\x85\x02\xa8\x01\x2c\x81\x85\x02\xa7\x01\x2a\x81\x87\x02\xa6"
  "\x01\x28\x81\x85\x02\xa5\x01\x26\x81\x85\x02\xa4\x01\x24\x81\x85"
  "\x02\xa3\x01\x22\x81\x89\x02\xa2\x01\x20\x81\x89\x02\xa1\x01\x1e"
  "\x81\x89\x02\xa0\x01\x1c\x81\x87\x02\x9f\x01\x1a\x81\x87\x02\x9e"
  "\x01\x18\x81\x87\x02\x9d\x01\x16\x81\x87\x02\x9c\x01\x14\x81\x87"
  "\x02\x9b\x01\x12\x81\x87\x02\x9a\x01\x10\x81\x85\x02\x99\x01\x0e"
  "\x81\x85\x02\x98\x01\x0c\x81\x85\x02\x97\x01\x0a\x84\x06\x96\x01"
  "\x08\x81\x87\x02\x95\x01\x06\x81\x87\x02\x94\x01\x04\x81\x87\x02"
  "\x2f\x4a\x42\x02\x20\x05\x63\x6f\x6e\x64\x05\x65\x6c\x73\x65\x3e"
  "\x06\x71\x75\x6f\x74\x65\x0b\x75\x63\x6f\x64\x65\x2d\x74\x79\x70"
  "\x65\x1d\x18\x70\x72\x69\x6d\x69\x74\x69\x76\x65\x2d\x63\x6f\x6d"
  "\x62\x69\x6e\x61\x74\x69\x6f\x6e\x2d\x33\x1d\x0c\x63\x6f\x6d\x62"
  "\x69\x6e\x61\x74\x69\x6f\x6e\x1d\x18\x70\x72\x69\x6d\x69\x74\x69"
  "\x76\x65\x2d\x63\x6f\x6d\x62\x69\x6e\x61\x74\x69\x6f\x6e\x2d\x32"
  "\x1d\x0e\x63\x6f\x6d\x62\x69\x6e\x61\x74\x69\x6f\x6e\x2d\x32\x03"
  "\x6f\x72\x1d\x18\x70\x72\x69\x6d\x69\x74\x69\x76\x65\x2d\x63\x6f"
  "\x6d\x62\x69\x6e\x61\x74\x69\x6f\x6e\x2d\x31\x1d\x0e\x63\x6f\x6d"
  "\x62\x69\x6e\x61\x74\x69\x6f\x6e\x2d\x31\x1d\x18\x70\x72\x69\x6d"
  "\x69\x74\x69\x76\x65\x2d\x63\x6f\x6d\x62\x69\x6e\x61\x74\x69\x6f"
  "\x6e\x2d\x30\x04\x09\x6c\x69\x73\x74\x2d\x72\x65\x66\x04\x0d\x63"
  "\x6c\x6f\x73\x65\x2d\x73\x79\x6e\x74\x61\x78\x03\xb6\x01\x1a\x81"
  "\x93\x02\xb5\x01\x18\x81\x8f\x02\xb4\x01\x16\x81\x91\x02\xb3\x01"
  "\x14\x81\x8d\x02\xb2\x01\x12\x81\x8b\x02\xb1\x01\x10\x81\x8d\x02"
  "\xb0\x01\x0e\x81\x89\x02\xaf\x01\x0c\x81\x8b\x02\xae\x01\x0a\x81"
  "\x87\x02\xad\x01\x08\x81\x89\x02\xac\x01\x06\x81\x85\x02\xab\x01"
  "\x04\x84\x06\x19\x35\x1d\x02\x21\x11\x63\x6f\x6d\x62\x69\x6e\x61"
  "\x74\x69\x6f\x6e\x2d\x73\x69\x7a\x65\x2b\x27\x0d\x1c\x08\x09\x31"
  "\x04\x3e\x03\x0f\x26\x76\x65\x63\x74\x6f\x72\x2d\x6c\x65\x6e\x67"
  "\x74\x68\x03\xbe\x01\x12\x81\x83\x02\xbd\x01\x10\x81\x83\x02\xbc"
  "\x01\x0e\x81\x83\x02\xbb\x01\x0c\x81\x83\x02\xba\x01\x0a\x81\x83"
  "\x02\xb9\x01\x08\x81\x83\x02\xb8\x01\x06\x81\x83\x02\xb7\x01\x04"
  "\x83\x04\x11\x25\x46\x02\x22\x45\x19\x1e\x2b\x27\x0d\x1c\x08\x09"
  "\x31\x04\x3e\x04\x0c\x26\x76\x65\x63\x74\x6f\x72\x2d\x72\x65\x66"
  "\x47\x03\x12\x03\x11\x05\xc6\x01\x12\x81\x83\x02\xc5\x01\x10\x81"
  "\x83\x02\xc4\x01\x0e\x81\x83\x02\xc3\x01\x0c\x81\x83\x02\xc2\x01"
  "\x0a\x81\x83\x02\xc1\x01\x08\x81\x83\x02\xc0\x01\x06\x81\x83\x02"
  "\xbf\x01\x04\x83\x04\x11\x29\x48\x02\x23\x1c\x2b\x27\x0d\x1c\x08"
  "\x09\x31\x04\x3e\x03\x03\x15\x03\x14\x05\x11\x26\x73\x75\x62\x76"
  "\x65\x63\x74\x6f\x72\x2d\x3e\x6c\x69\x73\x74\x49\x03\x10\x07\xd2"
  "\x01\x1a\x81\x85\x02\xd1\x01\x18\x81\x83\x02\xd0\x01\x16\x81\x83"
  "\x02\xcf\x01\x14\x81\x87\x02\xce\x01\x12\x81\x83\x02\xcd\x01\x10"
  "\x81\x83\x02\xcc\x01\x0e\x81\x83\x02\xcb\x01\x0c\x81\x83\x02\xca"
  "\x01\x0a\x81\x83\x02\xc9\x01\x08\x81\x83\x02\xc8\x01\x06\x81\x83"
  "\x02\xc7\x01\x04\x83\x04\x19\x34\x4a\x02\x24\x45\x19\x17\x63\x6f"
  "\x6d\x62\x69\x6e\x61\x74\x69\x6f\x6e\x2d\x63\x6f\x6d\x70\x6f\x6e"
  "\x65\x6e\x74\x73\x45\x2b\x27\x0d\x1c\x08\x09\x31\x04\x3e\x03\x03"
  "\x15\x03\x14\x04\x47\x05\x49\x03\x10\x03\x11\x03\x12\x0a\xe3\x01"
  "\x24\x81\x87\x02\xe2\x01\x22\x81\x87\x02\xe1\x01\x20\x81\x89\x02"
  "\xe0\x01\x1e\x81\x87\x02\xdf\x01\x1c\x81\x87\x02\xde\x01\x1a\x81"
  "\x87\x02\xdd\x01\x18\x81\x87\x02\xdc\x01\x16\x81\x89\x02\xdb\x01"
  "\x14\x81\x87\x02\xda\x01\x12\x81\x85\x02\xd9\x01\x10\x81\x85\x02"
  "\xd8\x01\x0e\x81\x85\x02\xd7\x01\x0c\x81\x85\x02\xd6\x01\x0a\x81"
  "\x85\x02\xd5\x01\x08\x81\x85\x02\xd4\x01\x06\x81\x85\x02\xd3\x01"
  "\x04\x84\x06\x23\x47\x49\x02\x25\x05\x63\x6f\x6e\x73\x02\x04\x45"
  "\x02\xe5\x01\x06\x81\x85\x02\xe4\x01\x04\x83\x04\x05\x0d\x47\x02"
  "\x26\x14\x6c\x65\x78\x69\x63\x61\x6c\x2d\x75\x6e\x61\x73\x73\x69"
  "\x67\x6e\x65\x64\x3f\x15\x02\x15\x6d\x61\x6b\x65\x2d\x74\x68\x65"
  "\x2d\x65\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x04\x41\x03\xe7"
  "\x01\x06\x81\x85\x02\xe6\x01\x04\x83\x04\x05\x0f\x14\x02\x27\x09"
  "\x1e\x15\x03\x1b\x03\x1e\x03\x1c\x03\x11\x74\x68\x65\x2d\x65\x6e"
  "\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x3f\x05\xf0\x01\x14\x81\x83"
  "\x02\xef\x01\x12\x81\x83\x02\xee\x01\x10\x81\x83\x02\xed\x01\x0e"
  "\x81\x83\x02\xec\x01\x0c\x81\x85\x02\xeb\x01\x0a\x81\x83\x02\xea"
  "\x01\x08\x81\x83\x02\xe9\x01\x06\x81\x83\x02\xe8\x01\x04\x83\x04"
  "\x13\x26\x15\x02\x28\x02\x03\x0d\x75\x6e\x61\x73\x73\x69\x67\x6e"
  "\x65\x64\x3f\x3f\x12\x04\x16\x65\x72\x72\x6f\x72\x3a\x6e\x6f\x74"
  "\x2d\x75\x6e\x61\x73\x73\x69\x67\x6e\x65\x64\x3f\x11\x03\xf2\x01"
  "\x06\x81\x85\x02\xf1\x01\x04\x84\x04\x05\x0e\x10\x02\x29\x08\x16"
  "\x53\x43\x6f\x64\x65\x20\x75\x6e\x61\x73\x73\x69\x67\x6e\x65\x64"
  "\x20\x74\x65\x73\x74\x05\x0e\x02\xf3\x01\x04\x84\x04\x03\x0c\x0e"
  "\x02\x2a\x11\x75\x6e\x61\x73\x73\x69\x67\x6e\x65\x64\x3f\x2d\x6e"
  "\x61\x6d\x65\x09\x04\x16\x67\x75\x61\x72\x61\x6e\x74\x65\x65\x2d"
  "\x75\x6e\x61\x73\x73\x69\x67\x6e\x65\x64\x3f\x03\x1c\x03\xf7\x01"
  "\x0a\x81\x83\x02\xf6\x01\x08\x81\x83\x02\xf5\x01\x06\x81\x83\x02"
  "\xf4\x01\x04\x83\x04\x09\x14\x02\x2b\x03\x09\x02\xf9\x01\x06\x81"
  "\x85\x02\xf8\x01\x04\x84\x06\x05\x0b\x2b\x04\x17\x75\x6e\x61\x73"
  "\x73\x69\x67\x6e\x65\x64\x3f\x2d\x63\x6f\x6d\x70\x6f\x6e\x65\x6e"
  "\x74\x73\x09\x04\x11\x0e\x04\x10\x04\x12\x15\x04\x11\x6d\x61\x6b"
  "\x65\x2d\x75\x6e\x61\x73\x73\x69\x67\x6e\x65\x64\x3f\x14\x04\x1b"
  "\x63\x6f\x6d\x62\x69\x6e\x61\x74\x69\x6f\x6e\x2d\x73\x75\x62\x65"
  "\x78\x70\x72\x65\x73\x73\x69\x6f\x6e\x73\x47\x04\x45\x49\x04\x1c"
  "\x4a\x04\x1e\x48\x04\x1a\x70\x72\x69\x6d\x69\x74\x69\x76\x65\x2d"
  "\x6f\x62\x6a\x65\x63\x74\x2d\x73\x65\x74\x2d\x74\x79\x70\x65\x33"
  "\x10\x15\x63\x6f\x6d\x62\x69\x6e\x61\x74\x69\x6f\x6e\x2d\x64\x69"
  "\x73\x70\x61\x74\x63\x68\x46\x04\x1d\x04\x43\x42\x0a\x41\x44\x04"
  "\x3e\x40\x04\x16\x67\x75\x61\x72\x61\x6e\x74\x65\x65\x2d\x63\x6f"
  "\x6d\x62\x69\x6e\x61\x74\x69\x6f\x6e\x3f\x04\x1b\x3d\x04\x1b\x64"
  "\x69\x73\x6a\x75\x6e\x63\x74\x69\x6f\x6e\x2d\x73\x75\x62\x65\x78"
  "\x70\x72\x65\x73\x73\x69\x6f\x6e\x73\x3c\x04\x2e\x3b\x04\x39\x3a"
  "\x04\x36\x38\x04\x33\x35\x04\x37\x34\x04\x32\x31\x04\x11\x6d\x61"
  "\x6b\x65\x2d\x64\x69\x73\x6a\x75\x6e\x63\x74\x69\x6f\x6e\x1a\x04"
  "\x1b\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x61\x6c\x2d\x73\x75\x62"
  "\x65\x78\x70\x72\x65\x73\x73\x69\x6f\x6e\x73\x30\x04\x2f\x2d\x04"
  "\x2b\x2c\x04\x29\x2a\x04\x26\x28\x04\x1d\x75\x6e\x64\x65\x66\x69"
  "\x6e\x65\x64\x2d\x63\x6f\x6e\x64\x69\x74\x69\x6f\x6e\x61\x6c\x2d"
  "\x62\x72\x61\x6e\x63\x68\x02\x23\x25\x04\x27\x24\x04\x22\x21\x04"
  "\x1f\x20\x04\x14\x73\x65\x71\x75\x65\x6e\x63\x65\x2d\x63\x6f\x6d"
  "\x70\x6f\x6e\x65\x6e\x74\x73\x19\x04\x17\x18\x04\x13\x16\x04\x0c"
  "\x0f\x04\x13\x67\x75\x61\x72\x61\x6e\x74\x65\x65\x2d\x73\x65\x71"
  "\x75\x65\x6e\x63\x65\x0d\x04\x0b\x0a\x04\x0e\x6d\x61\x6b\x65\x2d"
  "\x73\x65\x71\x75\x65\x6e\x63\x65\x06\x11\x6c\x6f\x63\x61\x6c\x2d"
  "\x61\x73\x73\x69\x67\x6e\x6d\x65\x6e\x74\x14\x69\x6e\x69\x74\x69"
  "\x61\x6c\x69\x7a\x65\x2d\x70\x61\x63\x6b\x61\x67\x65\x21\x04\x04"
  "\x1f\x73\x63\x2d\x6d\x61\x63\x72\x6f\x2d\x74\x72\x61\x6e\x73\x66"
  "\x6f\x72\x6d\x65\x72\x2d\x3e\x65\x78\x70\x61\x6e\x64\x65\x72\x02"
  "\x30\x62\x80\x80\x04\x2f\x60\x81\x81\x02\x2e\x5e\x81\x81\x02\x2d"
  "\x5c\x81\x83\x02\x2c\x5a\x81\x83\x02\x2b\x58\x81\x83\x02\x2a\x56"
  "\x81\x83\x02\x29\x54\x81\x83\x02\x28\x52\x81\x83\x02\x27\x50\x81"
  "\x83\x02\x26\x4e\x81\x83\x02\x25\x4c\x81\x83\x02\x24\x4a\x81\x83"
  "\x02\x23\x48\x81\x87\x02\x22\x46\x81\x85\x02\x21\x44\x81\x83\x02"
  "\x20\x42\x81\x83\x02\x1f\x40\x81\x83\x02\x1e\x3e\x81\x83\x02\x1d"
  "\x3c\x81\x83\x02\x1c\x3a\x81\x83\x02\x1b\x38\x81\x83\x02\x1a\x36"
  "\x81\x83\x02\x19\x34\x81\x83\x02\x18\x32\x81\x83\x02\x17\x30\x81"
  "\x83\x02\x16\x2e\x81\x83\x02\x15\x2c\x81\x83\x02\x14\x2a\x81\x83"
  "\x02\x13\x28\x81\x83\x02\x12\x26\x81\x83\x02\x11\x24\x81\x83\x02"
  "\x10\x22\x81\x83\x02\x0f\x20\x81\x83\x02\x0e\x1e\x81\x83\x02\x0d"
  "\x1c\x81\x83\x02\x0c\x1a\x81\x83\x02\x0b\x18\x81\x83\x02\x0a\x16"
  "\x81\x83\x02\x09\x14\x81\x83\x02\x08\x12\x81\x83\x02\x07\x10\x81"
  "\x83\x02\x06\x0e\x81\x83\x02\x05\x0c\x81\x83\x02\x04\x0a\x81\x83"
  "\x02\x03\x08\x81\x83\x02\x02\x06\x81\x83\x02\x01\x04\x81\x83\x02"
  "\x61\xc4\x01";

SCHEME_OBJECT *
scomb_so_data_15ad9a954a04abcb (entry_count_t dispatch_base)
{
  SCHEME_OBJECT ccb;
  SCHEME_OBJECT * current_block;
  DECLARE_VARIABLES_FOR_DATA ();

  ccb = (unstackify (((unsigned char *) (& (prog_scomb_so_data_15ad9a954a04abcb [0]))), (sizeof (prog_scomb_so_data_15ad9a954a04abcb)), dispatch_base));
  current_block = (OBJECT_ADDRESS (ccb));
  return (& (current_block [LABEL_52]));
}

DECLARE_COMPILED_DATA_NS ("scomb.so", scomb_so_data_15ad9a954a04abcb)

#endif /* !WANT_ONLY_CODE */

DECLARE_DYNAMIC_INITIALIZATION ("scomb.so", "c458b814e8ca1e34")
